 *====================== PROGRAM: CONTROL_PQ09.SAS ======================;
 * --------------------------------------------------------------------- ;
 * ---                   VERSION 5.0.3 - FEBRUARY, 2016                   --- ;
 * --------------------------------------------------------------------- ;
 * The PATIENT QUALITY INDICATOR PQI-09 STAND ALONE module of the AHRQ 
   Quality Indicators software includes the following three programs, 
   in addition to the programs CONTROL_PQ09.SAS and PQ09_PDFMTS.SAS:
        Program 1.   PQ09_PDSAS1:  Assigns HCUP PATIENT QUALITY 
                       Indicator PQI-09 to inpatient records.
        Program A2.  PQ09_PDSASA2:  Calculates observed area rates for
                     PATIENT QUALITY Indicator PQI-09.
        Program A3.  PQ09_PDSASA3:  Calculates risk-adjusted area rates 
                     for PATIENT QUALITY Indicator PQI-09.

 NOTE THAT THIS INDICATOR (PQI-09) IS ALSO INCLUDED WITH PDI MODULE. 

**************************************************************************** ;
****************************PLEASE READ************************************* ;
**************************************************************************** ;
 * The USER MUST modify portions of the following code in order to
   run this software.  With one exception (see NOTE immediately
   following this paragraph), the only changes necessary to run
   this software using your data are changes you make in this
   program (CONTROL_PQ09.SAS).  The modifications you make include such
   items as specifying the name and location of your input data
   set, the year of population data to be used, and the name and
   location of output data sets.
 
 * NOTE:  CONTROL_PQ09.SAS is written so that you have the option to 
          read in data from and write out data to different 
          locations.  For example, "LIBNAME IN0" points to the 
          location or pathname of your input data set for program
          PQ09_PDSAS1 and "LIBNAME OUT1" points to the location of the 
          output data set created by the PQ09_PDSAS1 program.  These 
          locations can be different.  This pattern of allowing 
          you to specify the location of each input and output 
          data set is true for each of the different programs 
          referenced in CONTROL_PQ09.SAS.  However, if you wish to read 
          in and write out all data to the same location you can.   
          The easiest way to do this is to make a global 
          change in CONTROL_PQ09.SAS, changing "C:\PATHNAME" to the 
          location you wish to use.

 * NOTE:  In each of the six programs included with this
          package, as well as in the program which generates
          formats, there is a line of code that begins with
          "FILENAME CONTROL".  The USER MUST include after
          "FILENAME CONTROL" the location of the CONTROL_PQ09.SAS 
           file.

 * Generally speaking, a first-time user of this software would
   proceed as follows:
        1.  Modify CONTROL_PQ09.SAS.  (MUST be done.)
        2.  In the program generating needed formats, i.e., in
            PQ09_PDFMTS.SAS, specify location (path name) of
            CONTROL_PQ09.SAS. (MUST be done.)
        3.  Run PQ09_PDFMTS.SAS.  (MUST be done.)
        4.  In Program 1, i.e., in PQ09_PDSAS1, specify location
            of CONTROL_PQ09.SAS program.  (MUST be done.)
        5.  Run PQ09_PDSAS1.  (MUST be done.)
        6.  If you want to generate area-level PATIENT Quality
            Indicator PQI-09:
               a.  In Program A2, i.e., in PQ09_PDSASA2, specify 
                   location of CONTROL_PQ09.SAS program.  (MUST be done 
                   if going to run Program A2.)
               b.  Run PQ09_PDSASA2.  (MUST have already run Program 1.)
        7.  If you want to generate risk-adjusted area-level Pediatric 
            Quality Indicators:
               a.  In Program A3, i.e., in PQ09_PDSASA3, specify location
                   of CONTROL_PQ09.SAS program.  (MUST be done if going to
                   run Program A3.)
               b.  Run PQ09_PDSASA3. (MUST have already run Program 1 
                   and A2.)
 * --------------------------------------------------------------------- ;
 * ---                       All Programs                            --- ;
 * --------------------------------------------------------------------- ;
TITLE 'TITLE';                                       *<===USER may modify;
LIBNAME LIBRARY  "C:\PATHNAME";                      *<==USER MUST modify;

 * --------------------------------------------------------------------- ;
 * --- INDICATE IF COUNTY-LEVEL AREAS SHOULD BE CONVERTED TO MAs      -- ;
 * ---     0 - County level with U.S. Census FIPS                     -- ;
 * ---     1 - County level with Modified FIPS                        -- ;
 * ---     2 - Metro Area level with OMB 1999 definition              -- ;
 * ---     3 - Metro Area level with OMB 2003 definition              -- ;
 * --------------------------------------------------------------------- ;
%LET MALEVL = 0;                                     *<===USER may modify;

 * --------------------------------------------------------------------- ;
 * NOTE:  In program A2, the user should select                          ;
 *          the population data for the year that best                   ;
 *          matches the discharge data.  Data are available for          ;
 *          1995 to 2014.                                                ;
 * --------------------------------------------------------------------- ;
%LET POPYEAR = 2013;                                *<===USER must modify;

 * --------------------------------------------------------------------- ;
 * --- SET NAME OF POPULATION FILE ------------------------------------- ;
 * --------------------------------------------------------------------- ;
FILENAME POPFILE  'C:\PATHNAME\pop95t14.txt';       *<===USER must modify;

 * --------------------------------------------------------------------- ;
 * --- INDICATE IF RECORDS SHOULD BE PRINTED AT END OF EACH PGM      --- ;
 * --------------------------------------------------------------------- ;
%LET PRINT = 0;                                      *<===USER may modify;

 * --------------------------------------------------------------------- ;
 * --- COMMENT OUT TO CREATE AN UCOMPRESSED FILE                     --- ;
 * --------------------------------------------------------------------- ;
OPTIONS COMPRESS=YES;


 * --------------------------------------------------------------------- ;
 * ---                         Program 1                             --- ;
 * --------------------------------------------------------------------- ;
LIBNAME IN0  "C:\PATHNAME";                          *<==USER MUST modify;
LIBNAME OUT1 "C:\PATHNAME";                          *<==USER MUST modify;

 * --------------------------------------------------------------------- ;
 * --- MODIFY INPUT AND OUTPUT FILE                                  --- ;
 * --------------------------------------------------------------------- ;
 * --- PROGRAM DEFAULT ASSUMES THERE ARE                             --- ;
 * ---     30 DIAGNOSES (DX1-DX30)                                   --- ;
 * ---     30 PROCEDURES (PR1-PR30)                                  --- ;
 * --------------------------------------------------------------------- ;
 * --- MODIFY NUMBER OF DIAGNOSES, PROCEDURES AND RELATED            --- ;
 * --- VARIABLES TO MATCH INPUT DATA                                 --- ;
 * --------------------------------------------------------------------- ;
%LET INFILE0  = SIDs_yyyy;                               *<==USER MUST modify;
%LET OUTFILE1 = PQ09_PDI1;                           *<===USER may modify;
%LET NDX = 35;                                       *<===USER may modify;
%LET NPR = 30;                                       *<===USER may modify;
%LET USEPOA = 1;                                     *<===USER may modify;

 * --------------------------------------------------------------------- ;
 * - SET PRDAY TO 1 IF DATA AVAILABLE REGARDING NUMBER OF DAYS       --- ;
 * - FROM ADMISSION TO SECONDARY PROCEDURES                          --- ;
 * --------------------------------------------------------------------- ;
%LET PRDAY = 1;                                      *<===USER may modify;

 * --------------------------------------------------------------------- ;
 * - CREATE PERMANENT SAS DATASET TO STORE RECORDS THAT WILL         --- ;
 * - NOT BE INCLUDED IN CALCULATIONS BECAUSE KEY VARIABLE            --- ;
 * - VALUES ARE MISSING.  THIS DATASET SHOULD BE REVIEWED AFTER      --- ;
 * - RUNNING PQ09_PDSAS1.											     --- ;
 * --------------------------------------------------------------------- ;
%LET DELFILE1  = PQ09_DELETED;                       *<===USER may modify;

 * ======================================================================;
 * ============AREA-LEVEL PEDIATRIC quality INDICATORS===================;
 * ======================================================================;
 * ---                   Program A2-Observed Rates                   --- ;
 * --------------------------------------------------------------------- ;
LIBNAME IN1 "C:\PATHNAME";                           *<==USER MUST modify;
LIBNAME OUTA2 "C:\PATHNAME";                         *<==USER MUST modify;

 * --------------------------------------------------------------------- ;
 * --- TYPELVLA indicates the levels (or _TYPES_) of                 --- ;
 * --- summarization to be kept in the output.                       --- ;
 * ---                                                               --- ;
 * ---  TYPELVLA      stratification                                 --- ;
 * ---  --------  -------------------------                          --- ;
 * ---     0      overall                                            --- ;
 * ---     1                           race                          --- ;
 * ---     2                     sex                                 --- ;
 * ---     3                     sex * race                          --- ;
 * ---     4               age                                       --- ;
 * ---     5               age *       race                          --- ;
 * ---     6               age * sex                                 --- ;
 * ---     7               age * sex * race                          --- ;
 * ---     8       area                                              --- ;
 * ---     9       area  *             race                          --- ;
 * ---    10       area  *       sex                                 --- ;
 * ---    11       area  *       sex * race                          --- ;
 * ---    12       area  * age                                       --- ;
 * ---    13       area  * age *       race                          --- ;
 * ---    14       area  * age * sex                                 --- ;
 * ---    15       area  * age * sex * race                          --- ;
 * ---                                                               --- ;
 * --- The default TYPELVLA (0,8) will provide an overall            --- ;
 * --- and area-level totals                                         --- ;
 * ---                                                               --- ;
 * --------------------------------------------------------------------- ;
%LET TYPELVLA = IN (0,8);                            *<===USER may modify;

 * --------------------------------------------------------------------- ;
 * --- SET NAME OF MICRODATA INPUT (OUTPUT FROM PROGRAM 1) AND       --- ;
 * --- SUMMARY OUTPUT FILE OF OBSERVED AREA RATES.                   --- ;
 * --------------------------------------------------------------------- ;
%LET INFILE1  = PQ09_PDI1;                           *<===USER may modify;
%LET OUTFILA2 = PQ09_PDA2;                           *<===USER may modify;

 * --------------------------------------------------------------------- ;
 * --- INDICATE IF WANT TO CREATE A COMMA-DELIMITED FILE FOR         --- ;
 * --- EXPORT INTO A SPREADSHEET.                                    --- ;
 * --------------------------------------------------------------------- ;
%LET TEXTA2 = 0;                                     *<===USER may modify;

 * --------------------------------------------------------------------- ;
 * --- IF YOU CREATE A COMMA-DELIMITED FILE, SPECIFY THE LOCATION      - ;
 * --- OF THE FILE.                                                  --- ;
 * --------------------------------------------------------------------- ;
FILENAME PDTEXTA2 "C:\PATHNAME\PQ09_PDTEXTA2.TXT";  *<===USER MUST modify;

 * --------------------------------------------------------------------- ;
 * ---       Program A3-Risk-Adjusted and Smoothed Rates             --- ;
 * --------------------------------------------------------------------- ;
LIBNAME INA2 'C:\PATHNAME';                         *<===USER MUST modify;
LIBNAME OUTA3 'C:\PATHNAME';                        *<===USER MUST modify;

* ---------------------------------------------------------------- ;           
 * --- SET NAME OF COVARIATE FILE.                                - ;           
 * --- THIS FILE CONTAINS THE REGRESSION COEFFICIENTS FOR EACH    - ;           
 * --- COVARIATE.  THERE IS ONE OBSERVATION PER PEDIATRIC QUALITY - ;           
 * --- INDICATOR.                                                 - ;           
 * ---------------------------------------------------------------- ;           
 * - SET TO COVPDA50 FOR AGE AND GENDER ADJUSTMENT ONLY (DEFAULT) - ;           
 * - SET TO CVPDA50 FOR AGE, GENDER AND SES ADJUSTMENT           - ;            
FILENAME COVARA 'C:\PATHNAME\COVPDA50.TXT';  *<===USER MUST modify;     
                                                                                
 * ---------------------------------------------------------------- ;           
 * --- SET NAME OF MSX STATISTICS FILE                            - ;           
 * ---   FILE CONTAINS AN ARRAY OF SIGNAL VARIANCE AND            - ;           
 * ---   POPULATION RATES                                         - ;           
 * ---------------------------------------------------------------- ;           
 * - SET TO MSXPDA50 FOR AGE AND GENDER ADJUSTMENT ONLY (DEFAULT) - ;           
 * - SET TO MXPDA50 FOR AGE, GENDER AND SES ADJUSTMENT           - ;            
FILENAME MSXA 'C:\PATHNAME\MSXPDA50.TXT';    *<===USER MUST modify;     
 
 * --------------------------------------------------------------------- ;
 * --- SET NAME OF INPUT RATES FILE (OUTPUT FROM PROGRAM A2) AND     --- ;
 * --- AREA LEVEL OUTPUT FILE.                                       --- ;
 * --------------------------------------------------------------------- ;
%LET INFILEA2 = PQ09_PDA2;                           *<===USER may modify;
%LET OUTFILA3 = PQ09_PDA3;                           *<===USER may modify;

 * --------------------------------------------------------------------- ;
 * --- INDICATE IF WANT TO CREATE A COMMA-DELIMITED FILE FOR         --- ;
 * --- EXPORT INTO A SPREADSHEET.                                    --- ;
 * --------------------------------------------------------------------- ;
%LET TEXTA3 = 0;                                     *<===USER may modify;

 * --------------------------------------------------------------------- ;
 * --- IF YOU CREATE A COMMA-DELIMITED FILE, SPECIFY THE LOCATION      - ;
 * --- OF THE FILE.                                                  --- ;
 * --------------------------------------------------------------------- ;
FILENAME PDTEXTA3 'C:\PATHNAME\PQ09_PDTEXTA3.TXT';   *<===USER may modify;
