*============================ PROGRAM: PQ09_PDSASA2.SAS =============================;
*====================================================================================;
*  Title:  PROGRAM A2 CALCULATES OBSERVED AREA RATES FOR AHRQ
*          PATIENT QUALITY INDICATOR-09 (PQI-09)
*
*  Description:
*          USES PROC SUMMARY TO CALCULATE OBSERVED RATES FOR
*          PEDIATRIC QUALITY INDICATORS ACROSS STRATIFIERS:
*          PROGRAM USES AREA, POPCAT, SEXCAT AND RACECAT.
*          THIS INDICATOR WAS ALSO INCLUDED IN PEDIATRIC QUALITY INDICATOR MODULE.
*
*                        >>>  VERSION 5.0.3 - FEBRUARY, 2016  <<<
*
*====================================================================================;

FILENAME CONTROL "C:\PATHNAME\CONTROL_PQ09.SAS";          *<==USER MUST modify;

%INCLUDE CONTROL;


 %MACRO CTY2MA;
    %IF &MALEVL EQ 0 %THEN %DO;
        ATTRIB MAREA LENGTH=$5
          LABEL='FIPS STATE COUNTY CODE';
        MAREA = FIPSTCO;
    %END;
    %ELSE %IF &MALEVL EQ 1 %THEN %DO;
        ATTRIB MAREA LENGTH=$5
          LABEL='MODIFIED FIPS';
        MAREA = INPUT(PUT(FIPSTCO,$M1AREA.),$5.);
    %END;
    %ELSE %IF &MALEVL EQ 2 %THEN %DO;
        ATTRIB MAREA LENGTH=$5
          LABEL='OMB 1999 METRO AREA';
        MAREA = INPUT(PUT(FIPSTCO,$M2AREA.),$5.);
    %END;
    %ELSE %IF &MALEVL EQ 3 %THEN %DO;
        ATTRIB MAREA LENGTH=$5
          LABEL='OMB 2003 METRO AREA';
        MAREA = INPUT(PUT(FIPSTCO,$M3AREA.),$5.);
    %END;
 %MEND;

 TITLE2 'PROGRAM A3 PART I';
 TITLE3 'AHRQ PEDIATRIC QUALITY INDICATORS: CALCULATE ADJUSTED AREA RATES';

 * ---------------------------------------------------------------- ;
 * --- ADD POPULATION DENOMINATOR --------------------------------- ;
 * --- THIS STEP DETERMINES WHICH AREAS ARE INCLUDED IN THE     --- ;
 * --- OUTPUT FROM PROGRAM A1.                                  --- ;
 * ---------------------------------------------------------------- ;

 DATA   TEMP0;
 SET    IN1.&INFILE1.;

 %CTY2MA

 RUN;

 PROC   SORT DATA=TEMP0 (KEEP=MAREA) OUT=MAREA NODUPKEY;
 BY     MAREA;
 RUN;

 DATA QIPOP0;
    LENGTH FIPSTCO $5 SEXCAT POPCAT RACECAT 3 
           POP_1995 POP_1996 POP_1997 POP_1998 POP_1999
           POP_2000 POP_2001 POP_2002 POP_2003 POP_2004
           POP_2005 POP_2006 POP_2007 POP_2008 POP_2009 
           POP_2010 POP_2011 POP_2012 POP_2013 POP_2014
           POP 8;

    INFILE POPFILE MISSOVER FIRSTOBS=2;

    INPUT FIPSTCO SEXCAT POPCAT RACECAT 
          POP_1995 POP_1996 POP_1997 POP_1998 POP_1999
          POP_2000 POP_2001 POP_2002 POP_2003 POP_2004
          POP_2005 POP_2006 POP_2007 POP_2008 POP_2009
          POP_2010 POP_2011 POP_2012 POP_2013 POP_2014;

    %CTY2MA

    POP = POP_&POPYEAR.;

    IF POPCAT IN (1,2,3,4);

 RUN;

 PROC   SUMMARY DATA=QIPOP0 NWAY;
 CLASS  MAREA POPCAT SEXCAT RACECAT;
 VAR    POP;
 OUTPUT OUT=QIPOP SUM=;
 RUN;

 PROC   SORT DATA=QIPOP;
 BY     MAREA POPCAT SEXCAT RACECAT;
 RUN;

 DATA   QIPOP(KEEP=MAREA POPCAT SEXCAT RACECAT POP);
 MERGE  MAREA(IN=X) QIPOP(IN=Y);
 BY     MAREA;

 IF X AND Y;

 RUN;

 * -------------------------------------------------------------- ;
 * --- PEDIATRIC QUALITY INDICATORS ADJUSTED RATES ------------- ;
 * -------------------------------------------------------------- ;
 * --- THIS STEP SELECTS THE OBSERVATIONS FROM THE PROGRAM A1 --- ;
 * --- OUTPUT FOR EACH PEDIATRIC QUALITY INDICATOR IN TURN.  --- ;
 * --- EACH ITERATION PASSES VARIABLES THAT CONTROL THE       --- ;
 * --- COVARIATES FOR THAT PEDIATRIC QUALITY INDICATOR:      --- ;
 * --- N - OBSERVATION NUMBER FROM THE MEANS AND COVAR FILES  --- ;
 * ---     ALSO IDENTIFIES THE FORMAT USED TO INDEX COVARIATES -- ;
 * --- PD - THE PEDIATRIC QUALITY INDICATOR NAME WITHOUT THE --- ;
 *          PREFIX (A)                                        --- ;
 * -------------------------------------------------------------- ;

 %MACRO MOD3(N,PD,DL);

 * --- THIS SET CREATES TEMP1 WHICH CONTAINS THE DEPENDENT    --- ;
 * --- VARIABLE (TPD) AND INDEPENDENT VARIABLES USED IN       --- ;
 * --- REGRESSION.  IT APPENDS TO THE DISCHARGE DATA ONE      --- ;
 * --- OBSERVATION PER MAREA AND DEMOGRAPHIC GROUP.            --- ;

 %IF &DL. = 0 %THEN %DO;

 DATA   TEMP_2;
 SET    IN1.&INFILE1.(KEEP=KEY FIPSTCO T&PD. POPCAT SEXCAT RACECAT);

 IF T&PD. IN (1);
 IF POPCAT IN (1,2,3,4);

 %CTY2MA

 RUN;

 PROC   SUMMARY DATA=TEMP_2 NWAY;
 CLASS  MAREA POPCAT SEXCAT RACECAT;
 VAR    T&PD.;
 OUTPUT OUT=TEMP_3 N=TCOUNT;
 RUN;

 PROC   SORT DATA=TEMP_3;
 BY     MAREA POPCAT SEXCAT RACECAT;
 RUN;

 /* FOR ZERO, REDUCE THE WEIGHT BY THE NUMERATOR COUNT */;

 DATA   TEMP_4(DROP=TCOUNT N);
 MERGE  QIPOP(IN=X KEEP=MAREA POPCAT SEXCAT RACECAT POP) 
        TEMP_3(KEEP=MAREA POPCAT SEXCAT RACECAT TCOUNT);
 BY     MAREA POPCAT SEXCAT RACECAT;

 IF X;

 N = &N.;

 IF POPCAT IN (1) THEN DO;
    IF N = 14 THEN POP = POP * 0.60; /* AGE < 2 */
    IF N = 15 THEN POP = .;          /* AGE < 6 */
    IF N = 16 THEN POP = POP * 0.95; /* AGEDAY < 90 */
    IF N = 18 THEN POP = POP * 0.95; /* AGEDAY < 90 */
    IF N = 90 THEN POP = .;          /* AGE < 6 */
    IF N = 91 THEN POP = .;          /* AGE < 6 */
    IF N = 92 THEN POP = .;          /* AGE < 6 */
 END;
 ELSE IF POPCAT IN (2) THEN DO;
   IF N = 15 THEN POP = POP * 0.80; /* AGE < 6 */
   IF N = 90 THEN POP = POP * 0.80; /* AGE < 6 */
   IF N = 91 THEN POP = POP * 0.80; /* AGE < 6 */
   IF N = 92 THEN POP = POP * 0.80; /* AGE < 6 */
 END;

 IF TCOUNT > 0 THEN PCOUNT = POP - TCOUNT;
 ELSE PCOUNT = POP;

 IF PCOUNT < 0 THEN PCOUNT = 0;

 IF PCOUNT = 0 THEN DELETE;
 
 RUN;

 /* FOR ONE, RETAIN ONLY RECORDS WITH A VALID FIPS CODE */;

 DATA   TEMP_3(DROP=POP);
 MERGE  TEMP_3(IN=X KEEP=MAREA POPCAT SEXCAT RACECAT TCOUNT)
        QIPOP(KEEP=MAREA POPCAT SEXCAT RACECAT POP);
 BY     MAREA POPCAT SEXCAT RACECAT;

 IF X;

 IF POP < 0 THEN PCOUNT = 0;
 ELSE IF TCOUNT > 0 THEN PCOUNT = TCOUNT;
 ELSE PCOUNT = 0;

 IF PCOUNT = 0 THEN DELETE;
 
 RUN;

 /* COMBINE THE NUMERATOR AND DENOMINATOR */;

 DATA   TEMP1;
 SET    TEMP_3(IN=X) TEMP_4;

 IF X THEN T&PD. = 1;
 ELSE T&PD. = 0;

 RUN;

 %END;
 %ELSE %DO;

 DATA   TEMP_2;
 SET    IN1.&INFILE1.(KEEP=KEY FIPSTCO T&PD. POPCAT SEXCAT RACECAT);

 IF T&PD. IN (0,1);
 IF POPCAT IN (1,2,3,4);

 %CTY2MA

 RUN;

 PROC   SUMMARY DATA=TEMP_2 NWAY;
 CLASS  T&PD. MAREA POPCAT SEXCAT RACECAT;
 VAR    T&PD.;
 OUTPUT OUT=TEMP_3 N=TCOUNT;
 RUN;

 PROC   SORT DATA=TEMP_3;
 BY     MAREA POPCAT SEXCAT RACECAT;
 RUN;

 /* RETAIN ONLY RECORDS WITH A VALID FIPS CODE */;

 DATA   TEMP1;
 MERGE  TEMP_3(IN=X KEEP=MAREA POPCAT SEXCAT RACECAT TCOUNT T&PD.)
        QIPOP(KEEP=MAREA POPCAT SEXCAT RACECAT);
 BY     MAREA POPCAT SEXCAT RACECAT;

 IF X;

 IF TCOUNT > 0 THEN PCOUNT = TCOUNT;
 ELSE PCOUNT = 0;

 IF PCOUNT = 0 THEN DELETE;
 
 RUN;

 %END;

 DATA   TEMP1;
 LENGTH FEMALE AGECAT1-AGECAT4 FAGECAT1-FAGECAT4
        POVCAT1-POVCAT10 3;
 SET    TEMP1;

 IF SEXCAT IN (2) THEN FEMALE = 1;
 ELSE FEMALE = 0;

 ARRAY ARRY1{4} AGECAT1-AGECAT4;
 ARRAY ARRY2{4} FAGECAT1-FAGECAT4;

 DO I = 1 TO 4;
    ARRY1(I) = 0; ARRY2(I) = 0;
 END;

 ARRY1(POPCAT) = 1;
 ARRY2(POPCAT) = FEMALE;

 ARRAY ARRY3{10} POVCAT1-POVCAT10;

 DO I = 1 TO 10;
    ARRY3(I) = 0;
 END;

 PVIDX = PUT(MAREA,$POVCAT.);

 IF PVIDX > 0 THEN ARRY3(PVIDX) = 1;

 RUN;

 
 DATA   TEMP1Y;
 SET    TEMP1;

 ONE = 1;

 RUN;

 PROC   SUMMARY DATA=TEMP1Y;
 CLASS  MAREA POPCAT SEXCAT RACECAT;
 VAR    T&PD. ONE;
 OUTPUT OUT=ADJ_&PD. SUM(T&PD. ONE)=T&PD. P&PD.;
 WEIGHT PCOUNT;
 RUN;

 DATA   ADJ_&PD.(KEEP=MAREA POPCAT SEXCAT RACECAT _TYPE_ T&PD. P&PD.);
 SET    ADJ_&PD.;

 IF _TYPE_ &TYPELVLA;

 RUN;

 PROC SORT DATA=ADJ_&PD.;
     BY MAREA POPCAT SEXCAT RACECAT;
 RUN; QUIT;

 PROC   DATASETS NOLIST;
 DELETE TEMP1 TEMP1Y TEMP_2 TEMP_3 TEMP_4;
 RUN;

 %MEND;

 %MOD3(60,APQ09,1);

 * --- MERGES THE MAREA ADJUSTED RATES FOR EACH PEDIATRIC QUALITY INDICATOR.  - ;
 * --- PREFIX FOR THE ADJUSTED RATES IS ADJ( Adjusted)                      --- ;
 
DATA TEMP2Y;
  SET ADJ_APQ09;
  BY MAREA POPCAT  SEXCAT RACECAT;
RUN;

 DATA &OUTFILA2.;
 SET TEMP2Y;

 ARRAY PPD2{1} PAPQ09;
 ARRAY TPD{1}  TAPQ09;
 ARRAY OPD{1}  OAPQ09;

 DO J = 1 to 1;
    IF TPD{J} GT 0 AND PPD2{J} GT 0 THEN OPD{J} = TPD{J} / PPD2{J};
    ELSE IF PPD2{J} GT 0 THEN OPD{J} = 0;
 END;

 LABEL
 TAPQ09 = 'PQI 09 Low Birth Weight Rate (Numerator)'
 ;
 LABEL
 PAPQ09 = 'PQI 09 Low Birth Weight Rate (Population)'
 ;
 LABEL
 OAPQ09 = 'PQI 09 Low Birth Weight Rate (Observed)'
 _TYPE_ = 'STRATIFICATION LEVEL'
 ;

 DROP J;

 RUN;

 PROC SORT DATA=&OUTFILA2. OUT=OUTA2.&OUTFILA2.;
 BY MAREA POPCAT SEXCAT RACECAT;
 RUN;

PROC DATASETS NOLIST;
  DELETE MAREA QIPOP QIPOP0 TEMP0 TEMP2Y
         ADJ_APQ09;
RUN; QUIT;

 * -------------------------------------------------------------- ;
 * --- CONTENTS AND MEANS OF AREA OBSERVED MEANS FILE ----------- ;
 * -------------------------------------------------------------- ;

 PROC CONTENTS DATA=OUTA2.&OUTFILA2. POSITION;
 RUN;

 *PROC MEANS DATA=OUTA2.&OUTFILA2.(WHERE=(_TYPE_ IN (8))) N NMISS MIN MAX MEAN SUM;
 *TITLE4 "SUMMARY OF AREA-LEVEL RATES (_TYPE_=8)";
 *RUN;

***----- TO PRINT VARIABLE LABELS COMMENT (DELETE) "NOLABELS" FROM PROC MEANS STATEMENTS -------***;

PROC MEANS DATA=OUTA2.&OUTFILA2. (WHERE=(_TYPE_ IN (8))) N NMISS MIN MAX SUM NOLABELS;
   VAR TAPQ09 ;
   TITLE  'SUMMARY OF PATIENT QUALITY AREA-LEVEL INDICATOR OVERALL NUMERATOR (SUM) WHEN _TYPE_=8';
RUN; QUIT;

PROC MEANS DATA=OUTA2.&OUTFILA2. (WHERE=(_TYPE_ IN (8))) N NMISS MIN MAX SUM NOLABELS;
   VAR PAPQ09;
   TITLE  'SUMMARY OF PATIENT QUALITY AREA-LEVEL INDICATOR OVERALL DENOMINATOR (SUM) WHEN _TYPE_=8';
RUN; QUIT;

PROC MEANS DATA=OUTA2.&OUTFILA2. (WHERE=(_TYPE_ IN (8))) N NMISS MIN MAX MEAN NOLABELS;
   VAR OAPQ09 ;
   TITLE  'SUMMARY OF PATIENT QUALITY AREA-LEVEL INDICATOR AVERAGE RATES(MEAN) WHEN _TYPE_=8';
RUN; QUIT;

 * -------------------------------------------------------------- ;
 * --- PRINT AREA OBSERVED MEANS FILE --------------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO PRT2;

 %IF &PRINT. = 1 %THEN %DO;

 %MACRO PRT(PD,TEXT);

 PROC  PRINT DATA=OUTA2.&OUTFILA2. LABEL SPLIT='*';
 VAR   MAREA POPCAT SEXCAT RACECAT TA&PD. PA&PD. OA&PD. ;
 LABEL MAREA    = "MAREA"
       POPCAT   = "POPCAT"
       SEXCAT   = "SEXCAT"
       RACECAT  = "RACECAT"
       TA&PD.   = "TA&PD.*(Numerator)"
       PA&PD.   = "PA&PD.*(Denominator)"
       OA&PD.   = "OA&PD.*(Observed)"
       ;
 FORMAT POPCAT POPCAT.   
        SEXCAT SEXCAT.
        RACECAT RACECAT.
        TA&PD. PA&PD. COMMA13.0
        OA&PD. 8.6
        ;
 TITLE4 "Indicator &PD.: &TEXT";
 RUN;

 %MEND PRT;

 %PRT(PQ09,Low Birth Weight Rate);

 %END;

 %MEND PRT2;

 %PRT2; 

 * -------------------------------------------------------------- ;
 * --- WRITE SAS OUTPUT DATA SET TO COMMA-DELIMITED TEXT FILE --- ;
 * --- FOR EXPORT INTO SPREADSHEETS ----------------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO TEXT;

 %IF &TEXTA2. = 1  %THEN %DO;

 DATA _NULL_;
 SET OUTA2.&OUTFILA2;
 FILE PDTEXTA2 LRECL=1000;
 IF _N_=1 THEN PUT "MAREA"  "," "Age"  "," "Sex"  "," "Race"  "," "Type" ","
 "TAPQ09" "," 
 "PAPQ09" "," 
 "OAPQ09"  
;

 PUT MAREA $5. "," POPCAT 3. "," SEXCAT 3. "," RACECAT 3.  "," _TYPE_ 2.  ","
 (TAPQ09) (7.0 ",")
 ","
 (PAPQ09) (13.2 ",")
 ","
 (OAPQ09) (12.10 ",")
 ;
 RUN;

 %END;

 %MEND TEXT;

 %TEXT;
