*============================ PROGRAM: PQ09_PDSASA3.SAS =============================;
*====================================================================================;
*  Title:  PROGRAM A3 CALCULATES RISK-ADJUSTED AREA RATES FOR
*          AHRQ PATIENT QUALITY INDICATOR-09 (PQI-09)
*
*  Description:
*          USES PROC SCORE TO CALCULATE RISK-ADJUSTED RATES FOR PEDIATRIC
*          QUALITY INDICATORS.
*          ADJUSTS FOR: AGE, SEXCAT AND POVCAT.
*          THIS INDICATOR WAS ALSO INCLUDED IN PEDIATRIC QUALITY INDICATOR MODULE.
*
*                         >>>  VERSION 5.0.3 - FEBRUARY, 2016  <<<
*
*====================================================================================;
FILENAME CONTROL "C:\PATHNAME\CONTROL_PQ09.SAS";          *<==USER MUST modify;

%INCLUDE CONTROL;


 %MACRO CTY2MA;
    %IF &MALEVL EQ 0 %THEN %DO;
        ATTRIB MAREA LENGTH=$5
          LABEL='FIPS STATE COUNTY CODE';
        MAREA = FIPSTCO;
    %END;
    %ELSE %IF &MALEVL EQ 1 %THEN %DO;
        ATTRIB MAREA LENGTH=$5
          LABEL='MODIFIED FIPS';
        MAREA = INPUT(PUT(FIPSTCO,$M1AREA.),$5.);
    %END;
    %ELSE %IF &MALEVL EQ 2 %THEN %DO;
        ATTRIB MAREA LENGTH=$5
          LABEL='OMB 1999 METRO AREA';
        MAREA = INPUT(PUT(FIPSTCO,$M2AREA.),$5.);
    %END;
    %ELSE %IF &MALEVL EQ 3 %THEN %DO;
        ATTRIB MAREA LENGTH=$5
          LABEL='OMB 2003 METRO AREA';
        MAREA = INPUT(PUT(FIPSTCO,$M3AREA.),$5.);
    %END;
 %MEND;

 TITLE2 'PROGRAM A3 PART I';
 TITLE3 'AHRQ PEDIATRIC QUALITY INDICATORS: CALCULATE ADJUSTED AREA RATES';

 * ---------------------------------------------------------------- ;
 * --- ADD POPULATION DENOMINATOR --------------------------------- ;
 * --- THIS STEP DETERMINES WHICH AREAS ARE INCLUDED IN THE     --- ;
 * --- OUTPUT FROM PROGRAM A1.                                  --- ;
 * ---------------------------------------------------------------- ;

 DATA   TEMP0;
 SET    IN1.&INFILE1.;

 %CTY2MA

 RUN;

 PROC   SORT DATA=TEMP0 (KEEP=MAREA) OUT=MAREA NODUPKEY;
 BY     MAREA;
 RUN;

 DATA QIPOP0;
    LENGTH FIPSTCO $5 SEXCAT POPCAT RACECAT 3 
           POP_1995 POP_1996 POP_1997 POP_1998 POP_1999
           POP_2000 POP_2001 POP_2002 POP_2003 POP_2004
           POP_2005 POP_2006 POP_2007 POP_2008 POP_2009 
           POP_2010 POP_2011 POP_2012 POP_2013 POP_2014
           POP 8;

    INFILE POPFILE MISSOVER FIRSTOBS=2;

    INPUT FIPSTCO SEXCAT POPCAT RACECAT 
          POP_1995 POP_1996 POP_1997 POP_1998 POP_1999
          POP_2000 POP_2001 POP_2002 POP_2003 POP_2004
          POP_2005 POP_2006 POP_2007 POP_2008 POP_2009
          POP_2010 POP_2011 POP_2012 POP_2013 POP_2014;

    %CTY2MA

    POP = POP_&POPYEAR.;

    IF POPCAT IN (1,2,3,4);

 RUN;

 PROC   SUMMARY DATA=QIPOP0 NWAY;
 CLASS  MAREA POPCAT SEXCAT RACECAT;
 VAR    POP;
 OUTPUT OUT=QIPOP SUM=;
 RUN;

 PROC   SORT DATA=QIPOP;
 BY     MAREA POPCAT SEXCAT RACECAT;
 RUN;

 DATA   QIPOP(KEEP=MAREA POPCAT SEXCAT RACECAT POP);
 MERGE  MAREA(IN=X) QIPOP(IN=Y);
 BY     MAREA;

 IF X AND Y;

 RUN;

 * -------------------------------------------------------------- ;
 * --- PEDIATRIC QUALITY INDICATORS ADJUSTED RATES ------------- ;
 * -------------------------------------------------------------- ;
 * --- THIS STEP SELECTS THE OBSERVATIONS FROM THE PROGRAM A1 --- ;
 * --- OUTPUT FOR EACH PEDIATRIC QUALITY INDICATOR IN TURN.  --- ;
 * --- EACH ITERATION PASSES VARIABLES THAT CONTROL THE       --- ;
 * --- COVARIATES FOR THAT PEDIATRIC QUALITY INDICATOR:      --- ;
 * --- N - OBSERVATION NUMBER FROM THE MEANS AND COVAR FILES  --- ;
 * ---     ALSO IDENTIFIES THE FORMAT USED TO INDEX COVARIATES -- ;
 * --- PD - THE PEDIATRIC QUALITY INDICATOR NAME WITHOUT THE --- ;
 *          PREFIX (A)                                        --- ;
 * -------------------------------------------------------------- ;

 %MACRO MOD3(N,PD,DL);

 * --- THIS SET CREATES TEMP1 WHICH CONTAINS THE DEPENDENT    --- ;
 * --- VARIABLE (TPD) AND INDEPENDENT VARIABLES USED IN       --- ;
 * --- REGRESSION.  IT APPENDS TO THE DISCHARGE DATA ONE      --- ;
 * --- OBSERVATION PER MAREA AND DEMOGRAPHIC GROUP.            --- ;

 %IF &DL. = 0 %THEN %DO;

 DATA   TEMP_2;
 SET    IN1.&INFILE1.(KEEP=KEY FIPSTCO T&PD. POPCAT SEXCAT RACECAT);

 IF T&PD. IN (1);
 IF POPCAT IN (1,2,3,4);

 %CTY2MA

 RUN;

 PROC   SUMMARY DATA=TEMP_2 NWAY;
 CLASS  MAREA POPCAT SEXCAT RACECAT;
 VAR    T&PD.;
 OUTPUT OUT=TEMP_3 N=TCOUNT;
 RUN;

 PROC   SORT DATA=TEMP_3;
 BY     MAREA POPCAT SEXCAT RACECAT;
 RUN;

 /* FOR ZERO, REDUCE THE WEIGHT BY THE NUMERATOR COUNT */;

 DATA   TEMP_4(DROP=TCOUNT N);
 MERGE  QIPOP(IN=X KEEP=MAREA POPCAT SEXCAT RACECAT POP) 
        TEMP_3(KEEP=MAREA POPCAT SEXCAT RACECAT TCOUNT);
 BY     MAREA POPCAT SEXCAT RACECAT;

 IF X;

 N = &N.;

 IF POPCAT IN (1) THEN DO;
    IF N = 14 THEN POP = POP * 0.60; /* AGE < 2 */
    IF N = 15 THEN POP = .;          /* AGE < 6 */
    IF N = 16 THEN POP = POP * 0.95; /* AGEDAY < 90 */
    IF N = 18 THEN POP = POP * 0.95; /* AGEDAY < 90 */
    IF N = 90 THEN POP = .;          /* AGE < 6 */
    IF N = 91 THEN POP = .;          /* AGE < 6 */
    IF N = 92 THEN POP = .;          /* AGE < 6 */
 END;
 ELSE IF POPCAT IN (2) THEN DO;
   IF N = 15 THEN POP = POP * 0.80; /* AGE < 6 */
   IF N = 90 THEN POP = POP * 0.80; /* AGE < 6 */
   IF N = 91 THEN POP = POP * 0.80; /* AGE < 6 */
   IF N = 92 THEN POP = POP * 0.80; /* AGE < 6 */
 END;

 IF TCOUNT > 0 THEN PCOUNT = POP - TCOUNT;
 ELSE PCOUNT = POP;

 IF PCOUNT < 0 THEN PCOUNT = 0;

 IF PCOUNT = 0 THEN DELETE;
 
 RUN;

 /* FOR ONE, RETAIN ONLY RECORDS WITH A VALID FIPS CODE */;

 DATA   TEMP_3(DROP=POP);
 MERGE  TEMP_3(IN=X KEEP=MAREA POPCAT SEXCAT RACECAT TCOUNT)
        QIPOP(KEEP=MAREA POPCAT SEXCAT RACECAT POP);
 BY     MAREA POPCAT SEXCAT RACECAT;

 IF X;

 IF POP < 0 THEN PCOUNT = 0;
 ELSE IF TCOUNT > 0 THEN PCOUNT = TCOUNT;
 ELSE PCOUNT = 0;

 IF PCOUNT = 0 THEN DELETE;
 
 RUN;

 /* COMBINE THE NUMERATOR AND DENOMINATOR */;

 DATA   TEMP1;
 SET    TEMP_3(IN=X) TEMP_4;

 IF X THEN T&PD. = 1;
 ELSE T&PD. = 0;

 RUN;

 %END;
 %ELSE %DO;

 DATA   TEMP_2;
 SET    IN1.&INFILE1.(KEEP=KEY FIPSTCO T&PD. POPCAT SEXCAT RACECAT);

 IF T&PD. IN (0,1);
 IF POPCAT IN (1,2,3,4);

 %CTY2MA

 RUN;

 PROC   SUMMARY DATA=TEMP_2 NWAY;
 CLASS  T&PD. MAREA POPCAT SEXCAT RACECAT;
 VAR    T&PD.;
 OUTPUT OUT=TEMP_3 N=TCOUNT;
 RUN;

 PROC   SORT DATA=TEMP_3;
 BY     MAREA POPCAT SEXCAT RACECAT;
 RUN;

 /* RETAIN ONLY RECORDS WITH A VALID FIPS CODE */;

 DATA   TEMP1;
 MERGE  TEMP_3(IN=X KEEP=MAREA POPCAT SEXCAT RACECAT TCOUNT T&PD.)
        QIPOP(KEEP=MAREA POPCAT SEXCAT RACECAT);
 BY     MAREA POPCAT SEXCAT RACECAT;

 IF X;

 IF TCOUNT > 0 THEN PCOUNT = TCOUNT;
 ELSE PCOUNT = 0;

 IF PCOUNT = 0 THEN DELETE;
 
 RUN;

 %END;

 DATA   TEMP1;
 LENGTH FEMALE AGECAT1-AGECAT4 FAGECAT1-FAGECAT4
        POVCAT1-POVCAT10 3;
 SET    TEMP1;

 IF SEXCAT IN (2) THEN FEMALE = 1;
 ELSE FEMALE = 0;

 ARRAY ARRY1{4} AGECAT1-AGECAT4;
 ARRAY ARRY2{4} FAGECAT1-FAGECAT4;

 DO I = 1 TO 4;
    ARRY1(I) = 0; ARRY2(I) = 0;
 END;

 ARRY1(POPCAT) = 1;
 ARRY2(POPCAT) = FEMALE;

 ARRAY ARRY3{10} POVCAT1-POVCAT10;

 DO I = 1 TO 10;
    ARRY3(I) = 0;
 END;

 PVIDX = PUT(MAREA,$POVCAT.);

 IF PVIDX > 0 THEN ARRY3(PVIDX) = 1;

 RUN;

 * --- THIS DATA STEP READS THE REGRESSION COEFFICIENTS FOR EACH - ;
 * --- COVARIATE.                                              --- ;

 DATA   TEMP2(KEEP=INTERCEP FEMALE AGECAT1-AGECAT4 FAGECAT1-FAGECAT4
                   POVCAT1-POVCAT10  
                   _NAME_ _TYPE_ _LINK_ _LNLIKE_ _STATUS_);
 LENGTH INTERCEP FEMALE AGECAT1-AGECAT4 FAGECAT1-FAGECAT4
        POVCAT1-POVCAT10 _LNLIKE_ 8
        _NAME_ _TYPE_ _LINK_ $8 _STATUS_ $11;
 INFILE COVARA MISSOVER LRECL=500;
 INPUT  N INTERCEP FEMALE AGECAT1-AGECAT4 FAGECAT1-FAGECAT4
        POVCAT1-POVCAT10  
        _NAME_ _TYPE_ _LINK_ _LNLIKE_ _STATUS_;

 IF N = &N.;

 RUN;

 * --- THIS PROC CALCULATES A PREDICTED INPATIENT QUALITY         - ;
 * --- INDICATOR FOR EACH OBSERVATION USING THE ACTUAL COVARIATES - ;
 * --- AND THE ESTIMATED COEFFICIENTS.                            - ;

 PROC   SCORE DATA=TEMP1 SCORE=TEMP2 TYPE=PARMS OUT=TEMP1Y;
 VAR    FEMALE AGECAT1-AGECAT4 FAGECAT1-FAGECAT4
        POVCAT1-POVCAT10;
 RUN;

 %let dsid=%sysfunc(open(temp1y));
 %let dnum=%sysfunc(attrn(&dsid,nobs));
 %let drc=%sysfunc(close(&dsid));

 %if &dnum ne 0 %then %do;

 DATA   TEMP1Y;
 SET    TEMP1Y;

 EHAT = EXP(MHAT)/(1 + EXP(MHAT));
 PHAT = EHAT * (1 - EHAT);
 ONE = 1;

 RUN;

 PROC   SUMMARY DATA=TEMP1Y;
 CLASS  MAREA POPCAT SEXCAT RACECAT;
 VAR    T&PD. EHAT PHAT ONE;
 OUTPUT OUT=R&PD. SUM(T&PD. EHAT PHAT ONE)=T&PD. EHAT PHAT P&PD.;
 WEIGHT PCOUNT;
 RUN;

 DATA   R&PD.(KEEP=MAREA POPCAT SEXCAT RACECAT _TYPE_
                   E&PD. R&PD. L&PD. U&PD. S&PD. X&PD.);
 SET    R&PD.;

 IF _TYPE_ &TYPELVLA;

 %INCLUDE MSXA;
 IF &N. = 14 THEN SUB_N = 1;
 IF &N. = 15 THEN SUB_N = 2;
 IF &N. = 16 THEN SUB_N = 3;
 IF &N. = 17 THEN SUB_N = 4;
 IF &N. = 18 THEN SUB_N = 5;
 IF &N. = 90 THEN SUB_N = 6;
 IF &N. = 91 THEN SUB_N = 7;
 IF &N. = 92 THEN SUB_N = 8;
 IF &N. = 60 THEN SUB_N = 9;

 E&PD. = EHAT / P&PD.;
 THAT = T&PD. / P&PD.;

 IF _TYPE_ IN (0,8) THEN DO;
    R&PD.   = (THAT / E&PD.) * ARRYA3(SUB_N);
    SE&PD.  = (ARRYA3(SUB_N) / E&PD.) * (1 / P&PD.) * SQRT(PHAT);
    VAR&PD. = SE&PD.**2;
    SN&PD.  = ARRYA2(SUB_N) / (ARRYA2(SUB_N) + VAR&PD.);
    S&PD.   = (R&PD. * SN&PD.) + ((1 -  SN&PD.) * ARRYA3(SUB_N));
    X&PD.   = SQRT(ARRYA2(SUB_N)- (SN&PD. * ARRYA2(SUB_N)));
 END;
 ELSE DO;
    R&PD.   = (THAT / E&PD.);
    SE&PD.  = (1 / E&PD.) * (1 / P&PD.) * SQRT(PHAT);
    S&PD.   = .;
    X&PD.   = .;
 END;

 L&PD.   = R&PD. - (1.96 * SE&PD.);
 IF L&PD. < 0 THEN L&PD. = 0;
 U&PD.   = R&PD. + (1.96 * SE&PD.);

 IF _TYPE_ IN (0,8) THEN DO;   
     IF L&PD. > 1 THEN L&PD. = 1;
	 IF U&PD. > 1 THEN U&PD. = 1;
	 IF R&PD. > 1 THEN R&PD. = 1;
 END;

 RUN;

 %end;
 %else %do;

 DATA   R&PD.;
    MAREA='';POPCAT=.;SEXCAT=.;RACECAT=.;_TYPE_=0;_FREQ_=0;E&PD=.;R&PD=.;L&PD=.;U&PD=.;P&PD=.;S&PD=.;X&PD=.;
    OUTPUT;
 RUN;

 %end;

 PROC SORT DATA=R&PD.;
   BY MAREA POPCAT SEXCAT RACECAT;
 RUN; QUIT;

 PROC   DATASETS NOLIST;
 DELETE TEMP1 TEMP1Y TEMP2;
 RUN;

 %MEND;

 %MOD3(60,APQ09,1);

 * --- MERGES THE MAREA ADJUSTED RATES FOR EACH PEDIATRIC QUALITY - ;
 * --- INDICATOR.  PREFIX FOR THE ADJUSTED RATES IS R(Risk      --- ;
 * --- Adjusted).                                               --- ;

 DATA   RISKADJ;
 SET    RAPQ09(KEEP=MAREA POPCAT SEXCAT RACECAT EAPQ09 RAPQ09 LAPQ09 UAPQ09 SAPQ09 XAPQ09);
 BY     MAREA POPCAT SEXCAT RACECAT;

 LABEL
 EAPQ09 = 'PQI 09 Low Birth Weight Rate  (Expected)'
 ;

 LABEL
 RAPQ09 = 'PQI 09 Low Birth Weight Rate  (Risk Adj)'
 ;

 LABEL
 LAPQ09 = 'PQI 09 Low Birth Weight Rate  (Lower CL)'
 ;

 LABEL
 UAPQ09 = 'PQI 09 Low Birth Weight Rate  (Upper CL)'
 ;

 LABEL
 SAPQ09 = 'PQI 09 Low Birth Weight Rate  (Smoothed)'
 ;

 LABEL
 XAPQ09 = 'PQI 09 Low Birth Weight Rate  (Smthe SE)'
 ;

 RUN;

*==================================================================;
*  Title:  PROGRAM A3  PART II:  MERGE AREA RATES FOR HCUP
*          PEDIATRIC QUALITY INDICATORS
*
*  Description:  MERGE RATES FOR PEDIATRIC QUALITY INDICATORS
*
*          >>>  VERSION 5.0.3 - FEBRUARY, 2016     <<<
*
*===================================================================;

 TITLE2 'PROGRAM A3  PART III';
 TITLE3 'AHRQ PEDIATRIC QUALITY INDICATORS:  AREA-LEVEL MERGED FILES';

 * ---------------------------------------------------------------- ;
 * --- PEDIATRIC QUALITY INDICATOR MERGED RATES                --- ;
 * ---------------------------------------------------------------- ;

 DATA   OUTA3.&OUTFILA3.;
 MERGE  INA2.&INFILEA2.(
             KEEP=MAREA POPCAT SEXCAT RACECAT _TYPE_ 
                  TAPQ09 PAPQ09 OAPQ09)
             RISKADJ(KEEP=MAREA POPCAT SEXCAT RACECAT
                          EAPQ09 RAPQ09 LAPQ09 UAPQ09 SAPQ09 XAPQ09);
 BY     MAREA POPCAT SEXCAT RACECAT;

 ARRAY ARRY1{1} EAPQ09;
 ARRAY ARRY2{1} RAPQ09;
 ARRAY ARRY3{1} LAPQ09;
 ARRAY ARRY4{1} UAPQ09;
 ARRAY ARRY5{1} SAPQ09;
 ARRAY ARRY6{1} XAPQ09;
 ARRAY ARRY7{1} PAPQ09;

 DO I = 1 TO 1;
   IF ARRY7(I) <= 2 THEN DO;
      ARRY1(I) = .; ARRY2(I) = .; ARRY3(I) = .; ARRY4(I) = .;
      ARRY5(I) = .; ARRY6(I) = .; 
   END;
 END;

 DROP I;

 FORMAT EAPQ09
		LAPQ09
		OAPQ09
		RAPQ09
		SAPQ09
		UAPQ09
		XAPQ09 13.7
		TAPQ09
		PAPQ09 13.0;

 RUN;

 * ---------------------------------------------------------------- ;
 * --- CONTENTS AND MEANS OF MAREA MERGED MEANS FILE             --- ;
 * ---------------------------------------------------------------- ;

 PROC CONTENTS DATA=OUTA3.&OUTFILA3. POSITION;
 RUN;

 *PROC MEANS DATA=OUTA3.&OUTFILA3.(WHERE=(_TYPE_ IN (8))) N NMISS MIN MAX MEAN SUM;
 *TITLE4  'SUMMARY OF AREA-LEVEL RATES (_TYPE_=8)';
 *RUN;

 
***----- TO PRINT VARIABLE LABELS COMMENT (DELETE) "NOLABELS" FROM PROC MEANS STATEMENTS -------***;

PROC MEANS DATA=OUTA3.&OUTFILA3. (WHERE=(_TYPE_ IN (8))) N NMISS MIN MAX SUM NOLABELS;
   VAR TAPQ09 ;
   TITLE  'SUMMARY OF PATIENT QUALITY AREA-LEVEL INDICATOR OVERALL NUMERATOR (SUM) WHEN _TYPE_=8';
RUN; QUIT;

PROC MEANS DATA=OUTA3.&OUTFILA3. (WHERE=(_TYPE_ IN (8))) N NMISS MIN MAX SUM NOLABELS;
   VAR PAPQ09;
   TITLE  'SUMMARY OF PATIENT QUALITY AREA-LEVEL INDICATOR OVERALL DENOMINATOR (SUM) WHEN _TYPE_=8';
RUN; QUIT;

PROC MEANS DATA=OUTA3.&OUTFILA3. (WHERE=(_TYPE_ IN (8))) N NMISS MIN MAX MEAN NOLABELS;
   VAR OAPQ09 EAPQ09 RAPQ09 SAPQ09  ;
   TITLE  'SUMMARY OF PATIENT QUALITY AREA-LEVEL INDICATOR AVERAGE RATES(MEAN) WHEN _TYPE_=8';
RUN; QUIT;

 * ---------------------------------------------------------------- ;
 * --- PRINT AREA MERGED MEANS FILE                             --- ;
 * ---------------------------------------------------------------- ;

 %MACRO PRT2;

 %IF &PRINT. = 1 %THEN %DO;

 %MACRO PRT(PD,TEXT);

 PROC   PRINT DATA=OUTA3.&OUTFILA3. LABEL SPLIT='*';
 VAR    MAREA POPCAT SEXCAT RACECAT 
        TA&PD. PA&PD. OA&PD. EA&PD. RA&PD. LA&PD. UA&PD. SA&PD. XA&PD.;
 LABEL MAREA    = "MAREA"
       POPCAT   = "POPCAT"
       SEXCAT   = "SEXCAT"
       RACECAT  = "RACECAT"
       TA&PD. = "TA&PD.*(Numerator)"
       PA&PD. = "PA&PD.*(Denominator)"
       OA&PD. = "OA&PD.*(Observed)"
       EA&PD. = "EA&PD.*(Expected)"
       RA&PD. = "RA&PD.*(Risk Adj)"
       LA&PD. = "LA&PD.*(Lower CL)"
       UA&PD. = "UA&PD.*(Upper CL)"
       SA&PD. = "SA&PD.*(Smoothed)"
       XA&PD. = "XA&PD.*(Smthe SE)"
       ;
 FORMAT POPCAT POPCAT.   
        SEXCAT SEXCAT.
        RACECAT RACECAT.
	  TA&PD. PA&PD. COMMA13.0
        OA&PD. EA&PD. RA&PD. LA&PD. UA&PD. SA&PD. XA&PD. 8.6;

 TITLE4 "FINAL OUTPUT";
 TITLE5 "Indicator &PD.: &TEXT";
 RUN;

 %MEND PRT;

 %PRT(PQ09,Low Birth Weight Rate);

 %END;

 %MEND PRT2 ;

 %PRT2;

 * ---------------------------------------------------------------- ;
 * --- WRITE SAS OUTPUT DATA SET TO TEXT FILE                   --- ;
 * ---------------------------------------------------------------- ;

 %MACRO TEXT;

 %IF &TEXTA3. = 1  %THEN %DO;

 DATA _NULL_;
 SET OUTA3.&OUTFILA3;
 FILE PDTEXTA3 LRECL=2000;
 IF _N_=1 THEN PUT "MAREA" "," "Age"  "," "Sex"  "," "Race"  ","  "Type" ","
 "TAPQ09" "," 
 "PAPQ09" "," 
 "OAPQ09" "," 
 "EAPQ09" "," 
 "RAPQ09" "," 
 "LAPQ09" "," 
 "UAPQ09" "," 
 "SAPQ09" "," 
 "XAPQ09"  
 ;

 PUT MAREA  $5. "," POPCAT 3. "," SEXCAT 3. "," RACECAT 3. "," _TYPE_ 2. ","
 (TAPQ09) (7.0 ",")
  ","
 (PAPQ09) (13.2 ",")
 ","
 (OAPQ09) (12.10 ",")
 ","
 (EAPQ09) (12.10 ",")
 ","
 (RAPQ09) (12.10 ",")
 ","
 (LAPQ09) (12.10 ",")
 ","
 (UAPQ09) (12.10 ",")
 ","
 (SAPQ09) (12.10 ",")
 ","
 (XAPQ09) (12.10 ",")
 ;
 RUN;

 %END;

 %MEND TEXT;

 %TEXT;
