*===================== PROGRAM: PQ09_PDFMTS.SAS =============================;
*============================================================================;
* Title:
*     Format Library for PATIENT QUALITY INDICATOR PQI-09 Program;
*
* Description:
*     FORMAT LIB FOR AHRQ PEDIATRIC QUALITY INDICATORS;
*     NOTE THAT THIS PATIENT QUALITY INDICATOR PQI-09 IS INCLUDED IN PEDIATRIC 
*     QUALITY INDICATOR MODULE (PDI) 
*
*              >>>       VERSION 5.0.3 - FEBRUARY, 2016         <<<
*
*     Note: Codes valid from 10/1/1994 to 11/30/2015 (FY 2015)
*  
* 
*============================================================================;
FILENAME CONTROL "C:\PATHNAME\CONTROL_PQ09.SAS";          *<==USER MUST modify;

%INCLUDE CONTROL;


PROC FORMAT DDNAME=LIBRARY;

 /* -------------------------------------------------------------- */
 /* --- FORMATS FOR STRATIFIERS ---------------------------------- */
 /* -------------------------------------------------------------- */

 /* --- FORMAT FOR SEX CATEGORY ---------------------------------- */
VALUE SEXCAT
 1 = 'Male'
 2 = 'Female'
  ;

 /* --- FORMAT FOR AGE CATEGORY ---------------------------------- */
VALUE PAGECAT
 1 = "<1"
 2 = "1 TO 2"
 3 = "3 TO 5"
 4 = "6 TO 12"
 5 = "13 TO 17"
 ;

 /* --- FORMAT FOR AGEDAY CATEGORY ------------------------------- */
VALUE AGEDCAT
 0 = "NA"
 1 = "0 TO 28"
 2 = "29 TO 60"
 3 = "61 TO 90"
 4 = "91+"
 ;

 /* --- FORMAT FOR BIRTH WEIGHT CATEGORY ------------------------- */
VALUE BWHTCAT
 0 = "NA"
 1 = "0 TO 499g"
 2 = "500 TO 749g"
 3 = "750 TO 999g"
 4 = "1000 TO 1249g"
 5 = "1250 TO 1499g"
 6 = "1500 TO 1749g"
 7 = "1750 TO 1999g"
 8 = "2000 TO 2499g"
 9 = "2500g or more"
 ;

 /* --- FORMAT FOR RACE CATEGORY --------------------------------- */
VALUE RACECAT
 1 = 'White'
 2 = 'Black'
 3 = 'Hispanic'
 4 = 'Asian and NH/PI'
 5 = 'Amer Indian/AN'
 6 = 'Other'
  ;

 /* --- FORMAT FOR PAYER CATEGORY ---------------------------------- */
VALUE PAYCAT
 1 = 'Medicare'
 2 = 'Medicaid'
 3 = 'Private'
 4 = 'Self Pay'
 5 = 'No Charge'
 6 = 'Other'
  ;

 /* --- FORMAT FOR POPULATION CATEGORY ----------------------------- */
VALUE POPCAT
 1 = '0 to 4'
 2 = '5 to 9'
 3 = '10 to 14'
 4 = '15 to 17'
  ;

/* -------------------------------------------------------------- */
 /* --- FORMATS FOR stratification variables--------------------- */
 /* -------------------------------------------------------------- */

  /* ---ACCIDENTAL PUNCTURE AND LACERATION------------- */

  VALUE GP01CAT
  1='Eye, ear, nose, mouthm throat, skin, breast and other low-risk procedures'
  2='Thoracic, cardiovascular, and specified neoplastic procedures'
  3='Kidney, and male/female reproductive procedures'
  4='Infectious, immunological, hematological, and ungroupable procedures'
  5='Trauma, orthopedic, and neurologic procedures'
  6='Gastrointestinal, hepatobiliary, and endocrine procedures';


  /* --- DECUBITUS ULCER------------- */

  VALUE GP02CAT
  1='Low risk'
  2='High risk';


  /* --- POSTOPERATIVE HEMORRHAGE OR HEMATOMA------------- */

  VALUE GP08CAT
  1='Low risk'
  2='High risk';

  /* --- POSTOPERATIVE SEPSIS------------- */

  VALUE GP10CAT
  1='Clean, elective'
  2='Clean, non-elective'
  3='Contaminated, elective'
  4='Contaminated, non-elective'
  5='Dirty';


  /* --- POSTOPERATIVE WOUND DEHISCENCE------------- */

  VALUE GP11CAT
  1='Clean, elective'
  2='Clean, non-elective'
  3='Contaminated, elective'
  4='Contaminated, non-elective'
  5='Dirty';


   /* --- SELECTED INFECTION DUE TO MEDICAL CARE----- */

 VALUE GP12CAT
  1='Low risk immunodeficient'
  2='Intermediate risk immunodeficient'
  3='High risk immunodeficient';


 * -------------------------------------------------------------- ;
 * --- PDI DEFINING FORMATS ------------------------------------- ;
 * -------------------------------------------------------------- ;

 * -------------------------------------------------------------- ;
 * --- FORMATS - PROVIDER AND AREA LEVEL INDICATORS ------------- ;
 * -------------------------------------------------------------- ;


 /* ----------------------------------------- */
 /* Palliative Care                           */
 /* ----------------------------------------- */

VALUE $PALLIAD
'V667 ' = '1' /* ENCOUNTR PALLIATIVE CARE */
OTHER = '0' ;

 /* ------------------------------ */
 /* NEONATE AND NEWBORN            */
 /* ------------------------------ */

 /* Liveborn (Populaton at Risk)           */
 /* ICD-9-CM Diagnosis Codes:              */

VALUE $LIVEBND
'V3000' = 1  /* SINGLE LB IN-HOSP W/O CS */
'V3001' = 1  /* SINGLE LB IN-HOSP W CS */
'V3100' = 1  /* TWIN-MATE LB-HOSP W/O CS */
'V3101' = 1  /* TWIN-MATE LB-IN HOS W CS */
'V3200' = 1  /* TWIN-MATE SB-HOSP W/O CS */
'V3201' = 1  /* TWIN-MATE SB-HOSP W CS */
'V3300' = 1  /* TWIN-NOS-IN HOSP W/O CS */
'V3301' = 1  /* TWIN-NOS-IN HOSP W CS */
'V3400' = 1  /* OTH MULT LB-HOSP W/O CS */
'V3401' = 1  /* OTH MULT LB-IN HOSP W CS */
'V3500' = 1  /* OTH MULT SB-HOSP W/O CS */
'V3501' = 1  /* OTH MULT SB-IN HOSP W CS */
'V3600' = 1  /* MULT LB/SB-IN HOS W/O CS */
'V3601' = 1  /* MULT LB/SB-IN HOSP W CS */
'V3700' = 1  /* MULT BRTH NOS-HOS W/O CS */
'V3701' = 1  /* MULT BIRTH NOS-HOSP W CS */
'V3900' = 1  /* LIVEBORN NOS-HOSP W/O CS */
'V3901' = 1  /* LIVEBORN NOS-HOSP W CS */
OTHER   = 0 ;

VALUE $V29D
"V290"  = "1" /* OBSERVATIONS FOR SUSPECTED INFECTIOUS CONDITION */
"V291"  = "1" /* OBSERVATIONS FOR SUSPECTED NEUROLOGICAL CONDITION */
"V292"  = "1" /* OBSERVATIONS FOR SUSPECTED RESPIRATORY CONDITION */
"V293"  = "1" /* OBSERVATIONS FOR SUSPECTED GENETIC OR METABOLIC CONDITION */
"V298"  = "1" /* OBSERVATIONS FOR OTHER SPECIFIED SUSPECTED CONDITION */
"V299"  = "1" /* OBSERVATIONS FOR UNSPECIFIED SUSPECTED CONDITION */
OTHER   = "0";

VALUE $LIVEB2D
'V301 ' = 1  /* SINGL LIVEBRN-BEFORE ADM */
'V302 ' = 1  /* SINGLE LIVEBORN-NONHOSP */
'V311 ' = 1  /* TWIN, MATE LB-BEFORE ADM */
'V312 ' = 1  /* TWIN, MATE LB-NONHOSP */
'V321 ' = 1  /* TWIN, MATE SB-BEFORE ADM */
'V322 ' = 1  /* TWIN, MATE SB-NONHOSP */
'V331 ' = 1  /* TWIN NOS-BEFORE ADMISSN */
'V332 ' = 1  /* TWIN NOS-NONHOSP */
'V341 ' = 1  /* OTH MULT NB-BEFORE ADM */
'V342 ' = 1  /* OTH MULTIPLE NB-NONHOSP */
'V351 ' = 1  /* OTH MULT SB-BEFORE ADM */
'V352 ' = 1  /* OTH MULTIPLE SB-NONHOSP */
'V361 ' = 1  /* MULT NB/SB-BEFORE ADM */
'V362 ' = 1  /* MULTIPLE NB/SB-NONHOSP */
'V371 ' = 1  /* MULT BRTH NOS-BEFORE ADM */
'V372 ' = 1  /* MULT BIRTH NOS-NONHOSP */
'V391 ' = 1  /* LIVEBORN NOS-BEFORE ADM */
'V392 ' = 1  /* LIVEBORN NOS-NONHOSP */
OTHER   = 0 ;

 /* ---------------------------------------------------------------- */
 /* ADULT DRGS                                                       */
 /* ---------------------------------------------------------------- */

 /* DIAGNOSTIC RELATED GROUPS (DRGS): */

VALUE $ADULTDR
"001" = "1" /* CRANIOTOMY, AGE GREATER THAN 17 EXCEPT FOR TRAUMA */
"002" = "1" /* CRANIOTOMY FOR TRAUMA, AGE GREATER THAN 17 */
"024" = "1" /* SEIZURE AND HEADACHE, AGE GREATER THAN 17 WITH CC */
"025" = "1" /* SEIZURE AND HEADACHE, AGE GREATER THAN 17 WITHOUT CC */
"028" = "1" /* TRAUMATIC STUPOR AND COMA, COMA LESS THAN ONE HOUR, AGE GREATER THAN 17 WITH CC */
"029" = "1" /* TRAUMATIC STUPOR AND COMA, COMA LESS THAN ONE HOUR, AGE GREATER THAN 17 WITHOUT CC */
"031" = "1" /* CONCUSSION, AGE GREATER THAN 17 WITH CC */
"032" = "1" /* CONCUSSION, AGE GREATER THAN 17 WITHOUT CC */
"040" = "1" /* EXTRAOCULAR PROCEDURES EXCEPT ORBIT, AGE GREATER THAN 17 */
"046" = "1" /* OTHER DISORDERS OF THE EYE, AGE GREATER THAN 17 WITH CC */
"047" = "1" /* OTHER DISORDER OF THE EYE, AGE GREATER THAN 17 WITHOUT CC */
"053" = "1" /* SINUS AND MASTOID PROCEDURES, AGE GREATER THAN 17 */
"057" = "1" /* TONSILLECTOMY AND ADENOIDECTOMY PROCEDURES EXCEPT TONSILLECTOMY AND/OR ADENOIDECTOMY ONLY, AGE GREATER THAN 17 */
"059" = "1" /* TONSILLECTOMY AND/OR ADENOIDECTOMY ONLY, AGE GREATER THAN 17 */
"061" = "1" /* MYRINGOTOMY WITH TUBE INSERTION, AGE GREATER THAN 17 */
"068" = "1" /* OTITIS MEDIA AND URI, AGE GREATER THAN 17 WITH CC */
"069" = "1" /* OTITIS MEDIA AND URI, AGE GREATER THAN 17 WITHOUT CC */
"073" = "1" /* OTHER EAR, NOSE, MOUTH AND THROAT DIAGNOSES, AGE GREATER THAN 17 */
"079" = "1" /* RESPIRATORY INFECTIONS AND INFLAMMATIONS, AGE GREATER THAN 17 WITH CC */
"080" = "1" /* RESPIRATORY INFECTIONS AND INFLAMMATIONS, AGE GREATER THAN 17 WITHOUT CC */
"089" = "1" /* SIMPLE PNEUMONIA AND PLEURISY, AGE GREATER THAN 17 WITH CC */
"090" = "1" /* SIMPLE PNEUMONIA AND PLEURISY, AGE GREATER THAN 17 WITHOUT CC */
"096" = "1" /* BRONCHITIS AND ASTHMA, AGE GREATER THAN 17 WITH CC */
"097" = "1" /* BRONCHITIS AND ASTHMA, AGE GREATER THAN 17 WITHOUT CC */
"135" = "1" /* CARDIAC CONGENITAL AND VALVULAR DISORDERS, AGE GREATER THAN 17 WITH CC */
"136" = "1" /* CARDIAC CONGENITAL AND VALVULAR DISORDERS, AGE GREATER THAN 17 WITHOUT CC */ 
"154" = "1" /* STOMACH, ESOPHAGEAL AND DUODENAL PROCEDURES, AGE GREATER THAN 17 WITH CC */
"155" = "1" /* STOMACH, ESOPHAGEAL AND DUODENAL PROCEDURES, AGE GREATER THAN 17 WIHOUT CC*/
"159" = "1" /* HERMIA PROCEDURES EXCEPT INGUINAL AND FEMORAL , AGE GREATER THAN 17 WITH CC */
"160" = "1" /* HERNIA PROCEDURES EXCEPT INGUINAL AND FEMORAL, AGE GREATER THAN 17 WITHOUT CC */
"161" = "1" /* INGUINAL AND FEMORAL HERNIA PROCEDURES, AGE GREATER THAN 17 WITH CC */
"162" = "1" /* INGUINAL AND FEMORAL HERNIA PROCEDURES, AGE GREATER THAN 17 WITHOUT CC */
"182" = "1" /* ESOPHAGITIS, GASTROENTERITIS AND MISCELLANEOUS DIGESTIVE DISORDERS, AGE GREATER THAN 17 WITH CC */
"183" = "1" /* ESOPHAGITIS, GASTROENTERITIS AND MISCELLANEOUS DIGESTIVE DISORDERS, AGE GREATER THAN 17 WITHOUT CC */
"185" = "1" /* DENTAL AND ORAL DISEASES EXCEPT EXTRACTIONS AND RESTORATIONS, AGE GREATER THAN 17 */
"188" = "1" /* OTHER DIGESTIVE SYSTEM DIAGNOSES, AGE GREATER THAN 17 WITH CC */
"189" = "1" /* OTHER DIGESTIVE SYSTEM DIAGNOSES, AGE GREATER THAN 17 WITHOUT CC */
"210" = "1" /* HIP AND FEMUR PROCEDURES EXCEPT MAJOR JOINT PROCEDURES, AGE GREATER THAN 17 WITH CC */
"211" = "1" /* HIP AND FEMUR PROCEDURES EXCEPT MAJOR JOINT PROCEDURES, AGE GREATER THAN 17 WITHOUT CC */
"218" = "1" /* LOWER EXTREMITY AND HUMERUS PROCEURES EXCEPT HIP, FOOT AND FEMUR, AGE GREATER THAN 17 WITH CC */
"219" = "1" /* LOWER EXTREMITY AND HUMERUS PROCEDURES EXCEPT HIP, FOOT AND FEMUR, AGE GREATER THAN 17 WITHOUT CC */
"250" = "1" /* FRACTURES, SPRAINS, STRAINS AND DISLOCATIONS OF FOREARM, HAND AND FOOT, AGE GREATER THAN 17 WITH CC */
"251" = "1" /* FRACTURES, SPRAINS, STRAINS AND DISLOCATIONS OF FOREARM, HAND AND FOOT, AGE GREATER THAN 17 WITHOUT CC */
"253" = "1" /* FRACTURES, SPRAINS, STRAINS AND DISLOCATIONS OF UPPER ARM AND LOWER LEG EXCEPT FOOT, AGE GREATER THAN 17 WITH CC */
"254" = "1" /* FRACTURES, SPRAINS, STRAINS AND DISLOCATIONS OF UPPER ARM AND LOWER LEG EXCEPT FOOT, AGE GREATER THAN 17 WITHOUT CC */
"277" = "1" /* CELLULITIS, AGE GREATER THAN 17 WITH CC */
"278" = "1" /* CELLULTIIS, AGE GREATER THAN 17 WITHOUT CC */
"280" = "1" /* TRAUMA TO SKIN, SUBCUTANEOUS TISSUE AND BREAST, AGE GREATER THAN 17 WITH CC */
"281" = "1" /* TRAUMA TO SKIN, SUBCUTANEOUS TISSUE AND BREAST, AGE GREATER THAN 17 WITHOUT CC */
"294" = "1" /* DIABETES, AGE GREATER THAN 35 */
"296" = "1" /* NUTRITIONAL AND MISCELLANEOUS METABOLIC DISORDERS, AGE GREATER THAN 17 WITH CC */
"297" = "1" /* NUTRITIONAL AND MISCELLANEOUS METABOLIC DISORDERS, AGE GREATER THAN 17 WITHOUT CC */
"312" = "1" /* URETHRAL PROCEDURES, AGE GREATER THAN 17 WITH CC */
"313" = "1" /* URETHRAL PROCEDURES, AGE GREATER THAN 17 WITHOUT CC */
"320" = "1" /* KIDNEY AND URINARY TRACT INFECTIONS, AGE GREATER THAN 17 WITH CC */
"321" = "1" /* KIDNEY AND URINARY TRACT INFECTIONS, AGE GREATER THAN 17 WITHOUT CC */
"325" = "1" /* KIDNEY AND URINARY TRACT SIGNS AND SYMPTOMS, AGE GREATER THAN 17 WITH CC */
"326" = "1" /* KIDNEY AND URINARY TRACT SIGNS AND SYMPTOMS, AGE GREATER THAN 17 WITHOUT CC */
"328" = "1" /* URETHRAL STRICTURE, AGE GREATER THAN 17 WITH CC */
"329" = "1" /* URETHRAL STRICTURE, AGE GREATER THAN 17 WITHOUT CC */
"331" = "1" /* OTHER KIDNEY AND URINARY TRACT DIAGNOSES, AGE GREATER THAN 17 WITH CC */
"332" = "1" /* OTHER KIDNEY AND URINARY TRACT DIAGNOSES, AGE GREATER THAN 17 WITHOUT CC */
"339" = "1" /* TESTES PROCEDURES FOR NONMALIGNANCY, AGE GREATER THAN 17 */
"342" = "1" /* CIRCUMCISION, AGE GREATER THAN 17 */
"392" = "1" /* SPLENECTOMY, AGE GREATER THAN 17 */
"395" = "1" /* RED BLOOD CELL DISORDERS, AGE GREATER THAN 17 */
"416" = "1" /* SEPTICEMIA, AGE GREATER THAN 17 */
"419" = "1" /* FEVER OF UNKNOWN ORIGIN, AGE GREATER THAN 17 WITH CC */
"420" = "1" /* FEVER OF UNKNOWN ORIGIN, AGE GREATER THAN 17 WITHOUT CC */
"421" = "1" /* VIRAL ILLNESS, AGE GREATER THAN 17 */
"444" = "1" /* TRAUMATIC INJURY, AGE GREATER THAN 17 WITH CC */
"445" = "1" /* TRAUMATIC INJURY, AGE GREATER THAN 17 WITHOUT CC */
"447" = "1" /* ALLERGIC REACTIONS, AGE GREATER THAN 17 */
"449" = "1" /* POISONING AND TOXIC EFFECTS OF DRUGS, AGE GREATER THAN 17 WITH CC */
"450" = "1" /* POISONING AND TOXIC EFFECTS OF DRUGS, AGE GREATER THAN 17 WITHOUT CC */
"473" = "1" /* ACUTE LEUKEMIA WITHOUT MAJOR OR PROCEDURE, AGE GREATER THAN 17 */
"562" = "1" /* SEIZURE AGE > 17 W CC */
"563" = "1" /* SEIZURE AGE > 17 W/O CC */
"564" = "1" /* HEADACHES AGE >17 */
"567" = "1" /* STOMACH, ESOPHAGEAL & DUODENAL PROC AGE > 17 W CC W MAJOR GI DX */
"568" = "1" /* STOMACH, ESOPHAGEAL & DUODENAL PROCEDURES PROC AGE > 17 W CC W/O MAJOR GI DX */
"575" = "1" /* SEPTICEMIA W MV96+ HOURS  AGE  >17 */
"576" = "1" /* SEPTICEMIA W/O MV96+ HOURS AGE  >17 */
OTHER  = "0" ;

 /* ---------------------------------------------------------------- */
 /* MEDICAL DRGS (deleted Adult DRGs)                                */
 /* ---------------------------------------------------------------- */

 /* DIAGNOSTIC RELATED GROUPS (DRGS): */

VALUE $MEDICDR
"009" = "1" /* SPINAL DISORDERS AND INJURIES */
"010" = "1" /* NERVOUS SYSTEM NEOPLASMS WITH CC */
"011" = "1" /* NERVOUS SYSTEM NEOPLASMS WITH CC */
"012" = "1" /* DEGENERATIVE NERVOUS SYSTEM DISORDERS */
"013" = "1" /* MULTIPLE SCLEROSIS AND CEREBELLAR ATAXIA */
"014" = "1" /* SPECIFIC CEREBROVASCULAR DISORDERS EXCEPT TRANSIENT ISCHEMIC ATTACK */
"015" = "1" /* TRANSIENT ISCHEMIC ATTACK AND PRECEREBRAL OCCLUSIONS */
"016" = "1" /* NONSPECIFIC CEREBROVASCULAR DISORDERS WITH CC */
"017" = "1" /* NONSPECIFIC CEREBROVASCULAR DISORDERS WITHOUT CC */
"018" = "1" /* CRANIAL AND PERIPHERAL NERVE DISORDERS WITH CC */
"019" = "1" /* CRANIAL AND PERIPHERAL NERVE DISORDERS WITHOUT CC */
"020" = "1" /* NERVOUS SYSTEM INFECTION EXCEPT VIRAL MENINGITIS */
"021" = "1" /* VIRAL MENINGITIS */
"022" = "1" /* HYPERTENSIVE ENCEPHALOPATHY */
"023" = "1" /* NONTRAUMATIC STUPOR AND COMA */
"026" = "1" /* SEIZURE AND HEADACHE, AGE 0-17 */
"027" = "1" /* TRAUMATIC STUPOR AND COMA, COMA GREATER THAN ONE HOUR */
"030" = "1" /* TRAUMATIC STUPOR AND COMA, COMA LESS THAN ONE HOUR, AGE 0-17 */
"033" = "1" /* CONCUSSION, AGE 0-17 */
"034" = "1" /* OTHER DISORDERS OF NERVOUS SYSTEM WITH CC */
"035" = "1" /* OTHER DISORDERS OF NERVOUS SYSTEM WITHOUT CC */
"043" = "1" /* HYPHEMA */
"044" = "1" /* ACUTE MAJOR EYE INFECTIONS */
"045" = "1" /* NEUROLOGICAL EYE DISORDERS */
"048" = "1" /* OTHER DISORDERS OF THE EYE, AGE 0-17 */
"064" = "1" /* EAR, NOSE, MOUTH AND THROAT MALIGNANCY */
"065" = "1" /* DISEQUILIBRIA */
"066" = "1" /* EPISTAXIS */
"067" = "1" /* EPIGLOTTITIS */
"070" = "1" /* OTITIS MEDIA AND URI, AGE 0-17 */
"071" = "1" /* LARYNGOTRACHEITIS */
"072" = "1" /* NASAL TRAUMA AND DEFORMITY */
"074" = "1" /* OTHER EAR, NOSE, MOUTH AND THROAT DIAGNOSES, AGE 0-17 */
"078" = "1" /* PULMONARY EMBOLISM */
"081" = "1" /* RESPIRATORY INFECTIONS AND INFLAMMATIONS, AGE 0-17 */
"082" = "1" /* RESPIRATORY NEOPLASMS */
"083" = "1" /* MAJOR CHEST TRAUMA WITH CC */
"084" = "1" /* MAJOR CHEST TRAUMA WITHOUT CC*/
"085" = "1" /* PLEURAL EFFUSION WITH CC */
"086" = "1" /* PLEURAL EFFUSION WITHOUT CC */
"087" = "1" /* PULMONARY EDEMA AND RESPIRATORY FAILURE */
"088" = "1" /* CHRONIC OBSTRUCTIVE PULMONARY DISEASE */
"091" = "1" /* SIMPLE PNEUMONIA AND PLEURISY, AGE 0-17 */
"092" = "1" /* INTERSTITIAL LUNG DISEASE WITH CC */
"093" = "1" /* INTERSTITIAL LUNG DISEASE WITHOUT CC */
"094" = "1" /* PNEUMOTHORAX WITH CC */
"095" = "1" /* PNEUMOTHORAX WITHOUT CC */
"098" = "1" /* BRONCHITIS AND ASTHMA, AGE 0-17 */
"099" = "1" /* RESPIRATORY SIGNS AND SYMPTOMS WITH CC */
"100" = "1" /* RESPIRATORY SIGNS AND SYMPTOMS WITHOUT CC */
"101" = "1" /* OTHER RESPIRATORY SYSTEM DIAGNOSES WITH CC */
"102" = "1" /* OTHER RESPIRATORY SYSTEM DIAGNOSES WITHOUT CC */
"121" = "1" /* CIRCULATORY DISORDERS WITH ACUTE MYOCARDIAL INFARCTION AND MAJOR COMPLICATION, DISCHARGED ALIVE */
"122" = "1" /* CIRCULATORY DISORDERS WITH ACUTE MYOCARDIAL INFARCTION WITHOUT MAJOR COMPLICATION, DISCHARGED ALIVE */
"123" = "1" /* CIRCULATORY DISORDERS WITH ACUTE MYOCARDIAL INFARCTION, EXPIRED */
"124" = "1" /* CIRCULATORY DISORDERS EXCEPT ACUTE MYOCARDIAL INFARCTION WITH CARDIAC CATHETERIZATION AND COMPLEX DIAGNOSIS */
"125" = "1" /* CIRCULATORY DISORDERS EXCEPT ACUTE MYOCARDIAL INFARCTION WITH CARDIAC CATHETERIZATION WITHOUT COMPLEX DIAGNOSIS */
"126" = "1" /* ACUTE AND SUB ACUTE ENDOCARDITIS */
"127" = "1" /* HEART FAILURE AND SHOCK */
"128" = "1" /* DEEP VEIN THROMBOPHLEBITIS */
"129" = "1" /* CARDIAC ARREST, UNEXPLAINED */
"130" = "1" /* PERIPHERAL VASCULAR DISORDERS WITH CC */
"131" = "1" /* PERIPHERAL VASCULAR DISORDERS WITHOUT CC */
"132" = "1" /* ATHEROSCLEROSIS WITH CC */
"133" = "1" /* ATHEROSCLEROSIS WITHOUT CC */
"134" = "1" /* HYPERTENSION */
"137" = "1" /* CARDIAC CONGENITAL AND VALVULAR DISORDERS, AGE 0 - 17*/
"138" = "1" /* CARDIAC ARRHYTHMIA AND CONDUCTION DISORDERS WITH CC */
"139" = "1" /* CARDIAC ARRHYTHMIA AND CONDUCTION DISORDERS WITHOUT CC */
"140" = "1" /* ANGINA PECTORIS*/
"141" = "1" /* SYNCOPE AND COLLAPSE WITH CC */
"142" = "1" /* SYNCOPE AND COLLAPSE WITHOUT CC */
"143" = "1" /* CHEST PAIN */
"144" = "1" /* OTHER CIRCULATORY SYSTEM DIAGNOSES WITH CC*/
"145" = "1" /* OTHER CIRCULATORY SYSTEM DIAGNOSES WITHOUT CC */
"172" = "1" /* DIGESTIVE MALIGNANCY WITH CC */
"173" = "1" /* DIGESTIVE MALIGNANCY WITHOUT CC */
"174" = "1" /* GI HEMORRHAGE WITH CC*/
"175" = "1" /* GI HEMORRHAGE WITHOUT CC */
"176" = "1" /* COMPLICATED PEPTIC ULCER */
"177" = "1" /* UNCOMPLICATED PEPTIC ULCER WITH CC */
"178" = "1" /* UNCOMPLICATED PEPTIC ULCER WITHOUT CC*/
"179" = "1" /* INFLAMMATORY BOWEL DISEASE */
"180" = "1" /* GI OBSTRUCTION WITH CC */
"181" = "1" /* GI OBSTRUCTION WITHOUT CC */
"184" = "1" /* ESOPHAGITIS, GASTROENTERITIS AND MISCELLANESOU DIGESTIVE DISORDERS, AGE 0-17 */
"186" = "1" /* DENTAL AND ORAL DISEASED EXCEPT EXTRACTIONS AND RESTORATIONS, AGE 0-17 */
"187" = "1" /* DENTAL EXTRACTIONS AND RESTORATIONS */
"190" = "1" /* OTHER DIGESTIVE SYSTEM DIAGNOSES, AGE 0-17 */
"202" = "1" /* CIRRHOSIS AND ALCOHOLIC HEPATITIS */
"203" = "1" /* MALIGNANCY OF HEPATOBILIARY SYSTEM OR PANCREAS */
"204" = "1" /* DISORDERS OF PANCREAS EXCEPT MALIGNANCY */
"205" = "1" /* DISORDERS OF LIVER EXCEPT MALIGNANCY, CIRRHOSIS AND ALCOHOLIC HEPATITIS WITH CC */
"206" = "1" /* DISORDERS OF LIVER EXCEPT MALIGNANCY, CIRRHOSIS AND ALCOHOLIC HEPATITIS WITHOUT CC */
"207" = "1" /* DISORDERS OF THE BILIARY TRACT WITH CC */
"208" = "1" /* DISORDERS OF THE BILIARY TRACT WITHOUT CC */
"235" = "1" /* FRACTURES OF FEMUR */
"236" = "1" /* FRACTURES OF HIP AND PELVIS */
"237" = "1" /* SPRAINS, STRAINS AND DISLOCATIONS OF HIP, PELVIS AND THIGH */
"238" = "1" /* OSTEOMYELITIS */
"239" = "1" /* PATHOLOGICAL FRACTURES AND MUSCULOSKELETAL AND CONNECTIVE TISSUE MALIGNANCY */
"240" = "1" /* CONNECTIVE TISSUE DISORDERS WITH CC */
"241" = "1" /* CONNECTIVE TISSUE DISORDERS WITHOUT CC */
"242" = "1" /* SEPTIC ARTHRITIS */
"243" = "1" /* MEDICAL BACK PROBLEMS */
"244" = "1" /* BONE DISEASES AND SPECIFIC ARTHROPATHIES WITH CC */
"245" = "1" /* BONE DISEASES AND SPECIFIC ARTHROPATHIES WITHOUT CC */
"246" = "1" /* NONSPECIFIC ARTHROPATHIES */
"247" = "1" /* SIGNS AND SYMPTOMS OF MUSCULOSKELETAL SYSTEM AND CONNECTIVE TISSUE */
"248" = "1" /* TENDONITIS, MYOSITIS AND BURSITIS */
"249" = "1" /* AFTERCARE, MUSCULOSKELETAL SYSTEM AND CONNECTIVE TISSUE */
"252" = "1" /* FRACTURES, SPRAINS, STRAINS AND DISLOCATIONS OF FOREARM, HAND AND FOOT, AGE 0-17 */
"255" = "1" /* FRACTURES, SPRAINS, STRAINS AND DISLOCATIONS OF UPPER ARM AND LOWER LEG EXCEPT FOOT, AGE 0-17 */
"256" = "1" /* OTHER MUSCULOSKELETAL SYSTEM AND CONNECTIVE TISSUE DIAGNOSES */
"271" = "1" /* SKIN ULCERS */
"272" = "1" /* MAJOR SKIN DISORDERS WITH CC */
"273" = "1" /* MAJOR SKIN DISORDERS WITHOUT CC */
"274" = "1" /* MALIGNANT BREAST DISORDERS WITH CC */
"275" = "1" /* MALIGNANT BREAST DISORDERS WITHOUT CC */
"276" = "1" /* NONMALIGNANT BREAST DISORDERS */
"279" = "1" /* CELLULITIS, AGE 0-17 */
"282" = "1" /* TRAUMA TO SKIN, SUBCUTANEOUS TISSUE AND BREAST, AGE 0-17 */
"283" = "1" /* MINOR SKIN DISORDERS WITH CC */
"284" = "1" /* MINOR SKIN DISORDERS WITHOUT CC */
"295" = "1" /* DIABETES, AGE 0-35 */
"298" = "1" /* NUTRITIONAL AND MISCELLANEOUS METABOLIC DISORDERS, AGE 0-17 */
"299" = "1" /* INBORN ERRORS OF METABOLISM */
"300" = "1" /* ENDOCRINE DISORDERS WITH CC */
"301" = "1" /* ENDOCRINE DISORDERS WITHOUT CC */
"316" = "1" /* RENAL FAILURE */
"317" = "1" /* ADMISSION FOR RENAL DIALYSIS */
"318" = "1" /* KIDNEY AND URINARY TRACT NEOPLASMS WITH CC */
"319" = "1" /* KIDNEY AND URINARY TRACT NEOPLASMS WITHOUT CC */
"322" = "1" /* KIDNEY AND URINARY TRACT INFECTION, AGE 0-17 */
"323" = "1" /* URINARY STONES WITH CC AND/ OR ESW LITHOTRIPSY */
"324" = "1" /* URINARY STONES WITHOUT CC */
"327" = "1" /* KIDNEY AND URINARY TRACT SIGNS AND SYMPTOMS, AGE 0-17 */
"330" = "1" /* URETHRAL STRICTURE, AGE 0-17 */
"333" = "1" /* OTHER KIDNEY AND URINARY TRACT DIAGNOSES, AGE 0-17 */
"346" = "1" /* MALIGNANCY OF MALE REPRODUCTIVE SYSTEM WITH CC */
"347" = "1" /* MALIGNANCY OF MALE REPRODUCTIVE SYSTEM WITHOUT CC */
"348" = "1" /* BENIGN PROSTATIC HYPERTROPHY WITH CC */
"349" = "1" /* BENIGN PROSTATIC HYPERTROPHY WITHOUT CC */
"350" = "1" /* INFLAMMATION OF THE MALE REPRODUCTIVE SYSTEM */
"351" = "1" /* STERILIZATION, MALE */
"352" = "1" /* OTHER MALE REPRODUCTIVE SYSTEM DIAGNOSES */
"366" = "1" /* MALIGNANCY OF FEMALE REPRODUCTIVE SYSTEM WITH CC */
"367" = "1" /* MALIGNANCY OF FEMALE REPRODUCTIVE SYSTEM WITHOUT CC */
"368" = "1" /* INFECTIONS OF FEMALE REPRODUCTIVE SYSTEM */
"369" = "1" /* MENSTRUAL AND OTHER FEMALE REPRODUCTIVE SYSTEM DISORDERS */
"372" = "1" /* VAGINAL DELIVERY WITH COMPLICATING DIAGNOSES */
"373" = "1" /* VAGINAL DELIVERY WITHOUT COMPLICATING DIAGNOSES */
"376" = "1" /* POSTPARTUM AND POSTABORTION DIAGNOSES WITHOUT OR PROCEDURE */
"378" = "1" /* ENTOPIC PREGNANCY */
"379" = "1" /* THREATENED ABORTION */
"380" = "1" /* ABORTION WITHOUT D AND G */
"382" = "1" /* FALSE LABOR */
"383" = "1" /* OTHER ANTEPARTUM DIAGNOSES WITH MEDICAL COMPLICATIONS */
"384" = "1" /* OTHER ANTEPARTUM DIAGNOSES WITHOUT MEDICAL COMPLICATIONS */
"385" = "1" /* NEONATES DIED OR TRANSFERRED TO ANOTHER ACUTE FACILITY */
"386" = "1" /* EXTREME IMMATURITY OR RESPIRATORY DISTRESS SYNDROME NEONATE */
"387" = "1" /* PREMATURITY W MAJOR PROBLEMS */
"388" = "1" /* PREMATURITY W/O MAJOR PROBLEMS */
"389" = "1" /* FULL TERM NEONATE W MAJOR PROBLEMS */
"390" = "1" /* NEONATE W OTHER SIGNIFICANT PROBLEMS */
"391" = "1" /* NORMAL NEWBORN */
"396" = "1" /* RED BLOOD CELL DISORDERS, AGE 0-17 */
"397" = "1" /* COAGULATION DISORDERS */
"398" = "1" /* RETICULOENDOTHELIAL AND IMMUNITY DISORDERS WITH CC */
"399" = "1" /* RETICULOENDOTHELIAL AND IMMUNITY DISORDERS WITHOUT CC */
"403" = "1" /* LYMPHOMA AND NONACUTE LEUKEMIA WITH CC */
"404" = "1" /* LYMPHOMA AND NONACUTE LEUKEMIA WITHOUT CC */
"405" = "1" /* ACUTE LEUKEMIA WITHOUT MAJOR OR PROCEDURE, AGE 0-17 */
"409" = "1" /* RADIOTHERAPY */
"410" = "1" /* CHEMOTHERAPY WITHOUT ACUTE LEUKEMIA AS SECONDARY DIAGNOSIS */
"411" = "1" /* HISTORY OF MALIGNANCY WITHOUT ENDOSCOPY */
"412" = "1" /* HISTORY OF MALIGNANCY WITH ENDOSCOPY */
"413" = "1" /* OTHER MYELOPROLIFERATIVE DISORDERS OR POORLY DIFFERENTIATED NEOPLASM DIAGNOSES WITH CC */
"414" = "1" /* OTHER MYELOPROLIFERATIVE DISORDERS OR POORLY DIFFERENTIATED NEOPLASM DIAGNOSES WITHOUT CC */
"417" = "1" /* SEPTICEMIA, AGE 0-17 */
"418" = "1" /* POSTOPERATIVE AND POSTTRAUMATIC INFECTIONS */
"422" = "1" /* VIRAL ILLNESS AND FEVER OF UNKNOWN ORIGIN, AGE 0-17 */
"423" = "1" /* OTHER INFECTIOUS AND PARASITIC DISEASES DIAGNOSES */
"425" = "1" /* ACUTE ADJUSTMENT REACTIONS AND DISTURBANCES OF PSYCHOSOCIAL DYSFUNCTION */
"426" = "1" /* DEPRESSIVE NEUROSES */
"427" = "1" /* NEUROSES EXCEPT DEPRESSIVE */
"428" = "1" /* DISORDERS OF PERSONALITY AND IMPULSE CONTROL */
"429" = "1" /* ORGANIC DISTURBANCES AND MENTAL RETARDATION */
"430" = "1" /* PSYCHOSES */
"431" = "1" /* CHILDHOOD MENTAL DISORDERS */
"432" = "1" /* OTHER MENTAL DISORDER DIAGNOSES */
"433" = "1" /* ALCOHOL/DRUG ABUSE OR DEPENDENCE, LEFT AGAINST MEDICAL ADVICE */
"434" = "1" /* ALCOHOL/DRUG ABUSE OR DEPENDENCE, DETOXIFICATION OR OTHER SYMPTOMATIC TREATMENT WITH CC */
"435" = "1" /* ALCOHOL/DRUG ABUSE OR DEPENDENCE, DETOXIFICATION OR OTHER SYMPTOMATIC TREATMENT WITHOUT CC */
"436" = "1" /* ALCOHOL/DRUG DEPENDENCE WITH REHABILITATION THERAPY */
"437" = "1" /* ALCOHOL DRUG DEPENDENCE WITH COMBINED REHABILITATION AND DETOXIFICATION THERAPY */
"446" = "1" /* TRAUMATIC INJURY, AGE 0-17 */
"448" = "1" /* ALLERGIC REACTIONS, AGE 0-17 */
"451" = "1" /* POISONING AND TOXIC EFFECTS OF DRUGS, AGE 0-17 */
"452" = "1" /* COMPLICATIONS OF TREATMENT WITH CC */
"453" = "1" /* COMPLICATIONS OF TREATMENT WITHOUT CC */
"454" = "1" /* OTHER INJURY, POISONING AND TOXIC EFFECT DIAGNOSES WITH CC */
"455" = "1" /* OTHER INJURY, POISONING AND TOXIC EFFECT DIAGNOSES WITHOUT CC */
"456" = "1" /* BURNS, TRANSFERRED TO ANOTHER ACUTE CARE FACILITY */
"457" = "1" /* EXTENSIVE BURNS W/O O.R. PROCEDUR */
"460" = "1" /* NON-EXTENSIVE BURNS W/O O.R. PROCEDURE */
"462" = "1" /* REHABILITATION */
"463" = "1" /* SIGNS AND SYMPTOMS WITH CC */
"464" = "1" /* SIGNS AND SYMPTOMS WITHOUT CC */
"465" = "1" /* AFTERCARE WITH HISTORY OF MALIGNANCY AS SECONDARY DIAGNOSIS */
"466" = "1" /* AFTERCARE WITHOUT HISTORY OF MALIGNANCY AS SECONDARY DIAGNOSIS */
"467" = "1" /* OTHER FACTORS INFLUENCING HEALTH STATUS */
"475" = "1" /* RESPIRATORY SYSTEM DIAGNOSIS WITH VENTILATOR SUPPORT */
"487" = "1" /* OTHER MULTIPLE SIGNIFICANT TRAUMA */
"489" = "1" /* HIV WITH MAJOR RELATED CONDITION */
"490" = "1" /* HIV WITH OR WITHOUT OTHER RELATED CONDITION */
"492" = "1" /* CHEMOTHERAPY WITH ACUTE LEUKEMIA AS SECONDARY DIAGNOSIS */
"505" = "1" /* EXTENSIVE 3RD DEGREE BURNS W/O SKIN GRAFT */
"508" = "1" /* FULL THICKNESS BURN W/O SKIN GRFT OR INHAL INJ W CC OR SIG TRAUMA */
"509" = "1" /* FULL THICKNESS BURN W/O SKIN GRFT OR INH INJ W/O CC OR SIG TRAUMA */
"510" = "1" /* NON-EXTENSIVE BURNS W CC OR SIGNIFICANT TRAUMA */
"511" = "1" /* NON-EXTENSIVE BURNS W/O CC OR SIGNIFICANT TRAUMA */
"521" = "1" /* ALCOHOL/DRUG ABUSE OR DEPENDENCE W CC */
"522" = "1" /* ALC/DRUG ABUSE OR DEPEND W REHABILITATION THERAPY W/O CC */
"523" = "1" /* ALC/DRUG ABUSE OR DEPEND W/O REHABILITATION THERAPY W/O CC */
"524" = "1" /* TRANSIENT ISCHEMIA */
"559" = "1" /* ACUTE ISCHEMIC STROKE WITH USE OF THROMBOLYTIC AGENT */
"560" = "1" /* BACTERIAL & TUBERCULOUS INFECTIONS OF NERVOUS SYSTEM */
"561" = "1" /* NON-BACTERIAL INFECTIONS OF NERVOUS SYSTEM EXCEPT VIRAL MENINGITIS */
"565" = "1" /* RESPIRATORY SYSTEM DIAGNOSIS WITH VENTILATOR SUPPORT 96+ HOURS */
"566" = "1" /* RESPIRATORY SYSTEM DIAGNOSIS WITH VENTILATOR SUPPORT < 96 HOURS */
"571" = "1" /* MAJOR ESOPHAGEAL DISORDERS */
"572" = "1" /* MAJOR GASTROINTESTINAL DISORDERS AND PERITONEAL INFECTIONS */
"574" = "1" /* MAJOR HEMATOLOGIC/IMMUNOLOGIC DIAG EXC SICKLE CELL CRISIS & COAGUL */
OTHER  = "0" ;

VALUE $MEDIC2R
'052' = '1' /* Spinal disorders & injuries w CC/MCC */
'053' = '1' /* Spinal disorders & injuries w/o CC/MCC */
'054' = '1' /* Nervous system neoplasms w MCC */
'055' = '1' /* Nervous system neoplasms w/o MCC */
'056' = '1' /* Degenerative nervous system disorders w MCC */
'057' = '1' /* Degenerative nervous system disorders w/o MCC */
'058' = '1' /* Multiple sclerosis & cerebellar ataxia w MCC */
'059' = '1' /* Multiple sclerosis & cerebellar ataxia w CC */
'060' = '1' /* Multiple sclerosis & cerebellar ataxia w/o CC/MCC */
'061' = '1' /* Acute ischemic stroke w use of thrombolytic agent w MCC */
'062' = '1' /* Acute ischemic stroke w use of thrombolytic agent w CC */
'063' = '1' /* Acute ischemic stroke w use of thrombolytic agent w/o CC/MCC */
'064' = '1' /* Intracranial hemorrhage or cerebral infarction w MCC */
'065' = '1' /* Intracranial hemorrhage or cerebral infarction w CC */
'066' = '1' /* Intracranial hemorrhage or cerebral infarction w/o CC/MCC */
'067' = '1' /* Nonspecific cva & precerebral occlusion w/o infarct w MCC */
'068' = '1' /* Nonspecific cva & precerebral occlusion w/o infarct w/o MCC */
'069' = '1' /* Transient ischemia */
'070' = '1' /* Nonspecific cerebrovascular disorders w MCC */
'071' = '1' /* Nonspecific cerebrovascular disorders w CC */
'072' = '1' /* Nonspecific cerebrovascular disorders w/o CC/MCC */
'073' = '1' /* Cranial & peripheral nerve disorders w MCC */
'074' = '1' /* Cranial & peripheral nerve disorders w/o MCC */
'075' = '1' /* Viral meningitis w CC/MCC */
'076' = '1' /* Viral meningitis w/o CC/MCC */
'077' = '1' /* Hypertensive encephalopathy w MCC */
'078' = '1' /* Hypertensive encephalopathy w CC */
'079' = '1' /* Hypertensive encephalopathy w/o CC/MCC */
'080' = '1' /* Nontraumatic stupor & coma w MCC */
'081' = '1' /* Nontraumatic stupor & coma w/o MCC */
'082' = '1' /* Traumatic stupor & coma, coma >1 hr w MCC */
'083' = '1' /* Traumatic stupor & coma, coma >1 hr w CC */
'084' = '1' /* Traumatic stupor & coma, coma >1 hr w/o CC/MCC */
'085' = '1' /* Traumatic stupor & coma, coma <1 hr w MCC */
'086' = '1' /* Traumatic stupor & coma, coma <1 hr w CC */
'087' = '1' /* Traumatic stupor & coma, coma <1 hr w/o CC/MCC */
'088' = '1' /* Concussion w MCC */
'089' = '1' /* Concussion w CC */
'090' = '1' /* Concussion w/o CC/MCC */
'091' = '1' /* Other disorders of nervous system w MCC */
'092' = '1' /* Other disorders of nervous system w CC */
'093' = '1' /* Other disorders of nervous system w/o CC/MCC */
'094' = '1' /* Bacterial & tuberculous infections of nervous system w MCC */
'095' = '1' /* Bacterial & tuberculous infections of nervous system w CC */
'096' = '1' /* Bacterial & tuberculous infections of nervous system w/o CC/MCC */
'097' = '1' /* Non-bacterial infect of nervous sys exc viral meningitis w MCC */
'098' = '1' /* Non-bacterial infect of nervous sys exc viral meningitis w CC */
'099' = '1' /* Non-bacterial infect of nervous sys exc viral meningitis w/o CC/MCC */
'100' = '1' /* Seizures w MCC */
'101' = '1' /* Seizures w/o MCC */
'102' = '1' /* Headaches w MCC */
'103' = '1' /* Headaches w/o MCC */
'121' = '1' /* Acute major eye infections w CC/MCC */
'122' = '1' /* Acute major eye infections w/o CC/MCC */
'123' = '1' /* Neurological eye disorders */
'124' = '1' /* Other disorders of the eye w MCC */
'125' = '1' /* Other disorders of the eye w/o MCC */
'146' = '1' /* Ear, nose, mouth & throat malignancy w MCC */
'147' = '1' /* Ear, nose, mouth & throat malignancy w CC */
'148' = '1' /* Ear, nose, mouth & throat malignancy w/o CC/MCC */
'149' = '1' /* Dysequilibrium */
'150' = '1' /* Epistaxis w MCC */
'151' = '1' /* Epistaxis w/o MCC */
'152' = '1' /* Otitis media & URI w MCC */
'153' = '1' /* Otitis media & URI w/o MCC */
'154' = '1' /* Nasal trauma & deformity w MCC */
'155' = '1' /* Nasal trauma & deformity w CC */
'156' = '1' /* Nasal trauma & deformity w/o CC/MCC */
'157' = '1' /* Dental & Oral Diseases w MCC */
'158' = '1' /* Dental & Oral Diseases w CC */
'159' = '1' /* Dental & Oral Diseases w/o CC/MCC */
'175' = '1' /* Pulmonary embolism w MCC */
'176' = '1' /* Pulmonary embolism w/o MCC */
'177' = '1' /* Respiratory infections & inflammations w MCC */
'178' = '1' /* Respiratory infections & inflammations w CC */
'179' = '1' /* Respiratory infections & inflammations w/o CC/MCC */
'180' = '1' /* Respiratory neoplasms w MCC */
'181' = '1' /* Respiratory neoplasms w CC */
'182' = '1' /* Respiratory neoplasms w/o CC/MCC */
'183' = '1' /* Major chest trauma w MCC */
'184' = '1' /* Major chest trauma w CC */
'185' = '1' /* Major chest trauma w/o CC/MCC */
'186' = '1' /* Pleural effusion w MCC */
'187' = '1' /* Pleural effusion w CC */
'188' = '1' /* Pleural effusion w/o CC/MCC */
'189' = '1' /* Pulmonary edema & respiratory failure */
'190' = '1' /* Chronic obstructive pulmonary disease w MCC */
'191' = '1' /* Chronic obstructive pulmonary disease w CC */
'192' = '1' /* Chronic obstructive pulmonary disease w/o CC/MCC */
'193' = '1' /* Simple pneumonia & pleurisy w MCC */
'194' = '1' /* Simple pneumonia & pleurisy w CC */
'195' = '1' /* Simple pneumonia & pleurisy w/o CC/MCC */
'196' = '1' /* Interstitial lung disease w MCC */
'197' = '1' /* Interstitial lung disease w CC */
'198' = '1' /* Interstitial lung disease w/o CC/MCC */
'199' = '1' /* Pneumothorax w MCC */
'200' = '1' /* Pneumothorax w CC */
'201' = '1' /* Pneumothorax w/o CC/MCC */
'202' = '1' /* Bronchitis & asthma w CC/MCC */
'203' = '1' /* Bronchitis & asthma w/o CC/MCC */
'204' = '1' /* Respiratory signs & symptoms */
'205' = '1' /* Other respiratory system diagnoses w MCC */
'206' = '1' /* Other respiratory system diagnoses w/o MCC */
'207' = '1' /* Respiratory system diagnosis w ventilator support 96+ hours */
'208' = '1' /* Respiratory system diagnosis w ventilator support <96 hours */
'280' = '1' /* Acute myocardial infarction, discharged alive w MCC */
'281' = '1' /* Acute myocardial infarction, discharged alive w CC */
'282' = '1' /* Acute myocardia infarction, discharged alive w/o CC/MCC */
'283' = '1' /* Acute myocardial infarction, expired w MCC */
'284' = '1' /* Acute myocardial infarction, expired w CC */
'285' = '1' /* Acute myocardial infarction, expired w/o CC/MCC */
'286' = '1' /* Circulatory disorders except AMI, w card cath w MCC */
'287' = '1' /* Circulatory disorders except AMI, w card cath w/o MCC */
'288' = '1' /* Acute & subacute endocarditis w MCC */
'289' = '1' /* Acute & subacute endocarditis w CC */
'290' = '1' /* Acute & subacute endocarditis w/o CC/MCC */
'291' = '1' /* Heart failure & shock w MCC */
'292' = '1' /* Heart failure & shock w CC */
'293' = '1' /* Heart failure & shock w/o CC/MCC */
'294' = '1' /* Deep vein thrombophlebitis w CC/MCC */
'295' = '1' /* Deep vein thrombophlebitis w/o CC/MCC */
'296' = '1' /* Cardiac arrest, unexplained w MCC */
'297' = '1' /* Cardiac arrest, unexplained w CC */
'298' = '1' /* Cardiac arrest, unexplained w/o CC/MCC */
'299' = '1' /* Peripheral vascular disorders w MCC */
'300' = '1' /* Peripheral vascular disorders w CC */
'301' = '1' /* Peripheral vascular disorders w/o CC/MCC */
'302' = '1' /* Atherosclerosis w MCC */
'303' = '1' /* Atherosclerosis w/o MCC */
'304' = '1' /* Hypertension w MCC */
'305' = '1' /* Hypertension w/o MCC */
'306' = '1' /* Cardiac congenital & valvular disorders w MCC */
'307' = '1' /* Cardiac congenital & valvular disorders w/o MCC */
'308' = '1' /* Cardiac arrhythmia & conduction disorders w MCC */
'309' = '1' /* Cardiac arrhythmia & conduction disorders w CC */
'310' = '1' /* Cardiac arrhythmia & conduction disorders w/o CC/MCC */
'311' = '1' /* Angina pectoris */
'312' = '1' /* Syncope & collapse */
'313' = '1' /* Chest pain */
'314' = '1' /* Other circulatory system diagnoses w MCC */
'315' = '1' /* Other circulatory system diagnoses w CC */
'316' = '1' /* Other circulatory system diagnoses w/o CC/MCC */
'368' = '1' /* Major esophageal disorders w MCC */
'369' = '1' /* Major esophageal disorders w CC */
'370' = '1' /* Major esophageal disorders w/o CC/MCC */
'371' = '1' /* Major gastrointestinal disorders & peritoneal infections w MCC */
'372' = '1' /* Major gastrointestinal disorders & peritoneal infections w CC */
'373' = '1' /* Major gastrointestinal disorders & peritoneal infections w/o CC/MCC */
'374' = '1' /* Digestive malignancy w MCC */
'375' = '1' /* Digestive malignancy w CC */
'376' = '1' /* Digestive malignancy w/o CC/MCC */
'377' = '1' /* G.I. hemorrhage w MCC */
'378' = '1' /* G.I. hemorrhage w CC */
'379' = '1' /* G.I. hemorrhage w/o CC/MCC */
'380' = '1' /* Complicated peptic ulcer w MCC */
'381' = '1' /* Complicated peptic ulcer w CC */
'382' = '1' /* Complicated peptic ulcer w/o CC/MCC */
'383' = '1' /* Uncomplicated peptic ulcer w MCC */
'384' = '1' /* Uncomplicated peptic ulcer w/o MCC */
'385' = '1' /* Inflammatory bowel disease w MCC */
'386' = '1' /* Inflammatory bowel disease w CC */
'387' = '1' /* Inflammatory bowel disease w/o CC/MCC */
'388' = '1' /* G.I. obstruction w MCC */
'389' = '1' /* G.I. obstruction w CC */
'390' = '1' /* G.I. obstruction w/o CC/MCC */
'391' = '1' /* Esophagitis, gastroent & misc digest disorders w MCC */
'392' = '1' /* Esophagitis, gastroent & misc digest disorders w/o MCC */
'393' = '1' /* Other digestive system diagnoses w MCC */
'394' = '1' /* Other digestive system diagnoses w CC */
'395' = '1' /* Other digestive system diagnoses w/o CC/MCC */
'432' = '1' /* Cirrhosis & alcoholic hepatitis w MCC */
'433' = '1' /* Cirrhosis & alcoholic hepatitis w CC */
'434' = '1' /* Cirrhosis & alcoholic hepatitis w/o CC/MCC */
'435' = '1' /* Malignancy of hepatobiliary system or pancreas w MCC */
'436' = '1' /* Malignancy of hepatobiliary system or pancreas w CC */
'437' = '1' /* Malignancy of hepatobiliary system or pancreas w/o CC/MCC */
'438' = '1' /* Disorders of pancreas except malignancy w MCC */
'439' = '1' /* Disorders of pancreas except malignancy w CC */
'440' = '1' /* Disorders of pancreas except malignancy w/o CC/MCC */
'441' = '1' /* Disorders of liver except malig,cirr,alc hepa w MCC */
'442' = '1' /* Disorders of liver except malig,cirr,alc hepa w CC */
'443' = '1' /* Disorders of liver except malig,cirr,alc hepa w/o CC/MCC */
'444' = '1' /* Disorders of the biliary tract w MCC */
'445' = '1' /* Disorders of the biliary tract w CC */
'446' = '1' /* Disorders of the biliary tract w/o CC/MCC */
'533' = '1' /* Fractures of femur w MCC */
'534' = '1' /* Fractures of femur w/o MCC */
'535' = '1' /* Fractures of hip & pelvis w MCC */
'536' = '1' /* Fractures of hip & pelvis w/o MCC */
'537' = '1' /* Sprains, strains, & dislocations of hip, pelvis & thigh w CC/MCC */
'538' = '1' /* Sprains, strains, & dislocations of hip, pelvis & thigh w/o CC/MCC */
'539' = '1' /* Osteomyelitis w MCC */
'540' = '1' /* Osteomyelitis w CC */
'541' = '1' /* Osteomyelitis w/o CC/MCC */
'542' = '1' /* Pathological fractures & musculoskelet & conn tiss malig w MCC */
'543' = '1' /* Pathological fractures & musculoskelet & conn tiss malig w CC */
'544' = '1' /* Pathological fractures & musculoskelet & conn tiss malig w/o CC/MCC */
'545' = '1' /* Connective tissue disorders w MCC */
'546' = '1' /* Connective tissue disorders w CC */
'547' = '1' /* Connective tissue disorders w/o CC/MCC */
'548' = '1' /* Septic arthritis w MCC */
'549' = '1' /* Septic arthritis w CC */
'550' = '1' /* Septic arthritis w/o CC/MCC */
'551' = '1' /* Medical back problems w MCC */
'552' = '1' /* Medical back problems w/o MCC */
'553' = '1' /* Bone diseases & arthropathies w MCC */
'554' = '1' /* Bone diseases & arthropathies w/o MCC */
'555' = '1' /* Signs & symptoms of musculoskeletal system & conn tissue w MCC */
'556' = '1' /* Signs & symptoms of musculoskeletal system & conn tissue w/o MCC */
'557' = '1' /* Tendonitis, myositis & bursitis w MCC */
'558' = '1' /* Tendonitis, myositis & bursitis w/o MCC */
'559' = '1' /* Aftercare, musculoskeletal system & connective tissue w MCC */
'560' = '1' /* Aftercare, musculoskeletal system & connective tissue w CC */
'561' = '1' /* Aftercare, musculoskeletal system & connective tissue w/o CC/MCC */
'562' = '1' /* Fx, sprn, strn & disl except femur, hip, pelvis & thigh w MCC */
'563' = '1' /* Fx, sprn, strn & disl except femur, hip, pelvis & thigh w/o MCC */
'564' = '1' /* Other musculoskeletal sys & connective tissue diagnoses w MCC */
'565' = '1' /* Other musculoskeletal sys & connective tissue diagnoses w CC */
'566' = '1' /* Other musculoskeletal sys & connective tissue diagnoses w/o CC/MCC */
'592' = '1' /* Skin ulcers w MCC */
'593' = '1' /* Skin ulcers w CC */
'594' = '1' /* Skin ulcers w/o CC/MCC */
'595' = '1' /* Major skin disorders w MCC */
'596' = '1' /* Major skin disorders w/o MCC */
'597' = '1' /* Malignant breast disorders w MCC */
'598' = '1' /* Malignant breast disorders w CC */
'599' = '1' /* Malignant breast disorders w/o CC/MCC */
'600' = '1' /* Non-malignant breast disorders w CC/MCC */
'601' = '1' /* Non-malignant breast disorders w/o CC/MCC */
'602' = '1' /* Cellulitis w MCC */
'603' = '1' /* Cellulitis w/o MCC */
'604' = '1' /* Trauma to the skin, subcut tiss & breast w MCC */
'605' = '1' /* Trauma to the skin, subcut tiss & breast w/o MCC */
'606' = '1' /* Minor skin disorders w MCC */
'607' = '1' /* Minor skin disorders w/o MCC */
'637' = '1' /* Diabetes w MCC */
'638' = '1' /* Diabetes w CC */
'639' = '1' /* Diabetes w/o CC/MCC */
'640' = '1' /* Nutritional & misc metabolic disorders w MCC */
'641' = '1' /* Nutritional & misc metabolic disorders w/o MCC */
'642' = '1' /* Inborn errors of metabolism */
'643' = '1' /* Endocrine disorders w MCC */
'644' = '1' /* Endocrine disorders w CC */
'645' = '1' /* Endocrine disorders w/o CC/MCC */
'682' = '1' /* Renal failure w MCC */
'683' = '1' /* Renal failure w CC */
'684' = '1' /* Renal failure w/o CC/MCC */
'685' = '1' /* Admit for renal dialysis */
'686' = '1' /* Kidney & urinary tract neoplasms w MCC */
'687' = '1' /* Kidney & urinary tract neoplasms w CC */
'688' = '1' /* Kidney & urinary tract neoplasms w/o CC/MCC */
'689' = '1' /* Kidney & urinary tract infections w MCC */
'690' = '1' /* Kidney & urinary tract infections w/o MCC */
'691' = '1' /* Urinary stones w esw lithotripsy w CC/MCC */
'692' = '1' /* Urinary stones w esw lithotripsy w/o CC/MCC */
'693' = '1' /* Urinary stones w/o esw lithotripsy w MCC */
'694' = '1' /* Urinary stones w/o esw lithotripsy w/o MCC */
'695' = '1' /* Kidney & urinary tract signs & symptoms w MCC */
'696' = '1' /* Kidney & urinary tract signs & symptoms w/o MCC */
'697' = '1' /* Urethral stricture */
'698' = '1' /* Other kidney & urinary tract diagnoses w MCC */
'699' = '1' /* Other kidney & urinary tract diagnoses w CC */
'700' = '1' /* Other kidney & urinary tract diagnoses w/o CC/MCC */
'722' = '1' /* Malignancy, male reproductive system w MCC */
'723' = '1' /* Malignancy, male reproductive system w CC */
'724' = '1' /* Malignancy, male reproductive system w/o CC/MCC */
'725' = '1' /* Benign prostatic hypertrophy w MCC */
'726' = '1' /* Benign prostatic hypertrophy w/o MCC */
'727' = '1' /* Inflammation of the male reproductive system w MCC */
'728' = '1' /* Inflammation of the male reproductive system w/o MCC */
'729' = '1' /* Other male reproductive system diagnoses w CC/MCC */
'730' = '1' /* Other male reproductive system diagnoses w/o CC/MCC */
'754' = '1' /* Malignancy, female reproductive system w MCC */
'755' = '1' /* Malignancy, female reproductive system w CC */
'756' = '1' /* Malignancy, female reproductive system w/o CC/MCC */
'757' = '1' /* Infections, female reproductive system w MCC */
'758' = '1' /* Infections, female reproductive system w CC */
'759' = '1' /* Infections, female reproductive system w/o CC/MCC */
'760' = '1' /* Menstrual & other female reproductive system disorders w CC/MCC */
'761' = '1' /* Menstrual & other female reproductive system disorders w/o CC/MCC */
'774' = '1' /* Vaginal delivery w complicating diagnoses */
'775' = '1' /* Vaginal delivery w/o complicating diagnoses */
'776' = '1' /* Postpartum & post abortion diagnoses w/o O.R. procedure */
'777' = '1' /* Ectopic pregnancy */
'778' = '1' /* Threatened abortion */
'779' = '1' /* Abortion w/o D&C */
'780' = '1' /* False labor */
'781' = '1' /* Other antepartum diagnoses w medical complications */
'782' = '1' /* Other antepartum diagnoses w/o medical complications */
'789' = '1' /* Neonates, died or transferred to another acute care facility */
'790' = '1' /* Extreme immaturity or respiratory distress syndrome, neonate */
'791' = '1' /* Prematurity w major problems */
'792' = '1' /* Prematurity w/o major problems */
'793' = '1' /* Full term neonate w major problems */
'794' = '1' /* Neonate w other significant problems */
'795' = '1' /* Normal newborn */
'808' = '1' /* Major hematol/immun diag exc sickle cell crisis & coagul w MCC */
'809' = '1' /* Major hematol/immun diag exc sickle cell crisis & coagul w CC */
'810' = '1' /* Major hematol/immun diag exc sickle cell crisis & coagul w/o CC/MCC */
'811' = '1' /* Red blood cell disorders w MCC */
'812' = '1' /* Red blood cell disorders w/o MCC */
'813' = '1' /* Coagulation disorders */
'814' = '1' /* Reticuloendothelial & immunity disorders w MCC */
'815' = '1' /* Reticuloendothelial & immunity disorders w CC */
'816' = '1' /* Reticuloendothelial & immunity disorders w/o CC/MCC */
'834' = '1' /* Acute leukemia w/o major O.R. procedure w MCC */
'835' = '1' /* Acute leukemia w/o major O.R. procedure w CC */
'836' = '1' /* Acute leukemia w/o major O.R. procedure w/o CC/MCC */
'837' = '1' /* Chemo w acute leukemia as sdx or w high dose chemo agent w MCC */
'838' = '1' /* Chemo w acute leukemia as sdx w CC or high dose chemo agent */
'839' = '1' /* Chemo w acute leukemia as sdx w/o CC/MCC */
'840' = '1' /* Lymphoma & non-acute leukemia w MCC */
'841' = '1' /* Lymphoma & non-acute leukemia w CC */
'842' = '1' /* Lymphoma & non-acute leukemia w/o CC/MCC */
'843' = '1' /* Other myeloprolif dis or poorly diff neopl diag w MCC */
'844' = '1' /* Other myeloprolif dis or poorly diff neopl diag w CC */
'845' = '1' /* Other myeloprolif dis or poorly diff neopl diag w/o CC/MCC */
'846' = '1' /* Chemotherapy w/o acute leukemia as secondary diagnosis w MCC */
'847' = '1' /* Chemotherapy w/o acute leukemia as secondary diagnosis w CC */
'848' = '1' /* Chemotherapy w/o acute leukemia as secondary diagnosis w/o CC/MCC */
'849' = '1' /* Radiotherapy */
'862' = '1' /* Postoperative & post-traumatic infections w MCC */
'863' = '1' /* Postoperative & post-traumatic infections w/o MCC */
'864' = '1' /* Fever of unknown origin */
'865' = '1' /* Viral illness w MCC */
'866' = '1' /* Viral illness w/o MCC */
'867' = '1' /* Other infectious & parasitic diseases diagnoses w MCC */
'868' = '1' /* Other infectious & parasitic diseases diagnoses w CC */
'869' = '1' /* Other infectious & parasitic diseases diagnoses w/o CC/MCC */
'870' = '1' /* Septicemia w MV 96+ hours */
'871' = '1' /* Septicemia w/o MV 96+ hours w MCC */
'872' = '1' /* Septicemia w/o MV 96+ hours w/o MCC */
'880' = '1' /* Acute adjustment reaction & psychosocial dysfunction */
'881' = '1' /* Depressive neuroses */
'882' = '1' /* Neuroses except depressive */
'883' = '1' /* Disorders of personality & impulse control */
'884' = '1' /* Organic disturbances & mental retardation */
'885' = '1' /* Psychoses */
'886' = '1' /* Behavioral & developmental disorders */
'887' = '1' /* Other mental disorder diagnoses */
'894' = '1' /* Alcohol/drug abuse or dependence, left ama */
'895' = '1' /* Alcohol/drug abuse or dependence w rehabilitation therapy */
'896' = '1' /* Alcohol/drug abuse or dependence w/o rehabilitation therapy w MCC */
'897' = '1' /* Alcohol/drug abuse or dependence w/o rehabilitation therapy w/o MCC */
'913' = '1' /* Traumatic injury w MCC */
'914' = '1' /* Traumatic injury w/o MCC */
'915' = '1' /* Allergic reactions w MCC */
'916' = '1' /* Allergic reactions w/o MCC */
'917' = '1' /* Poisoning & toxic effects of drugs w MCC */
'918' = '1' /* Poisoning & toxic effects of drugs w/o MCC */
'919' = '1' /* Complications of treatment w MCC */
'920' = '1' /* Complications of treatment w CC */
'921' = '1' /* Complications of treatment w/o CC/MCC */
'922' = '1' /* Other injury, poisoning & toxic effect diag w MCC */
'923' = '1' /* Other injury, poisoning & toxic effect diag w/o MCC */
'933' = '1' /* Extensive burns or full thickness burns w MV 96+ hrs w/o skin graft */
'934' = '1' /* Full thickness burn w/o skin grft or inhal inj */
'935' = '1' /* Non-extensive burns */
'945' = '1' /* Rehabilitation w CC/MCC */
'946' = '1' /* Rehabilitation w/o CC/MCC */
'947' = '1' /* Signs & symptoms w MCC */
'948' = '1' /* Signs & symptoms w/o MCC */
'949' = '1' /* Aftercare w CC/MCC */
'950' = '1' /* Aftercare w/o CC/MCC */
'951' = '1' /* Other factors influencing health status */
'963' = '1' /* Other multiple significant trauma w MCC */
'964' = '1' /* Other multiple significant trauma w CC */
'965' = '1' /* Other multiple significant trauma w/o CC/MCC */
'974' = '1' /* HIV w major related condition w MCC */
'975' = '1' /* HIV w major related condition w CC */
'976' = '1' /* HIV w major related condition w/o CC/MCC */
'977' = '1' /* HIV w or w/o other related condition */
OTHER = '0' ;

 /* ---------------------------------------------------------------- */
 /* SURGICAL DRGS  (deleted Adult DRGs)                              */
 /* ---------------------------------------------------------------- */

 /* DIAGNOSTIC RELATED GROUPS (DRGS): */

VALUE $SURGIDR
"001" = "1" /* CRANIOTOMY, AGE GREATER THAN 17 EXCEPT FOR TRAUMA */
"002" = "1" /* CRANIOTOMY FOR TRAUMA, AGE GREATER THAN 17 */
"003" = "1" /* CRANIOTOMY, AGE 0-17 */
"004" = "1" /* SPINAL PROCEDURES */
"005" = "1" /* EXTRACRANIAL VASCULAR PROCEDURES */
"006" = "1" /* CARPAL TUNNEL RELEASE */
"007" = "1" /* PERIPHERAL AND CRANIAL NERVE AND OTHER NERVOUS SYSTEM PROCEDURES WITH CC */
"008" = "1" /* PERIPHERAL AND CRANIAL NERVE AND OTHER NERVOUS SYSTEM PROCEDURES WITHOUT CC */
"036" = "1" /* RETINAL PROCEDURES */
"037" = "1" /* ORBITAL PROCEDURES */
"038" = "1" /* PRIMARY IRIS PROCEDURES */
"039" = "1" /* LENS PROCEDURES WITH OR WITHOUT VITRECTOMY */
"040" = "1" /* EXTRAOCULAR PROCEDURES EXCEPT ORBIT, AGE GREATER THAN 17 */
"041" = "1" /* EXTRAOCULAR PROCEDURES EXCEPT ORBIT, AGE 0-17 */
"042" = "1" /* INTRAOCULAR PROCEDURES EXCEPT RETINA, IRIS AND LENS */
"049" = "1" /* MAJOR HEAD AND NECK PROCEDURES */
"050" = "1" /* SIALOADENECTOMY */
"051" = "1" /* SALIVARY GLAND PROCEDURES EXCEPT SIALOADENECTOMY */
"052" = "1" /* CLEFT LIP AND PALATE REPAIR */
"053" = "1" /* SINUS AND MASTOID PROCEDURES, AGE GREATER THAN 17 */
"054" = "1" /* SINUS AND MASTOID PROCEDURES, AGE 0-17 */
"055" = "1" /* MISCELLANEOUS EAR, NOSE, MOUTH AND THROAT PROCEDURES */
"056" = "1" /* RHINOPLASTY */
"058" = "1" /* TONSILLECTOMY AND ADNOIDECTOMY PROCEDURES EXCEPT TONSILLECTOMY AND/OR ADENOIDECTOMY ONLY, AGE 0-17 */
"059" = "1" /* TONSILLECTOMY AND/OR ADENOIDECTOMY ONLY, AGE GREATER THAN 17 */
"060" = "1" /* TONSILLECTOMY AND/OR ADENOIDECTOMY ONLY, AGE 0 - 17 */
"061" = "1" /* MYRINGOTOMY WITH TUBE INSERTION, AGE GREATER THAN 17 */
"062" = "1" /* MYRINGOTOMY WITH TUBE INSERTION, AGE 0-17 */
"063" = "1" /* OTHER EAR, NOSE, MOUTH AND THROAT OR PROCEDURES */
"075" = "1" /* MAJOR CHEST PROCEDURES */
"076" = "1" /* OTHER RESPIRATORY SYSTEM OR PROCEDURES WITH CC */
"077" = "1" /* OTHER RESPIRATORY SYSTEM OR PROCEDURES WITHOUT CC */
"103" = "1" /* HEART TRANSPLANT */
"104" = "1" /* CARDIAC VALVE AND OTHER MAJOR CARDIOTHORACIC PROCEDURES WITH CARDIAC CATHETERIZATION */
"105" = "1" /* CARDIAC VALVE AND OTHER MAJOR CARDIOTHORACIC PROCEDURES WITHOUT CARDIAC CATHETERIZATION */
"106" = "1" /* CORONARY BYPASS WITH PTCA */
"107" = "1" /* CORONARY BYPASS WITH CARDIAC CATHETERIZATION */
"108" = "1" /* OTHER CARDIOTHORACIC PROCEDURES */
"109" = "1" /* CORONARY BYPASS WITHOUT CARDIAC CATHETERIZATION */
"110" = "1" /* MAJOR CARDIOVASCULAR PROCEDURES WITH CC */
"111" = "1" /* MAJOR CARDIOVASCULAR PROCEDURES WITHOUT CC */
"112" = "1" /* PERCUTANEOUS CARDIOVASCULAR PROCEDURES */
"113" = "1" /* AMPUTATION FOR CIRCULATORY SYSTEM DISORDERS EXCEPT UPPER LIMB AND TOE */
"114" = "1" /* UPPER LIMB AND TOES AMPUTATION FOR CIRCULATORY SITE */
"115" = "1" /* PERMANENT CARDIAC PACEMAKER IMPLANT WITH ACUTE MYOCARDIAL INFARCTION, HEART FAILURE OR SHOCK OR ACID LEAD OR GENERATOR PROCEDURE */
"116" = "1" /* OTHER PERMANENT CARDIAC PACEMAKER IMPLANT OR PTCA WITH CORONARY ARTERIAL STENT */
"117" = "1" /* CARDIAC PACEMAKER REVISION EXCEPT DEVICE REPLACEMENT */
"118" = "1" /* CARDIAC PACEMAKER DEVICE REPLACEMENT */
"119" = "1" /* VEIN LIGATION AND STRIPPING */
"120" = "1" /* OTHER CIRCULATORY SYSTEM OR PROCEDURES */
"146" = "1" /* RECTAL RESECTION WITH CC */
"147" = "1" /* RECTAL RESECTION WITHOUT CC */
"148" = "1" /* MAJOR SMALL AND LARGE BOWEL PROCEDURES WITH CC */
"149" = "1" /* MAJOR SMALL AND LARGE BOWEL PROCEDURES WITHOUT CC */
"150" = "1" /* PERITONEAL ADHESIOLYSIS WITH CC */
"151" = "1" /* PERITONEAL ADHESIOLYSIS WITHOUT CC */
"152" = "1" /* MINOR SMALL AND LARGE BOWEL PROCEDURES WITH CC */
"153" = "1" /* MINOR SMALL AND LARGE BOWEL PROCEDURES WITHOUT CC */
"154" = "1" /* STOMACH, ESOPHAGEAL AND DUODENAL PROCEDURES, AGE GREATER THAN 17 WITH CC */
"155" = "1" /* STOMACH, ESOPHAGEAL AND DUODENAL PROCEDURES, AGE GREATER THAN 17 WIHOUT CC*/
"156" = "1" /* STOMACH, ESOPHAGEAL AND DUODENAL PROCEDURES, AGE 0-17 */
"157" = "1" /* ANAL AND STOMAL PROCEDURES WITH CC */
"158" = "1" /* ANAL AND STOMAL PROCEDURES WITHOUT CC */
"159" = "1" /* HERMIA PROCEDURES EXCEPT INGUINAL AND FEMORAL , AGE GREATER THAN 17 WITH CC */
"160" = "1" /* HERNIA PROCEDURES EXCEPT INGUINAL AND FEMORAL, AGE GREATER THAN 17 WITHOUT CC */
"161" = "1" /* INGUINAL AND FEMORAL HERNIA PROCEDURES, AGE GREATER THAN 17 WITH CC */
"162" = "1" /* INGUINAL AND FEMORAL HERNIA PROCEDURES, AGE GREATER THAN 17 WITHOUT CC */
"163" = "1" /* HERNIA PROCEDURES, AGE 0-17 */
"164" = "1" /* APPENDECTOMY WITH COMPLICATED PRINCIPAL DIAGNOSIS WITH CC */
"165" = "1" /* APPENDECTOMY WITH COMPLICATED PRINCIPAL DIAGNOSIS WIHTOUT CC */
"166" = "1" /* APPENDECTOMY WITHOUT COMPLICATED PRINCIPAL IAGNOSIS WITH CC */
"167" = "1" /* APPENDECTOMY WITHOUT COMPLICATED PRINCIPAL DIAGNOSIS WITHOUT CC */
"168" = "1" /* MOUTH PROCEDURES WITH CC */
"169" = "1" /* MOUTH PROCEDURES WITHOUT CC */
"170" = "1" /* OTHER DIGESTIVE SYSTEM OR PROCEDURES WITH CC */
"171" = "1" /* OTHER DIGESTIVE SYSTEM OR PROCEDURES WITHOUT CC */
"191" = "1" /* PANCREAS, LIVER AND SHUNT PROCEDURES WITH CC */
"192" = "1" /* PANCREAS, LIVER AND SHUNT PROCEDURES WITHOUT CC */
"193" = "1" /* BILIARY TRACT PROCEDURES EXCEPT ONLY CHOLECYSTECTOIMY WITH OR WITHOUT COMMON DUCT EXPLORATION WITH CC */
"194" = "1" /* BILIARY TRACT PROCEDURES EXCEPT ONLY CHOLECYSTECTOMY WITH OR WITHOUT COMMON DUCT EXPLORATION WITHOUT CC */
"195" = "1" /* CHOLECYSTECTOMY WITH COMMON DUCT EXPLORATION WITH CC */
"196" = "1" /* CHOLECYSTECTOMY WITH COMMON DUCT EXPLORATION WITHOUT CC */
"197" = "1" /* CHOLECYSTECTOMY EXCEPT BY LAPAROSCOPE WITHOUT COMMON DUCT EXPLORATION WITH CC */
"198" = "1" /* CHOLECYSTECTOMY EXCEPT BY LAPAROSCOPE WITHOUT COMMON DUCT EXPORTATION WITHOUT CC */
"199" = "1" /* HEPATOBILIARY DIAGNOSTIC PROCEDURE FOR MALIGNANCY */
"200" = "1" /* HEPATOBILIARY DIAGNOSTIC PROCEDURE FOR NONMALIGNANCY */
"201" = "1" /* OTHER HEPATOBILIARY OR PANCREAS OR PROCEDURES */
"209" = "1" /* MAJOR JOINT AND LIMB REATTACHMENT PROCEDURES OF LOWER EXTREMITY */
"210" = "1" /* HIP AND FEMUR PROCEDURES EXCEPT MAJOR JOINT PROCEDURES, AGE GREATER THAN 17 WITH CC */
"211" = "1" /* HIP AND FEMUR PROCEDURES EXCEPT MAJOR JOINT PROCEDURES, AGE GREATER THAN 17 WITHOUT CC */
"212" = "1" /* HIP AND FEMUR PROCEDURES EXCEPT MAJOR JOINT PROCEDURE, AGE 0-17 */
"213" = "1" /* AMPUTATION FOR MUSCULOSKELETAL SYSTEM AND CONNECTIVE TISSUE DISORDERS */
"214" = "1" /* BACK & NECK PROCEDURES WITH CC */
"215" = "1" /* BACK & NECK PROCEDURES WITHOUT CC */
"216" = "1" /* BIOPSIES OF MUSCULOSKELETAL SYSTEM AND CONNECTIVE TISSUE */
"217" = "1" /* WOUND DEBRIDEMENT AND SKIN GRAFT EXCEPT HAND FOR MUSCULOSKELETAL AND CONNECTIVE TISSUE DISORDERS */
"218" = "1" /* LOWER EXTREMITY AND HUMERUS PROCEURES EXCEPT HIP, FOOT AND FEMUR, AGE GREATER THAN 17 WITH CC */
"219" = "1" /* LOWER EXTREMITY AND HUMERUS PROCEDURES EXCEPT HIP, FOOT AND FEMUR, AGE GREATER THAN 17 WITHOUT CC */
"220" = "1" /* LOWER EXTREMITY AND HUMERUS PROCEDURES EXCEPT HIP, FOOT AND FEMUR, AGE 0-17 */
"221" = "1" /* KNEE PROCEDURES WITH CC */
"222" = "1" /* KNEE PROCEDURES WITHOUT CC */
"223" = "1" /* MAJOR SHOULDER/ELBOW PROCEDURES OR OTHER UPPER EXTREMITY PROCEDURES WITH CC */
"224" = "1" /* SHOULDER, ELBOW OR FOREARM PROCEDURES EXCEPT MAJOR JOINT PROCEDURES WITHOUT CC */
"225" = "1" /* FOOT PROCEDURES*/
"226" = "1" /* SOFT TISSUE PROCEDURES WITH CC */
"227" = "1" /* SOFT TISSUE PROCEDURES WITHOUT CC */
"228" = "1" /* MAJOR THUMB OR JOINT PROCEDURES OR OTHER HAND OR WRIST PROCEDURES WITH CC */
"229" = "1" /* HAND OR WRIST PROCEDURES EXCEPT MAJOR JOINT PROCEDURES WITHOUT CC */
"230" = "1" /* LOCAL EXCISION AND REMOVAL OF INTERNAL FIXATION DEVICES OF HIP AND FEMUR */
"231" = "1" /* LOCAL EXCISION AND REMOVAL OF INTERNAL FIXATION DEVICES EXCEPT HIP AND FEMUR */
"232" = "1" /* ARTHROSCOPY */
"233" = "1" /* OTHER MUSCULOSKELETAL SYSTEM AND CONNECTIVE TISSUE OR PROCEDURES WITH CC */
"234" = "1" /* OTHER MUSCULOSKELETAL SYSTEM AND CONNECTIVE TISSUE OR PROCEDURES WITHOUT CC */
"257" = "1" /* TOTAL MASTECTOMY FOR MALIGNANCY WITH CC */
"258" = "1" /* TOTAL MASTECTOMY FOR MALIGNANCY WITHOUT CC */
"259" = "1" /* SUBTOTAL MASTECTOMY FOR MALIGNANCY WITH CC */
"260" = "1" /* SUBTOTAL MASTECTOMY FOR MALIGNANCY WITHOUT CC */
"261" = "1" /* BREAST PROCEDURE FOR NONMALIGNANCY EXCEPT BIOPSY AND LOCAL EXCISION */
"262" = "1" /* BREAST BIOPSY AND LOCAL EXCISION FOR NONMALIGNANCY */
"263" = "1" /* SKIN GRAFT AND/OR DEBRIDEMENT FOR SKIN ULCER OR CELLULITIS WITH CC */
"264" = "1" /* SKIN GRAFT AND OR DEBRIDEMENT FOR SKIN ULCER OR CELLULITIS WITHOUT CC */
"265" = "1" /* SKIN GRAFT AND OR DEBRIDEMENT EXCEPT FOR SKIN ULCER OR CELLULITIS WITH CC */
"266" = "1" /* SKIN GRAFT AND/OR DEBRIDEMENT EXCEPT FOR SKIN ULCER OR CELLUTLITIES WITHOUT CC */
"267" = "1" /* PERIANAL AND PILONIDAL PROCEDURES */
"268" = "1" /* SKIN, SUBCUTANEOUS TISSUE AND BREAST PLASTIC PROCEDURES */
"269" = "1" /* OTHER SKIN, SUBCUTANEOUS TISSUE AND BREAST PROCEDURES WITH CC */
"270" = "1" /* OTHER SKIN, SUBCUTANEOUS TISSUE AND BREAST PROCEDURS WITHOUT CC */
"285" = "1" /* AMPUTAETION OF LOWER LIMB FOR ENDOCRINE, NUTRITIONAL AND METABOLIC DISORDERS */
"286" = "1" /* ADRENAL AND PITUITARY PROCEDURES */
"287" = "1" /* SKIN GRAFTS AND WOUND DEBRIDEMENTS FOR ENDOCRINE, NUTRITIONAL AND METABOLIC DISORDERS */
"288" = "1" /* OR PROCEDURES FOR OBESITY */
"289" = "1" /* PARATHYROID PROCEDURES */
"290" = "1" /* THYROID PROCEDURES */
"291" = "1" /* THYROGLOSSAL PROCEDURES */
"292" = "1" /* OTHER ENDOCRINE, NUTRITIONAL AND METABOLIC OR PROCEDURES WITH CC */
"293" = "1" /* OTHER ENDOCRINE, NUTRITIONAL AND METABOLIC OR PROCEDURES WITHOUT CC */
"302" = "1" /* KIDNEY TRANSPLANT */
"303" = "1" /* KIDNEY, URETER AND MAJOR BLADDER PROCEDURES FOR NEOPLASM */
"304" = "1" /* KIDNEY, URETER AND MAJOR BLADDER PROCEDURES FOR NONNEOPLASMS WITH CC */
"305" = "1" /* KIDNEY, URETER AND MAJOR BLADDER PROCEDURES FOR NONEOPLSMS WITHOUT CC */
"306" = "1" /* PROSTATECTOMY WITH CC */
"307" = "1" /* PROSTATECTOMY WITHOUT CC */
"308" = "1" /* MINOR BLADDER PROCEDURES WITH CC */
"309" = "1" /* MINOR BLADDER PROCEDURES WITHOUT CC */
"310" = "1" /* TRANSURETHRAL PROCEDURES WITH CC */
"311" = "1" /* TRANSURETHRAL PROCEDURES WITHOUT CC */
"312" = "1" /* URETHRAL PROCEDURES, AGE GREATER THAN 17 WITH CC */
"313" = "1" /* URETHRAL PROCEDURES, AGE GREATER THAN 17 WITHOUT CC */
"314" = "1" /* URETHRAL PROCEDURES, AGE 0-17 */
"315" = "1" /* OTHER KIDNEY AND URINARY TRACT OR PROCEDURES */
"334" = "1" /* MAJOR MALE PELVIC PROCEDURES WITH CC */
"335" = "1" /* MAJOR MALE PELVIC PROCEDURES WITHOUT CC */
"336" = "1" /* TRANSURETHRAL PROSTATECTOMY WITH CC */
"337" = "1" /* TRANSURETHRAL PROSTATECTOMY WITHOUT CC */
"338" = "1" /* TESTES PROCEDURES FOR MALIGNANCY */
"339" = "1" /* TESTES PROCEDURES FOR NONMALIGNANCY, AGE GREATER THAN 17 */
"340" = "1" /* TESTES PROCEDURES FOR NONMALIGNANCY, AGE 0-17 */
"341" = "1" /* PENIS PROCEDURES */
"342" = "1" /* CIRCUMCISION, AGE GREATER THAN 17 */
"343" = "1" /* CIRCUMCISION, AGE 0-17 */
"344" = "1" /* OTHER MALE REPRODUCTIVE SYSTEM OR PROCEDURES FOR MALIGNANCY */
"345" = "1" /* OTHER MALE REPRODUCTIVE SYSTEM OR PROCEDURES EXCEPT FOR MALIGNANCY */
"353" = "1" /* PELVIC EVISCERATION, RADICAL HYSTERECTOMY AND RADICAL VULVECTOMY */
"354" = "1" /* UTERINE AND ADNEXA PROCEDURES FOR NONOVARIAN/ADNEXAL MALIGNANCY WITH CC */
"355" = "1" /* UTERINE AND ADNEXA PROCEDURES FOR NONOVARIAN/ADNEXA PROCEDURES WITHOUT CC*/
"356" = "1" /* FEMALE REPRODUCTIVE SYSTEM RECONSTRUCTIVE PROCEDURES */
"357" = "1" /* UTERINE AND ADNEXA PROCEDURES FOR OVARIAN OR ADNEXAL MALIGNANCY */
"358" = "1" /* UTERINE AND ADNEXA PROCEDURES FOR NONMALIGNANCY WITH CC */
"359" = "1" /* UTERINE AND ADNEXA PROCEDURES FOR NONMALIGNANCY WITHOUT CC */
"360" = "1" /* VAGINA, CERVIX AND VULVA PROCEDURES */
"361" = "1" /* LAPAROSCOPY AND INCISIONAL TUBAL INTERRUPTION */
"362" = "1" /* ENDOSCOPIC TUBAL INTERRUPTION */
"363" = "1" /* D AND C, CONIZATION AND RADIOIMPLANT FOR MALIGNANCY */
"364" = "1" /* D AND C, CONIZATION EXCEPT FOR MALIGNANCY */
"365" = "1" /* OTHER FEMALE REPRODUCTIVE SYSTEM OR PROCEDURES */
"370" = "1" /* CESAREAN SECTION WITH CC */
"371" = "1" /* CESAREAN SECTION WITHOUT CC */
"374" = "1" /* VAGINAL DELIVERY WITH STERILIZATION AND/OR D AND C */
"375" = "1" /* VAGINAL DELIVERY WITH OR PROCEDURE EXCEPT STERILIZATION AND/OR D AND C */
"377" = "1" /* POSTPARTUM AND POSTABORTION DIAGNOSES WITH OR PROCEDURE */
"381" = "1" /* ABORTION WITH D AND C ASPIRATION CURETTAGE OR HYSTERECTOMY */
"392" = "1" /* SPLENECTOMY, AGE GREATER THAN 17 */
"393" = "1" /* SPLENECTOMY, AGE 0-17 */
"394" = "1" /* OTHER OR PROCEDURES OF THE BLOOD AND BLOOD-FORMING ORGANS */
"400" = "1" /* LYMPHOMA AND LEUKEMIA WITH MAJOR OR PROCEDURES */
"401" = "1" /* LYMPHOMA AND NONACUTE LEUKEMIA WITH OTHER OR PROCEDURE WITH CC */
"402" = "1" /* LYMPHOMA AND NONACUTE LEUKEMIA WITH OTHER OR PROCEDURE WITHOUT CC */
"406" = "1" /* MYELOPROLIFERATIVE DISORDERS OR POORLY DIFFERENTIATED NEOPLASMS WITH MAJOR OR PROCEDURES WITH CC */
"407" = "1" /* MYELOPROLIFERATIVE DISORDERS OR POORLY DIFFERENTIATED NEOPLASMS WITH MAJOR OR PROCEDURES WITHOUT CC */
"408" = "1" /* MYELOPROLIFERATIVE DISORDERS OR POORLY DIFFERENTIATED NEOPLASMS WITH OTHER OR PROCEDURES */
"415" = "1" /* OR PROCEDURE FOR INFECTIOUS AND PARASITIC DISEASES */
"424" = "1" /* OR PROCEDURES WITH PRINCIPAL DIAGNOSIS OF MENTAL ILLNESS */
"439" = "1" /* SKIN GRAFTS FOR INJURIES */
"440" = "1" /* WOUND DEBRIDEMENTS FOR INJURIES */
"441" = "1" /* HAND PROCEDURES FOR INJURIES*/
"442" = "1" /* OTHER OR PROCEDURES FOR INJURIES WITH CC */
"443" = "1" /* OTHER OR PROCEDURES FOR INJURIES WITHOUT CC */
"458" = "1" /* NON-EXTENSIVE BURNS W SKIN GRAFT */
"459" = "1" /* NON-EXTENSIVE BURNS W WOUND DEBRIDEMENT OR OTHER O.R. PROC */
"461" = "1" /* OR PROCEDURES WITH DIAGNOSES OF OTHER CONTACT WITH HEALTH SERVICES */
"468" = "1" /* EXTENSIVE OR PROCEDURE UNRELATED TO PRINCIPAL DIAGNOSIS */
"471" = "1" /* BILATERAL OR MULTIPLE MAJOR JOINT PROCEDURES OF LOWER EXTREMITY */
"472" = "1" /* EXTENSIVE BURNS W O.R. PROCEDURE */
"476" = "1" /* PROSTATIC OR PROCEDURE UNRELATED TO PRINCIPAL DIAGNOSIS */
"477" = "1" /* NONEXTENSIVE OR PROCEDURE UNRELATED TO PRINCIPAL DIAGNOSIS */
"478" = "1" /* OTHER VASCULAR PROCEDURES WITH CC */
"479" = "1" /* OTHER VASCULAR PROCEDURES WITHOUT CC */
"480" = "1" /* LIVER TRANSPLANT */
"481" = "1" /* BONE MARROW TRANSPLANT */
"482" = "1" /* TRACHEOSTOMY FOR FACE, MOUTH AND NECK DIAGNOSES */
"483" = "1" /* TRACHEOSTOMY EXCEPT FOR FACE, MOUTH AND NECK DIAGNOSES */
"484" = "1" /* CRANIOTOMY FOR MULTIPLE SIGNIFICANT TRAUMA */
"485" = "1" /* LIMB REATTACHMENT, HIP AND FEMUR PROCEDURES FOR MULTIPLE SIGNIFICANT TRAUMA */
"486" = "1" /* OTHER OR PROCEDURES FOR MULTIPLE SIGNIFICANT TRAUMA */
"488" = "1" /* HIV WITH EXTENSIVE OR PROCEDURE */
"491" = "1" /* MAJOR JOINT AND LIMB REATTACHMENT PROCEDURES OF UPPER EXTREMITY */
"493" = "1" /* LAPAROSCOPIC CHOLECYSTECTOMY WITHOUT COMMON DUCT EXPLORATION WITH CC */
"494" = "1" /* LAPAROSCOPIC CHOLECYSTECTOMY WITHOUT COMMON DUCT EXPLORATION WITHOUT CC */
"495" = "1" /* LUNG TRANSPLANT */
"496" = "1" /* COMBINED ANTERIOR/POSTERIOR SPINAL FUSION */
"497" = "1" /* SPINAL FUSION WITH CC */
"498" = "1" /* SPINAL FUSION WITHOUT CC */
"499" = "1" /* BACK AND NECK PROCEDURES EXCEPT SPINAL FUSION WITH CC */
"500" = "1" /* BACK AND NECK PROCEDURES EXCEPT SPINAL FUSION WITHOUT CC */
"501" = "1" /* KNEE PROCEDURES WITH PRINCIPAL DIAGNOSIS OF INFECTION, WITH CC */
"502" = "1" /* KNEE PROCEDURES WITH PRINCIPAL DIAGNOSIS OF INFECTION, WITHOUT CC */
"503" = "1" /* KNEE PROCEDURES WITHOUT PRINCIPAL DIAGNOSIS OF INFECTION */
"504" = "1" /* EXTENSIVE 3RD DEGREE BURNS W SKIN GRAFT */
"506" = "1" /* FULL THICKNESS BURN W SKIN GRAFT OR INHAL INJ W CC OR SIG TRAUMA */
"507" = "1" /* FULL THICKNESS BURN W SKIN GRFT OR INHAL INJ W/O CC OR SIG TRAUMA */
"512" = "1" /* SIMULTANEOUS PANCREAS/KIDNEY TRANSPLANT */
"513" = "1" /* PANCREAS TRANSPLANT */
"514" = "1" /* CARDIAC DEFIBRILLATOR IMPLANT W CARDIAC CATH */
"515" = "1" /* CARDIAC DEFIBRILLATOR IMPLANT WITHOUT CARDIAC CATH */
"516" = "1" /* PERCUTANEOUS CARDIOVASC PROC W AMI */
"517" = "1" /* PERC CARDIO PROC W NON-DRUG ELUTING STENT WITHOUT AMI */
"518" = "1" /* PERC CARDIO PROC WITHOUT CORONARY ARTERY STENT OR AMI */
"519" = "1" /* CERVICAL SPINAL FUSION W CC */
"520" = "1" /* CERVICAL SPINAL FUSION WITHOUT CC */
"525" = "1" /* HEART ASSIST SYSTEM IMPLANT */
"526" = "1" /* PERCUTNEOUS CARDIOVASULAR PROC W DRUG ELUTING STENT W AMI */
"527" = "1" /* PERCUTNEOUS CARDIOVASULAR PROC W DRUG ELUTING STENT WITHOUT AMI */
"528" = "1" /* INTRACRANIAL VASCULAR PROC W PDX HEMORRHAGE */
"529" = "1" /* VENTRICULAR SHUNT PROCEDURES W CC */
"530" = "1" /* VENTRICULAR SHUNT PROCEDURES W/O CC */
"531" = "1" /* SPINAL PROCEDURES W CC */
"532" = "1" /* SPINAL PROCEDURES W/O CC */
"533" = "1" /* EXTRACRANIAL PROCEDURES W CC */
"534" = "1" /* EXTRACRANIAL PROCEDURES W/O CC */
"535" = "1" /* CARDIAC DEFIB IMPLANT W CARDIAC CATH W AMI/HF/SHOCK */
"536" = "1" /* CARDIAC DEFIB IMPLANT W CARDIAC CATH W/O AMI/HF/SHOCK */
"537" = "1" /* LOCAL EXCIS & REMOV OF INT FIX DEV EXCEPT HIP & FEMUR W CC */
"538" = "1" /* LOCAL EXCIS & REMOV OF INT FIX DEV EXCEPT HIP & FEMUR W/O CC */
"539" = "1" /* LYMPHOMA & LEUKEMIA W MAJOR OR PROCEDURE W CC */
"540" = "1" /* LYMPHOMA & LEUKEMIA W MAJOR OR PROCEDURE W/O CC */
"541" = "1" /* TRACH W MV 96+HRS OR PDX EXC FACE, MTH, FACE & NECK DX W/MAJ OR */
"542" = "1" /* TRACH W MV 96+HRS OR PDX EXC FACE, MTH, FACE & NECK DX W/O MJ OR */
"543" = "1" /* CRANIOTOMY WITH IMPLANTATION OF CHEMOTHERAPEUTIC AGENT OR ACUTE 
               COMPLEX CENTRAL NERVOUS SYSTEM PRINCIPAL DIAGNOSIS */
"544" = "1" /* MAJOR JOINT REPLACEMENT OR REATTACHMENT OF LOWER EXTREMITY */
"545" = "1" /* REVISION OF HIP OR KNEE REPLACEMENT */
"546" = "1" /* SPINAL FUSION EXC CERV WITH CURVATURE OF THE SPINE OR MALIG */
"547" = "1" /* CORONARY BYPASS W CARDIAC CATH W MAJOR CV DX */
"548" = "1" /* CORONARY BYPASS W CARDIAC CATH W/O MAJOR CV DX */
"549" = "1" /* CORONARY BYPASS W/O CARDIAC CATH W MAJOR CV DX */
"550" = "1" /* CORONARY BYPASS W/O CARDIAC CATH W/O MAJOR CV DX */
"551" = "1" /* PERMANENT CARDIAC PACEMAKER IMPL W MAJ CV DX OR AICD LEAD OR GNRTR */
"552" = "1" /* OTHER PERMANENT CARDIAC PACEMAKER IMPLANT W/O MAJOR CV DX */
"553" = "1" /* OTHER VASCULAR PROCEDURES W CC W MAJOR CV DX */
"554" = "1" /* OTHER VASCULAR PROCEDURES W CC W/O MAJOR CV DX */
"555" = "1" /* PERCUTANEOUS CARDIOVASCULAR PROC W MAJOR CV DX */
"556" = "1" /* PERCUTANEOUS CARDIOVASC PROC W NON-DRUG-ELUTING STENT W/O MAJ CV DX */
"557" = "1" /* PERCUTANEOUS CARDIOVASCULAR PROC W DRUG-ELUTING STENT W MAJOR CV DX */
"558" = "1" /* PERCUTANEOUS CARDIOVASCULAR PROC W DRUG-ELUTING STENT W/O MAJ CV DX */
"567" = "1" /* STOMACH, ESOPHAGEAL & DUODENAL PROC AGE > 17 W CC W MAJOR GI DX */
"568" = "1" /* STOMACH, ESOPHAGEAL & DUODENAL PROCEDURES PROC AGE > 17 W CC W/O MAJOR GI DX */
"569" = "1" /* MAJOR SMALL & LARGE BOWEL PROCEDURES W CC W MAJOR GI DX */
"570" = "1" /* MAJOR SMALL & LARGE BOWEL PROCEDURES W CC W/O MAJOR GI DX */
"573" = "1" /* MAJOR BLADDER PROCEDURES */
"577" = "1" /* CAROTID ARTERY STENT PROCEDURE */
"578" = "1" /* INFECTIOUS & PARASITIC DISEASES W OR PROCEDURE */
"579" = "1" /* POSTOPERATIVE OR POST-TRAUMATIC INFECTIONS W OR PROCEDURE */
OTHER = "0" ;

VALUE $SURGI2R
'001' = '1' /* Heart transplant or implant of heart assist system w MCC */
'002' = '1' /* Heart transplant or implant of heart assist system w/o MCC */
'003' = '1' /* ECMO or trach w MV 96+ hrs or PDX exc face, mouth & neck w maj O.R. */
'004' = '1' /* Trach w MV 96+ hrs or PDX exc face, mouth & neck w/o maj O.R. */
'005' = '1' /* Liver transplant w MCC or intestinal transplant */
'006' = '1' /* Liver transplant w/o MCC */
'007' = '1' /* Lung transplant */
'008' = '1' /* Simultaneous pancreas/kidney transplant */
'009' = '1' /* Bone marrow transplant */
'010' = '1' /* Pancreas transplant */
'011' = '1' /* Tracheostomy for face,mouth & neck diagnoses w MCC */
'012' = '1' /* Tracheostomy for face,mouth & neck diagnoses w CC */
'013' = '1' /* Tracheostomy for face,mouth & neck diagnoses w/o CC/MCC */
'014' = '1' /* ALLOGENEIC BONE MARROW TRANSPLANT */
'015' = '1' /* AUTOLOGOUS BONE MARROW TRANSPLANT */
'016' = '1' /* AUTOLOGOUS BONE MARROW TRANSPLANT W CC/MCC */
'017' = '1' /* AUTOLOGOUS BONE MARROW TRANSPLANT W/O CC/MCC */
'020' = '1' /* Intracranial vascular procedures w PDX hemorrhage w MCC */
'021' = '1' /* Intracranial vascular procedures w PDX hemorrhage w CC */
'022' = '1' /* Intracranial vascular procedures w PDX hemorrhage w/o CC/MCC */
'023' = '1' /* Cranio w major dev impl/acute complex CNS PDX w MCC or chemo implant */
'024' = '1' /* Cranio w major dev impl/acute complex CNS PDX w/o MCC */
'025' = '1' /* Craniotomy & endovascular intracranial procedures w MCC */
'026' = '1' /* Craniotomy & endovascular intracranial procedures w CC */
'027' = '1' /* Craniotomy & endovascular intracranial procedures w/o CC/MCC */
'028' = '1' /* Spinal procedures w MCC */
'029' = '1' /* Spinal procedures w CC or spinal neurostimulators */
'030' = '1' /* Spinal procedures w/o CC/MCC */
'031' = '1' /* Ventricular shunt procedures w MCC */
'032' = '1' /* Ventricular shunt procedures w CC */
'033' = '1' /* Ventricular shunt procedures w/o CC/MCC */
'034' = '1' /* Carotid artery stent procedure w MCC */
'035' = '1' /* Carotid artery stent procedure w CC */
'036' = '1' /* Carotid artery stent procedure w/o CC/MCC */
'037' = '1' /* Extracranial procedures w MCC */
'038' = '1' /* Extracranial procedures w CC */
'039' = '1' /* Extracranial procedures w/o CC/MCC */
'040' = '1' /* Periph/cranial nerve & other nerv syst proc w MCC */
'041' = '1' /* Periph/cranial nerve & other nerv syst proc w CC or periph neurostim */
'042' = '1' /* Periph/cranial nerve & other nerv syst proc w/o CC/MCC */
'113' = '1' /* Orbital procedures w CC/MCC */
'114' = '1' /* Orbital procedures w/o CC/MCC */
'115' = '1' /* Extraocular procedures except orbit */
'116' = '1' /* Intraocular procedures w CC/MCC */
'117' = '1' /* Intraocular procedures w/o CC/MCC */
'129' = '1' /* Major head & neck procedures w CC/MCC or major device */
'130' = '1' /* Major head & neck procedures w/o CC/MCC */
'131' = '1' /* Cranial/facial procedures w CC/MCC */
'132' = '1' /* Cranial/facial procedures w/o CC/MCC */
'133' = '1' /* Other ear, nose, mouth & throat O.R. procedures w CC/MCC */
'134' = '1' /* Other ear, nose, mouth & throat O.R. procedures w/o CC/MCC */
'135' = '1' /* Sinus & mastoid procedures w CC/MCC */
'136' = '1' /* Sinus & mastoid procedures w/o CC/MCC */
'137' = '1' /* Mouth procedures w CC/MCC */
'138' = '1' /* Mouth procedures w/o CC/MCC */
'139' = '1' /* Salivary gland procedures */
'163' = '1' /* Major chest procedures w MCC */
'164' = '1' /* Major chest procedures w CC */
'165' = '1' /* Major chest procedures w/o CC/MCC */
'166' = '1' /* Other resp system O.R. procedures w MCC */
'167' = '1' /* Other resp system O.R. procedures w CC */
'168' = '1' /* Other resp system O.R. procedures w/o CC/MCC */
'215' = '1' /* Other heart assist system implant */
'216' = '1' /* Cardiac valve & oth maj cardiothoracic proc w card cath w MCC */
'217' = '1' /* Cardiac valve & oth maj cardiothoracic proc w card cath w CC */
'218' = '1' /* Cardiac valve & oth maj cardiothoracic proc w card cath w/o CC/MCC */
'219' = '1' /* Cardiac valve & oth maj cardiothoracic proc w/o card cath w MCC */
'220' = '1' /* Cardiac valve & oth maj cardiothoracic proc w/o card cath w CC */
'221' = '1' /* Cardiac valve & oth maj cardiothoracic proc w/o card cath w/o CC/MCC */
'222' = '1' /* Cardiac defib implant w cardiac cath w AMI/HF/shock w MCC */
'223' = '1' /* Cardiac defib implant w cardiac cath w AMI/HF/shock w/o MCC */
'224' = '1' /* Cardiac defib implant w cardiac cath w/o AMI/HF/shock w MCC */
'225' = '1' /* Cardiac defib implant w cardiac cath w/o AMI/HF/shock w/o MCC */
'226' = '1' /* Cardiac defibrillator implant w/o cardiac cath w MCC */
'227' = '1' /* Cardiac defibrillator implant w/o cardiac cath w/o MCC */
'228' = '1' /* Other cardiothoracic procedures w MCC */
'229' = '1' /* Other cardiothoracic procedures w CC */
'230' = '1' /* Other cardiothoracic procedures w/o CC/MCC */
'231' = '1' /* Coronary bypass w PTCA w MCC */
'232' = '1' /* Coronary bypass w PTCA w/o MCC */
'233' = '1' /* Coronary bypass w cardiac cath w MCC */
'234' = '1' /* Coronary bypass w cardiac cath w/o MCC */
'235' = '1' /* Coronary bypass w/o cardiac cath w MCC */
'236' = '1' /* Coronary bypass w/o cardiac cath w/o MCC */
'237' = '1' /* Major cardiovasc procedures w MCC or thoracic aortic anuerysm repair */
'238' = '1' /* Major cardiovasc procedures w/o MCC */
'239' = '1' /* Amputation for circ sys disorders exc upper limb & toe w MCC */
'240' = '1' /* Amputation for circ sys disorders exc upper limb & toe w CC */
'241' = '1' /* Amputation for circ sys disorders exc upper limb & toe w/o CC/MCC */
'242' = '1' /* Permanent cardiac pacemaker implant w MCC */
'243' = '1' /* Permanent cardiac pacemaker implant w CC */
'244' = '1' /* Permanent cardiac pacemaker implant w/o CC/MCC */
'245' = '1' /* AICD lead & generator procedures */
'246' = '1' /* Perc cardiovasc proc w drug-eluting stent w MCC or 4+ vessels/stents */
'247' = '1' /* Perc cardiovasc proc w drug-eluting stent w/o MCC */
'248' = '1' /* Perc cardiovasc proc w non-drug-eluting stent w MCC or 4+ ves/stents */
'249' = '1' /* Perc cardiovasc proc w non-drug-eluting stent w/o MCC */
'250' = '1' /* Perc cardiovasc proc w/o coronary artery stent or AMI w MCC */
'251' = '1' /* Perc cardiovasc proc w/o coronary artery stent or AMI w/o MCC */
'252' = '1' /* Other vascular procedures w MCC */
'253' = '1' /* Other vascular procedures w CC */
'254' = '1' /* Other vascular procedures w/o CC/MCC */
'255' = '1' /* Upper limb & toe amputation for circ system disorders w MCC */
'256' = '1' /* Upper limb & toe amputation for circ system disorders w CC */
'257' = '1' /* Upper limb & toe amputation for circ system disorders w/o CC/MCC */
'258' = '1' /* Cardiac pacemaker device replacement w MCC */
'259' = '1' /* Cardiac pacemaker device replacement w/o MCC */
'260' = '1' /* Cardiac pacemaker revision except device replacement w MCC */
'261' = '1' /* Cardiac pacemaker revision except device replacement w CC */
'262' = '1' /* Cardiac pacemaker revision except device replacement w/o CC/MCC */
'263' = '1' /* Vein ligation & stripping */
'264' = '1' /* Other circulatory system O.R. procedures */
'265' = '1' /* AICD LEAD PROCEDURES */
'266' = '1' /* Endovascular Cardiac Valve Replacement w MCC */
'267' = '1' /* Endovascular Cardiac Valve Replacement w/o MCC */
'326' = '1' /* Stomach, esophageal & duodenal proc w MCC */
'327' = '1' /* Stomach, esophageal & duodenal proc w CC */
'328' = '1' /* Stomach, esophageal & duodenal proc w/o CC/MCC */
'329' = '1' /* Major small & large bowel procedures w MCC */
'330' = '1' /* Major small & large bowel procedures w CC */
'331' = '1' /* Major small & large bowel procedures w/o CC/MCC */
'332' = '1' /* Rectal resection w MCC */
'333' = '1' /* Rectal resection w CC */
'334' = '1' /* Rectal resection w/o CC/MCC */
'335' = '1' /* Peritoneal adhesiolysis w MCC */
'336' = '1' /* Peritoneal adhesiolysis w CC */
'337' = '1' /* Peritoneal adhesiolysis w/o CC/MCC */
'338' = '1' /* Appendectomy w complicated principal diag w MCC */
'339' = '1' /* Appendectomy w complicated principal diag w CC */
'340' = '1' /* Appendectomy w complicated principal diag w/o CC/MCC */
'341' = '1' /* Appendectomy w/o complicated principal diag w MCC */
'342' = '1' /* Appendectomy w/o complicated principal diag w CC */
'343' = '1' /* Appendectomy w/o complicated principal diag w/o CC/MCC */
'344' = '1' /* Minor small & large bowel procedures w MCC */
'345' = '1' /* Minor small & large bowel procedures w CC */
'346' = '1' /* Minor small & large bowel procedures w/o CC/MCC */
'347' = '1' /* Anal & stomal procedures w MCC */
'348' = '1' /* Anal & stomal procedures w CC */
'349' = '1' /* Anal & stomal procedures w/o CC/MCC */
'350' = '1' /* Inguinal & femoral hernia procedures w MCC */
'351' = '1' /* Inguinal & femoral hernia procedures w CC */
'352' = '1' /* Inguinal & femoral hernia procedures w/o CC/MCC */
'353' = '1' /* Hernia procedures except inguinal & femoral w MCC */
'354' = '1' /* Hernia procedures except inguinal & femoral w CC */
'355' = '1' /* Hernia procedures except inguinal & femoral w/o CC/MCC */
'356' = '1' /* Other digestive system O.R. procedures w MCC */
'357' = '1' /* Other digestive system O.R. procedures w CC */
'358' = '1' /* Other digestive system O.R. procedures w/o CC/MCC */
'405' = '1' /* Pancreas, liver & shunt procedures w MCC */
'406' = '1' /* Pancreas, liver & shunt procedures w CC */
'407' = '1' /* Pancreas, liver & shunt procedures w/o CC/MCC */
'408' = '1' /* Biliary tract proc except only cholecyst w or w/o c.d.e. w MCC */
'409' = '1' /* Biliary tract proc except only cholecyst w or w/o c.d.e. w CC */
'410' = '1' /* Biliary tract proc except only cholecyst w or w/o c.d.e. w/o CC/MCC */
'411' = '1' /* Cholecystectomy w c.d.e. w MCC */
'412' = '1' /* Cholecystectomy w c.d.e. w CC */
'413' = '1' /* Cholecystectomy w c.d.e. w/o CC/MCC */
'414' = '1' /* Cholecystectomy except by laparoscope w/o c.d.e. w MCC */
'415' = '1' /* Cholecystectomy except by laparoscope w/o c.d.e. w CC */
'416' = '1' /* Cholecystectomy except by laparoscope w/o c.d.e. w/o CC/MCC */
'417' = '1' /* Laparoscopic cholecystectomy w/o c.d.e. w MCC */
'418' = '1' /* Laparoscopic cholecystectomy w/o c.d.e. w CC */
'419' = '1' /* Laparoscopic cholecystectomy w/o c.d.e. w/o CC/MCC */
'420' = '1' /* Hepatobiliary diagnostic procedures w MCC */
'421' = '1' /* Hepatobiliary diagnostic procedures w CC */
'422' = '1' /* Hepatobiliary diagnostic procedures w/o CC/MCC */
'423' = '1' /* Other hepatobiliary or pancreas O.R. procedures w MCC */
'424' = '1' /* Other hepatobiliary or pancreas O.R. procedures w CC */
'425' = '1' /* Other hepatobiliary or pancreas O.R. procedures w/o CC/MCC */
'453' = '1' /* Combined anterior/posterior spinal fusion w MCC */
'454' = '1' /* Combined anterior/posterior spinal fusion w CC */
'455' = '1' /* Combined anterior/posterior spinal fusion w/o CC/MCC */
'456' = '1' /* Spinal fus exc cerv w spinal curv/malig/infec or 9+ fus w MCC */
'457' = '1' /* Spinal fus exc cerv w spinal curv/malig/infec or 9+ fus w CC */
'458' = '1' /* Spinal fus exc cerv w spinal curv/malig/infec or 9+ fus w/o CC/MCC */
'459' = '1' /* Spinal fusion except cervical w MCC */
'460' = '1' /* Spinal fusion except cervical w/o MCC */
'461' = '1' /* Bilateral or multiple major joint procs of lower extremity w MCC */
'462' = '1' /* Bilateral or multiple major joint procs of lower extremity w/o MCC */
'463' = '1' /* Wnd debrid & skn grft exc hand, for musculo-conn tiss dis w MCC */
'464' = '1' /* Wnd debrid & skn grft exc hand, for musculo-conn tiss dis w CC */
'465' = '1' /* Wnd debrid & skn grft exc hand, for musculo-conn tiss dis w/o CC/MCC */
'466' = '1' /* Revision of hip or knee replacement w MCC */
'467' = '1' /* Revision of hip or knee replacement w CC */
'468' = '1' /* Revision of hip or knee replacement w/o CC/MCC */
'469' = '1' /* Major joint replacement or reattachment of lower extremity w MCC */
'470' = '1' /* Major joint replacement or reattachment of lower extremity w/o MCC */
'471' = '1' /* Cervical spinal fusion w MCC */
'472' = '1' /* Cervical spinal fusion w CC */
'473' = '1' /* Cervical spinal fusion w/o CC/MCC */
'474' = '1' /* Amputation for musculoskeletal sys & conn tissue dis w MCC */
'475' = '1' /* Amputation for musculoskeletal sys & conn tissue dis w CC */
'476' = '1' /* Amputation for musculoskeletal sys & conn tissue dis w/o CC/MCC */
'477' = '1' /* Biopsies of musculoskeletal system & connective tissue w MCC */
'478' = '1' /* Biopsies of musculoskeletal system & connective tissue w CC */
'479' = '1' /* Biopsies of musculoskeletal system & connective tissue w/o CC/MCC */
'480' = '1' /* Hip & femur procedures except major joint w MCC */
'481' = '1' /* Hip & femur procedures except major joint w CC */
'482' = '1' /* Hip & femur procedures except major joint w/o CC/MCC */
'483' = '1' /* Major joint & limb reattachment proc of upper extremity w CC/MCC */
'484' = '1' /* Major joint & limb reattachment proc of upper extremity w/o CC/MCC */
'485' = '1' /* Knee procedures w pdx of infection w MCC */
'486' = '1' /* Knee procedures w pdx of infection w CC */
'487' = '1' /* Knee procedures w pdx of infection w/o CC/MCC */
'488' = '1' /* Knee procedures w/o pdx of infection w CC/MCC */
'489' = '1' /* Knee procedures w/o pdx of infection w/o CC/MCC */
'490' = '1' /* Back & neck proc exc spinal fusion w CC/MCC or disc device/neurostim */
'491' = '1' /* Back & neck proc exc spinal fusion w/o CC/MCC */
'492' = '1' /* Lower extrem & humer proc except hip,foot,femur w MCC */
'493' = '1' /* Lower extrem & humer proc except hip,foot,femur w CC */
'494' = '1' /* Lower extrem & humer proc except hip,foot,femur w/o CC/MCC */
'495' = '1' /* Local excision & removal int fix devices exc hip & femur w MCC */
'496' = '1' /* Local excision & removal int fix devices exc hip & femur w CC */
'497' = '1' /* Local excision & removal int fix devices exc hip & femur w/o CC/MCC */
'498' = '1' /* Local excision & removal int fix devices of hip & femur w CC/MCC */
'499' = '1' /* Local excision & removal int fix devices of hip & femur w/o CC/MCC */
'500' = '1' /* Soft tissue procedures w MCC */
'501' = '1' /* Soft tissue procedures w CC */
'502' = '1' /* Soft tissue procedures w/o CC/MCC */
'503' = '1' /* Foot procedures w MCC */
'504' = '1' /* Foot procedures w CC */
'505' = '1' /* Foot procedures w/o CC/MCC */
'506' = '1' /* Major thumb or joint procedures */
'507' = '1' /* Major shoulder or elbow joint procedures w CC/MCC */
'508' = '1' /* Major shoulder or elbow joint procedures w/o CC/MCC */
'509' = '1' /* Arthroscopy */
'510' = '1' /* Shoulder,elbow or forearm proc,exc major joint proc w MCC */
'511' = '1' /* Shoulder,elbow or forearm proc,exc major joint proc w CC */
'512' = '1' /* Shoulder,elbow or forearm proc,exc major joint proc w/o CC/MCC */
'513' = '1' /* Hand or wrist proc, except major thumb or joint proc w CC/MCC */
'514' = '1' /* Hand or wrist proc, except major thumb or joint proc w/o CC/MCC */
'515' = '1' /* Other musculoskelet sys & conn tiss O.R. proc w MCC */
'516' = '1' /* Other musculoskelet sys & conn tiss O.R. proc w CC */
'517' = '1' /* Other musculoskelet sys & conn tiss O.R. proc w/o CC/MCC */
'518' = '1' /* Back & Neck Procedure excluding spinal fusion w MCC or disc device/neurostimulator */
'519' = '1' /* Back & Neck Procedure excluding spinal fusion w CC */
'520' = '1' /* Back & Neck Procedure excluding spinal fusion w/o CC/MCC */
'570' = '1' /* SKIN DEBRIDEMENT W MCC */
'571' = '1' /* SKIN DEBRIDEMENT W CC */
'572' = '1' /* SKIN DEBRIDEMENT W/O CC/MCC */
'573' = '1' /* Skin graft for skn ulcer or cellulitis w MCC */
'574' = '1' /* Skin graft for skn ulcer or cellulitis w CC */
'575' = '1' /* Skin graft for skn ulcer or cellulitis w/o CC/MCC */
'576' = '1' /* Skin graft exc for skin ulcer or cellulitis w MCC */
'577' = '1' /* Skin graft exc for skin ulcer or cellulitis w CC */
'578' = '1' /* Skin graft exc for skin ulcer or cellulitis w/o CC/MCC */
'579' = '1' /* Other skin, subcut tiss & breast proc w MCC */
'580' = '1' /* Other skin, subcut tiss & breast proc w CC */
'581' = '1' /* Other skin, subcut tiss & breast proc w/o CC/MCC */
'582' = '1' /* Mastectomy for malignancy w CC/MCC */
'583' = '1' /* Mastectomy for malignancy w/o CC/MCC */
'584' = '1' /* Breast biopsy, local excision & other breast procedures w CC/MCC */
'585' = '1' /* Breast biopsy, local excision & other breast procedures w/o CC/MCC */
'614' = '1' /* Adrenal & pituitary procedures w CC/MCC */
'615' = '1' /* Adrenal & pituitary procedures w/o CC/MCC */
'616' = '1' /* Amputat of lower limb for endocrine,nutrit,& metabol dis w MCC */
'617' = '1' /* Amputat of lower limb for endocrine,nutrit,& metabol dis w CC */
'618' = '1' /* Amputat of lower limb for endocrine,nutrit,& metabol dis w/o CC/MCC */
'619' = '1' /* O.R. procedures for obesity w MCC */
'620' = '1' /* O.R. procedures for obesity w CC */
'621' = '1' /* O.R. procedures for obesity w/o CC/MCC */
'622' = '1' /* Skin grafts & wound debrid for endoc, nutrit & metab dis w MCC */
'623' = '1' /* Skin grafts & wound debrid for endoc, nutrit & metab dis w CC */
'624' = '1' /* Skin grafts & wound debrid for endoc, nutrit & metab dis w/o CC/MCC */
'625' = '1' /* Thyroid, parathyroid & thyroglossal procedures w MCC */
'626' = '1' /* Thyroid, parathyroid & thyroglossal procedures w CC */
'627' = '1' /* Thyroid, parathyroid & thyroglossal procedures w/o CC/MCC */
'628' = '1' /* Other endocrine, nutrit & metab O.R. proc w MCC */
'629' = '1' /* Other endocrine, nutrit & metab O.R. proc w CC */
'630' = '1' /* Other endocrine, nutrit & metab O.R. proc w/o CC/MCC */
'652' = '1' /* Kidney transplant */
'653' = '1' /* Major bladder procedures w MCC */
'654' = '1' /* Major bladder procedures w CC */
'655' = '1' /* Major bladder procedures w/o CC/MCC */
'656' = '1' /* Kidney & ureter procedures for neoplasm w MCC */
'657' = '1' /* Kidney & ureter procedures for neoplasm w CC */
'658' = '1' /* Kidney & ureter procedures for neoplasm w/o CC/MCC */
'659' = '1' /* Kidney & ureter procedures for non-neoplasm w MCC */
'660' = '1' /* Kidney & ureter procedures for non-neoplasm w CC */
'661' = '1' /* Kidney & ureter procedures for non-neoplasm w/o CC/MCC */
'662' = '1' /* Minor bladder procedures w MCC */
'663' = '1' /* Minor bladder procedures w CC */
'664' = '1' /* Minor bladder procedures w/o CC/MCC */
'665' = '1' /* Prostatectomy w MCC */
'666' = '1' /* Prostatectomy w CC */
'667' = '1' /* Prostatectomy w/o CC/MCC */
'668' = '1' /* Transurethral procedures w MCC */
'669' = '1' /* Transurethral procedures w CC */
'670' = '1' /* Transurethral procedures w/o CC/MCC */
'671' = '1' /* Urethral procedures w CC/MCC */
'672' = '1' /* Urethral procedures w/o CC/MCC */
'673' = '1' /* Other kidney & urinary tract procedures w MCC */
'674' = '1' /* Other kidney & urinary tract procedures w CC */
'675' = '1' /* Other kidney & urinary tract procedures w/o CC/MCC */
'707' = '1' /* Major male pelvic procedures w CC/MCC */
'708' = '1' /* Major male pelvic procedures w/o CC/MCC */
'709' = '1' /* Penis procedures w CC/MCC */
'710' = '1' /* Penis procedures w/o CC/MCC */
'711' = '1' /* Testes procedures w CC/MCC */
'712' = '1' /* Testes procedures w/o CC/MCC */
'713' = '1' /* Transurethral prostatectomy w CC/MCC */
'714' = '1' /* Transurethral prostatectomy w/o CC/MCC */
'715' = '1' /* Other male reproductive system O.R. proc for malignancy w CC/MCC */
'716' = '1' /* Other male reproductive system O.R. proc for malignancy w/o CC/MCC */
'717' = '1' /* Other male reproductive system O.R. proc exc malignancy w CC/MCC */
'718' = '1' /* Other male reproductive system O.R. proc exc malignancy w/o CC/MCC */
'734' = '1' /* Pelvic evisceration, rad hysterectomy & rad vulvectomy w CC/MCC */
'735' = '1' /* Pelvic evisceration, rad hysterectomy & rad vulvectomy w/o CC/MCC */
'736' = '1' /* Uterine & adnexa proc for ovarian or adnexal malignancy w MCC */
'737' = '1' /* Uterine & adnexa proc for ovarian or adnexal malignancy w CC */
'738' = '1' /* Uterine & adnexa proc for ovarian or adnexal malignancy w/o CC/MCC */
'739' = '1' /* Uterine,adnexa proc for non-ovarian/adnexal malig w MCC */
'740' = '1' /* Uterine,adnexa proc for non-ovarian/adnexal malig w CC */
'741' = '1' /* Uterine,adnexa proc for non-ovarian/adnexal malig w/o CC/MCC */
'742' = '1' /* Uterine & adnexa proc for non-malignancy w CC/MCC */
'743' = '1' /* Uterine & adnexa proc for non-malignancy w/o CC/MCC */
'744' = '1' /* D&C, conization, laparascopy & tubal interruption w CC/MCC */
'745' = '1' /* D&C, conization, laparascopy & tubal interruption w/o CC/MCC */
'746' = '1' /* Vagina, cervix & vulva procedures w CC/MCC */
'747' = '1' /* Vagina, cervix & vulva procedures w/o CC/MCC */
'748' = '1' /* Female reproductive system reconstructive procedures */
'749' = '1' /* Other female reproductive system O.R. procedures w CC/MCC */
'750' = '1' /* Other female reproductive system O.R. procedures w/o CC/MCC */
'765' = '1' /* Cesarean section w CC/MCC */
'766' = '1' /* Cesarean section w/o CC/MCC */
'767' = '1' /* Vaginal delivery w sterilization &/or D&C */
'768' = '1' /* Vaginal delivery w O.R. proc except steril &/or D&C */
'769' = '1' /* Postpartum & post abortion diagnoses w O.R. procedure */
'770' = '1' /* Abortion w D&C, aspiration curettage or hysterotomy */
'799' = '1' /* Splenectomy w MCC */
'800' = '1' /* Splenectomy w CC */
'801' = '1' /* Splenectomy w/o CC/MCC */
'802' = '1' /* Other O.R. proc of the blood & blood forming organs w MCC */
'803' = '1' /* Other O.R. proc of the blood & blood forming organs w CC */
'804' = '1' /* Other O.R. proc of the blood & blood forming organs w/o CC/MCC */
'820' = '1' /* Lymphoma & leukemia w major O.R. procedure w MCC */
'821' = '1' /* Lymphoma & leukemia w major O.R. procedure w CC */
'822' = '1' /* Lymphoma & leukemia w major O.R. procedure w/o CC/MCC */
'823' = '1' /* Lymphoma & non-acute leukemia w other O.R. proc w MCC */
'824' = '1' /* Lymphoma & non-acute leukemia w other O.R. proc w CC */
'825' = '1' /* Lymphoma & non-acute leukemia w other O.R. proc w/o CC/MCC */
'826' = '1' /* Myeloprolif disord or poorly diff neopl w maj O.R. proc w MCC */
'827' = '1' /* Myeloprolif disord or poorly diff neopl w maj O.R. proc w CC */
'828' = '1' /* Myeloprolif disord or poorly diff neopl w maj O.R. proc w/o CC/MCC */
'829' = '1' /* Myeloprolif disord or poorly diff neopl w other O.R. proc w CC/MCC */
'830' = '1' /* Myeloprolif disord or poorly diff neopl w other O.R. proc w/o CC/MCC */
'853' = '1' /* Infectious & parasitic diseases w O.R. procedure w MCC */
'854' = '1' /* Infectious & parasitic diseases w O.R. procedure w CC */
'855' = '1' /* Infectious & parasitic diseases w O.R. procedure w/o CC/MCC */
'856' = '1' /* Postoperative or post-traumatic infections w O.R. proc w MCC */
'857' = '1' /* Postoperative or post-traumatic infections w O.R. proc w CC */
'858' = '1' /* Postoperative or post-traumatic infections w O.R. proc w/o CC/MCC */
'876' = '1' /* O.R. procedure w principal diagnoses of mental illness */
'901' = '1' /* Wound debridements for injuries w MCC */
'902' = '1' /* Wound debridements for injuries w CC */
'903' = '1' /* Wound debridements for injuries w/o CC/MCC */
'904' = '1' /* Skin grafts for injuries w CC/MCC */
'905' = '1' /* Skin grafts for injuries w/o CC/MCC */
'906' = '1' /* Hand procedures for injuries */
'907' = '1' /* Other O.R. procedures for injuries w MCC */
'908' = '1' /* Other O.R. procedures for injuries w CC */
'909' = '1' /* Other O.R. procedures for injuries w/o CC/MCC */
'927' = '1' /* Extensive burns or full thickness burns w MV 96+ hrs w skin graft */
'928' = '1' /* Full thickness burn w skin graft or inhal inj w CC/MCC */
'929' = '1' /* Full thickness burn w skin graft or inhal inj w/o CC/MCC */
'939' = '1' /* O.R. proc w diagnoses of other contact w health services w MCC */
'940' = '1' /* O.R. proc w diagnoses of other contact w health services w CC */
'941' = '1' /* O.R. proc w diagnoses of other contact w health services w/o CC/MCC */
'955' = '1' /* Craniotomy for multiple significant trauma */
'956' = '1' /* Limb reattachment, hip & femur proc for multiple significant trauma */
'957' = '1' /* Other O.R. procedures for multiple significant trauma w MCC */
'958' = '1' /* Other O.R. procedures for multiple significant trauma w CC */
'959' = '1' /* Other O.R. procedures for multiple significant trauma w/o CC/MCC */
'969' = '1' /* HIV w extensive O.R. procedure w MCC */
'970' = '1' /* HIV w extensive O.R. procedure w/o MCC */
'981' = '1' /* Extensive O.R. procedure unrelated to principal diagnosis w MCC */
'982' = '1' /* Extensive O.R. procedure unrelated to principal diagnosis w CC */
'983' = '1' /* Extensive O.R. procedure unrelated to principal diagnosis w/o CC/MCC */
'984' = '1' /* Prostatic O.R. procedure unrelated to principal diagnosis w MCC */
'985' = '1' /* Prostatic O.R. procedure unrelated to principal diagnosis w CC */
'986' = '1' /* Prostatic O.R. procedure unrelated to principal diagnosis w/o CC/MCC */
'987' = '1' /* Non-extensive O.R. proc unrelated to principal diagnosis w MCC */
'988' = '1' /* Non-extensive O.R. proc unrelated to principal diagnosis w CC */
'989' = '1' /* Non-extensive O.R. proc unrelated to principal diagnosis w/o CC/MCC */
OTHER = '0' ;

 /* ---------------------------------------------------------------- */
 /* LOW BIRTH WEIGHT                                                 */
 /* ---------------------------------------------------------------- */

 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $LW500G
"76401" = "1"
"76411" = "1"
"76421" = "1"
"76491" = "1"
"76501" = "1"
"76511" = "1"
"V2131" = "1"
OTHER = "0" ;

VALUE $LW750G
"76402" = "1"
"76412" = "1"
"76422" = "1"
"76492" = "1"
"76502" = "1"
"76512" = "1"
"V2132" = "1"
OTHER   = "0";

VALUE $LW1000G
"76403" = "1"
"76413" = "1"
"76423" = "1"
"76493" = "1"
"76503" = "1"
"76513" = "1"
"V2132" = "1"
OTHER   = "0";

VALUE $LW1250G
"76404" = "1"
"76414" = "1"
"76424" = "1"
"76494" = "1"
"76504" = "1"
"76514" = "1"
"V2133" = "1"
OTHER   = "0";

VALUE $LW1500G
"76405" = "1"
"76415" = "1"
"76425" = "1"
"76495" = "1"
"76505" = "1"
"76515" = "1"
"V2133" = "1"
OTHER   = "0";

VALUE $LW1750G
"76406" = "1"
"76416" = "1"
"76426" = "1"
"76496" = "1"
"76506" = "1"
"76516" = "1"
"V2134" = "1"
OTHER   = "0";

VALUE $LW2000G
"76407" = "1"
"76417" = "1"
"76427" = "1"
"76497" = "1"
"76507" = "1"
"76517" = "1"
"V2134" = "1"
OTHER   = "0";

VALUE $LW2500G
"76408" = "1" /* LT-FOR-DATES 2000-2499G */
"76418" = "1" /* LT-DATE W/MAL 2000-2499G */
"76428" = "1" /* FETAL MALNUTR 2000-2499G */
"76498" = "1" /* FET GRWTH RET 2000-2499G */
"76508" = "1" /* EXTREME IMMAT 2000-2499G */
"76518" = "1" /* OTHER PRETERM INFANTS 2000-2499G */
"V2135" = "1"
OTHER   = "0";

VALUE $LW2500P
"76409" = "1" /* LT-FOR-DATES 2000-2499G */
"76419" = "1" /* LT-DATE W/MAL 2000-2499G */
"76429" = "1" /* FETAL MALNUTR 2000-2499G */
"76499" = "1" /* FET GRWTH RET 2000-2499G */
"76509" = "1" /* EXTREME IMMAT 2000-2499G */
"76519" = "1" /* OTHER PRETERM INFANTS 2000-2499G */
OTHER   = "0";


 /* ------------------------------------ */
 /* ACCIDENTAL PUNCTURE OR LACERATION   */
 /*   PROVIDER INDICATOR / PSI #  1     */
 /*   AREA     INDICATOR / PSI # TBD    */
 /* ----------------------------------- */

 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $TECHNID
"9982"  = "1" /* ACCIDENTAL PUNCTURE OR LACERATION DURING A PROCEDURE */
OTHER   = "0" ;

 /* ICD-9-CM PROCEDURE CODES: */

VALUE $SPINEP
"0301" = "1" /* REMOVAL FB SPINAL CANAL */
"0302" = "1" /* REOPEN LAMINECTOMY SITE */
"0309" = "1" /* SPINAL CANAL EXPLOR NEC */
"0353" = "1" /* VERTEBRAL FX REPAIR */
"036" = "1" /* SPINAL CORD ADHESIOLYSIS */
"8053" = "1" /* REP ANULUS FIBROSUS-GRFT */
"8054" = "1" /* REP ANULS FIBROS NEC/NOS */
"8100" = "1" /* SPINAL FUSION NOS */
"8101" = "1" /* ATLAS-AXIS FUSION */
"8102" = "1" /* OTHER CERVICAL FUS ANT */
"8103" = "1" /* OTHER CERVICAL FUS POST */
"8104" = "1" /* DORSAL/DORSOLUM FUS ANT */
"8105" = "1" /* DORSAL/DORSOLUM FUS POST */
"8106" = "1" /* LUMBAR/LUMBOSAC FUS ANT */
"8107" = "1" /* LUMBAR/LUMBOSAC FUS LAT */
"8108" = "1" /* LUMBAR/LUMBOSAC FUS POST */
"8130" = "1" /* SPINAL REFUSION NOS */
"8131" = "1" /* REFUSION OF ATLAS-AXIS */
"8132" = "1" /* REFUSION OF OTH CERV ANT */
"8133" = "1" /* REFUS OF OTH CERV POST */
"8134" = "1" /* REFUSION OF DORSAL ANT */
"8135" = "1" /* REFUSION OF DORSAL POST */
"8136" = "1" /* REFUSION OF LUMBAR ANT */
"8137" = "1" /* REFUSION OF LUMBAR LAT */
"8138" = "1" /* REFUSION OF LUMBAR POST */
"8139" = "1" /* REFUSION OF SPINE NEC */
"8162" = "1" /* FUS/REFUS 2-3 VERTEBRAE */
"8163" = "1" /* FUS/REFUS 4-8 VERTEBRAE */
"8164" = "1" /* FUS/REFUS 9 VERTEBRAE */
"8165" = "1" /* VERTEBROPLASTY */
"8166" = "1" /* KYPHOPLASTY */
"8451" = "1" /* INS SPINAL FUSION DEVICE */
"8458" = "1" /* IMP INTRSPINE DECOMP DEV */
"8459" = "1" /* INSERT OTHR SPIN DEVICE */
"8460" = "1" /* INSERT DISC PROS NOS */
"8461" = "1" /* INS PART DISC PROS CERV */
"8462" = "1" /* INS TOT DISC PROST CERV */
"8463" = "1" /* INS SPIN DISC PROS THOR */
"8464" = "1" /* INS PART DISC PROS LUMB */
"8465" = "1" /* INS TOTL DISC PROS LUMB */
"8466" = "1" /* REVISE DISC PROST CERV */
"8467" = "1" /* REVISE DISC PROST THORA */
"8468" = "1" /* REVISE DISC PROSTH LUMB */
"8469" = "1" /* REVISE DISC PROSTH NOS */
"8480" = "1" /* INS/REPL INTERSPINE DEV */
"8481" = "1" /* REV INTERSPINE DEVICE */
"8482" = "1" /* INS/REPL PDCL STABIL DEV */
"8483" = "1" /* REV PEDCL DYN STABIL DEV */
"8485" = "1" /* REV FACET REPLACE DEVICE */
OTHER   = "0" ;


 /* ------------------------------ */
 /* PRESSURE ULCER                 */
 /*   PROVIDER INDICATOR / PDI # 2 */
 /* ------------------------------ */

 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $DECUBID
"7070" = "1" /* DECUBITUS ULCER */
"70700" = "1" /* DECUBITUS ULCER SITE NOS */
"70701" = "1" /* DECUBITUS ULCER ELBOW */
"70702" = "1" /* DECUBITUS ULCER UP BACK */
"70703" = "1" /* DECUBITUS ULCER LOW BACK */
"70704" = "1" /* DECUBITUS ULCER HIP */
"70705" = "1" /* DECUBITUS ULCER BUTTOCK */
"70706" = "1" /* DECUBITUS ULCER ANKLE */
"70707" = "1" /* DECUBITUS ULCER HEEL */
"70709" = "1" /* DECUBITUS ULCER SITE NEC */
OTHER  = "0" ;

 /* EXCLUDE: STAGE I OR STAGE II */
 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $DECUBVD
"70723" = "1" /* PRESSURE ULCER, STAGE III */
"70724" = "1" /* PRESSURE ULCER, STAGE IV */
"70725" = "1" /* PRESSURE ULCER, UNSTAGEBL */
OTHER   = "0" ;

 /* EXCLUDE: DEBRIDEMENT OR PEDICLE GRAFT */
 /* ICD-9-CM PROCEDURE CODES: */

VALUE $DEBRIDP
"8345"  = "1" /* OTHER MYECTOMY */           
"8622"  = "1" /* EXC WOUND DEBRIDEMENT */    
"8628"  = "1" /* NONEXCIS DEBRIDEMENT WND */ 
"8670"  = "1" /* PEDICLE GRAFT/FLAP NOS */   
"8671"  = "1" /* CUT & PREP PEDICLE GRAFT */ 
"8672"  = "1" /* PEDICLE GRAFT ADVANCEMEN */ 
"8674"  = "1" /* ATTACH PEDICLE GRAFT NEC */ 
"8675"  = "1" /* REVISION OF PEDICLE GRFT */ 
OTHER   = "0" ;

 /* STRATIFIED BY: HEMIPLEGIA, PARAPLEGIA, OR QUADRIPLEGIA */
 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $HEMIPID
"33371" = "1" /* ATHETOID CEREBRAL PALSY */  
"3341 " = "1" /* HERED SPASTIC PARAPLEGIA */
"3420"  = "1" /* FLACCID HEMIPLEGIA */
"34200" = "1" /* FLCCD HMIPLGA UNSPF SIDE */
"34201" = "1" /* FLCCD HMIPLGA DOMNT SIDE */
"34202" = "1" /* FLCCD HMIPLG NONDMNT SDE */
"3421"  = "1" /* SPASTIC HEMIPLEGIA */
"34210" = "1" /* SPSTC HMIPLGA UNSPF SIDE */
"34211" = "1" /* SPSTC HMIPLGA DOMNT SIDE */
"34212" = "1" /* SPSTC HMIPLG NONDMNT SDE */
"34280" = "1" /* OT SP HMIPLGA UNSPF SIDE */
"34281" = "1" /* OT SP HMIPLGA DOMNT SIDE */
"34282" = "1" /* OT SP HMIPLG NONDMNT SDE */
"3429"  = "1" /* HEMIPLEGIA, UNSPECIFIED */
"34290" = "1" /* UNSP HEMIPLGA UNSPF SIDE */
"34291" = "1" /* UNSP HEMIPLGA DOMNT SIDE */
"34292" = "1" /* UNSP HMIPLGA NONDMNT SDE */
"3430"  = "1" /* INFANTILE CEREBRAL PALSY, DIPLEGIC */
"3431"  = "1" /* INFANTILE CEREBRAL PALSY, HEMIPLEGIC */
"3432"  = "1" /* INFANTILE CEREBRAL PALSY, QUADRIPLEGIC */
"3433"  = "1" /* INFANTILE CEREBRAL PALSY, MONOPLEGIC */
"3434"  = "1" /* INFANTILE CEREBRAL PALSY INFANTILE HEMIPLEGIA */
"3438"  = "1" /* INFANTILE CEREBRAL PALSY OTHER SPECIFIED INFANTILE CEREBRAL PALSY */
"3439"  = "1" /* INFANTILE CEREBRAL PALSY, INFANTILE CEREBRAL PALSY, UNSPECIFIED */
"3440"  = "1" /* QUADRIPLEGIA AND QUADRIPARESIS */
"34400" = "1" /* QUADRIPLEGIA, UNSPECIFD */
"34401" = "1" /* QUADRPLG C1-C4, COMPLETE */
"34402" = "1" /* QUADRPLG C1-C4, INCOMPLT */
"34403" = "1" /* QUADRPLG C5-C7, COMPLETE */
"34404" = "1" /* QUADRPLG C5-C7, INCOMPLT */
"34409" = "1" /* OTHER QUADRIPLEGIA */
"3441"  = "1" /* PARAPLEGIA */
"3442"  = "1" /* DIPLEGIA OF UPPER LIMBS */
"3443"  = "1" /* MONOPLEGIA OF LOWER LIMB */
"34430" = "1" /* MONPLGA LWR LMB UNSP SDE */
"34431" = "1" /* MONPLGA LWR LMB DMNT SDE */
"34432" = "1" /* MNPLG LWR LMB NONDMNT SD */
"3444"  = "1" /* MONOPLEGIA OF UPPER LIMB */
"34440" = "1" /* MONPLGA UPR LMB UNSP SDE */
"34441" = "1" /* MONPLGA UPR LMB DMNT SDE */
"34442" = "1" /* MNPLG UPR LMB NONDMNT SD */
"3445"  = "1" /* UNSPECIFIED MONOPLEGIA */
"3446" = "1" /* CAUDA EQUINA SYNDROME */
"34460" = "1" /* CAUDA EQUINA SYNDROME, WITHOUT MENTION OF NEUROGENIC BLADDER */
"34461" = "1" /* CAUDA EQUINA SYNDROME, WITH NEUROGENIC BLADDER */
"3448"  = "1" /* OTHER SPECIFIED PARALYTIC SYNDROMES */
"34481" = "1" /* LOCKED-IN STATE */
"34489" = "1" /* OTH SPCF PARALYTIC SYND */
"3449"  = "1" /* PARALYSIS, UNSPECIFIED */
"43820" = "1" /* LATE EF-HEMPLGA SIDE NOS */
"43821" = "1" /* LATE EF-HEMPLGA DOM SIDE */
"43822" = "1" /* LATE EF-HEMIPLGA NON-DOM */
"43830" = "1" /* LATE EF-MPLGA UP LMB NOS */
"43831" = "1" /* LATE EF-MPLGA UP LMB DOM */
"43832" = "1" /* LT EF-MPLGA UPLMB NONDOM */
"43840" = "1" /* LTE EF-MPLGA LOW LMB NOS */
"43841" = "1" /* LTE EF-MPLGA LOW LMB DOM */
"43842" = "1" /* LT EF-MPLGA LOWLMB NONDM */
"43850" = "1" /* LT EF OTH PARAL SIDE NOS */
"43851" = "1" /* LT EF OTH PARAL DOM SIDE */
"43852" = "1" /* LT EF OTH PARALS NON-DOM */
"43853" = "1" /* LT EF OTH PARALS-BILAT */
"76870" = "1" /* HYPOXC-ISCHEM ENCEPH NOS */ 
"76872" = "1" /* MOD HYPOX-ISCHEM ENCEPH */  
"76873" = "1" /* SEV HYPOX-ISCHEM ENCEPH */  
OTHER   = "0" ;


 /* STRATIFIED BY: SPINA BIFIDA */
 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $SPIBIFD
"74100"  = "1" /* SPINA BIFIDA, W HYDROCEPHALUS UNSPECIFIED REGION */
"74101"  = "1" /* SPINA BIFIDA, W HYDROCEPHALUS CERVICAL REGION */
"74102"  = "1" /* SPINA BIFIDA, W HYDROCEPHALUS DORSAL REGION */
"74103"  = "1" /* SPINA BIFIDA, W HYDROCEPHALUS LUMBAR REGION */
"74190"  = "1" /* SPINA BIFIDA, W/O HYDROCEPHALUS UNSPECIFIED REGION */
"74191"  = "1" /* SPINA BIFIDA, W/O HYDROCEPHALUS CERVICAL REGION */
"74192"  = "1" /* SPINA BIFIDA, W/O HYDROCEPHALUS DORSAL REGION */
"74193"  = "1" /* SPINA BIFIDA, W/O HYDROCEPHALUS LUMBAR REGION */
OTHER   = "0" ;

 /* STRATIFIED BY: Anoxic Brain */
 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $ANOXBD
"3481"  = "1" /* ANOXIC BRAIN DAMAGE */
"7685"  = "1" /* SEVERE BIRTH ASPHYXIA */
OTHER   = "0" ;

 /* STRATIFIED BY: other continuous mechanical ventilation code for 96 or more consecutive hours */
 /* ICD-9-CM PROCEDURE CODES: */

VALUE $CMVENP
"9672"  = "1" /* CONTINUOUS MECHANICAL VENTILATION FOR 96 CONSECUTIVE HOURS OR MORE */
OTHER   = "0" ;


 /* -------------------------------------- */
 /* FOREIGN BODY LEFT IN DURING PROCEDURE */
 /*   PROVIDER INDICATOR / PDI #  3       */
 /*   AREA     INDICATOR / PDI # TBD      */
 /* ------------------------------------- */

 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $FOREIID
"9984"  = "1" /* FOREIGN BODY ACCIDENTALLY LEFT DURING A PROCEDURE */
"9987"  = "1" /* ACUTE REACTION TO FOREIGN SUBSTANCE ACCIDENTALLY LEFT DURING   A PROCEDURE */
OTHER   = "0" ;


 /* ------------------------------- */
 /* IATROGENIC PNEUMOTHORAX         */
 /*   PROVIDER INDICATOR / PDI #4&5 */
 /*   AREA     INDICATOR / PDI #TBD */
 /* ------------------------------- */

 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $IATROID
"5121"  = "1" /* IATROGENIC PNEUMOTHORAX */
OTHER   = "0" ;

/* EXCLUDE: CHEST TRAUMA */
/* ICD-9-CM DIAGNOSIS CODES: */

VALUE $CTRAUMD
"80700" = "1" /* FRACTURE RIB NOS-CLOSED */
"80701" = "1" /* FRACTURE ONE RIB-CLOSED */
"80702" = "1" /* FRACTURE TWO RIBS-CLOSED */
"80703" = "1" /* FRACTURE THREE RIBS-CLOS */
"80704" = "1" /* FRACTURE FOUR RIBS-CLOSE */
"80705" = "1" /* FRACTURE FIVE RIBS-CLOSE */
"80706" = "1" /* FRACTURE SIX RIBS-CLOSED */
"80707" = "1" /* FRACTURE SEVEN RIBS-CLOS */
"80708" = "1" /* FX EIGHT/MORE RIB-CLOSED */
"80709" = "1" /* FX MULT RIBS NOS-CLOSED */
"80710" = "1" /* FRACTURE RIB NOS-OPEN */
"80711" = "1" /* FRACTURE ONE RIB-OPEN */
"80712" = "1" /* FRACTURE TWO RIBS-OPEN */
"80713" = "1" /* FRACTURE THREE RIBS-OPEN */
"80714" = "1" /* FRACTURE FOUR RIBS-OPEN */
"80715" = "1" /* FRACTURE FIVE RIBS-OPEN */
"80716" = "1" /* FRACTURE SIX RIBS-OPEN */
"80717" = "1" /* FRACTURE SEVEN RIBS-OPEN */
"80718" = "1" /* FX EIGHT/MORE RIBS-OPEN */
"80719" = "1" /* FX MULT RIBS NOS-OPEN */
"8072"  = "1" /* FRACTURE OF STERNUM-CLOS */
"8073"  = "1" /* FRACTURE OF STERNUM-OPEN */
"8074"  = "1" /* FLAIL CHEST */
"8075"  = "1" /* FX LARYNX/TRACHEA-CLOSED */
"8076"  = "1" /* FX LARYNX/TRACHEA-OPEN */
"8090"  = "1" /* FRACTURE TRUNK BONE-CLOS */
"8091"  = "1" /* FRACTURE TRUNK BONE-OPEN */
"8600"  = "1" /* TRAUM PNEUMOTHORAX-CLOSE */
"8601"  = "1" /* TRAUM PNEUMOTHORAX-OPEN */
"8602"  = "1" /* TRAUM HEMOTHORAX-CLOSED */
"8603"  = "1" /* TRAUM HEMOTHORAX-OPEN */
"8604"  = "1" /* TRAUM PNEUMOHEMOTHOR-CL */
"8605"  = "1" /* TRAUM PNEUMOHEMOTHOR-OPN */
"86100" = "1" /* HEART INJURY NOS-CLOSED */
"86101" = "1" /* HEART CONTUSION-CLOSED */
"86102" = "1" /* HEART LACERATION-CLOSED */
"86103" = "1" /* HEART CHAMBER LACERAT-CL */
"86110" = "1" /* HEART INJURY NOS-OPEN */
"86111" = "1" /* HEART CONTUSION-OPEN */
"86112" = "1" /* HEART LACERATION-OPEN */
"86113" = "1" /* HEART CHAMBER LACER-OPN */
"86120" = "1" /* LUNG INJURY NOS-CLOSED */
"86121" = "1" /* LUNG CONTUSION-CLOSED */
"86122" = "1" /* LUNG LACERATION-CLOSED */
"86130" = "1" /* LUNG INJURY NOS-OPEN */
"86131" = "1" /* LUNG CONTUSION-OPEN */
"86132" = "1" /* LUNG LACERATION-OPEN */
"8620"  = "1" /* DIAPHRAGM INJURY-CLOSED */
"8621"  = "1" /* DIAPHRAGM INJURY-OPEN */
"86221" = "1" /* BRONCHUS INJURY-CLOSED */
"86222" = "1" /* ESOPHAGUS INJURY-CLOSED */
"86229" = "1" /* INTRATHORACIC INJ NEC-CL */
"86231" = "1" /* BRONCHUS INJURY-OPEN */
"86232" = "1" /* ESOPHAGUS INJURY-OPEN */
"86239" = "1" /* INTRATHORAC INJ NEC-OPEN */
"8628"  = "1" /* INTRATHORACIC INJ NOS-CL */
"8629"  = "1" /* INTRATHORAC INJ NOS-OPEN */
"8750"  = "1" /* OPEN WOUND OF CHEST */
"8751"  = "1" /* OPEN WOUND CHEST-COMPL */
"8760"  = "1" /* OPEN WOUND OF BACK */
"8761"  = "1" /* OPEN WOUND BACK-COMPL */
"9010"  = "1" /* INJURY THORACIC AORTA */
"9011"  = "1" /* INJ INNOMIN/SUBCLAV ART */
"9012"  = "1" /* INJ SUPERIOR VENA CAVA */
"9013"  = "1" /* INJ INNOMIN/SUBCLAV VEIN */
"90140" = "1" /* INJ PULMONARY VESSEL NOS */
"90141" = "1" /* INJURY PULMONARY ARTERY */
"90142" = "1" /* INJURY PULMONARY VEIN */
"90181" = "1" /* INJ INTERCOSTAL ART/VEIN */
"90182" = "1" /* INJ INT MAMMARY ART/VEIN */
"90183" = "1" /* INJ MULT THORACIC VESSEL */
"90189" = "1" /* INJ THORACIC VESSEL NEC */
"9019"  = "1" /* INJ THORACIC VESSEL NOS */
"9110"  = "1" /* SUPERFICIAL INJURY OF TRUNK, ABRASION OR FRICTION BURN WITHOUT MENTION OF INFECTION */
"9111"  = "1" /* SUPERFICIAL INJURY OF TRUNK, ABRASION OR FRICTION BURN, INFECTED */
"9118"  = "1" /* OTHER AND UNSPECIFIED SUPERFICIAL INJURY OF TRUNK, WITHOUT MENTION OF INFECTION */
"9119"  = "1" /* OTHER AND UNSPECIFIED SUPERFICIAL INJURY OF TRUNK, INFECTED */
"9220"  = "1" /* CONTUSION OF TRUNK, BREAST */
"9221"  = "1" /* CONTUSION OF TRUNK, CHEST WALL */
"9223"  = "1" /* CONTUSION OF TRUNK, BACK */
"92231" = "1" /* BACK CONTUSION */
"92233" = "1" /* INTERSCPLR REG CONTUSION */ 
"9228"  = "1" /* CONTUSION OF TRUNK, MULTIPLE SITES OF TRUNK */
"9229"  = "1" /* CONTUSION OF TRUNK, UNSPECIFIED PART */
"92611" = "1" /* CRUSHING INJURY BACK */
"92619" = "1" /* CRUSHING INJ TRUNK NEC */
"9268"  = "1" /* MULT CRUSHING INJ TRUNK */
"9269"  = "1" /* CRUSHING INJ TRUNK NOS */
"9290"  = "1" /* CRUSH INJ MULT SITE NEC */
"9299"  = "1" /* CRUSHING INJURY NOS */
"9541"  = "1" /* INJURY TO OTHER NERVES OF TRUNK, OTHER SYMPATHETIC */
"9548"  = "1" /* INJURY TO OTHER NERVES OF TRUNK, OTHER SPECIFIED NERVES OF TRUNK */
"9549"  = "1" /* INJURY TO OTHER NERVES OF TRUNK, UNSPECIFIED NERVES OF TRUNK */
"95911" = "1" /* OTHER INJURY TO CHEST WALL */
"95919" = "1" /* OTHER INJURY TO OTHER SITES OF TRUNK */
"9599"  = "1" /* INJURY, UNSPECIFIED SITE */
OTHER   = "0" ;

 /* EXCLUDE: PLEURAL EFFUSION */
 /* ICD-9-CM DIAGNOSIS CODES: */;

VALUE $PLEURAD
"0101 "  = "1" /* TUBERCULOUS PLEURISY IN PRIMARY PROGRESSIVE TUBERCULOSIS */
"01010"  = "1" /* TUBERCULOUS PLEURISY IN PRIMARY PROGRESSIVE TUBERCULOSIS, UNSPECIFIED */
"01011"  = "1" /* TPIPPT, BACTERIAL OR HISTOLOGICAL EXAM NOT DONE */
"01012"  = "1" /* TPIPPT, BACTERIAL OR HISTOLOGICAL EXAM UNKNOWN */
"01013"  = "1" /* TPIPPT, TUBERCLE BACILI FOUND BY MICROSCOPY */
"01014"  = "1" /* TPIPPT, TUBERCLE BACILI NOT FOUND BY MICROSCOPY BUT BY BACTERIAL CULTURE */
"01015"  = "1" /* TPIPPT, TUBERCLE BACILI NOT FOUND BY BACTERIOLOGICAL BUT CONFIRMED HISTOLOGICALLY */
"01016"  = "1" /* TPIPPT, TUBERCLE BACILI NOT FOUND BY BACTERILOGICAL OR HISTOLOGICAL BUT CONFIRMED OTHER METHODS */
"0117 "  = "1" /* TUBRCULOUS PNEUMOTHORAX */
"01170"  = "1" /* TUBRCULOUS PNEUMOTHORAX, UNSPECIFIED */
"01171"  = "1" /* TPNEU, BACTERIAL OR HISTOLOGICAL EXAM NOT DONE */
"01172"  = "1" /* TPNEU, BACTERIAL OR HISTOLOGICAL EXAM UNKNOWN */
"01173"  = "1" /* TPNEU, TUBERCLE BACILI FOUND BY MICROSCOPY */
"01174"  = "1" /* TPNEU, TUBERCLE BACILI NOT FOUND BY MICROSCOPY BUT BY BACTERIAL CULTURE */
"01175"  = "1" /* TPNEU, TUBERCLE BACILI NOT FOUND BY BACTERIOLOGICAL BUT CONFIRMED HISTOLOGICALLY */
"01176"  = "1" /* TPENU, TUBERCLE BACILI NOT FOUND BY BACTERILOGICAL OR HISTOLOGICAL BUT CONFIRMED OTHER METHODS */
"0120 "  = "1" /* TUBERCULOUS PLEURISY */
"01200"  = "1" /* TUBERCULOUS PLEURISY, UNSPECIFIED */
"01201"  = "1" /* TP, BACTERIAL OR HISTOLOGICAL EXAM NOT DONE */
"01202"  = "1" /* TP, BACTERIAL OR HISTOLOGICAL EXAM UNKNOWN */
"01203"  = "1" /* TP, TUBERCLE BACILI FOUND BY MICROSCOPY */
"01204"  = "1" /* TP, TUBERCLE BACILI NOT FOUND BY MICROSCOPY BUT BY BACTERIAL CULTURE */
"01205"  = "1" /* TP, TUBERCLE BACILI NOT FOUND BY BACTERIOLOGICAL BUT CONFIRMED HISTOLOGICALLY */
"01206"  = "1" /* TP, TUBERCLE BACILI NOT FOUND BY BACTERILOGICAL OR HISTOLOGICAL BUT CONFIRMED OTHER METHODS */
"1972 "  = "1" /* SECOND MALIG NEO PLEURA */  
"5111 "  = "1" /* WITH EFUSION, WITH MENTION OF A BACTERIAL CAUSE OTHER THAN TUBERCULOSIS */
"5118 "  = "1" /* OTHER SPECIFIED FORM OF EFFUSION, EXCEPT TUBERCULOUS */
"51181"  = "1" /* MALIGNANT PLEURAL EFFUSN */
"51189"  = "1" /* EFFUSION NEC EXC TB */
"5119 "  = "1" /* UNSPECIFIED PLEURAL EFFUSION */
OTHER    = "0" ;

 /* EXCLUDE: THORACIC SURGERY */
 /* ICD-9-CM PROCEDURE CODES: */

VALUE $THORAIP
"0522" = "1" /* CERVICAL SYMPATHECTOMY */
"0523" = "1" /* LUMBAR SYMPATHECTOMY */
"0529" = "1" /* OTHER SYMPATHECTOMY */
"0780" = "1" /* THYMECTOMY NOS */
"0781" = "1" /* OTH PART EXCISION THYMUS */
"0782" = "1" /* OTH TOTL EXCISION THYMUS */
"0783" = "1" /* THORAC PART EXISN THYMUS */
"0784" = "1" /* THORAC TOTAL EXC THYMUS */
"3121" = "1" /* MEDIASTINAL TRACHEOSTOMY */
"3145" = "1" /* OPEN BIOPSY OF LARYNX OR TRACHEA */
"3173" = "1" /* CLOSURE OF OTHER FISTULA OF TRACHEA */
"3179" = "1" /* OTHER REPAIR AND PLASTIC OPERATIONS ON TRACHEA */
"3199" = "1" /* OTHER OPERATIONS ON TRACHEA */
"3209" = "1" /* OTHER LOCAL EXCISION OR DESTRUCTION OF LESION OR TISSUE OF BRONCHUS */
"321"  = "1" /* OTHER EXCISION OF BRONCHUS */
"3220" = "1" /* THORAC EXC LUNG LESION */
"3221" = "1" /* PLICATION OF EMPHYSEMATIOUS BLEB */
"3222" = "1" /* LUNG VOLUME REDUCTION SURGERY */
"3223" = "1" /* OPEN ABLTN LUNG LES/TISS */
"3224" = "1" /* PERC ABLTN LUNG LES/TISS */ 
"3225" = "1" /* THOR ABLTN LUNG LES/TISS */ 
"3226" = "1" /* ABLTN LUNG TISS NEC/NOS */  
"3227" = "1" /* BRNC THRMPLSTY, ABLT MSCL */ 
"3228" = "1" /* ENDOSCOPIC EXCISION OR DETRUCTION OF LESION OR TISSUE OF LUNG */
"3229" = "1" /* OTHER LOCAL EXCISION OR DESTRUCTION OF LESION OR TISSUE OF LUNG */
"323"  = "1" /* SEGMENTAL RESECTION OF LUNG */
"3230" = "1" /* THORAC SEG LUNG RESECT */
"3239" = "1" /* OTH SEG LUNG RESECT NOS */
"324"  = "1" /* LOBECTOMY OF LUNG */
"3241" = "1" /* THORAC LOBECTOMY LUNG */
"3249" = "1" /* LOBECTOMY OF LUNG NEC */
"325"  = "1" /* COMPLETE PNEUMONECTOMY */
"3250" = "1" /* THORACOSPC PNEUMONECTOMY */
"3259" = "1" /* OTHER PNEUMONECTOMY NOS */
"326"  = "1" /* RADICAL DISSECTION OF THORACIC STRUCTURES */
"329"  = "1" /* OTHER EXCISION OF LUNG */
"330"  = "1" /* INCISION OF BRONCHUS */
"331"  = "1" /* INCISION OF LUNG */
"3320" = "1" /* THORACOSCOPC LUNG BIOPSY */
"3325" = "1" /* OPEN BIOPSY OF BRONCHUS */
"3327" = "1" /* CLOSED ENDOSCOPIC BIOPSY OF LUNG */
"3331" = "1" /* DESTRUCTION OF PHRENIC NERVE FOR COLLAPSE OF LUNG (NO LONGER PERFORMED) */
"3332" = "1" /* ARTIFICAL PNEUMOTHORAX FOR COLLAPSE OF LUNG */
"3334" = "1" /* THORACOPLASTY */
"3339" = "1" /* OTHER SURGICAL COLLAPSE OF LUNG */
"3341" = "1" /* SUTURE OF LACERATION OF BRONCHUS */
"3342" = "1" /* CLOSURE OF BRONCHIAL FISTULA */
"3343" = "1" /* CLOSURE OF LACERATION OF LUNG */
"3348" = "1" /* OTHER REPAIR OAND PLASTIC OPERATIONS ON BRONCHUS */
"3349" = "1" /* OTHER REPAIR AND PLASTIC OPERATIONS ON LUNG */
"335"  = "1" /* LUNG TRANSPLANTATION */
"3350" = "1" /* LUNG TRANSPLANTATION, NOS */
"3351" = "1" /* UNILATERAL LUNG TRANSPLANTATION */
"3352" = "1" /* BILATERAL LUNG TRANSPLANTATION */
"336"  = "1" /* COMBINED HEART-LUNG TRANSPLANTATION */
"3392" = "1" /* LIGATION OF BRONCHUS */
"3393" = "1" /* PUNCTURE OF LUNG */
"3398" = "1" /* OTHER OPERATIONS ON BRONCHUS */
"3399" = "1" /* OTHER OPERATIONS ON LUNG */
"3329" = "1" /* OTHER DIAGNOSTIC PROCEDURE ON LUNG AND BRONCHUS */
"3333" = "1" /* PNEUMOPERITONEUM FOR COLLAPSE OF LUNG */
"3401" = "1" /* INCISION OF CHEST WALL */
"3402" = "1" /* EXPLORATORY THORACOTOMY */
"3403" = "1" /* REOPENING OF RECENT THORACOTOMY SITE */
"3405" = "1" /* CREATION OF PLEUROPERITONEAL SHUNT */
"3409" = "1" /* OTHER INCISION OF PLEURA */
"341"  = "1" /* INCISION OF MEDIASTINUM */
"3420" = "1" /* THORACOSCOPIC PLEURAL BX */
"3421" = "1" /* TRANSPLEURAL THORACOSOCOPY */
"3422" = "1" /* MEDIASTINOSCOPY */
"3423" = "1" /* BIOPSY OF CHEST WALL */
"3425" = "1" /* CLOSED [PERCUTANEOUS][NEEDLE] BIOPSY OF MEDIASTINUM */
"3426" = "1" /* OPEN BIOPSY OF MEDIASTINUM */
"3427" = "1" /* BIOPSY OF DIAPHRAGM */
"3428" = "1" /* OTHER DIAGNOSTIC PROCEDURES ON CHEST WALL, PLEURA, AND DIAPHRAGM */
"3429" = "1" /* OTHER DIAGNOSTIC PROCEDURES ON MEDIASTINUM */
"343"  = "1" /* EXCISION OR DESTRUCTION OF LESION OR TISSUE OF MEDIASTINUM */
"344"  = "1" /* EXCISION OR DESTRUCTION OF LESION OF CHEST WALL */
"3451" = "1" /* DECORTICATION OF LUNG */
"3452" = "1" /* THORACOSCOPC DECORT LUNG */
"3459" = "1" /* OTHER EXCISION OF PLEURA */
"3471" = "1" /* SUTURE OF LACERATION OF CHEST WALL */
"3472" = "1" /* CLOSURE OF THORACOSTOMY */
"3473" = "1" /* CLOSURE OF OTHER FISTULA OF THORAX */
"3474" = "1" /* REPAIR OF PECTUS DEFORMITY */
"3479" = "1" /* OTHER REPAIR OF CHEST WALL */
"3481" = "1" /* EXCISION OF LESION OR TISSUE OF DIAPHRAGM */
"3482" = "1" /* SUTURE OF LACERATION OF DIAPHRAGM */
"3483" = "1" /* CLOSURE OF FISTULA OF DIAPHRAGM */
"3484" = "1" /* OTHER REPAIR OF DIAPHRAGM */
"3485" = "1" /* IMPLANTATION OF DIAPHRAGMATIC PACEMAKER */
"3489" = "1" /* OTHER OPERATIONS ON DIAPHRAGM */
"3493" = "1" /* REPAIR OF PLEURA */
"3499" = "1" /* OTHER */
"4061" = "1" /* CANNULATION OF THORACIC DUCT */
"4062" = "1" /* FISTULIZATION OF THORACIC DUCT */
"4063" = "1" /* CLOSURE OF FISTULA OF THORACIC DUCT */
"4064" = "1" /* LIGATION OF THORACIC DUCT */
"4069" = "1" /* OTHER OPERATIONS ON THORACIC DUCT */
"4201" = "1" /* INCISION OF ESOPHAGEAL WEB */
"4209" = "1" /* OTHER INCISION OF EXOPHAGUS */
"4210" = "1" /* ESOPHAGOSTOMY, NOS */
"4211" = "1" /* CERVICAL ESOPHAGOSTOMY */
"4212" = "1" /* EXTERIORIZATION OF ESOPHAGEAL POUCH */
"4219" = "1" /* OTHER EXTERNAL FISTULIZATION OF ESOPHAGUS */
"4221" = "1" /* OPERATIVE ESOPHAGOSCOPY BY INCISION */
"4225" = "1" /* OPEN BIOPSY OF ESOPHAGUS */
"4231" = "1" /* LOCAL EXCISION OF ESOPHAGEAL DIVERTICULUM */
"4232" = "1" /* LOCAL EXCISION OF OTHER LESION OR TISSUE OF ESOPHAGUS */
"4239" = "1" /* OTHER DESTRUCTION OF LESION OR TISSUE OF ESOPHAGUS */
"4240" = "1" /* ESOPHAGECTOMY, NOS */
"4241" = "1" /* PARTIAL ESOPHAGECTOMY */
"4242" = "1" /* TOTAL ESOPHAGECTOMY */
"4251" = "1" /* INTRATHORACIC ESOPHAGOESOPHAGOSTOMY */
"4252" = "1" /* INTRATHORACIC ESOPHAGOGASTROSTOMY */
"4253" = "1" /* INTRATHORACIC ESOPHAGEAL ANASTOMOSIS WITH INTERPOSITION OF SMALL BOWEL */
"4254" = "1" /* OTHER INTRATHORACIC ESOPHAGOENTEROSOTOMY */
"4255" = "1" /* INTRATHORACIC ESOPHAGEAL ANASTOMOSIS WITH INTERPOSITION OF COLON */
"4256" = "1" /* OTHER INTRATHORACIC ESOPHAGOCOLOSTOMY */
"4258" = "1" /* INTRATHORACIC ESOPHAGEAL ANASTOMOSIS WITH OTHER INTERPOSITION */
"4259" = "1" /* OTHER INTRATHORACIC ANASTOMOSIS OF ESOPHAGUS */
"4261" = "1" /* ANTESTERNAL ESOPHAGOESOPHAGOSTOMY */
"4262" = "1" /* ANTESTERNAL ESOPHAGOGASTROSTOMY */
"4263" = "1" /* ANTESTERNAL ESOPHAGEAL ANASTOMOSIS WITH INTERPOSITION OF SMALL BOWEL */
"4264" = "1" /* OTHER ANTESTERNAL ESOPHAGOENTEROSTOMY */
"4265" = "1" /* ANTESTERNAL ESOPHAGEAL ANASTOMOSIS WITH INTERPOSITION OF COLON */
"4266" = "1" /* OTHER ANTESTERNAL ESOPHAGOCOLOSTOMY */
"4268" = "1" /* OTHER ANTESTERNAL ESOPHAGEAL ANASTOMOSIS WITH INTERPOSISION */
"4269" = "1" /* OTHER ANTESTERNAL ANASTOMOSIS OF ESOPHAGUS */
"427"  = "1" /* ESOPHAGOMYOTOMY */
"4281" = "1" /* INSERTION OF PERMANENT TUBE INTO ESOPHAGUS */
"4282" = "1" /* SUTURE OF LACERATION OF ESOPHAGUS */
"4283" = "1" /* CLOSURE OF ESOPHAGOSTOMY */
"4284" = "1" /* REPAIR OF ESOPHAGEAL FISTULA, NEC */
"4285" = "1" /* REPAIR OF ESOPHAGEAL STRICTURE */
"4286" = "1" /* PRODUCTION OF SUBCUTANEOUS TUNNEL WITHOUT ESOPHAGEAL ANASTOMOSIS */
"4287" = "1" /* OTHER GRAFT OF ESOPHAGUS */
"4289" = "1" /* OTHER REPAIR OF ESOPHAGUS */
"435 " = "1" /* PROXIMAL GASTRECTOMY */
"4399" = "1" /* TOTAL GASTRECTOMY NEC */
"4465" = "1" /* ESOPHAGOGASTROPLASTY */
"4466" = "1" /* OTHER PROCEDURES FOR CREATION OF ESOPHAGOGASTRIC SPHINTERIC COMPETENCE */
"4467" = "1" /* LAP CREAT ESOPH SPHINCT */
"7781" = "1" /* OTH CHEST CAGE OSTECTOMY */
"7791" = "1" /* TOT CHEST CAGE OSTECTOMY */
"8104" = "1" /* DORSAL AND DORSO-LUMBAR FUSION, ANTERIOR TECHNIQUE */
"8134" = "1" /* REFUSION OF DORSAL AND DORSOLUMBAR SPINE, ANTERIOR TECHNIQUE */
OTHER  = "0" ;

 /* EXCLUDE: LUNG CANCER PROCEDURE */
 /* ICD-9-CM PROCEDURE CODES: */

VALUE $LUNGCIP
"3239" = "1" /* OTH SEG LUNG RESECT NOS */
"3249" = "1" /* LOBECTOMY OF LUNG NEC */
"3259" = "1" /* OTHER PNEUMONECTOMY NOS */
"3230" = "1" /* Added 5.0: THORACOSCOPIC SURGERY */
"3241" = "1" /* Added 5.0: THORACOSCOPIC SURGERY */
"3250" = "1" /* Added 5.0: THORACOSCOPIC SURGERY */
OTHER  = "0" ;


 /* EXCLUDE: LUNG OR PLEURAL BIOPSY */
 /* ICD-9-CM PROCEDURE CODES: */

VALUE $LUNGBIP
"3326" = "1" /* CLOSED [PERCUTANEOUS] [NEEDLE] BIOPSY OF LUNG */
"3328" = "1" /* OPEN BIOPSY OF LUNG */
"3424" = "1" /* PLEURAL BIOPSY */
OTHER  = "0" ;

 /* EXCLUDE: CARDIAC PROCEDURE */
 /* ICD-9-CM PROCEDURE CODES: */

VALUE $CARDSIP
"3506" = "1" /* Transapical replacement of aortic valve */
"3508" = "1" /* Transapical replacement of pulmonary valve */
"3510" = "1" /* Open heart valvuloplasty without replacement, unspecified valve */
"3511" = "1" /* Open heart valvuloplasty of aortic valve without replacement */
"3512" = "1" /* Open heart valvuloplasty of mitral valve without replacement */
"3513" = "1" /* Open heart valvuloplasty of pulmonary valve without replacement */
"3514" = "1" /* Open heart valvuloplasty of tricuspid valve without replacement */
"3520" = "1" /* Replacement of unspecified heart valve */
"3521" = "1" /* Replacement of aortic valve with tissue graft */
"3522" = "1" /* Other replacement of aortic valve */
"3523" = "1" /* Replacement of mitral valve with tissue graft */
"3524" = "1" /* Other replacement of mitral valve */
"3525" = "1" /* Replacement of pulmonary valve with tissue graft */
"3526" = "1" /* Other replacement of pulmonary valve */
"3527" = "1" /* Replacement of tricuspid valve with tissue graft */
"3528" = "1" /* Other replacement of tricuspid valve */
"3531" = "1" /* Operations on papillary muscle */
"3532" = "1" /* Operations on chordae tendineae */
"3533" = "1" /* Annuloplasty */
"3534" = "1" /* Infundibulectomy  */
"3535" = "1" /* Operations on trabeculae carneae cordis */
"3539" = "1" /* Operations on other structures adjacent to valves of heart */
"3550" = "1" /* Repair of unspecified septal defect of heart with prosthesis */
"3551" = "1" /* Repair of atrial septal defect with prosthesis, open technique */
"3553" = "1" /* Repair of ventricular septal defect with prosthesis, open technique */
"3554" = "1" /* Repair of endocardial cushion defect with prosthesis */
"3560" = "1" /* Repair of unspecified septal defect of heart with tissue graft */
"3561" = "1" /* Repair of atrial septal defect with tissue graft */
"3562" = "1" /* Repair of ventricular septal defect with tissue graft */
"3563" = "1" /* Repair of endocardial cushion defect with tissue graft */
"3570" = "1" /* Other and unspecified repair of unspecified septal defect of heart */
"3571" = "1" /* Other and unspecified repair of atrial septal defect */
"3572" = "1" /* Other and unspecified repair of ventricular septal defect */
"3573" = "1" /* Other and unspecified repair of endocardial cushion defect */
"3581" = "1" /* Total repair of tetralogy of Fallot */
"3582" = "1" /* Total repair of total anomalous pulmonary venous connection */
"3583" = "1" /* Total repair of truncus arteriosus */
"3584" = "1" /* Total correction of transposition of great vessels, not elsewhere classified */
"3591" = "1" /* Interatrial transposition of venous return */
"3592" = "1" /* Creation of conduit between right ventricle and pulmonary artery */
"3593" = "1" /* Creation of conduit between left ventricle and aorta */
"3594" = "1" /* Creation of conduit between atrium and pulmonary artery */
"3595" = "1" /* Revision of corrective procedure on heart */
"3597" = "1" /* PERC MTRL VLV REPR W IMP */
"3598" = "1" /* Other operations on septa of heart */
"3599" = "1" /* Other operations on valves of heart */
"3603" = "1" /* Open chest coronary artery angioplasty */
"3610" = "1" /* Aortocoronary bypass for heart revascularization, not otherwise specified */
"3611" = "1" /* (Aorto)coronary bypass of one coronary artery */
"3612" = "1" /* (Aorto)coronary bypass of two coronary arteries */
"3613" = "1" /* (Aorto)coronary bypass of three coronary arteries */
"3614" = "1" /* (Aorto)coronary bypass of four or more coronary arteries */
"3615" = "1" /* Single internal mammary-coronary artery bypass */
"3616" = "1" /* Double internal mammary-coronary artery bypass */
"3617" = "1" /* Abdominal -coronary artery bypass */
"3619" = "1" /* Other bypass anastomosis for heart revascularization */
"362 " = "1" /* Heart revascularization by arterial implant */
"3631" = "1" /* Open chest transmyocardial revascularization */
"3632" = "1" /* Other transmyocardial revascularization */
"3639" = "1" /* Other heart revascularization */
"3691" = "1" /* Repair of aneurysm of coronary vessel */
"3699" = "1" /* Other operations on vessels of heart */
"370 " = "1" /* Pericardiocentesis */
"3710" = "1" /* Incision of heart, not otherwise specified */
"3711" = "1" /* Cardiotomy */
"3712" = "1" /* Pericardiotomy */
"3731" = "1" /* Pericardiectomy */
"3732" = "1" /* Excision of aneurysm of heart */
"3733" = "1" /* Excision or destruction of other lesion or tissue of heart, open approach */
"3735" = "1" /* Partial ventriculectomy */
"3737" = "1" /* EXC/DEST HRT LES, THRSPC */
"3736" = "1" /* EXC LEFT ATRIAL APPENDAG */
"3741" = "1" /* Implantation of prosthetic cardiac support device around the heart */
"3749" = "1" /* Other repair of heart and pericardium */
"3751" = "1" /* Heart transplantation */
"3752" = "1" /* Implantation of total replacement heart system */
"3753" = "1" /* Replacement of repair of thoracic unit of total replacement heart system */
"3754" = "1" /* Replacement or repair of other implantable component of total replacement heart system */
"3755" = "1" /* REM INT BIVENT HRT SYS */
"3760" = "1" /* IMP BIVN EXT HRT AST SYS */
"3761" = "1" /* Implant of pulsation balloon */
"3762" = "1" /* Insertion of non-implantable heart assist system */
"3763" = "1" /* Repair of heart assist system */
"3764" = "1" /* Removal of heart assist system */
"3765" = "1" /* Implant of external heart assist system  */
"3766" = "1" /* Insertion of implantable heart assist system */
"3767" = "1" /* Implantation of cardiomyostimulation system */
"3791" = "1" /* Open chest cardiac massage */
"3804" = "1" /* Incision of vessel, aorta */
"3805" = "1" /* Incision of vessel, other thoracic */
"3844" = "1" /* Resection of abdominal aorta with graft replacement */
"3845" = "1" /* Resection of thoracic vessel with graft replacement */
"3864" = "1" /* Excision of lesion of aorta */
"3865" = "1" /* Excision of lesion other thoracic vessel */
"3884" = "1" /* Ligation , division of aorta */
"3885" = "1" /* Ligation, division of other thoracic vessels */
"390 " = "1" /* Systemic to pulmonary artery shunt */
"3921" = "1" /* Caval-pulmonary artery anastomosis */
"3922" = "1" /* Aorta-subclavian-carotid bypass */
"3923" = "1" /* Other intrathoracic vascular shunt or bypass */
OTHER  = "0" ;

 /* EXCLUDE: CARDIAC SURGERY */
 /* DIAGNOSTIC RELATED GROUPS (DRGS): */

VALUE $CARDSDR
"103" = "1" /* HEART TRANSPLANT */
"104" = "1" /* CARDIAC VALVE AND OTHER MAJOR CARDIOTHORACIC PROCEDURES WITH CARDIAC CATHETERIZATION */
"105" = "1" /* CARDIAC VALVE AND OTHER MAJOR CARDIOTHORACIC PROCEDURES WITHOUT CARDIAC CATHETERIZATION */
"106" = "1" /* CORONARY BYPASS WITH PTCA */
"107" = "1" /* CORONARY BYPASS WITH CARDIAC CATHETERIZATION */
"108" = "1" /* OTHER CARDIOTHORACIC PROCEDURES */
"109" = "1" /* CORONARY BYPASS WITHOUT CARDIAC CATHETERIZATION */
"110" = "1" /* MAJOR CARDIOVASCULAR PROCEDURES WITH CC */
"111" = "1" /* MAJOR CARDIOVASCULAR PROCEDURES WITHOUT CC */
"525" = "1" /* HEART ASSIST SYSTEM IMPLANT */
"547" = "1" /* CORONARY BYPASS W CARDIAC CATH W MAJOR CV DX */
"548" = "1" /* CORONARY BYPASS W CARDIAC CATH W/O MAJOR CV DX */
"549" = "1" /* CORONARY BYPASS W/O CARDIAC CATH W MAJOR CV DX */
"550" = "1" /* CORONARY BYPASS W/O CARDIAC CATH W/O MAJOR CV DX */
OTHER = "0" ;

 /* EXCLUDE: DIAPHRAGMATIC SURGERY REPAIR */
 /* ICD-9-CM PROCEDURE CODES: */

VALUE $DIAPHRP
"537 " = "1" /* ABD REPAIR-DIAPHR HERNIA */
"5371" = "1" /* LAP ABD REP-DIAPHR HERN */
"5372" = "1" /* OPN ABD DIAPHRM HERN NEC */
"5375" = "1" /* ABD REP-DIAPHR HERN NOS */
"5380" = "1" /* THOR REP-DIAPH HERN NOS */
"5381" = "1" /* DIAPHRAGMATIC PLICATION */
"5382" = "1" /* PARASTERN HERNIA REPAIR */
"5383" = "1" /* LAP THORC APP-DIAPH HERN */
"5384" = "1" /* OPN THORC DIAPH HERN NEC */
OTHER  = "0" ;

 /* ----------------------------------------- */
 /* Pediatric Heart Surgery (PRPEDH)          */
 /*   Mortality (post-op) Indicator / PDI #6  */
 /*   Volume Indicator / PDI #7               */
 /* ----------------------------------------- */

 /* Pediatric Heart Surgery (#1) */
 /* Procedures to repair congenital heart defect */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRPED1P
'3500' = "1"  /* ENDOVASCULAR REPLACEMENT OF UNSPECIFIED HEART VALVE */
'3501' = "1"  /* CLOSED AORTIC VALVOTOMY */
'3502' = "1"  /* CLOSED MITRAL VALVOTOMY */
'3503' = "1"  /* CLOSED PULMON VALVOTOMY */
'3504' = "1"  /* CLOSED TRICUSP VALVOTOMY */
'3505' = "1"  /* ENDOVASCULAR REPLACEMENT OF AORTIC VALVE  */
'3506' = "1"  /* TRANSAPICAL REPLACEMENT OF AORTIC VALVE */
'3507' = "1"  /* ENDOVASCULAR REPLACEMENT OF PULMONARY VALVE */
'3508' = "1"  /* TTRANSAPICAL REPLACEMENT PULMONARY VALVE*/
'3510' = "1"  /* OPEN VALVULOPLASTY NOS */
'3511' = "1"  /* OPN AORTIC VALVULOPLASTY */
'3512' = "1"  /* OPN MITRAL VALVULOPLASTY */
'3513' = "1"  /* OPN PULMON VALVULOPLASTY */
'3514' = "1"  /* OPN TRICUS VALVULOPLASTY */
'3520' = "1"  /* REPLACE HEART VALVE NOS */
'3521' = "1"  /* REPLACE AORT VALV-TISSUE */
'3522' = "1"  /* REPLACE AORTIC VALVE NEC */
'3523' = "1"  /* REPLACE MITR VALV-TISSUE */
'3524' = "1"  /* REPLACE MITRAL VALVE NEC */
'3525' = "1"  /* REPLACE PULM VALV-TISSUE */
'3526' = "1"  /* REPLACE PULMON VALVE NEC */
'3527' = "1"  /* REPLACE TRIC VALV-TISSUE */
'3528' = "1"  /* REPLACE TRICUSP VALV NEC */
'3531' = "1"  /* PAPILLARY MUSCLE OPS */
'3532' = "1"  /* CHORDAE TENDINEAE OPS */
'3533' = "1"  /* ANNULOPLASTY */
'3534' = "1"  /* INFUNDIBULECTOMY */
'3535' = "1"  /* TRABECUL CARNEAE CORD OP */
'3539' = "1"  /* TISS ADJ TO VALV OPS NEC */
'3541' = "1"  /* ENLARGE EXISTING SEP DEF */
'3542' = "1"  /* CREATE SEPTAL DEFECT */
'3550' = "1"  /* PROSTH REP HRT SEPTA NOS */
'3551' = "1"  /* PROS REP ATRIAL DEF-OPN */
'3552' = "1"  /* PROS REPAIR ATRIA DEF-CL */
'3553' = "1"  /* PROST REPAIR VENTRIC DEF */
'3554' = "1"  /* PROS REP ENDOCAR CUSHION */
'3560' = "1"  /* GRFT REPAIR HRT SEPT NOS */
'3561' = "1"  /* GRAFT REPAIR ATRIAL DEF */
'3562' = "1"  /* GRAFT REPAIR VENTRIC DEF */
'3563' = "1"  /* GRFT REP ENDOCAR CUSHION */
'3570' = "1"  /* HEART SEPTA REPAIR NOS */
'3571' = "1"  /* ATRIA SEPTA DEF REP NEC */
'3572' = "1"  /* VENTR SEPTA DEF REP NEC */
'3573' = "1"  /* ENDOCAR CUSHION REP NEC */
'3581' = "1"  /* TOT REPAIR TETRAL FALLOT */
'3582' = "1"  /* TOTAL REPAIR OF TAPVC */
'3583' = "1"  /* TOT REP TRUNCUS ARTERIOS */
'3584' = "1"  /* TOT COR TRANSPOS GRT VES  */
'3591' = "1"  /* INTERAT VEN RETRN TRANSP */
'3592' = "1"  /* CONDUIT RT VENT-PUL ART */
'3593' = "1"  /* CONDUIT LEFT VENTR-AORTA */
'3594' = "1"  /* CONDUIT ARTIUM-PULM ART */
'3595' = "1"  /* HEART REPAIR REVISION */
'3598' = "1"  /* OTHER HEART SEPTA OPS */
'3599' = "1"  /* OTHER OP ON HRT VALVES */
'3699' = "1"  /* OTHER OPERATIONS ON VESSEL OF HEART */
'3733' = "1"  /* EXCISION OR DESTRUCTION OF OTHER LESION 
                 OR TISSUE OF HEART */
'3736' = "1" /* EXC LEFT ATRIAL APPENDAG */
'375 ' = "1"  /* HEART TRANSPLANTATION */
'3751' = "1"  /* HEART TRANSPLANTATION */
'3752' = "1"  /* IMPLANT TOT REP HRT SYS */
'390 ' = "1"  /* SYSTEMIC-PULM ART SHUNT */
'3921' = "1"  /* CAVAL-PULMON ART ANASTOM */
OTHER  = "0" ;

 /* Pediatric Heart Surgery (#2): */
 /* Other cardiac surgery */

 /* ICD-9-CM Diagnosis Codes: */

VALUE $PRPED2D
'7450 ' = "1"  /* COMMON TRUNCUS */
'74510' = "1"  /* COMPL TRANSPOS GREAT VES */
'74511' = "1"  /* DOUBLE OUTLET RT VENTRIC */
'74512' = "1"  /* CORRECT TRANSPOS GRT VES */
'74519' = "1"  /* TRANSPOS GREAT VESS NEC */
'7452 ' = "1"  /* TETRALOGY OF FALLOT */
'7453 ' = "1"  /* COMMON VENTRICLE */
'7454 ' = "1"  /* VENTRICULAR SEPT DEFECT */
'7455 ' = "1"  /* SECUNDUM ATRIAL SEPT DEF */
'74560' = "1"  /* ENDOCARD CUSHION DEF NOS */
'74561' = "1"  /* OSTIUM PRIMUM DEFECT */
'74569' = "1"  /* ENDOCARD CUSHION DEF NEC */
'7457 ' = "1"  /* COR BILOCULARE */
'7458 ' = "1"  /* SEPTAL CLOSURE ANOM NEC */
'7459 ' = "1"  /* SEPTAL CLOSURE ANOM NOS */
'74600' = "1"  /* PULMONARY VALVE ANOM NOS */
'74601' = "1"  /* CONG PULMON VALV ATRESIA */
'74602' = "1"  /* CONG PULMON VALVE STENOS */
'74609' = "1"  /* PULMONARY VALVE ANOM NEC */
'7461 ' = "1"  /* CONG TRICUSP ATRES/STEN */
'7462 ' = "1"  /* EBSTEIN'S ANOMALY */
'7463 ' = "1"  /* CONG AORTA VALV STENOSIS */
'7464 ' = "1"  /* CONG AORTA VALV INSUFFIC */
'7465 ' = "1"  /* CONGEN MITRAL STENOSIS */
'7466 ' = "1"  /* CONG MITRAL INSUFFICIENC */
'7467 ' = "1"  /* HYPOPLAS LEFT HEART SYND */
'74681' = "1"  /* CONG SUBAORTIC STENOSIS */
'74682' = "1"  /* COR TRIATRIATUM */
'74683' = "1"  /* INFUNDIB PULMON STENOSIS */
'74684' = "1"  /* OBSTRUCT HEART ANOM NEC */
'74685' = "1"  /* CORONARY ARTERY ANOMALY */
'74687' = "1"  /* MALPOSITION OF HEART */
'74689' = "1"  /* CONG HEART ANOMALY NEC */
'7469 ' = "1"  /* CONG HEART ANOMALY NOS */
'7470 ' = "1"  /* PATENT DUCTUS ARTERIOSUS */
'74710' = "1"  /* COARCTATION OF AORTA */
'74711' = "1"  /* INTERRUPT OF AORTIC ARCH */
'74720' = "1"  /* CONG ANOM OF AORTA NOS */
'74721' = "1"  /* ANOMALIES OF AORTIC ARCH */
'74722' = "1"  /* AORTIC ATRESIA/STENOSIS */
'74729' = "1"  /* CONG ANOM OF AORTA NEC */
'7473 ' = "1"  /* PULMONARY ARTERY ANOM */
'74731' = "1"  /* PULMONARY ARTERY COARCTATION AND ATRESIA*/
'74732' = "1"  /* PULMONARY ARTERIOVENOUS MALFORMATION */
'74739' = "1"  /* OTHER ANAMOLIES OF PULMONARY ARTERY AND PULMONARY CIRCULATION*/
'74740' = "1"  /* GREAT VEIN ANOMALY NOS */
'74741' = "1"  /* TOT ANOM PULM VEN CONNEC */
'74742' = "1"  /* PART ANOM PULM VEN CONN */
'74749' = "1"  /* GREAT VEIN ANOMALY NEC */
OTHER   = "0" ;

 /* ICD-9-CM Procedure Codes: */

VALUE $PRPED2P
'3834' = "1"  /* RESECTION OF ABDOMINAL AORTA WITH ANASTOMOSIS */
'3835' = "1"  /* THOR VESSEL RESECT/ANAST */
'3844' = "1"  /* RESECTION OF ABDOMINAL AORTA WITH REPLACEMENT */
'3845' = "1"  /* RESECT THORAC VES W REPL */
'3864' = "1"  /* OTHER EXCISION OF ABDOMINAL AORTA */
'3865' = "1"  /* OTHER EXCISION OF THORACIC VESSEL */
'3884' = "1"  /* OTHER SURGICAL OCCLUSION OF ABDOMINAL AORTA */
'3885' = "1"  /* OCCLUDE THORACIC VES NEC */
'3949' = "1"  /* OTHER REVISION OF VASCULAR PROCEDURE */
'3956' = "1"  /* REPAIR OF BLOOD VESSEL WITH TISSUE PATCH GRAFT */
'3957' = "1"  /* REPAIR OF BLOOD VESSEL WITH SYNTHETIC PATCH GRAFT */
'3958' = "1"  /* REPAIR OF BLOOD VESSEL WITH UNSPECIFIED TYPE OF PATCH GRAFT */
'3959' = "1"  /* REPAIR OF VESSEL NEC */
OTHER  = "0" ;

 /* Pediatric Heart Surgery */
 /* Exclusions */

 /* PHS Exclusion #1: */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $PRPED3D
'7470 ' = "1"  /* PATENT DUCTUS ARTERIOSUS */
OTHER  = "0" ;

 /* ICD-9-CM Procedure Codes: */

VALUE $PRPD3AP
'3500' = "1"  /* CLOSED HEART VALVOTOMY, UNSPECIFIED VALUE */
'3501' = "1"  /* CLOSED HEART VALVOTOMY, AORTIC VALUE */
'3502' = "1"  /* CLOSED HEART VALVOTOMY, MITRAL VALUE */
'3503' = "1"  /* CLOSED HEART VALVOTOMY, PULMONARY VALUE */
'3504' = "1"  /* CLOSED HEART VALVOTOMY, TRICUSPID VALUE */
OTHER  = "0" ;

VALUE $PRPD3BP
'3541' = "1"  /* ENLARGEMENT OF EXISTING ATRIAL SEPTAL DEFECT */
'3542' = "1"  /* CREATION OF SEPTAL DEFECT IN HEART */
OTHER  = "0" ;

VALUE $PRPD3CP
'3551' = "1"  /* REPAIR OF ATIAL SEPTAL DEFECT WITH PROSTHESIS, OPEN TECHNIQUE */
'3571' = "1"  /* OTHER AND UNSPECIFIED REPAIR OF ATRIAL SEPTAL DEFECT */
OTHER  = "0" ;

VALUE $PRPD3DP
'3553' = "1"  /* REPAIR OF VENTRICULAR SEPTAL DEFECT WITH PROSTHESIS */
'3572' = "1"  /* OTHER AND UNSPECIFIED REPAIR OF VENTRICULAR SEPTAL DEFECT */
OTHER  = "0" ;

VALUE $PRPD3EP
'3885' = "1"  /* OCCLUDE THORACIC VES NEC */
OTHER  = "0" ;

VALUE $PRPD3FP
'3884' = "1"  /* OTHER SURGICAL OCCLUSION OF AORTA, ABDOMINAL */
'3885' = "1"  /* OTHER SURGICAL OCCLUSION OF THORACIC VESSEL */
'3959' = "1"  /* OTHER REPAIR OF VESSEL */
OTHER  = "0" ;

VALUE $PRPED5P
'3961' = "1"  /* EXTRACORPOREAL CIRCULAT */
OTHER  = "0" ;

VALUE $PRPED6P
'3721' = "1"  /* RT HEART CARDIAC CATH */
'3722' = "1"  /* LEFT HEART CARDIAC CATH */
'3723' = "1"  /* RT/LEFT HEART CARD CATH */
'8842' = "1"  /* CONTRAST AORTOGRAM */
'8843' = "1"  /* CONTR PULMON ARTERIOGRAM */
'8844' = "1"  /* ARTERIOGRAPHY OF OTHER INTRATHORACIC VESSELS */
'8850' = "1"  /* ANGIOCARDIOGRAPHY, NOT OTHERWISE SPECIFIED */
'8851' = "1"  /* ANGIOCARDIOGRAPHY OF VENAE CAVAE */
'8852' = "1"  /* ANGIOCARDIOGRAPHY OF RIGHT HEART STRUCTURES */
'8853' = "1"  /* ANGIOCARDIOGRAPHY OF LEFT HEART STRUCTURES */
'8854' = "1"  /* COMBINED RIGHT AND LEFT HEART ANGIOCARDIOGRAPHY */
'8855' = "1"  /* CORONARY ARTERIOGRAPHY USING A SINGLE CATHETER */
'8856' = "1"  /* CORONARY ARTERIOGRAPHY USING TWO CATHETERS */
'8857' = "1"  /* OTHER AND UNSPECIFIED CORONARY ARTERIOGRAPHY */
'8858' = "1"  /* NEGATIVE-CONTRAST CARDIAC ROENTGENOGRAPHY */
OTHER  = "0" ;

 /* PHS Exclusion #2: */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRPED4P
'3541' = "1"  /* ENLARGE EXISTING SEP DEF */
'3552' = "1"  /* PROS REPAIR ATRIA DEF-CL */
OTHER  = "0" ;

 /* PHS Exclusion #3: */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $PRPED4D
'76500' = "1"  /* EXTREME IMMATUR WTNOS */
'76501' = "1"  /* EXTREME IMMATUR <500G */
'76502' = "1"  /* EXTREME IMMATUR 500-749G */
'76503' = "1"  /* EXTREME IMMATUR 750-999G */
'76504' = "1"  /* EXTREME IMMAT 1000-1249G */
'76505' = "1"  /* EXTREME IMMAT 1250-1499G */
'76506' = "1"  /* EXTREME IMMAT 1500-1749G */
'76507' = "1"  /* EXTREME IMMAT 1750-1999G */
'76508' = "1"  /* EXTREME IMMAT 2000-2499G */
'76509' = "1"  /* EXTREME IMMAT 2500+G */
'76510' = "1"  /* PRETERM INFANT NEC WTNOS */
'76511' = "1"  /* PRETERM NEC <500G */
'76512' = "1"  /* PRETERM NEC 500-749G */
'76513' = "1"  /* PRETERM NEC 750-999G */
'76514' = "1"  /* PRETERM NEC 1000-1249G */
'76515' = "1"  /* PRETERM NEC 1250-1499G */
'76516' = "1"  /* PRETERM NEC 1500-1749G */
'76517' = "1"  /* PRETERM NEC 1750-1999G */
'76518' = "1"  /* PRETERM NEC 2000-2499G */
'76519' = "1"  /* PRETERM NEC 2500+G */
OTHER  = "0" ; 

 /* ICD-9-CM Procedure Codes: */

VALUE $PRPED7P
'375 ' = "1"  /* HEART TRANSPLANTATION */
'3751' = "1"  /* HEART TRANSPLANTATION */
'3752' = "1"  /* IMPLANT TOT REP HRT SYS */
OTHER  = "0" ;


 /* ASD or VSD */

 /* ICD-9-CM Diagnosis Codes: */

VALUE $PRPED5D
'7454 ' = "1"  /* VENTRICULAR SEPT DEFECT */
'7455 ' = "1"  /* SECUNDUM ATRIAL SEPT DEF */
OTHER   = "0" ;

 /* ------------------------------------- */
 /* PERI-OPERATIVE HEMORRHAGE OR HEMATOMA */
 /*   PROVIDER INDICATOR / PDI # 8        */
 /* ------------------------------------- */

 /* POST-OPERATIVE HEMORRHAGE OR HEMATOMA */
 /* ICD-9-CM DIAGNOSIS CODE: */

VALUE $POHMRI2D
"99811" = "1" /* HEMORRHAGE COMPLICATING A PROCEDURE */
"99812" = "1" /* Consolidated for 5.0: HEMATOMA COMPLICATING A PROCEDURE */
OTHER   = "0" ;

 /* COMBINED */
 /* ICD-9-CM PROCEDURE CODES: */

VALUE $HEMIP
"1809" = "1" /* OTHER INCISION OF EXTERNAL EAR */
"287"  = "1" /* CONTROL OF HEMORRHAGE AFTER TONSILLECTOMY AND ADENOIDECTOMY */
"3880" = "1" /* OTHER SURGICAL OCCLUSION OF UNSPECIFIED SITE */
"3881" = "1" /* OTHER SURGICAL OCCLUSION OF INTRACRANIAL VESSELS */
"3882" = "1" /* OTHER SURGICAL OCCLUSION OF OTHER VESSELS OF HEAD AND NECK */
"3883" = "1" /* OTHER SURGICAL OCCLUSION OF UPPER LIMB VESSELS */
"3884" = "1" /* OTHER SURGICAL OCCLUSION OF AORTA, ABDOMINAL */
"3885" = "1" /* OTHER SURGICAL OCCLUSION OF THORACIC VESSEL */
"3886" = "1" /* OTHER SURGICAL OCCLUSION OF ABDOMINAL ARTERIES */
"3887" = "1" /* OTHER SURGICAL OCCLUSION OF VESSELS ABDOMINAL VEINS */
"3888" = "1" /* OTHER SURGICAL OCCLUSION OF LOWER LIMB ARTERIES */
"3889" = "1" /* OTHER SURGICAL OCCLUSION OF LOWER LIMB VEINS */
"3941" = "1" /* CONTROL OF HEMORRHAGE FOLLOWING VASCULAR SURGERY*/
"3998" = "1" /* CONTROL OF HEMORRHAGE NOS */
"4995" = "1" /* CONTROL OF (POSTOPERATIVE) HEMORRHAGE OF ANUS */
"540"  = "1" /* INCISION OF ABDOMINAL WALL */
"5412" = "1" /* REOPENING OF RECENT LAPAROTOMY SITE */
"5793" = "1" /* CONTROL OF (POSTOPERATIVE HEMORRHAGE OF BLADDER) */
"5919" = "1" /* OTHER INCISION OF PERIVESICLE TISSUE */
"6094" = "1" /* CONTROL OF (POSTOPERATIVE) HEMORRHAGE OF PROSTATE */
"610"  = "1" /* INCISION AND DRAINAGE OF SCROTUM AND TUNICA AND VAGINALIS */
"6998" = "1" /* OTHER OPERATIONS ON SUPPORTING STRUCTURES OF UTERUS */
"7014" = "1" /* OTHER VAGINOTOMY */
"7109" = "1" /* OTHER INCISION OF VULVA AND PERINEUM */
"7591" = "1" /* EVACUATION OF OBSTETRICAL INCISIONAL HEMATOMA OF PERINEUM */
"7592" = "1" /* EVACUATION OF OTHER HEMATOMA OF VULVA OR VAGINA */
"8604" = "1" /* OTHER INCISION WITH DRAINAGE OF SKIN AND SUBCUTANEOUS TISSUE */
OTHER  = "0" ;

 /* ICD-9-CM PROCEDURE CODES: */

 /* PDI-08 **/
 /* Hemorrhage or Hematoma-related Procedure codes: */
 /* ICD-9-CM PROCEDURE CODES: */

VALUE $HEMOTH2P
/* Consolidated for 5.0 - Originally From $HEMATIP */
"1809" = "1" /* OTHER INCISION OF EXTERNAL EAR */
"540"  = "1" /* INCISION OF ABDOMINAL WALL */
"5412" = "1" /* REOPENING OF RECENT LAPAROTOMY SITE */
"5919" = "1" /* OTHER INCISION OF PERIVESICLE TISSUE */
"610"  = "1" /* INCISION AND DRAINAGE OF SCROTUM AND TUNICA AND VAGINALIS */
"6998" = "1" /* OTHER OPERATIONS ON SUPPORTING STRUCTURES OF UTERUS */
"7014" = "1" /* OTHER VAGINOTOMY */
"7109" = "1" /* OTHER INCISION OF VULVA AND PERINEUM */
"7591" = "1" /* EVACUATION OF OBSTETRICAL INCISIONAL HEMATOMA OF PERINEUM */
"7592" = "1" /* EVACUATION OF OTHER HEMATOMA OF VULVA OR VAGINA */
"8604" = "1" /* OTHER INCISION WITH DRAINAGE OF SKIN AND SUBCUTANEOUS TISSUE */
/* Consolidated for 5.0 - Originally From $HEMORIP */
"287"  = "1" /* CONTROL OF HEMORRHAGE AFTER TONSILLECTOMY AND ADENOIDECTOMY */
"3880" = "1" /* OTHER SURGICAL OCCLUSION OF UNSPECIFIED SITE */
"3881" = "1" /* OTHER SURGICAL OCCLUSION OF INTRACRANIAL VESSELS */
"3882" = "1" /* OTHER SURGICAL OCCLUSION OF OTHER VESSELS OF HEAD AND NECK */
"3883" = "1" /* OTHER SURGICAL OCCLUSION OF UPPER LIMB VESSELS */
"3884" = "1" /* OTHER SURGICAL OCCLUSION OF AORTA, ABDOMINAL */
"3885" = "1" /* OTHER SURGICAL OCCLUSION OF THORACIC VESSEL */
"3886" = "1" /* OTHER SURGICAL OCCLUSION OF ABDOMINAL ARTERIES */
"3887" = "1" /* OTHER SURGICAL OCCLUSION OF VESSELS ABDOMINAL VEINS */
"3888" = "1" /* OTHER SURGICAL OCCLUSION OF LOWER LIMB ARTERIES */
"3889" = "1" /* OTHER SURGICAL OCCLUSION OF LOWER LIMB VEINS */
"3941" = "1" /* CONTROL OF HEMORRHAGE FOLLOWING VASCULAR SURGERY*/
"3998" = "1" /* CONTROL OF HEMORRHAGE NOS */
"4995" = "1" /* CONTROL OF (POSTOPERATIVE) HEMORRHAGE OF ANUS */
"5793" = "1" /* CONTROL OF (POSTOPERATIVE HEMORRHAGE OF BLADDER) */
"6094" = "1" /* CONTROL OF (POSTOPERATIVE) HEMORRHAGE OF PROSTATE */
/* Original $HEMOTHP Format Below */
"0121" = "1" /* Incision and drainage of cranial sinus */
"0124" = "1" /* Other craniotomy */
"0131" = "1" /* Incision of cerebral meninges */
"0139" = "1" /* Other incision of brain */
"0213" = "1" /* Ligation of meningeal vessel */
"0239" = "1" /* Other operations to establish drainage of ventricle */
"0241" = "1" /* Irrigation and exploration of ventricular shunt */
"0309" = "1" /* Other exploration and decompression of spinal canal */
"0401" = "1" /* Excision of acoustic neuroma */
"0404" = "1" /* Other incision of cranial and peripheral nerves */
"0443" = "1" /* Release of carpal tunnel */
"0444" = "1" /* Release of tarsal tunnel */
"0602" = "1" /* Reopening of wound of thyroid field */
"0609" = "1" /* Other incision of thyroid field */
"0692" = "1" /* Ligation of thyroid vessels */
"0700" = "1" /* Adrenal exploration NOS */
"0701" = "1" /* Unilat adrenal explorat */
"0702" = "1" /* Bilat adrenal explorat */
"0741" = "1" /* Incision of adrenal gland */
"0743" = "1" /* Ligation of adrenal vessels */
"0751" = "1" /* Exploration of pineal field */
"0752" = "1" /* Incision of pineal gland */
"0771" = "1" /* Exploration of pituitary fossa */
"0772" = "1" /* Incision of pituitary gland */
"0791" = "1" /* Exploration of thymus field */
"0792" = "1" /* Incision of thymus */
"0795" = "1" /* Thoracoscopic incision of thymus */
"0809" = "1" /* Other incision of eyelid */
"090 " = "1" /* Incision of lacrimal gland */
"0953" = "1" /* Incision of lacrimal sac */
"1244" = "1" /* Excision of lesion of ciliary body */
"1289" = "1" /* Other operations on sclera */
"149 " = "1" /* Other operations on retina, choroid, and posterior chamber */
"1609" = "1" /* Other orbitotomy */
"1802" = "1" /* Incision of external auditory canal */
"1811" = "1" /* Otoscopy */
"2001" = "1" /* Myringotomy with insertion of tube */
"2009" = "1" /* Other myringotomy */
"2021" = "1" /* Mastoid incision */
"2022" = "1" /* Petrus pyram air cel inc */
"2023" = "1" /* Middle ear incision */
"2079" = "1" /* Other incision, excision, and destruction of inner ear */
"2100" = "1" /* Control of epistaxis, not otherwise specified */
"2101" = "1" /* Control of epistaxis by anterior nasal packing */
"2102" = "1" /* Control of epistaxis by posterior (and anterior) packing */
"2103" = "1" /* Control of epistaxis by cauterization (and packing) */
"2104" = "1" /* Control of epistaxis by ligation of ethmoidal arteries */
"2105" = "1" /* Control of epistaxis by (transantral) ligation of the */
"2106" = "1" /* Control of epistaxis by ligation of the external carotid */
"2107" = "1" /* Control of epistaxis by excision of nasal mucosa and skin  */
"2109" = "1" /* Control of epistaxis by other means */
"211 " = "1" /* Incision of nose */
"2121" = "1" /* Rhinoscopy */
"2219" = "1" /* Other diagnostic procedures on nasal sinuses */
"2239" = "1" /* Other external maxillary antrotomy */
"2241" = "1" /* Frontal sinusotomy */
"2251" = "1" /* Ethmoidotomy */
"2252" = "1" /* Sphenoidotomy */
"260 " = "1" /* Incision of salivary gland or duct */
"270 " = "1" /* Drainage of face and floor of mouth */
"280 " = "1" /* Incision and drainage of tonsil and peritonsillar structures */
"2911" = "1" /* Pharyngoscopy */
"313 " = "1" /* Other incision of larynx or trachea */
"3141" = "1" /* Tracheoscopy through artificial stoma */
"3142" = "1" /* Laryngoscopy and other tracheoscopy */
"330 " = "1" /* Incision of bronchus */
"331 " = "1" /* Incision of lung */
"3321" = "1" /* Bronchoscopy through artificial stoma */
"3322" = "1" /* Fiberoptic bronchoscopy */
"3323" = "1" /* Other bronchoscopy */
"3324" = "1" /* Closed (endoscopic) biopsy of bronchus */
"3402" = "1" /* Exploratory thoracotomy */
"3403" = "1" /* Reopening of recent thoracotomy site */
"3409" = "1" /* Other incision of pleura */
"341 " = "1" /* Incision of mediastinum */
"3421" = "1" /* Transpleural thoracoscopy */
"3422" = "1" /* Mediastinoscopy */
"3582" = "1" /* Total repair of total anomalous pulmonary venous connection */
"3639" = "1" /* Other heart revascularization */
"3699" = "1" /* Other operations on vessels of heart */
"370 " = "1" /* Pericardiocentesis */
"3711" = "1" /* Cardiotomy */
"3799" = "1" /* Other operations on heart and pericardium */
"3800" = "1" /* Incision of vessel NOS */
"3801" = "1" /* Intracran vessel incis */
"3802" = "1" /* Head/neck ves incis NEC */
"3803" = "1" /* Upper limb vessel incis */
"3804" = "1" /* Incision of aorta */
"3805" = "1" /* Thoracic vessel inc NEC */
"3806" = "1" /* Abdomen artery incision */
"3807" = "1" /* Abdominal vein incision */
"3808" = "1" /* Lower limb artery incis */
"3809" = "1" /* Lower limb vein incision */
"3850" = "1" /* Varicose v lig-strip NOS */
"3851" = "1" /* Intcran var v lig-strip */
"3852" = "1" /* Head/neck var v lig-str */
"3853" = "1" /* Arm varicose v lig-strip */
"3855" = "1" /* Thorac var v lig-strip */
"3857" = "1" /* Abd varicos v liga-strip */
"3859" = "1" /* Leg varicos v liga-strip */
"387 " = "1" /* Interruption of the vena cava */
"3930" = "1" /* Suture of vessel NOS */
"3931" = "1" /* Suture of artery */
"3932" = "1" /* Suture of vein */
"3952" = "1" /* Other repair of aneurysm */
"3953" = "1" /* Repair of arteriovenous fistula */
"3972" = "1" /* Endovascular repair or occlusion of head and neck vessels */
"3976" = "1" /* Endovascular embolization or occlusion of vessel(s) of head or neck using bioactive coils */
"3979" = "1" /* Other endovascular repair (of aneurysm) of other vessels */
"398 " = "1" /* Operations on carotid body and other vascular bodies */
"400 " = "1" /* Incision of lymphatic structures */
"412 " = "1" /* Splenotomy */
"4209" = "1" /* Other incision of esophagus */
"4221" = "1" /* Operative esophagoscopy by incision */
"4222" = "1" /* Esophagoscopy through artificial stoma */
"4223" = "1" /* Other esophagoscopy */
"4233" = "1" /* Endoscopic excision or destruction of lesion or tissue of   */
"4239" = "1" /* Other destruction of lesion or tissue of esophagus */
"4291" = "1" /* Ligation of esophageal varices */
"430 " = "1" /* Gastrotomy */
"4341" = "1" /* Endoscopic excision or destruction of lesion or tissue of  */
"4411" = "1" /* Transabdominal gastroscopy */
"4412" = "1" /* Gastroscopy through artificial stoma */
"4413" = "1" /* Other gastroscopy */
"4440" = "1" /* Suture peptic ulcer NOS */
"4441" = "1" /* Sut gastric ulcer site */
"4442" = "1" /* Suture duoden ulcer site */
"4443" = "1" /* Endosc control gast hem */
"4444" = "1" /* Transcath embo gast hem */
"4449" = "1" /* Other control gast hem */
"4491" = "1" /* Ligation of gastric varices */
"4500" = "1" /* Intestinal incision NOS */
"4501" = "1" /* Duodenal incision */
"4502" = "1" /* Small bowel incision NEC */
"4503" = "1" /* Large bowel incision */
"4511" = "1" /* Transabdominal endoscopy of small intestine */
"4512" = "1" /* Endoscopy of small intestine through artificial stoma */
"4513" = "1" /* Other endoscopy of small intestine */
"4516" = "1" /* Esophagogastroduodenoscopy (EGD) with closed biopsy */
"4521" = "1" /* Transabdominal endoscopy of large intestine */
"4522" = "1" /* Endoscopy of large intestine through artificial stoma */
"4523" = "1" /* Colonoscopy */
"4524" = "1" /* Flexible sigmoidoscopy */
"4543" = "1" /* Endoscopic destruction of other lesion or tissue of large   */
"4549" = "1" /* Other destruction of lesion of large intestine */
"480 " = "1" /* Proctotomy */
"4821" = "1" /* Transabdominal proctosigmoidoscopy */
"4822" = "1" /* Proctosigmoidoscopy through artificial stoma */
"4823" = "1" /* Rigid proctosigmoidoscopy */
"4921" = "1" /* Anoscopy */
"4945" = "1" /* Ligation of hemorrhoids */
"500 " = "1" /* Hepatotomy */
"5110" = "1" /* Endoscopic retrograde cholangiopancreatography */
"5111" = "1" /* Endoscopic retrograde cholangiography */
"5141" = "1" /* Common duct exploration for removal of calculus */
"5142" = "1" /* Common duct exploration for relief of other obstruction */
"5149" = "1" /* Incision of other bile ducts for relief of obstruction */
"5151" = "1" /* Common duct exploration */
"5159" = "1" /* Bile duct incision NEC */
"5184" = "1" /* Endoscopic dilation of ampulla and biliary duct */
"5188" = "1" /* Endoscopic removal of stone(s) from biliary tract */
"5196" = "1" /* Percutaneous extraction of common duct stones */
"5198" = "1" /* Other percutaneous procedures on biliary tract */
"5209" = "1" /* Other pancreatotomy */
"5213" = "1" /* Endoscopic retrograde pancreatography */
"5411" = "1" /* Exploratory laparotomy */
"5419" = "1" /* Other laparotomy */
"5421" = "1" /* Laparoscopy */
"5495" = "1" /* Incision of peritoneum */
"5501" = "1" /* Nephrotomy */
"5511" = "1" /* Pyelotomy */
"5521" = "1" /* Nephroscopy */
"5522" = "1" /* Pyeloscopy */
"562 " = "1" /* Ureterotomy */
"5631" = "1" /* Ureteroscopy */
"5719" = "1" /* Other cystotomy */
"5731" = "1" /* Cystoscopy through artificial stoma */
"5732" = "1" /* Other cystoscopy */
"580 " = "1" /* Urethrotomy */
"5822" = "1" /* Other urethroscopy */
"5909" = "1" /* Other incision of perirenal or periureteral tissue */
"600 " = "1" /* Incision of prostate */
"6081" = "1" /* Incision of periprostatic tissue */
"620 " = "1" /* Incision of testis */
"631 " = "1" /* Excision of varicocele and hydrocele of spermatic cord */
"636 " = "1" /* Vasotomy */
"6372" = "1" /* Ligation of spermatic cord */
"6392" = "1" /* Epididymotomy */
"6393" = "1" /* Incision of spermatic cord */
"6492" = "1" /* Incision of penis */
"6501" = "1" /* Laparoscopic oophorotomy */
"6509" = "1" /* Other oophorotomy */
"6601" = "1" /* Salpingotomy */
"680 " = "1" /* Hysterotomy */
"6811" = "1" /* Digital examination of uterus */
"6812" = "1" /* Hysteroscopy */
"6824" = "1" /* Uterine artery embolization [UAE] with coils */
"6825" = "1" /* Uterine artery embolization [UAE] without coils */
"6995" = "1" /* Incision of cervix */
"700 " = "1" /* Culdocentesis */
"7012" = "1" /* Culdotomy */
"7021" = "1" /* Vaginoscopy */
"7022" = "1" /* Culdoscopy */
"757 " = "1" /* Manual exploration of uterine cavity, postpartum */
"7710" = "1" /* Other incision of bone without division, unspecified site */
"8010" = "1" /* Other arthrotomy, unspecified site */
"8201" = "1" /* Exploration of tendon sheath of hand */
"8202" = "1" /* Myotomy of hand */
"8203" = "1" /* Bursotomy of hand */
"8204" = "1" /* Incision and drainage of palmar or thenar space */
"8209" = "1" /* Other incision of soft tissue of hand */
"8301" = "1" /* Exploration of tendon sheath */
"8302" = "1" /* Myotomy */
"8303" = "1" /* Bursotomy */
"8309" = "1" /* Other incision of soft tissue */
"850 " = "1" /* Mastotomy */
"8603" = "1" /* Incision of pilonidal sinus or cyst */
"8609" = "1" /* Other incision of skin and subcutaneous tissue */
"9621" = "1" /* Dilation of frontonasal duct */
"9925" = "1" /* Injection or infusion of cancer chemotherapeutic substance */
"9929" = "1" /* Injection or infusion of other therapeutic or prophylactic */
OTHER  = "0" ;

 /* COMBINED */
 /* ICD-9-CM PROCEDURE CODES: */

VALUE $HEMIPB
"0121" = "1" /* Incision and drainage of cranial sinus */
"0124" = "1" /* Other craniotomy */
"0131" = "1" /* Incision of cerebral meninges */
"0139" = "1" /* Other incision of brain */
"0213" = "1" /* Ligation of meningeal vessel */
"0239" = "1" /* Other operations to establish drainage of ventricle */
"0241" = "1" /* Irrigation and exploration of ventricular shunt */
"0309" = "1" /* Other exploration and decompression of spinal canal */
"0401" = "1" /* Excision of acoustic neuroma */
"0404" = "1" /* Other incision of cranial and peripheral nerves */
"0443" = "1" /* Release of carpal tunnel */
"0444" = "1" /* Release of tarsal tunnel */
"0602" = "1" /* Reopening of wound of thyroid field */
"0609" = "1" /* Other incision of thyroid field */
"0692" = "1" /* Ligation of thyroid vessels */
"0700" = "1" /* Adrenal exploration NOS */
"0701" = "1" /* Unilat adrenal explorat */
"0702" = "1" /* Bilat adrenal explorat */
"0741" = "1" /* Incision of adrenal gland */
"0743" = "1" /* Ligation of adrenal vessels */
"0751" = "1" /* Exploration of pineal field */
"0752" = "1" /* Incision of pineal gland */
"0771" = "1" /* Exploration of pituitary fossa */
"0772" = "1" /* Incision of pituitary gland */
"0791" = "1" /* Exploration of thymus field */
"0792" = "1" /* Incision of thymus */
"0795" = "1" /* Thoracoscopic incision of thymus */
"0809" = "1" /* Other incision of eyelid */
"090 " = "1" /* Incision of lacrimal gland */
"0953" = "1" /* Incision of lacrimal sac */
"1244" = "1" /* Excision of lesion of ciliary body */
"1289" = "1" /* Other operations on sclera */
"149 " = "1" /* Other operations on retina, choroid, and posterior chamber */
"1609" = "1" /* Other orbitotomy */
"1802" = "1" /* Incision of external auditory canal */
"1809" = "1" /* OTHER INCISION OF EXTERNAL EAR */
"1811" = "1" /* Otoscopy */
"2001" = "1" /* Myringotomy with insertion of tube */
"2009" = "1" /* Other myringotomy */
"2021" = "1" /* Mastoid incision */
"2022" = "1" /* Petrus pyram air cel inc */
"2023" = "1" /* Middle ear incision */
"2079" = "1" /* Other incision, excision, and destruction of inner ear */
"2100" = "1" /* Control of epistaxis, not otherwise specified */
"2101" = "1" /* Control of epistaxis by anterior nasal packing */
"2102" = "1" /* Control of epistaxis by posterior (and anterior) packing */
"2103" = "1" /* Control of epistaxis by cauterization (and packing) */
"2104" = "1" /* Control of epistaxis by ligation of ethmoidal arteries */
"2105" = "1" /* Control of epistaxis by (transantral) ligation of the */
"2106" = "1" /* Control of epistaxis by ligation of the external carotid */
"2107" = "1" /* Control of epistaxis by excision of nasal mucosa and skin  */
"2109" = "1" /* Control of epistaxis by other means */
"211 " = "1" /* Incision of nose */
"2121" = "1" /* Rhinoscopy */
"2219" = "1" /* Other diagnostic procedures on nasal sinuses */
"2239" = "1" /* Other external maxillary antrotomy */
"2241" = "1" /* Frontal sinusotomy */
"2251" = "1" /* Ethmoidotomy */
"2252" = "1" /* Sphenoidotomy */
"260 " = "1" /* Incision of salivary gland or duct */
"270 " = "1" /* Drainage of face and floor of mouth */
"280 " = "1" /* Incision and drainage of tonsil and peritonsillar structures */
"287"  = "1" /* CONTROL OF HEMORRHAGE AFTER TONSILLECTOMY AND ADENOIDECTOMY */
"2911" = "1" /* Pharyngoscopy */
"313 " = "1" /* Other incision of larynx or trachea */
"3141" = "1" /* Tracheoscopy through artificial stoma */
"3142" = "1" /* Laryngoscopy and other tracheoscopy */
"330 " = "1" /* Incision of bronchus */
"331 " = "1" /* Incision of lung */
"3321" = "1" /* Bronchoscopy through artificial stoma */
"3322" = "1" /* Fiberoptic bronchoscopy */
"3323" = "1" /* Other bronchoscopy */
"3324" = "1" /* Closed (endoscopic) biopsy of bronchus */
"3402" = "1" /* Exploratory thoracotomy */
"3403" = "1" /* Reopening of recent thoracotomy site */
"3409" = "1" /* Other incision of pleura */
"341 " = "1" /* Incision of mediastinum */
"3421" = "1" /* Transpleural thoracoscopy */
"3422" = "1" /* Mediastinoscopy */
"3582" = "1" /* Total repair of total anomalous pulmonary venous connection */
"3639" = "1" /* Other heart revascularization */
"3699" = "1" /* Other operations on vessels of heart */
"370 " = "1" /* Pericardiocentesis */
"3711" = "1" /* Cardiotomy */
"3799" = "1" /* Other operations on heart and pericardium */
"3800" = "1" /* Incision of vessel NOS */
"3801" = "1" /* Intracran vessel incis */
"3802" = "1" /* Head/neck ves incis NEC */
"3803" = "1" /* Upper limb vessel incis */
"3804" = "1" /* Incision of aorta */
"3805" = "1" /* Thoracic vessel inc NEC */
"3806" = "1" /* Abdomen artery incision */
"3807" = "1" /* Abdominal vein incision */
"3808" = "1" /* Lower limb artery incis */
"3809" = "1" /* Lower limb vein incision */
"3850" = "1" /* Varicose v lig-strip NOS */
"3851" = "1" /* Intcran var v lig-strip */
"3852" = "1" /* Head/neck var v lig-str */
"3853" = "1" /* Arm varicose v lig-strip */
"3855" = "1" /* Thorac var v lig-strip */
"3857" = "1" /* Abd varicos v liga-strip */
"3859" = "1" /* Leg varicos v liga-strip */
"387 " = "1" /* Interruption of the vena cava */
"3880" = "1" /* OTHER SURGICAL OCCLUSION OF UNSPECIFIED SITE */
"3881" = "1" /* OTHER SURGICAL OCCLUSION OF INTRACRANIAL VESSELS */
"3882" = "1" /* OTHER SURGICAL OCCLUSION OF OTHER VESSELS OF HEAD AND NECK */
"3883" = "1" /* OTHER SURGICAL OCCLUSION OF UPPER LIMB VESSELS */
"3884" = "1" /* OTHER SURGICAL OCCLUSION OF AORTA, ABDOMINAL */
"3885" = "1" /* OTHER SURGICAL OCCLUSION OF THORACIC VESSEL */
"3886" = "1" /* OTHER SURGICAL OCCLUSION OF ABDOMINAL ARTERIES */
"3887" = "1" /* OTHER SURGICAL OCCLUSION OF VESSELS ABDOMINAL VEINS */
"3888" = "1" /* OTHER SURGICAL OCCLUSION OF LOWER LIMB ARTERIES */
"3889" = "1" /* OTHER SURGICAL OCCLUSION OF LOWER LIMB VEINS */
"3930" = "1" /* Suture of vessel NOS */
"3931" = "1" /* Suture of artery */
"3932" = "1" /* Suture of vein */
"3941" = "1" /* CONTROL OF HEMORRHAGE FOLLOWING VASCULAR SURGERY*/
"3952" = "1" /* Other repair of aneurysm */
"3953" = "1" /* Repair of arteriovenous fistula */
"3972" = "1" /* Endovascular repair or occlusion of head and neck vessels */
"3979" = "1" /* Other endovascular repair (of aneurysm) of other vessels */
"398 " = "1" /* Operations on carotid body and other vascular bodies */
"3998" = "1" /* CONTROL OF HEMORRHAGE NOS */
"400 " = "1" /* Incision of lymphatic structures */
"412 " = "1" /* Splenotomy */
"4209" = "1" /* Other incision of esophagus */
"4221" = "1" /* Operative esophagoscopy by incision */
"4222" = "1" /* Esophagoscopy through artificial stoma */
"4223" = "1" /* Other esophagoscopy */
"4233" = "1" /* Endoscopic excision or destruction of lesion or tissue of   */
"4239" = "1" /* Other destruction of lesion or tissue of esophagus */
"4291" = "1" /* Ligation of esophageal varices */
"430 " = "1" /* Gastrotomy */
"4341" = "1" /* Endoscopic excision or destruction of lesion or tissue of  */
"4411" = "1" /* Transabdominal gastroscopy */
"4412" = "1" /* Gastroscopy through artificial stoma */
"4413" = "1" /* Other gastroscopy */
"4440" = "1" /* Suture peptic ulcer NOS */
"4441" = "1" /* Sut gastric ulcer site */
"4442" = "1" /* Suture duoden ulcer site */
"4443" = "1" /* Endosc control gast hem */
"4444" = "1" /* Transcath embo gast hem */
"4449" = "1" /* Other control gast hem */
"4491" = "1" /* Ligation of gastric varices */
"4500" = "1" /* Intestinal incision NOS */
"4501" = "1" /* Duodenal incision */
"4502" = "1" /* Small bowel incision NEC */
"4503" = "1" /* Large bowel incision */
"4511" = "1" /* Transabdominal endoscopy of small intestine */
"4512" = "1" /* Endoscopy of small intestine through artificial stoma */
"4513" = "1" /* Other endoscopy of small intestine */
"4516" = "1" /* Esophagogastroduodenoscopy (EGD) with closed biopsy */
"4521" = "1" /* Transabdominal endoscopy of large intestine */
"4522" = "1" /* Endoscopy of large intestine through artificial stoma */
"4523" = "1" /* Colonoscopy */
"4524" = "1" /* Flexible sigmoidoscopy */
"4543" = "1" /* Endoscopic destruction of other lesion or tissue of large   */
"4549" = "1" /* Other destruction of lesion of large intestine */
"480 " = "1" /* Proctotomy */
"4821" = "1" /* Transabdominal proctosigmoidoscopy */
"4822" = "1" /* Proctosigmoidoscopy through artificial stoma */
"4823" = "1" /* Rigid proctosigmoidoscopy */
"4921" = "1" /* Anoscopy */
"4945" = "1" /* Ligation of hemorrhoids */
"4995" = "1" /* CONTROL OF (POSTOPERATIVE) HEMORRHAGE OF ANUS */
"500 " = "1" /* Hepatotomy */
"5110" = "1" /* Endoscopic retrograde cholangiopancreatography */
"5111" = "1" /* Endoscopic retrograde cholangiography */
"5141" = "1" /* Common duct exploration for removal of calculus */
"5142" = "1" /* Common duct exploration for relief of other obstruction */
"5149" = "1" /* Incision of other bile ducts for relief of obstruction */
"5151" = "1" /* Common duct exploration */
"5159" = "1" /* Bile duct incision NEC */
"5184" = "1" /* Endoscopic dilation of ampulla and biliary duct */
"5188" = "1" /* Endoscopic removal of stone(s) from biliary tract */
"5196" = "1" /* Percutaneous extraction of common duct stones */
"5198" = "1" /* Other percutaneous procedures on biliary tract */
"5209" = "1" /* Other pancreatotomy */
"5213" = "1" /* Endoscopic retrograde pancreatography */
"540"  = "1" /* INCISION OF ABDOMINAL WALL */
"5411" = "1" /* Exploratory laparotomy */
"5412" = "1" /* REOPENING OF RECENT LAPAROTOMY SITE */
"5419" = "1" /* Other laparotomy */
"5421" = "1" /* Laparoscopy */
"5495" = "1" /* Incision of peritoneum */
"5501" = "1" /* Nephrotomy */
"5511" = "1" /* Pyelotomy */
"5521" = "1" /* Nephroscopy */
"5522" = "1" /* Pyeloscopy */
"562 " = "1" /* Ureterotomy */
"5631" = "1" /* Ureteroscopy */
"5719" = "1" /* Other cystotomy */
"5731" = "1" /* Cystoscopy through artificial stoma */
"5732" = "1" /* Other cystoscopy */
"5793" = "1" /* CONTROL OF (POSTOPERATIVE HEMORRHAGE OF BLADDER) */
"580 " = "1" /* Urethrotomy */
"5822" = "1" /* Other urethroscopy */
"5909" = "1" /* Other incision of perirenal or periureteral tissue */
"5919" = "1" /* OTHER INCISION OF PERIVESICLE TISSUE */
"600 " = "1" /* Incision of prostate */
"6081" = "1" /* Incision of periprostatic tissue */
"6094" = "1" /* CONTROL OF (POSTOPERATIVE) HEMORRHAGE OF PROSTATE */
"610"  = "1" /* INCISION AND DRAINAGE OF SCROTUM AND TUNICA AND VAGINALIS */
"620 " = "1" /* Incision of testis */
"631 " = "1" /* Excision of varicocele and hydrocele of spermatic cord */
"636 " = "1" /* Vasotomy */
"6372" = "1" /* Ligation of spermatic cord */
"6392" = "1" /* Epididymotomy */
"6393" = "1" /* Incision of spermatic cord */
"6492" = "1" /* Incision of penis */
"6501" = "1" /* Laparoscopic oophorotomy */
"6509" = "1" /* Other oophorotomy */
"6601" = "1" /* Salpingotomy */
"680 " = "1" /* Hysterotomy */
"6811" = "1" /* Digital examination of uterus */
"6812" = "1" /* Hysteroscopy */
"6995" = "1" /* Incision of cervix */
"6998" = "1" /* OTHER OPERATIONS ON SUPPORTING STRUCTURES OF UTERUS */
"700 " = "1" /* Culdocentesis */
"7012" = "1" /* Culdotomy */
"7014" = "1" /* OTHER VAGINOTOMY */
"7021" = "1" /* Vaginoscopy */
"7022" = "1" /* Culdoscopy */
"7109" = "1" /* OTHER INCISION OF VULVA AND PERINEUM */
"757 " = "1" /* Manual exploration of uterine cavity, postpartum */
"7591" = "1" /* EVACUATION OF OBSTETRICAL INCISIONAL HEMATOMA OF PERINEUM */
"7592" = "1" /* EVACUATION OF OTHER HEMATOMA OF VULVA OR VAGINA */
"7710" = "1" /* Other incision of bone without division, unspecified site */
"8010" = "1" /* Other arthrotomy, unspecified site */
"8201" = "1" /* Exploration of tendon sheath of hand */
"8202" = "1" /* Myotomy of hand */
"8203" = "1" /* Bursotomy of hand */
"8204" = "1" /* Incision and drainage of palmar or thenar space */
"8209" = "1" /* Other incision of soft tissue of hand */
"8301" = "1" /* Exploration of tendon sheath */
"8302" = "1" /* Myotomy */
"8303" = "1" /* Bursotomy */
"8309" = "1" /* Other incision of soft tissue */
"850 " = "1" /* Mastotomy */
"8603" = "1" /* Incision of pilonidal sinus or cyst */
"8604" = "1" /* OTHER INCISION WITH DRAINAGE OF SKIN AND SUBCUTANEOUS TISSUE */
"8609" = "1" /* Other incision of skin and subcutaneous tissue */
"9621" = "1" /* Dilation of frontonasal duct */
"9925" = "1" /* Injection or infusion of cancer chemotherapeutic substance */
"9929" = "1" /* Injection or infusion of other therapeutic or prophylactic */
OTHER  = "0" ;



 /* COAGULATION DISORDERS */
 /* ICD-9-CM DIAGNOSIS CODES: */

/* VALUE $COAGDID - Removed for 5.0 */


/* STRATIFIED BY: COAGULOPATHIES */
/* ICD-9-CM DIAGNOSIS CODE: */

VALUE $ACGOFD
"2860"  = "1" /* CONG FACTOR VIII DIORD */
"2861"  = "1" /* CONG FACTOR IX DISORDER */
"2862"  = "1" /* CONG FACTOR XI DISORDER */
"2863"  = "1" /* CONG DEF CLOT FACTOR NEC */
"2864"  = "1" /* VON WILLEBRAND'S DISEASE */
"2865"  = "1" /* CIRCULATING ANTICOAG DIS */
"28652" = "1" /* ACQUIRED HEMOPHILIA */
"28653" = "1" /* Antiphosopholipid antibody with hemorrhagic disorder */
"28659" = "1" /* OTHER Other hemorrhagic disorder due to intrinstic circularting anticoagulants, antibodies, or inhibitors */
"2866"  = "1" /* DEFIBRINATION SYNDROME */
"2867"  = "1" /* ACQ COAGUL FACTOR DEFIC */
"2869"  = "1" /* COAGULAT DEFECT NEC NOS */
"2871"  = "1" /* THROMBOCYTOPATHY */
"2873"  = "1" /* PRIMARY THROMBOCYTOPENIA */
"28730" = "1" /* PRIM THROMBOCYTOPEN NOS */  
"28731" = "1" /* IMMUNE THROMBOCYT PURPRA */ 
"28732" = "1" /* EVANS' SYNDROME */          
"28733" = "1" /* CONG/HERID THROMB PURPRA */ 
"28739" = "1" /* PRIM THROMBOCYTOPEN NEC */  
"2874"  = "1" /* SECOND THROMBOCYTOPENIA */
"28741" = "1" /* POSTTRANSFUSION PURPURA */
"2875"  = "1" /* THROMBOCYTOPENIA NOS */
"2878"  = "1" /* HEMORRHAGIC COND NEC */
"2879"  = "1" /* HEMORRHAGIC COND NOS */
OTHER   = "0" ;

/*STRATIFIED: BY PR CODE FOR ECMO */
/* ICD-9-CM CODE PROCEDURE CODE: */

VALUE $ECMOP
"3965" = "1" /* ECMO */
OTHER  = "0" ;


 /* ---------------------------------- */
 /* POST-OPERATIVE RESPIRATORY FAILURE */
 /*   PROVIDER INDICATOR / PDI # 9     */
 /* ---------------------------------- */


 /* ICD-9-CM ACUTE RESPIRATORY FAILURE DIAGNOSIS CODES (BEFORE oCT 1, 2011) */

VALUE $ACURFID										/** FOR DISCHARGES BEFORE OCTOBER 1, 2011 **/
"51881" = "1" /* ACUTE RESPIRATRY FAILURE */         /** FOR DISCHARGES ON OR AFTER OCTOBER 1, 2011   */
"51884" = "1" /* ACUTE AND CHRONIC ESPIRATRY FAILURE */
OTHER   = '0' ;

/* On 1/6/2012 Removed this code: */
/*    5185"  = "1" */ /* PULMONARY INSUFFICIENCY FOLLOWING TRAUMA AND SURGERY */


 /* ICD-9-CM ACUTE RESPIRATORY FAILURE DIAGNOSIS CODES (ON OR AFTER oCT 1, 2011)*/

VALUE $ACURF2D
"51851" = "1" /* ACUTE RESPIRATRY FAILURE FOLLOWING TRAUMA AND SURGERY */
"51853" = "1" /* ACUTE AND CHRONC RESPIRATRY FAILURE FOLLOWING TRAUMA AND SURGERY */
OTHER   = "0" ;


 /* ICD-9-CM PROCEDURE CODES: */

VALUE $BLANK
OTHER  = "0" ;

VALUE $PR9604P
"9604" = "1" /* INSERT OF SENSTAKEN TUBE */
OTHER  = "0" ;

VALUE $PR9670P
"9670" = "1" /* CONTINUOUS MECHANICAL VENTILATION OF UNSPEC DURATION */
OTHER  = "0" ;

VALUE $PR9671P
"9671" = "1" /* CONTINUOUS MECHANICAL VENTILATION FOR LESS THAN 96 CONSECUTIVE HRS */
OTHER  = "0" ;

VALUE $PR9672P
"9672" = "1" /* CONTINUOUS MECHANICAL VENTILATION FOR 96 CONSECUTIVE HRS OR MORE*/
OTHER  = "0" ;

 /* EXCLUDE: TRACHEOSTOMY */;
 /* ICD-9-CM PROCEDURE CODE: */;

VALUE $TRACHIP
"311 " = "1" /* Added for 5.0: TEMPORARY TRACHEOSTOMY */
"3121" = "1" /* MEDIASTINAL TRACHEOSTOMY */
"3129" = "1" /* OTHER PERM TRACHEOSTOMY */
"3174" = "1" /* REVISION OF TRACHEOSTOMY */
OTHER  = "0" ;

 /* EXCLUDE: NEUROMUSCULAR DISORDERS */;
 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $NEUROMD
"3570 " = "1" /* AC INFECT POLYNEURITIS */
"35800" = "1" /* MYSTHNA GRVS W/O AC EXAC */
"35801" = "1" /* MYASTHNA GRAVS W AC EXAC */
"3581 " = "1" /* MYASTHENIA IN OTH DIS */
"3582 " = "1" /* TOXIC MYONEURAL DISORDER */
"35830" = "1" /* LAMBERT-EATON SYNDROME, UNSPECIFIED */
"35831" = "1" /* LAMBERT-EATON SYNDROME IN NEOPLASTIC DISEASE */
"35839" = "1" /* LAMBERT-EATON SYNDROME IN OTHER DISEASES CLASSIFIED ELSEWHERE */
"3588 " = "1" /* MYONEURAL DISORDERS NEC */
"3589 " = "1" /* MYONEURAL DISORDERS NOS */
"3590 " = "1" /* CONG HERED MUSC DYSTRPHY */
"3591 " = "1" /* HERED PROG MUSC DYSTRPHY */
"3592 " = "1" /* MYOTONIC DISORDERS */
"35921" = "1" /* MYOTONIC MUSCULAR DYSTROPHY */
"35922" = "1" /* MYOTONIA CONGENITA */
"35923" = "1" /* MYOTONIC CHONDRODYSTRPHY */
"35929" = "1" /* OTHER UNSPECIFIED MYOTONIC DISORDER */
"3593 " = "1" /* FAMIL PERIODIC PARALYSIS */
"3594 " = "1" /* TOXIC MYOPATHY */
"3595 " = "1" /* MYOPATHY IN ENDOCRIN DIS */
"3596 " = "1" /* INFL MYOPATHY IN OTH DIS */
"35971" = "1" /* INCLUSION BODY MYOSITIS */
"35979" = "1" /* INFLM/IMMUNE MYOPATH NEC */
"35981" = "1" /* CRITICAL ILLNESS MYOPTHY */
"35989" = "1" /* MYOPATHIES NEC */
"3599 " = "1" /* MYOPATHY NOS */
OTHER   = "0" ;

 /* EXCLUDE: CRANIOFACIAL ANOMALIES */;
 /* ICD-9-CM PROCEDURE CODE: */;

VALUE $NUCRANP
'253  ' = "1" /* Complete glossectomy */
'254  ' = "1" /* Radical glossectomy */
'2991 ' = "1" /* Dilation of pharynx */   
'3009 ' = "1" /* Other excision or destruction of lesion or tissue of larynx */           
'3021 ' = "1" /* Epiglottidectomy */
'3022 ' = "1" /* Vocal cordectomy */      
'3029 ' = "1" /* Other partial laryngectomy */  
'303  ' = "1" /* Complete laryngectomy */
'304  ' = "1" /* Radical laryngectomy */
'313  ' = "1" /* Other incision of larynx or trachea */
'315  ' = "1" /* Local excision or destruction of lesion or tissue of trachea */    
'3169 ' = "1" /* Other repair of larynx */
'3173 ' = "1" /* Closure of other fistula of trachea */
'3175 ' = "1" /* Reconstruction of trachea and construction of artificial larynx */ 
'3179 ' = "1" /* Other repair and plastic operations on trachea */                  
'3198 ' = "1" /* Other operations on larynx */
'3199 ' = "1" /* Other operations on trachea */
'214  ' = "1" /* RESECTION OF NOSE */
'2161 ' = "1" /* DIATHER/CRYO TURBINECTOM */
'2162 ' = "1" /* TURBINATE FRACTURE */
'2169 ' = "1" /* TURBINECTOMY NEC */
'2172 ' = "1" /* OPEN REDUCTION NASAL FX */
'2199 ' = "1" /* NASAL OPERATION NEC */
'2231 ' = "1" /* RADICAL MAXILLARY ANTROT */
'2239 ' = "1" /* EXT MAXILLARY ANTROT NEC */
'2241 ' = "1" /* FRONTAL SINUSOTOMY */
'2242 ' = "1" /* FRONTAL SINUSECTOMY */
'2250 ' = "1" /* SINUSOTOMY NOS */
'2251 ' = "1" /* ETHMOIDOTOMY */
'2252 ' = "1" /* SPHENOIDOTOMY */
'2253 ' = "1" /* MULTIPLE SINUS INCISION */
'2260 ' = "1" /* SINUSECTOMY NOS */
'2261 ' = "1" /* C-LUC EXC MAX SINUS LES */
'2262 ' = "1" /* EXC MAX SINUS LESION NEC */
'2263 ' = "1" /* ETHMOIDECTOMY */
'2264 ' = "1" /* SPHENOIDECTOMY */
'2271 ' = "1" /* NASAL SINUS FISTULA CLOS */
'2279 ' = "1" /* NASAL SINUS REPAIR NEC */
'229  ' = "1" /* OTHER NASAL SINUS OPS */
'251  ' = "1" /* DESTRUCTION TONGUE LES */
'252  ' = "1" /* PARTIAL GLOSSECTOMY */
'2559 ' = "1" /* REPAIR OF TONGUE NEC */
'2594 ' = "1" /* OTHER GLOSSOTOMY */
'2599 ' = "1" /* TONGUE OPERATION NEC */
'2621 ' = "1" /* SALIVARY CYST MARSUPIAL */
'2629 ' = "1" /* SALIV LESION EXCIS NEC */
'2630 ' = "1" /* SIALOADENECTOMY NOS */
'2631 ' = "1" /* PARTIAL SIALOADENECTOMY */
'2632 ' = "1" /* COMPLETE SIALOADENECTOMY */
'2641 ' = "1" /* SUTURE OF SALIV GLND LAC */
'2642 ' = "1" /* SALIVARY FISTULA CLOSURE */
'2649 ' = "1" /* SALIVARY REPAIR NEC */
'2699 ' = "1" /* SALIVARY OPERATION NEC */
'270  ' = "1" /* DRAIN FACE & MOUTH FLOOR */
'271  ' = "1" /* INCISION OF PALATE */
'2731 ' = "1" /* LOC EXC BONY PALATE LES */
'2732 ' = "1" /* WIDE EXC BONY PALATE LES */
'2742 ' = "1" /* WIDE EXCISION OF LIP LES */
'2743 ' = "1" /* EXCISION OF LIP LES NEC */
'2749 ' = "1" /* EXCISION OF MOUTH NEC */
'2753 ' = "1" /* CLOSURE OF MOUTH FISTULA */
'2754 ' = "1" /* REPAIR OF CLEFT LIP */
'2755 ' = "1" /* FULL-THICK GRFT TO MOUTH */
'2756 ' = "1" /* SKIN GRAFT TO MOUTH NEC */
'2757 ' = "1" /* PEDICLE ATTACH TO MOUTH */
'2759 ' = "1" /* MOUTH REPAIR NEC */
'2761 ' = "1" /* SUTURE OF PALATE LACERAT */
'2762 ' = "1" /* CLEFT PALATE CORRECTION */
'2763 ' = "1" /* REVIS CLEFT PALAT REPAIR */
'2764 ' = "1" /* INSERT PALATAL IMPLANT (Begin 2004) */
'2769 ' = "1" /* OTH PLASTIC REPAIR PALAT */
'2771 ' = "1" /* INCISION OF UVULA */
'2772 ' = "1" /* EXCISION OF UVULA */
'2773 ' = "1" /* REPAIR OF UVULA */
'2779 ' = "1" /* OTHER UVULA OPERATIONS */
'2792 ' = "1" /* MOUTH INCISION NOS */
'2799 ' = "1" /* ORAL CAVITY OPS NEC */
'280  ' = "1" /* PERITONSILLAR I & D */
'284  ' = "1" /* EXCISION OF TONSIL TAG */
'285  ' = "1" /* EXCISION LINGUAL TONSIL */
'2891 ' = "1" /* INCIS TO REMOV TONSIL FB */
'2892 ' = "1" /* EXCIS TONSIL/ADENOID LES */
'2899 ' = "1" /* TONSIL/ADENOID OPS NEC */
'290  ' = "1" /* PHARYNGOTOMY */
'292  ' = "1" /* EXC BRANCHIAL CLEFT CYST */
'293  ' = "1" /* DESTRUCT PHARYNGEAL LES (Begin 1980 End 1991) */
'2931 ' = "1" /* CRICOPHARYNGEAL MYOTOMY (Begin 1991) */
'2932 ' = "1" /* PHARYNGEAL DIVERTICULEC (Begin 1991) */
'2933 ' = "1" /* PHARYNGECTOMY (Begin 1991) */
'2939 ' = "1" /* EXCIS/DESTR LES PHAR NEC (Begin 1991) */
'294  ' = "1" /* PLASTIC OP ON PHARYNX */
'2951 ' = "1" /* SUTURE OF PHARYNGEAL LAC */
'2952 ' = "1" /* CLOS BRANCH CLEFT FISTUL */
'2953 ' = "1" /* CLOS PHARYNX FISTULA NEC */
'2954 ' = "1" /* LYSIS PHARYNGEAL ADHES */
'2959 ' = "1" /* PHARYNGEAL REPAIR NEC */
'2992 ' = "1" /* DIVIS GLOSSOPHARYNG NERV */
'2999 ' = "1" /* PHARYNGEAL OPERATION NEC */
'310  ' = "1"  /* LARYNGO-TRACHEAL OPERATIONS */
'3161 ' = "1"  /* LARYNGO-TRACHEAL OPERATIONS */
'3162 ' = "1"  /* LARYNGO-TRACHEAL OPERATIONS */
'3163 ' = "1"  /* LARYNGO-TRACHEAL OPERATIONS */
'3164 ' = "1"  /* LARYNGO-TRACHEAL OPERATIONS */
'3171 ' = "1"  /* LARYNGO-TRACHEAL OPERATIONS */
'3172 ' = "1"  /* LARYNGO-TRACHEAL OPERATIONS */ 
'3191 ' = "1"  /* LARYNGO-TRACHEAL OPERATIONS */
'3192 ' = "1"  /* LARYNGO-TRACHEAL OPERATIONS */
'3193 ' = "1"  /* LARYNGO-TRACHEAL OPERATIONS */
'3194 ' = "1"  /* LARYNGO-TRACHEAL OPERATIONS */
'3195 ' = "1"  /* LARYNGO-TRACHEAL OPERATIONS */
OTHER  = "0" ;


VALUE $CRANI2P
"252 " = "1" /* Partial glossectomy */
"2559" = "1" /* Other repair and plastic operations on tongue */	
"2732" = "1" /* Wide excision or destruction of lesion or tissue of bony palate */	
"2762" = "1" /* Correction of cleft palate */
"2763" = "1" /* Revision of cleft palate repair */
"2769" = "1" /* Other plastic repair of palate */
"2931" = "1" /* Cricopharyngeal myotomy */
"7631" = "1" /* Partial mandibulectomy */
"7639" = "1" /* Partial ostectomy of other facial bone */
"7641" = "1" /* Total mandibulectomy with synchronous reconstruction */
"7642" = "1" /* Other total mandibulectomy */
"7643" = "1" /* Other reconstruction of mandible */
"7644" = "1" /* Total ostectomy of other facial bone with synchronous reconstruction */
"7645" = "1" /* Other total ostectomy of other facial bone */
"7646" = "1" /* Other reconstruction of other facial bone */
"7661" = "1" /* Closed osteoplasty [osteotomy] of mandibular ramus */
"7662" = "1" /* Open osteoplasty [osteotomy] of mandibular ramus */
"7663" = "1" /* Osteoplasty [osteotomy] of body of mandible */
"7664" = "1" /* Other orthognathic surgery on mandible */
"7665" = "1" /* Segmental osteoplasty [osteotomy] of maxilla */	
"7666" = "1" /* Total osteoplasty [osteotomy] of maxilla */
"7669" = "1" /* Other facial bone repair */	
"7670" = "1" /* Reduction of facial fracture, not otherwise specified */
"7671" = "1" /* Closed reduction of malar and zygomatic fracture */
"7672" = "1" /* Open reduction of malar and zygomatic fracture */
"7673" = "1" /* Closed reduction of maxillary fracture */
"7674" = "1" /* Open reduction of maxillary fracture */
"7675" = "1" /* Closed reduction of mandibular fracture */
"7676" = "1" /* Open reduction of mandibular fracture */
"7677" = "1" /* Open reduction of alveolar fracture */
"7678" = "1" /* Other closed reduction of facial fracture */
"7679" = "1" /* Other open reduction of facial fracture */
"7691" = "1" /* Bone graft to facial bone */
"7692" = "1" /* Insertion of synthetic implant in facial bone */
"7693" = "1" /* Closed reduction of temporomandibular dislocation */
"7694" = "1" /* Open reduction of temporomandibular dislocation */
"7695" = "1" /* Other manipulation of temporomandibular joint */
"7696" = "1" /* Injection of therapeutic substance into temporomandibular joint */
"7697" = "1" /* Removal of internal fixation device from facial bone */
"7699" = "1" /*Other operations on facial bones and joints */
OTHER  = "0" ;

VALUE $CRANIID
"74483" = "1" /* Macrostomia */
"74484" = "1" /* Microstomia */
"7449 " = "1" /* Unspecified anomalies of face and neck */
"7483 " = "1" /* Congenital anomalies of skull and face bones */
"7560 " = "1" /* Tracheomalacia and congenital tracheal stenosis */
OTHER  = "0" ;

 /* ------------------------------- */
 /* POST-OPERATIVE SEPSIS           */
 /*   PROVIDER INDICATOR / PSI # 10 */
 /* ------------------------------- */

 /* SEPTICEMIA */
 /* ICD-9-CM DIAGNOSIS CODES: FOR DISCHARGES BEFORE OCTOBER 1, 2011 */

 /* SEPTICEMIA */
 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $SEPTIID 
"0380"  = "1" /* STREPTOCOCCAL SEPTICEMIA */
"0381"  = "1" /* STAPHYLOCOCCAL SEPTICEMIA */
"03810" = "1" /* STAPHYLOCOCCAL SEPTICEMIA, UNSPECIFIED */
"03811" = "1" /* METH SUSC STAPH AUR SEPT */
"03812" = "1" /* MRSA SEPTICEMIA */
"03819" = "1" /* OTHER STAPHYLOCOCCAL SEPTICEMIA */
"0382"  = "1" /* PNEUMOCOCCAL SEPTICEMIA (STREPTOCOCCUS PNEUMONIAE SEPTICEMIA) */
"0383"  = "1" /* SEPTICEMIA DUE TO ANAEROBES */
"03840" = "1" /* GRAM-NEGATIVE ORGANISM, UNSPECIFIED */
"03841" = "1" /* HEMOPHILUS INFLUENZAE */
"03842" = "1" /* ESCHERICHIA COLI */
"03843" = "1" /* PSEUDOMONAS */
"03844" = "1" /* SERRATIA */
"03849" = "1" /* SEPTICEMIA DUE TO OTHER GRAM-NEGATIVE ORGANISMS */
"0388"  = "1" /* OTHER SPECIFIED SEPTICEMIAS */
"0389"  = "1" /* UNSPECIFIED SEPTICEMIA */
"78552" = "1" /* SEPTIC SHOCK */             
"78559" = "1" /* SHOCK W/O TRAUMA NEC */     
"99591" = "1" /* SYSTEMIC INFLAMMATORY RESPONSE SYNDROME DUE TO INFECTIOUS 
                 PROCESS WITHOUT ORGAN DYSFUNCTION */
"99592" = "1" /* SYSTEMIC INFLAMMATORY RESPONSE SYNDROME DUE TO INFECTIOUS
                 PROCESS WITH ORGAN DYSFUNCTION */
"9980"  = "1" /* POSTOPERATIVE SHOCK */              /** NOT VALID AFTER oCTOBER 1, 2011 **/      
"99800"  = "1" /* POSTOPERATIVE SHOCK, UNSPECIFIED*/
"99802"  = "1" /* SHOCK FOLLOWING TRAUMA OR SURGERY, SEPTIC */  
OTHER   = "0" ;


 /* ICD-9-CM DIAGNOSIS CODES: FOR DISCHARGES BEFORE OCTOBER 1, 2011 */

VALUE $SEPTI2D
"0380"  = "1" /* STREPTOCOCCAL SEPTICEMIA */
"03810" = "1" /* STAPHYLOCOCCAL SEPTICEMIA, UNSPECIFIED */
"03811" = "1" /* METH SUSC STAPH AUR SEPT */
"03812" = "1" /* MRSA SEPTICEMIA */
"03819" = "1" /* OTHER STAPHYLOCOCCAL SEPTICEMIA */
"0382"  = "1" /* PNEUMOCOCCAL SEPTICEMIA (STREPTOCOCCUS PNEUMONIAE SEPTICEMIA) */
"0383"  = "1" /* SEPTICEMIA DUE TO ANAEROBES */
"03840" = "1" /* GRAM-NEGATIVE ORGANISM, UNSPECIFIED */
"03841" = "1" /* HEMOPHILUS INFLUENZAE */
"03842" = "1" /* ESCHERICHIA COLI */
"03843" = "1" /* PSEUDOMONAS */
"03844" = "1" /* SERRATIA */
"03849" = "1" /* SEPTICEMIA DUE TO OTHER GRAM-NEGATIVE ORGANISMS */
"0388"  = "1" /* OTHER SPECIFIED SEPTICEMIAS */
"0389"  = "1" /* UNSPECIFIED SEPTICEMIA */
"78552" = "1" /* SEPTIC SHOCK */             
"99591" = "1" /* SYSTEMIC INFLAMMATORY RESPONSE SYNDROME DUE TO INFECTIOUS 
                 PROCESS WITHOUT ORGAN DYSFUNCTION */
"99592" = "1" /* SYSTEMIC INFLAMMATORY RESPONSE SYNDROME DUE TO INFECTIOUS
                 PROCESS WITH ORGAN DYSFUNCTION */
"9980"  = "1" /* POSTOPERATIVE SHOCK */               /*  NOT VALID AFTER OCTOBER 1, 2011 */ 
"99802" = "1" /* SHOCK FOLLOWING TRAUMA OR SURGERY, SEPTIC */ 
OTHER   = "0" ;



 
 /* EXCLUDE: INFECTION */
 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $INFECID
"0010" = "1" /* CHOLERA D/T VIB CHOLERAE */
"0011" = "1" /* CHOLERA D/T VIB EL TOR */
"0019" = "1" /* CHOLERA NOS */
"0020" = "1" /* TYPHOID FEVER */
"0021" = "1" /* PARATYPHOID FEVER A */
"0022" = "1" /* PARATYPHOID FEVER B */
"0023" = "1" /* PARATYPHOID FEVER C */
"0029" = "1" /* PARATYPHOID FEVER NOS */
"0030" = "1" /* SALMONELLA ENTERITIS */
"0031" = "1" /* SALMONELLA SEPTICEMIA */
"00320" = "1" /* LOCAL SALMONELLA INF NOS */
"00321" = "1" /* SALMONELLA MENINGITIS */
"00322" = "1" /* SALMONELLA PNEUMONIA */
"00323" = "1" /* SALMONELLA ARTHRITIS */
"00324" = "1" /* SALMONELLA OSTEOMYELITIS */
"00329" = "1" /* LOCAL SALMONELLA INF NEC */
"0038" = "1" /* SALMONELLA INFECTION NEC */
"0039" = "1" /* SALMONELLA INFECTION NOS */
"0040" = "1" /* SHIGELLA DYSENTERIAE */
"0041" = "1" /* SHIGELLA FLEXNERI */
"0042" = "1" /* SHIGELLA BOYDII */
"0043" = "1" /* SHIGELLA SONNEI */
"0048" = "1" /* SHIGELLA INFECTION NEC */
"0049" = "1" /* SHIGELLOSIS NOS */
"0050" = "1" /* STAPH FOOD POISONING */
"0051" = "1" /* BOTULISM */
"0052" = "1" /* FOOD POIS D/T C. PERFRIN */
"0053" = "1" /* FOOD POIS: CLOSTRID NEC */
"0054" = "1" /* FOOD POIS: V. PARAHAEM */
"00581" = "1" /* FOOD POISN D/T V. VULNIF */
"00589" = "1" /* BACT FOOD POISONING NEC */
"0059" = "1" /* FOOD POISONING NOS */
"00800" = "1" /* INTEST INFEC E COLI NOS */
"00801" = "1" /* INT INF E COLI ENTRPATH */
"00802" = "1" /* INT INF E COLI ENTRTOXGN */
"00803" = "1" /* INT INF E COLI ENTRNVSV */
"00804" = "1" /* INT INF E COLI ENTRHMRG */
"00809" = "1" /* INT INF E COLI SPCF NEC */
"0081" = "1" /* ARIZONA ENTERITIS */
"0082" = "1" /* AEROBACTER ENTERITIS */
"0083" = "1" /* PROTEUS ENTERITIS */
"00841" = "1" /* STAPHYLOCOCC ENTERITIS */
"00842" = "1" /* PSEUDOMONAS ENTERITIS */
"00843" = "1" /* INT INFEC CAMPYLOBACTER */
"00844" = "1" /* INT INF YRSNIA ENTRCLTCA */
"00845" = "1" /* INT INF CLSTRDIUM DFCILE */
"00846" = "1" /* INTES INFEC OTH ANEROBES */
"00847" = "1" /* INT INF OTH GRM NEG BCTR */
"00849" = "1" /* BACTERIAL ENTERITIS NEC */
"0085" = "1" /* BACTERIAL ENTERITIS NOS */
"0200" = "1" /* BUBONIC PLAGUE */
"0201" = "1" /* CELLULOCUTANEOUS PLAGUE */
"0202" = "1" /* SEPTICEMIC PLAGUE */
"0203" = "1" /* PRIMARY PNEUMONIC PLAGUE */
"0204" = "1" /* SECONDARY PNEUMON PLAGUE */
"0205" = "1" /* PNEUMONIC PLAGUE NOS */
"0208" = "1" /* OTHER TYPES OF PLAGUE */
"0209" = "1" /* PLAGUE NOS */
"0210" = "1" /* ULCEROGLANDUL TULAREMIA */
"0211" = "1" /* ENTERIC TULAREMIA */
"0212" = "1" /* PULMONARY TULAREMIA */
"0213" = "1" /* OCULOGLANDULAR TULAREMIA */
"0218" = "1" /* TULAREMIA NEC */
"0219" = "1" /* TULAREMIA NOS */
"0220" = "1" /* CUTANEOUS ANTHRAX */
"0221" = "1" /* PULMONARY ANTHRAX */
"0222" = "1" /* GASTROINTESTINAL ANTHRAX */
"0223" = "1" /* ANTHRAX SEPTICEMIA */
"0228" = "1" /* OTHER ANTHRAX MANIFEST */
"0229" = "1" /* ANTHRAX NOS */
"0230" = "1" /* BRUCELLA MELITENSIS */
"0231" = "1" /* BRUCELLA ABORTUS */
"0232" = "1" /* BRUCELLA SUIS */
"0233" = "1" /* BRUCELLA CANIS */
"0238" = "1" /* BRUCELLOSIS NEC */
"0239" = "1" /* BRUCELLOSIS NOS */
"024" = "1" /* GLANDERS */
"025" = "1" /* MELIOIDOSIS */
"0260" = "1" /* SPIRILLARY FEVER */
"0261" = "1" /* STREPTOBACILLARY FEVER */
"0269" = "1" /* RAT-BITE FEVER NOS */
"0270" = "1" /* LISTERIOSIS */
"0271" = "1" /* ERYSIPELOTHRIX INFECTION */
"0272" = "1" /* PASTEURELLOSIS */
"0278" = "1" /* ZOONOTIC BACT DIS NEC */
"0279" = "1" /* ZOONOTIC BACT DIS NOS */
"0320" = "1" /* FAUCIAL DIPHTHERIA */
"0321" = "1" /* NASOPHARYNX DIPHTHERIA */
"0322" = "1" /* ANT NASAL DIPHTHERIA */
"0323" = "1" /* LARYNGEAL DIPHTHERIA */
"03281" = "1" /* CONJUNCTIVAL DIPHTHERIA */
"03282" = "1" /* DIPHTHERITIC MYOCARDITIS */
"03283" = "1" /* DIPHTHERITIC PERITONITIS */
"03284" = "1" /* DIPHTHERITIC CYSTITIS */
"03285" = "1" /* CUTANEOUS DIPHTHERIA */
"03289" = "1" /* DIPHTHERIA NEC */
"0329" = "1" /* DIPHTHERIA NOS */
"0330" = "1" /* BORDETELLA PERTUSSIS */
"0331" = "1" /* BORDETELLA PARAPERTUSSIS */
"0338" = "1" /* WHOOPING COUGH NEC */
"0339" = "1" /* WHOOPING COUGH NOS */
"0340" = "1" /* STREP SORE THROAT */
"0341" = "1" /* SCARLET FEVER */
"035" = "1" /* ERYSIPELAS */
"0360" = "1" /* MENINGOCOCCAL MENINGITIS */
"0361" = "1" /* MENINGOCOCC ENCEPHALITIS */
"0362" = "1" /* MENINGOCOCCEMIA */
"0363" = "1" /* MENINGOCOCC ADRENAL SYND */
"03640" = "1" /* MENINGOCOCC CARDITIS NOS */
"03641" = "1" /* MENINGOCOCC PERICARDITIS */
"03642" = "1" /* MENINGOCOCC ENDOCARDITIS */
"03643" = "1" /* MENINGOCOCC MYOCARDITIS */
"03681" = "1" /* MENINGOCOCC OPTIC NEURIT */
"03682" = "1" /* MENINGOCOCC ARTHROPATHY */
"03689" = "1" /* MENINGOCOCCAL INFECT NEC */
"0369" = "1" /* MENINGOCOCCAL INFECT NOS */
"037" = "1" /* TETANUS */
"0380" = "1" /* STREPTOCOCCAL SEPTICEMIA */
"03810" = "1" /* STAPHYLCOCC SEPTICEM NOS */
"03811" = "1" /* METH SUSC STAPH AUR SEPT */
"03812" = "1" /* MRSA SEPTICEMIA */
"03819" = "1" /* STAPHYLCOCC SEPTICEM NEC */
"0382" = "1" /* PNEUMOCOCCAL SEPTICEMIA */
"0383" = "1" /* ANAEROBIC SEPTICEMIA */
"03840" = "1" /* GRAM-NEG SEPTICEMIA NOS */
"03841" = "1" /* H. INFLUENAE SEPTICEMIA */
"03842" = "1" /* E COLI SEPTICEMIA */
"03843" = "1" /* PSEUDOMONAS SEPTICEMIA */
"03844" = "1" /* SERRATIA SEPTICEMIA */
"03849" = "1" /* GRAM-NEG SEPTICEMIA NEC */
"0388" = "1" /* SEPTICEMIA NEC */
"0389" = "1" /* SEPTICEMIA NOS */
"0390" = "1" /* CUTANEOUS ACTINOMYCOSIS */
"0391" = "1" /* PULMONARY ACTINOMYCOSIS */
"0392" = "1" /* ABDOMINAL ACTINOMYCOSIS */
"0393" = "1" /* CERVICOFAC ACTINOMYCOSIS */
"0394" = "1" /* MADURA FOOT */
"0398" = "1" /* ACTINOMYCOSIS NEC */
"0399" = "1" /* ACTINOMYCOSIS NOS */
"0400" = "1" /* GAS GANGRENE */
"0401" = "1" /* RHINOSCLEROMA */
"0402" = "1" /* WHIPPLE"S DISEASE */
"0403" = "1" /* NECROBACILLOSIS */
"04041" = "1" /* INFANT BOTULISM */
"04042" = "1" /* WOUND BOTULISM */
"04081" = "1" /* TROPICAL PYOMYOSITIS */
"04082" = "1" /* TOXIC SHOCK SYNDROME */
"04089" = "1" /* BACTERIAL DISEASES NEC */
"04100" = "1" /* STREPTOCOCCUS UNSPECF */
"04101" = "1" /* STREPTOCOCCUS GROUP A */
"04102" = "1" /* STREPTOCOCCUS GROUP B */
"04103" = "1" /* STREPTOCOCCUS GROUP C */
"04104" = "1" /* ENTEROCOCCUS GROUP D */
"04105" = "1" /* STREPTOCOCCUS GROUP G */
"04109" = "1" /* OTHER STREPTOCOCCUS */
"04110" = "1" /* STAPHYLOCOCCUS UNSPCFIED */
"04111" = "1" /* MTH SUS STPH AUR ELS/NOS */
"04112" = "1" /* MRSA ELSEWHERE/NOS */
"04119" = "1" /* OTHER STAPHYLOCOCCUS */
"0412"  = "1" /* PNEUMOCOCCUS INFECT NOS */
"0413"  = "1" /* KLEBSIELLA INFECT NOS */
"0414"  = "1" /* E. COLI INFECT NOS */
"04141" = "1" /* SHIGA TOXIN-PRODUCING ESCHERICHIA COLI [E.COLI](STEC)O157 */
"04142" = "1" /* OTHER SPECIFIED SHIGA TOXIN-PRODUCING ESCHERICHIA COLI [E.COLI] (STEC)*/
"04143" = "1" /* SHIGA TOXIN-PRODUCING ESCHERICHIA COLI [E.COLI] (STEC),UNSPECIFIED */
"04149" = "1" /* OTHER AND UNSPECIFIED ESCHERICHIA COLI [E.COLI] */
"0415"  = "1" /* H. INFLUENZAE INFECT NOS */
"0416"  = "1" /* PROTEUS INFECTION NOS */
"0417"  = "1" /* PSEUDOMONAS INFECT NOS */
"04182" = "1" /* BACTEROIDES FRAGILIS */
"04183" = "1" /* CLOSTRIDIUM PERFRINGENS */
"04184" = "1" /* OTHER ANAEROBES */
"04185" = "1" /* OTH GRAM NEGATV BACTERIA */
"04186" = "1" /* HELICOBACTER PYLORI */
"04189" = "1" /* OTH SPECF BACTERIA */
"0419"  = "1" /* BACTERIAL INFECTION NOS */
"0783 " = "1" /* CAT-SCRATCH DISEASE */
"0980"  = "1" /* ACUTE GC INFECT LOWER GU */
"09810" = "1" /* GC (ACUTE) UPPER GU NOS */
"09811" = "1" /* GC CYSTITIS (ACUTE) */
"09812" = "1" /* GC PROSTATITIS (ACUTE) */
"09813" = "1" /* GC ORCHITIS (ACUTE) */
"09814" = "1" /* GC SEM VESICULIT (ACUTE) */
"09815" = "1" /* GC CERVICITIS (ACUTE) */
"09816" = "1" /* GC ENDOMETRITIS (ACUTE) */
"09817" = "1" /* ACUTE GC SALPINGITIS */
"09819" = "1" /* GC (ACUTE) UPPER GU NEC */
"0982"  = "1" /* CHR GC INFECT LOWER GU */
"09830" = "1" /* CHR GC UPPER GU NOS */
"09831" = "1" /* GC CYSTITIS, CHRONIC */
"09832" = "1" /* GC PROSTATITIS, CHRONIC */
"09833" = "1" /* GC ORCHITIS, CHRONIC */
"09834" = "1" /* GC SEM VESICULITIS, CHR */
"09835" = "1" /* GC CERVICITIS, CHRONIC */
"09836" = "1" /* GC ENDOMETRITIS, CHRONIC */
"09837" = "1" /* GC SALPINGITIS (CHRONIC) */
"09839" = "1" /* CHR GC UPPER GU NEC */
"09840" = "1" /* GONOCOCCAL CONJUNCTIVIT */
"09841" = "1" /* GONOCOCCAL IRIDOCYCLITIS */
"09842" = "1" /* GONOCOCCAL ENDOPHTHALMIA */
"09843" = "1" /* GONOCOCCAL KERATITIS */
"09849" = "1" /* GONOCOCCAL EYE NEC */
"09850" = "1" /* GONOCOCCAL ARTHRITIS */
"09851" = "1" /* GONOCOCCAL SYNOVITIS */
"09852" = "1" /* GONOCOCCAL BURSITIS */
"09853" = "1" /* GONOCOCCAL SPONDYLITIS */
"09859" = "1" /* GC INFECT JOINT NEC */
"0986" = "1" /* GONOCOCCAL INFEC PHARYNX */
"0987" = "1" /* GC INFECT ANUS & RECTUM */
"09881" = "1" /* GONOCOCCAL KERATOSIS */
"09882" = "1" /* GONOCOCCAL MENINGITIS */
"09883" = "1" /* GONOCOCCAL PERICARDITIS */
"09884" = "1" /* GONOCOCCAL ENDOCARDITIS */
"09885" = "1" /* GONOCOCCAL HEART DIS NEC */
"09886" = "1" /* GONOCOCCAL PERITONITIS */
"09889" = "1" /* GONOCOCCAL INF SITE NEC */
"3200" = "1" /* HEMOPHILUS MENINGITIS */
"3201" = "1" /* PNEUMOCOCCAL MENINGITIS */
"3202" = "1" /* STREPTOCOCCAL MENINGITIS */
"3203" = "1" /* STAPHYLOCOCC MENINGITIS */
"3207" = "1" /* MENING IN OTH BACT DIS */
"32081" = "1" /* ANAEROBIC MENINGITIS */
"32082" = "1" /* MNINGTS GRAM-NEG BCT NEC */
"32089" = "1" /* MENINGITIS OTH SPCF BACT */
"3209" = "1" /* BACTERIAL MENINGITIS NOS */
"3229" = "1" /* MENINGITIS NOS            */
"3240" = "1" /* INTRACRANIAL ABSCESS */
"3241" = "1" /* INTRASPINAL ABSCESS */
"3249" = "1" /* CNS ABSCESS NOS */
"36000" = "1" /* PURULENT ENDOPHTHALM NOS */
"36001" = "1" /* ACUTE ENDOPHTHALMITIS */
"36002" = "1" /* PANOPHTHALMITIS */
"36004" = "1" /* VITREOUS ABSCESS */
"37055" = "1" /* CORNEAL ABSCESS */
"37200" = "1" /* ACUTE CONJUNCTIVITIS NOS */
"37203" = "1" /* MUCOPUR CONJUNCTIVIT NEC */
"37204" = "1" /* PSEUDOMEMB CONJUNCTIVIT */
"37220" = "1" /* BLEPHAROCONJUNCTIVIT NOS */
"37221" = "1" /* ANGULAR BLEPHAROCONJUNCT */
"37230" = "1" /* CONJUNCTIVITIS NOS */
"37300" = "1" /* BLEPHARITIS NOS */
"37301" = "1" /* ULCERATIVE BLEPHARITIS */
"37311" = "1" /* HORDEOLUM EXTERNUM */
"37312" = "1" /* HORDEOLUM INTERNUM */
"37313" = "1" /* ABSCESS OF EYELID */
"37500" = "1" /* DACRYOADENITIS NOS */
"37501" = "1" /* ACUTE DACRYOADENITIS */
"37530" = "1" /* DACRYOCYSTITIS NOS */
"37531" = "1" /* ACUTE CANALICULITIS */
"37532" = "1" /* ACUTE DACRYOCYSTITIS */
"37601" = "1" /* ORBITAL CELLULITIS */
"37602" = "1" /* ORBITAL PERIOSTITIS */
"37603" = "1" /* ORBITAL OSTEOMYELITIS */
"37604" = "1" /* TENONITIS */
"38010" = "1" /* INFEC OTITIS EXTERNA NOS */
"38011" = "1" /* ACUTE INFECTION OF PINNA */
"38012" = "1" /* ACUTE SWIMMERS" EAR */
"38013" = "1" /* AC INFECT EXTERN EAR NEC */
"38014" = "1" /* MALIGNANT OTITIS EXTERNA */
"38150" = "1" /* EUSTACHIAN SALPING NOS */
"38151" = "1" /* AC EUSTACHIAN SALPING */
"38200" = "1" /* AC SUPP OTITIS MEDIA NOS */
"38201" = "1" /* AC SUPP OM W DRUM RUPT */
"38202" = "1" /* AC SUPP OM IN OTH DIS */
"3821" = "1" /* CHR TUBOTYMP SUPP OTITIS MEDIA */
"3822" = "1" /* CHR ATTICOANTRAL SUPP OTITIS MEDIA */
"3823" = "1" /* CHR SUPP OTITIS MEDIA NOS */
"3824" = "1" /* SUPPUR OTITIS MEDIA NOS */
"3829" = "1" /* OTITIS MEDIA NOS */
"38300" = "1" /* AC MASTOIDITIS W/O COMPL */
"38301" = "1" /* SUBPERI MASTOID ABSCESS */
"38302" = "1" /* AC MASTOIDITIS-COMPL NEC */
"38320" = "1" /* PETROSITIS NOS */
"38321" = "1" /* ACUTE PETROSITIS */
"38400" = "1" /* ACUTE MYRINGITIS NOS */
"38633" = "1" /* SUPPURATIV LABYRINTHITIS */
"4200" = "1" /* AC PERICARDIT IN OTH DIS */
"42090" = "1" /* ACUTE PERICARDITIS NOS */
"42099" = "1" /* ACUTE PERICARDITIS NEC */
"4210" = "1" /* AC/SUBAC BACT ENDOCARD */
"4211" = "1" /* AC/SUBAC INFECT ENDOCARD */
"4219" = "1" /* AC/SUBAC ENDOCARDIT NOS */
"42292" = "1" /* SEPTIC MYOCARDITIS */
"4610" = "1" /* AC MAXILLARY SINUSITIS */
"4611" = "1" /* AC FRONTAL SINUSITIS */
"4612" = "1" /* AC ETHMOIDAL SINUSITIS */
"4613" = "1" /* AC SPHENOIDAL SINUSITIS */
"4618" = "1" /* OTHER ACUTE SINUSITIS */
"4619" = "1" /* ACUTE SINUSITIS NOS */
"462" = "1" /* ACUTE PHARYNGITIS */
"463" = "1" /* ACUTE TONSILLITIS */
"46430" = "1" /* AC EPIGLOTTITIS NO OBSTR */
"46431" = "1" /* AC EPIGLOTTITIS W OBSTR */
"4660" = "1" /* ACUTE BRONCHITIS */
"475" = "1" /* PERITONSILLAR ABSCESS */
"47822" = "1" /* PARAPHARYNGEAL ABSCESS */
"47824" = "1" /* RETROPHARYNGEAL ABSCESS */
"481" = "1" /* PNEUMOCOCCAL PNEUMONIA */
"4820" = "1" /* K. PNEUMONIAE PNEUMONIA */
"4821" = "1" /* PSEUDOMONAL PNEUMONIA */
"4822" = "1" /* H.INFLUENZAE PNEUMONIA */
"48230" = "1" /* STREPTOCOCCAL PNEUMN NOS */
"48231" = "1" /* PNEUMONIA STRPTOCOCCUS A */
"48232" = "1" /* PNEUMONIA STRPTOCOCCUS B */
"48239" = "1" /* PNEUMONIA OTH STREP */
"48240" = "1" /* STAPHYLOCOCCAL PNEU NOS */
"48241" = "1" /* METH SUS PNEUM D/T STAPH */
"48242" = "1" /* METH RES PNEU D/T STAPH */
"48249" = "1" /* STAPH PNEUMONIA NEC */
"48281" = "1" /* PNEUMONIA ANAEROBES */
"48282" = "1" /* PNEUMONIA E COLI */
"48283" = "1" /* PNEUMO OTH GRM-NEG BACT */
"48284" = "1" /* LEGIONNAIRES" DISEASE */
"48289" = "1" /* PNEUMONIA OTH SPCF BACT */
"4829" = "1" /* BACTERIAL PNEUMONIA NOS */
"4843" = "1" /* PNEUMONIA IN WHOOPING COUGH */
"4845" = "1" /* PNEUMONIA IN ANTHRAX */
"4848" = "1" /* PNEUMONIA IN OTHER INF DIS  */
"485" = "1" /* BRONCHOPNEUMONIA ORG NOS */
"486" = "1" /* PNEUMONIA, ORGANISM NOS */
"490" = "1" /* BRONCHITIS NOS */
"49122" = "1" /* OBS CHR BRONC W AC BRONC */
"4941" = "1" /* BRONCHIECTASIS W AC EXAC */
"5100" = "1" /* EMPYEMA WITH FISTULA */
"5109" = "1" /* EMPYEMA W/O FISTULA */
"5111" = "1" /* BACT PLEUR/EFFUS NOT TB */
"5130" = "1" /* ABSCESS OF LUNG */
"5131" = "1" /* ABSCESS OF MEDIASTINUM */
"51901" = "1" /* TRACHEOSTOMY INFECTION */
"5192" = "1" /* MEDIASTINITIS */
"5220" = "1" /* PULPITIS */
"5225" = "1" /* PERIAPICAL ABSCESS */
"5227" = "1" /* PERIAPICAL ABSC W SINUS */
"5230" = "1" /* ACUTE GINGIVITIS */
"52300" = "1" /* ACUTE GINGITITIS, PLAQUE */ 
"52301" = "1" /* AC GINGIVITIS,NONPLAQUE */  
"5233" = "1" /* ACUTE PERIODONTITIS       */
"52330" = "1" /* AGGRES PERIODONTITIS NOS */ 
"52331" = "1" /* AGGRES PERIODONTITIS,LOC */ 
"52332" = "1" /* AGGRES PERIODONTITIS,GEN */ 
"52333" = "1" /* ACUTE PERIODONTITIS */  
"5264" = "1" /* INFLAMMATION OF JAW */
"5273" = "1" /* SALIVARY GLAND ABSCESS */
"5283" = "1" /* CELLULITIS/ABSCESS MOUTH */
"53641" = "1" /* GASTROSTOMY INFECTION     */
"53901"  = "1" /* INFECTION DUE TO GASTRIC BAND PROCEDURE */
"53981"  = "1" /* INFECTION DUE TO OTHER BARIATRIC PROCEDURE */
"59681" = "1" /* INFECTION OF CYSTOSTOMY */
"5400" = "1" /* AC APPEND W PERITONITIS */
"5401" = "1" /* ABSCESS OF APPENDIX */
"5409" = "1" /* ACUTE APPENDICITIS NOS */
"541" = "1" /* APPENDICITIS NOS */
"542" = "1" /* OTHER APPENDICITIS */
"56201" = "1" /* DVRTCLI SML INT W/O HMRG */
"56203" = "1" /* DVRTCLI SML INT W HMRHG */
"56211" = "1" /* DVRTCLI COLON W/O HMRHG */
"56213" = "1" /* DVRTCLI COLON W HMRHG */
"566" = "1" /* ANAL & RECTAL ABSCESS */
"5670" = "1" /* PERITONITIS IN INFEC DIS */
"5671" = "1" /* PNEUMOCOCCAL PERITONITIS */
"5672" = "1" /* SUPPURAT PERITONITIS NEC */
"56721" = "1" /* PERITONITIS (ACUTE) GEN  */
"56722" = "1" /* PERITONEAL ABSCESS  */
"56723" = "1" /* SPONTAN BACT PERITONITIS  */
"56729" = "1" /* SUPPURAT PERITONITIS NEC  */
"56731" = "1" /* PSOAS MUSCLE ABSCESS  */
"56738" = "1" /* RETROPERITON ABSCESS NEC  */
"56739" = "1" /* RETROPERITON INFECT NEC  */
"56781" = "1" /* CHOLEPERITONITIS  */
"56782" = "1" /* SCLEROSING MESENTERITIS  */
"56789" = "1" /* PERITONITIS NEC  */
"5679" = "1" /* PERITONITIS NOS */
"5695" = "1" /* INTESTINAL ABSCESS */
"56961" = "1" /* COLOSTY/ENTEROST INFECTN */
"5720" = "1" /* ABSCESS OF LIVER */
"5721" = "1" /* PORTAL PYEMIA */
"57400" = "1" /* CHOLELITH W AC CHOLECYST */
"57401" = "1" /* CHOLELITH/AC GB INF-OBST */
"57430" = "1" /* CHOLEDOCHOLITH/AC GB INF */
"57431" = "1" /* CHOLEDOCHLITH/AC GB-OBST */
"57460" = "1" /* GALL&BIL CAL W/AC W/O OB */
"57461" = "1" /* GALL&BIL CAL W/AC W OBS */
"57480" = "1" /* GAL&BIL CAL W/AC&CHR W/O */
"57481" = "1" /* GAL&BIL CAL W/AC&CH W OB */
"5750" = "1" /* ACUTE CHOLECYSTITIS */
"57510" = "1" /* CHOLECYSTITIS UNSPEC */
"57512" = "1" /* AC&CHRON CHOLECYSTITIS */
"5754" = "1" /* PERFORATION GALLBLADDER */
"5761" = "1" /* CHOLANGITIS */
"5763" = "1" /* PERFORATION OF BILE DUCT */
"5770" = "1" /* ACUTE PANCREATITIS */
"59010" = "1" /* AC PYELONEPHRITIS NOS */
"59011" = "1" /* AC PYELONEPHR W MED NECR */
"5902" = "1" /* RENAL/PERIRENAL ABSCESS */
"5903" = "1" /* PYELOURETERITIS CYSTICA */
"59080" = "1" /* PYELONEPHRITIS NOS        */
"59081" = "1" /* PYELONEPHRIT IN OTH DIS */
"5909" = "1" /* INFECTION OF KIDNEY NOS */
"5950" = "1" /* ACUTE CYSTITIS */
"5954" = "1" /* CYSTITIS IN OTH DIS */
"59581" = "1" /* CYSTITIS CYSTICA */
"59589" = "1" /* CYSTITIS NEC */
"5959" = "1" /* CYSTITIS NOS */
"5970" = "1" /* URETHRAL ABSCESS */
"5990" = "1" /* URIN TRACT INFECTION NOS */
"6010" = "1" /* ACUTE PROSTATITIS */
"6012" = "1" /* ABSCESS OF PROSTATE */
"6013" = "1" /* PROSTATOCYSTITIS */
"6014" = "1" /* PROSTATITIS IN OTH DIS */
"6018" = "1" /* PROSTATITIS  */
"6019" = "1" /* PROSTATITIS NOS */
"6031" = "1" /* INFECTED HYDROCELE */
"6040" = "1" /* ORCHITIS WITH ABSCESS */
"60490" = "1" /* ORCHITIS/EPIDIDYMIT NOS */
"60491" = "1" /* ORCHITIS IN OTH DISEASE */
"6071" = "1" /* BALANOPOSTHITIS */
"6072" = "1" /* INFLAM DIS, PENIS NEC */
"6080" = "1" /* SEMINAL VESICULITIS */
"6084" = "1" /* MALE GEN INFLAM DIS NEC */
"6110" = "1" /* INFLAM DISEASE OF BREAST */
"6140" = "1" /* AC SALPINGO-OOPHORITIS */
"6141" = "1" /* CHRON SALPINGITIS OOPHORITIS */
"6142" = "1" /* SALPINGO-OOPHORITIS NOS */
"6143" = "1" /* ACUTE PARAMETRITIS */
"6144" = "1" /* CHRON OR UNSP CELLULITIS */
"6145" = "1" /* AC PELV PERITONITIS-FEM */
"6149" = "1" /* PID NOS */
"6150" = "1" /* AC UTERINE INFLAMMATION */
"6159" = "1" /* UTERINE INFLAM DIS NOS */
"6160" = "1" /* CERVICITIS */
"61610" = "1" /* VAGINITIS NOS */
"6163" = "1" /* BARTHOLIN"S GLND ABSCESS */
"6164" = "1" /* ABSCESS OF VULVA NEC */
"63400" = "1" /* SPON ABOR W PEL INF-UNSP */
"63401" = "1" /* SPON ABOR W PELV INF-INC */
"63402" = "1" /* SPON ABOR W PEL INF-COMP */
"63500" = "1" /* LEG ABOR W PELV INF-UNSP */
"63501" = "1" /* LEG ABOR W PELV INF-INC */
"63502" = "1" /* LEG ABOR W PELV INF-COMP */
"63600" = "1" /* ILLEG AB W PELV INF-UNSP */
"63601" = "1" /* ILLEG AB W PELV INF-INC */
"63602" = "1" /* ILLEG AB W PELV INF-COMP */
"63700" = "1" /* ABORT NOS W PEL INF-UNSP */
"63701" = "1" /* ABORT NOS W PEL INF-INC */
"63702" = "1" /* ABORT NOS W PEL INF-COMP */
"6380" = "1" /* ATTEM ABORT W PELVIC INF */
"6390" = "1" /* POSTABORTION GU INFECT */
"64650" = "1" /* BACTERIURIA PREG-UNSPEC */
"64651" = "1" /* ASYM BACTERIURIA-DELIVER */
"64652" = "1" /* ASY BACTERURIA-DEL W P/P */
"64653" = "1" /* ASY BACTERIURIA-ANTEPART */
"64654" = "1" /* ASY BACTERIURIA-POSTPART */
"64660" = "1" /* GU INFECT IN PREG-UNSPEC */
"64661" = "1" /* GU INFECTION-DELIVERED */
"64662" = "1" /* GU INFECTION-DELIV W P/P */
"64663" = "1" /* GU INFECTION-ANTEPARTUM */
"64664" = "1" /* GU INFECTION-POSTPARTUM */
"64710" = "1" /* GONORRHEA IN PREG-UNSPEC */
"64711" = "1" /* GONORRHEA-DELIVERED */
"64712" = "1" /* GONORRHEA-DELIVER W P/P */
"64713" = "1" /* GONORRHEA-ANTEPARTUM */
"64714" = "1" /* GONORRHEA-POSTPARTUM */
"64780" = "1" /* INF DIS IN PREG NEC-UNSP */
"64781" = "1" /* INFECT DIS NEC-DELIVERED */
"64782" = "1" /* INFECT DIS NEC-DEL W P/P */
"64783" = "1" /* INFECT DIS NEC-ANTEPART */
"64784" = "1" /* INFECT DIS NEC-POSTPART */
"64790" = "1" /* INFECT IN PREG NOS-UNSP */
"64791" = "1" /* INFECT NOS-DELIVERED */
"64792" = "1" /* INFECT NOS-DELIVER W P/P */
"64793" = "1" /* INFECT NOS-ANTEPARTUM */
"64794" = "1" /* INFECT NOS-POSTPARTUM */
"65840" = "1" /* AMNIOTIC INFECTION-UNSP */
"65841" = "1" /* AMNIOTIC INFECTION-DELIV */
"65843" = "1" /* AMNIOTIC INFECT-ANTEPART */
"67000" = "1" /* MAJ PUERP INF NOS-UNSP */
"67002" = "1" /* MAJ PUER INF NOS-DEL P/P */
"67004" = "1" /* MAJOR PUERP INF NOS-P/P */
"67010" = "1" /* PUERP ENDOMETRITIS-UNSP */
"67012" = "1" /* PUERP ENDOMET DEL W P/P */
"67014" = "1" /* PUERP ENDOMET-POSTPART */
"67020" = "1" /* PUERPERAL SEPSIS-UNSP */
"67022" = "1" /* PUERPRL SEPSIS-DEL W P/P */
"67024" = "1" /* PUERPERL SEPSIS-POSTPART */
"67030" = "1" /* PUERP SEPTC THROMB-UNSP */
"67032" = "1" /* PRP SPTC THRMB-DEL W P/P */
"67034" = "1" /* PRP SEPTC THRMB-POSTPART */
"67080" = "1" /* MAJ PRP INFEC NEC-UNSPEC */
"67082" = "1" /* MAJ PRP INF NEC-DL W P/P */
"67084" = "1" /* MAJ PUERP INFEC NEC-P/P */
"67500" = "1" /* INFECT NIPPLE PREG-UNSP */
"67501" = "1" /* INFECT NIPPLE-DELIVERED */
"67502" = "1" /* INFECT NIPPLE-DEL W P/P */
"67503" = "1" /* INFECT NIPPLE-ANTEPARTUM */
"67504" = "1" /* INFECT NIPPLE-POSTPARTUM */
"67510" = "1" /* BREAST ABSCESS PREG-UNSP */
"67511" = "1" /* BREAST ABSCESS-DELIVERED */
"67512" = "1" /* BREAST ABSCESS-DEL W P/P */
"67513" = "1" /* BREAST ABSCESS-ANTEPART */
"67514" = "1" /* BREAST ABSCESS-POSTPART */
"67580" = "1" /* BREAST INF PREG NEC-UNSP */
"67581" = "1" /* BREAST INFECT NEC-DELIV */
"67582" = "1" /* BREAST INF NEC-DEL W P/P */
"67583" = "1" /* BREAST INF NEC-ANTEPART */
"67584" = "1" /* BREAST INF NEC-POSTPART */
"67590" = "1" /* BREAST INF PREG NOS-UNSP */
"67591" = "1" /* BREAST INFECT NOS-DELIV */
"67592" = "1" /* BREAST INF NOS-DEL W P/P */
"67593" = "1" /* BREAST INF NOS-ANTEPART */
"67594" = "1" /* BREAST INF NOS-POSTPART */
"6800" = "1" /* CARBUNCLE OF FACE */
"6801" = "1" /* CARBUNCLE OF NECK */
"6802" = "1" /* CARBUNCLE OF TRUNK */
"6803" = "1" /* CARBUNCLE OF ARM */
"6804" = "1" /* CARBUNCLE OF HAND */
"6805" = "1" /* CARBUNCLE OF BUTTOCK */
"6806" = "1" /* CARBUNCLE OF LEG */
"6807" = "1" /* CARBUNCLE OF FOOT */
"6808" = "1" /* CARBUNCLE, SITE NEC */
"6809" = "1" /* CARBUNCLE NOS */
"68100" = "1" /* CELLULITIS, FINGER NOS */
"68101" = "1" /* FELON */
"68102" = "1" /* ONYCHIA OF FINGER */
"68110" = "1" /* CELLULITIS, TOE NOS */
"68111" = "1" /* ONYCHIA OF TOE */
"6819" = "1" /* CELLULITIS OF DIGIT NOS */
"6820" = "1" /* CELLULITIS OF FACE */
"6821" = "1" /* CELLULITIS OF NECK */
"6822" = "1" /* CELLULITIS OF TRUNK */
"6823" = "1" /* CELLULITIS OF ARM */
"6824" = "1" /* CELLULITIS OF HAND */
"6825" = "1" /* CELLULITIS OF BUTTOCK */
"6826" = "1" /* CELLULITIS OF LEG */
"6827" = "1" /* CELLULITIS OF FOOT */
"6828" = "1" /* CELLULITIS, SITE NEC */
"6829" = "1" /* CRLLULITIS, SITE NOS */
"683" = "1" /* ACUTE LYMPHADENITIS */
"684" = "1" /* IMPETIGO */
"68600" = "1" /* PYODERMA NOS */
"68609" = "1" /* PYODERMA OTHER */
"6868" = "1" /* LOCAL SKIN INFECTION NEC */
"6869" = "1" /* LOCAL SKIN INFECTION NOS */
"69581" = "1" /* RITTER"S DISEASE */
"70700" = "1" /* DECUBITUS ULCER SITE NOS (Begin 2004)*/ 
"70701" = "1" /* DECUBITUS ULCERELBOW (Begin 2004) */    
"70702" = "1" /* DECUBITUS ULCERUP BACK (Begin 2004) */  
"70703" = "1" /* DECUBITUS ULCERLOW BACK (Begin 2004)*/  
"70704" = "1" /* DECUBITUS ULCERHIP (Begin 2004) */      
"70705" = "1" /* DECUBITUS ULCERBUTTOCK (Begin 2004) */  
"70706" = "1" /* DECUBITUS ULCERANKLE (Begin 2004) */    
"70707" = "1" /* DECUBITUS ULCERHEEL (Begin 2004) */     
"70709" = "1" /* DECUBITUS ULCERSITE NEC (Begin 2004) */
"70720" = "1" /* PRESSURE ULCER,STAGE NOS */
"70722" = "1" /* PRESSURE ULCER, STAGE II */
"70723" = "1" /* PRESSURE ULCER,STAGE III */
"70724" = "1" /* PRESSURE ULCER, STAGE IV */
"71100" = "1" /* PYOGEN ARTHRITIS-UNSPEC */
"71101" = "1" /* PYOGEN ARTHRITIS-SHLDER */
"71102" = "1" /* PYOGEN ARTHRITIS-UP/ARM */
"71103" = "1" /* PYOGEN ARTHRITIS-FOREARM */
"71104" = "1" /* PYOGEN ARTHRITIS-HAND */
"71105" = "1" /* PYOGEN ARTHRITIS-PELVIS */
"71106" = "1" /* PYOGEN ARTHRITIS-L/LEG */
"71107" = "1" /* PYOGEN ARTHRITIS-ANKLE */
"71108" = "1" /* PYOGEN ARTHRITIS NEC */
"71109" = "1" /* PYOGEN ARTHRITIS-MULT */
"71190" = "1" /* INF ARTHRITIS NOS-UNSPEC */
"71191" = "1" /* INF ARTHRITIS NOS-SHLDER */
"71192" = "1" /* INF ARTHRITIS NOS-UP/ARM */
"71193" = "1" /* INF ARTHRIT NOS-FOREARM */
"71194" = "1" /* INF ARTHRIT NOS-HAND */
"71195" = "1" /* INF ARTHRIT NOS-PELVIS */
"71196" = "1" /* INF ARTHRIT NOS-L/LEG */
"71197" = "1" /* INF ARTHRIT NOS-ANKLE */
"71198" = "1" /* INF ARTHRIT NOS-OTH SITE */
"71199" = "1" /* INF ARTHRITIS NOS-MULT */
"7280" = "1" /* INFECTIVE MYOSITIS */
"72886" = "1" /* NECROTIZING FASCIITIS */
"73000" = "1" /* AC OSTEOMYELITIS-UNSPEC */
"73001" = "1" /* AC OSTEOMYELITIS-SHLDER */
"73002" = "1" /* AC OSTEOMYELITIS-UP/ARM */
"73003" = "1" /* AC OSTEOMYELITIS-FOREARM */
"73004" = "1" /* AC OSTEOMYELITIS-HAND */
"73005" = "1" /* AC OSTEOMYELITIS-PELVIS */
"73006" = "1" /* AC OSTEOMYELITIS-L/LEG */
"73007" = "1" /* AC OSTEOMYELITIS-ANKLE */
"73008" = "1" /* AC OSTEOMYELITIS NEC */
"73009" = "1" /* AC OSTEOMYELITIS-MULT */
"73010" = "1" /* CHR OSTEOMYELITIS-UNSP */
"73011" = "1" /* CHR OSTEOMYELIT-SHLDER */
"73012" = "1" /* CHR OSTEOMYELIT-UP/ARM */
"73013" = "1" /* CHR OSTEOMYELIT-FOREARM */
"73014" = "1" /* CHR OSTEOMYELIT-HAND */
"73015" = "1" /* CHR OSTEOMYELIT-PELVIS */
"73016" = "1" /* CHR OSTEOMYELIT-L/LEG */
"73017" = "1" /* CHR OSTEOMYELIT-ANKLE */
"73018" = "1" /* CHR OSTEOMYELIT NEC */
"73019" = "1" /* CHR OSTEOMYELIT-MULT */
"73020" = "1" /* OSTEOMYELITIS NOS-UNSPEC */
"73021" = "1" /* OSTEOMYELITIS NOS-SHLDER */
"73022" = "1" /* OSTEOMYELITIS NOS-UP/ARM */
"73023" = "1" /* OSTEOMYELIT NOS-FOREARM */
"73024" = "1" /* OSTEOMYELITIS NOS-HAND */
"73025" = "1" /* OSTEOMYELITIS NOS-PELVIS */
"73026" = "1" /* OSTEOMYELITIS NOS-L/LEG */
"73027" = "1" /* OSTEOMYELITIS NOS-ANKLE */
"73028" = "1" /* OSTEOMYELIT NOS-OTH SITE */
"73029" = "1" /* OSTEOMYELITIS NOS-MULT */
"73030" = "1" /* PERIOSTITIS-UNSPEC */
"73031" = "1" /* PERIOSTITIS-SHLDER */
"73032" = "1" /* PERIOSTITIS-UP/ARM */
"73033" = "1" /* PERIOSTITIS-FOREARM */
"73034" = "1" /* PERIOSTITIS-HAND */
"73035" = "1" /* PERIOSTITIS-PELVIS */
"73036" = "1" /* PERIOSTITIS-L/LEG */
"73037" = "1" /* PERIOSTITIS-ANKLE */
"73038" = "1" /* PERIOSTITIS NEC */
"73039" = "1" /* PERIOSTITIS-MULT */
"73080" = "1" /* BONE INFECT NEC-UNSPEC */
"73081" = "1" /* BONE INFECT NEC-SHLDER */
"73082" = "1" /* BONE INFECT NEC-UP/ARM */
"73083" = "1" /* BONE INFECT NEC-FOREARM */
"73084" = "1" /* BONE INFECT NEC-HAND */
"73085" = "1" /* BONE INFECT NEC-PELVIS */
"73086" = "1" /* BONE INFECT NEC-L/LEG */
"73087" = "1" /* BONE INFECT NEC-ANKLE */
"73088" = "1" /* BONE INFECT NEC-OTH SITE */
"73089" = "1" /* BONE INFECT NEC-MULT */
"73090" = "1" /* BONE INFEC NOS-UNSP SITE */
"73091" = "1" /* BONE INFECT NOS-SHLDER */
"73092" = "1" /* BONE INFECT NOS-UP/ARM */
"73093" = "1" /* BONE INFECT NOS-FOREARM */
"73094" = "1" /* BONE INFECT NOS-HAND */
"73095" = "1" /* BONE INFECT NOS-PELVIS */
"73096" = "1" /* BONE INFECT NOS-L/LEG */
"73097" = "1" /* BONE INFECT NOS-ANKLE */
"73098" = "1" /* BONE INFECT NOS-OTH SITE */
"73099" = "1" /* BONE INFECT NOS-MULT */
"7713" = "1" /* TETANUS NEONATORUM */
"7714" = "1" /* OMPHALITIS OF NEWBORN */
"7715" = "1" /* NEONATAL INFEC MASTITIS */
"77181" = "1" /* NB SEPTICEMIA SEPSIS */
"77182" = "1" /* NB URINARY TRACT INFECTN */
"77183" = "1" /* BACTEREMIA OF NEWBORN */
"77189" = "1" /* PERINATAL INFECTION NEC */
"7775" = "1" /* NECROT ENTEROCOLITIS NB */
"77750" = "1" /* NEC ENTEROCOLTIS NB NOS */
"77751" = "1" /* STG I NEC ENTEROCOL NB */
"77752" = "1" /* STG II NEC ENTEROCOL NB */
"77753" = "1" /* STG III NEC ENTEROCOL NB */
"7854" = "1" /* GANGRENE */
"78552" = "1" /* SEPTIC SHOCK */
"7907" = "1" /* BACTEREMIA */
"9101" = "1" /* ABRASION HEAD-INFECTED */
"9103" = "1" /* BLISTER HEAD-INFECTED */
"9105" = "1" /* INSECT BITE HEAD-INFECT */
"9107" = "1" /* FOREIGN BODY HEAD-INFECT */
"9109" = "1" /* SUPERF INJ HEAD NEC-INF */
"9111" = "1" /* ABRASION TRUNK-INFECTED */
"9113" = "1" /* BLISTER TRUNK-INFECTED */
"9115" = "1" /* INSECT BITE TRUNK-INFEC */
"9117" = "1" /* FOREIGN BODY TRUNK-INFEC */
"9119" = "1" /* SUPERF INJ TRNK NEC-INF */
"9121" = "1" /* ABRASION SHLDR/ARM-INFEC */
"9123" = "1" /* BLISTER SHOULDER/ARM-INF */
"9125" = "1" /* INSECT BITE SHLD/ARM-INF */
"9127" = "1" /* FB SHOULDER/ARM-INFECT */
"9129" = "1" /* SUPERF INJ SHLDR NEC-INF */
"9131" = "1" /* ABRASION FOREARM-INFECT */
"9133" = "1" /* BLISTER FOREARM-INFECTED */
"9135" = "1" /* INSECT BITE FOREARM-INF */
"9137" = "1" /* FOREIGN BODY FOREARM-INF */
"9139" = "1" /* SUPRF INJ FORARM NEC-INF */
"9141" = "1" /* ABRASION HAND-INFECTED */
"9143" = "1" /* BLISTER HAND-INFECTED */
"9145" = "1" /* INSECT BITE HAND-INFECT */
"9147" = "1" /* FOREIGN BODY HAND-INFECT */
"9149" = "1" /* SUPERF INJ HAND NEC-INF */
"9151" = "1" /* ABRASION FINGER-INFECTED */
"9153" = "1" /* BLISTER FINGER-INFECTED */
"9155" = "1" /* INSECT BITE FINGER-INFEC */
"9157" = "1" /* FOREIGN BODY FINGER-INF */
"9159" = "1" /* SUPRF INJ FINGER NEC-INF */
"9161" = "1" /* ABRASION HIP/LEG-INFECT */
"9163" = "1" /* BLISTER HIP & LEG-INFECT */
"9165" = "1" /* INSECT BITE HIP/LEG-INF */
"9167" = "1" /* FOREIGN BDY HIP/LEG-INF */
"9169" = "1" /* SUPERF INJ LEG NEC-INFEC */
"9171" = "1" /* ABRASION FOOT/TOE-INFEC */
"9173" = "1" /* BLISTER FOOT & TOE-INFEC */
"9175" = "1" /* INSECT BITE FOOT/TOE-INF */
"9177" = "1" /* FOREIGN BDY FOOT/TOE-INF */
"9179" = "1" /* SUPERF INJ FOOT NEC-INF */
"9191" = "1" /* ABRASION NEC-INFECTED */
"9193" = "1" /* BLISTER NEC-INFECTED */
"9195" = "1" /* INSECT BITE NEC-INFECTED */
"9197" = "1" /* SUPERFICIAL FB NEC-INFEC */
"9199" = "1" /* SUPERFIC INJ NEC-INFECT */
"99590" = "1" /* SIRS, NOS */
"99591" = "1" /* SIRS-INFECT W/O ORG DYSF */
"99592" = "1" /* SIRS-INFECT W ORGAN DYSF */
"99660" = "1" /* INFECT INFLAMM DEVICE IMPLANT GRAFT NOS */
"99661" = "1" /* INFECT INFLAMM CARDIAC DEVICE IMPLANT GRAFT */
"99662" = "1" /* INFECT INFLAMM VASCULAR DEVICE IMPLANT GRAFT  */
"99663" = "1" /* INFECT INFLAMM NERV DEVICE IMPLANT GRAFT  */
"99664" = "1" /* INFECT INFLAMM URINARY CATH */
"99665" = "1" /* INFECT INFLAMM GU DEVICE IMPLANT GRAFT  */
"99666" = "1" /* INFECT INFLAMM JOINT PROSTH */
"99667" = "1" /* INFECT INFLAMM OTH ORTHOP DEVICE IMPLANT GRAFT NOS */
"99669" = "1" /* INFECT INFLAMM OTH DEVICE IMPLANT GRAFT */
"99762" = "1" /* INFECTION AMPUTAT STUMP */
"99802" = "1" /* POSTOPERATIVE SHOCK, SEPTIC */
"99851" = "1" /* INFECTED POSTOP SEROMA */
"99859" = "1" /* OTHER POSTOP INFECTION */
"9993" = "1"  /* INFEC COMPL MED CARE NEC */
"99931" = "1" /* OTHER AND UNSPECIFIED INFECTION DUE TO CENTRAL VENOUS CATHETER */
"99932" = "1" /* BLOODSTREAM INFECTION DUE TO CENTRAL VENOUS CATHETER */
"99933" = "1" /* LOCAL INFECTION DUE TO CENTRAL VENOUS CATHETER */
"99934" = "1" /* ACUTE INFECTION FOLLOWING TRANSFUSION, INFUSION, OR INJECTION OF BLOOD AND BLOOD PRODUCTS */
OTHER   = "0" ;


 /* DRGS SURGICAL CLASS =1, TYPE OF DRGS = CLEAN */

VALUE DRG1C
0101 = '1'
0102 = '1'
0103 = '1'
0104 = '1'
0105 = '1'
0106 = '1'
0107 = '1'
0108 = '1'
0201 = '1'
0202 = '1'
0203 = '1'
0301 = '1'
0302 = '1'
0303 = '1'
0304 = '1'
0305 = '1'
0501 = '1'
0502 = '1'
0503 = '1'
0504 = '1'
0505 = '1'
0506 = '1'
0507 = '1'
0508 = '1'
0509 = '1'
0510 = '1'
0511 = '1'
0513 = '1'
0514 = '1'
0515 = '1'
0516 = '1'
0517 = '1'
0518 = '1'
0519 = '1'
0540 = '1'
0599 = '1'
0609 = '1'
0801 = '1'
0802 = '1'
0803 = '1'
0804 = '1'
0805 = '1'
0806 = '1'
0807 = '1'
0808 = '1'
0809 = '1'
0810 = '1'
0811 = '1'
0812 = '1'
0813 = '1'
0814 = '1'
0815 = '1'
0816 = '1'
0817 = '1'
0818 = '1'
0819 = '1'
0820 = '1'
0821 = '1'
0822 = '1'
0823 = '1'
0824 = '1'
0825 = '1'
0826 = '1'
0899 = '1'
0904 = '1'
0905 = '1'
1001 = '1'
1002 = '1'
1004 = '1'
1005 = '1'
1006 = '1'
1203 = '1'
1601 = '1'
1602 = '1'
7701 = '1'
7705 = '1'
OTHER = '0' ;

/* DRGS SURGICAL CLASS =2, TYPE OF DRGS = CLEAN CONTAMINATED */

VALUE DRG2C
0113 = '1'
0401 = '1'
0402 = '1'
0601 = '1'
0602 = '1'
0603 = '1'
0604 = '1'
0606 = '1'
0607 = '1'
0608 = '1'
0611 = '1'
0701 = '1'
0702 = '1'
0703 = '1'
0704 = '1'
0705 = '1'
0706 = '1'
0707 = '1'
0902 = '1'
0903 = '1'
1003 = '1'
1101 = '1'
1102 = '1'
1103 = '1'
1104 = '1'
1105 = '1'
1106 = '1'
1107 = '1'
1108 = '1'
1109 = '1'
1201 = '1'
1202 = '1'
1204 = '1'
1205 = '1'
1206 = '1'
1301 = '1'
1302 = '1'
1303 = '1'
1304 = '1'
1305 = '1'
1306 = '1'
1307 = '1'
1308 = '1'
1401 = '1'
1402 = '1'
1403 = '1'
1404 = '1'
1405 = '1'
7702 = '1'
7703 = '1'
7704 = '1'
7706 = '1'
7799 = '1'
8899 = '1'
OTHER = '0' ;

/* DRGS SURGICAL CLASS =3, TYPE OF DRGS = POTENTIALLY CONTAMINATED */

VALUE DRG3C
0901 = '1'
2101 = '1'
2102 = '1'
2103 = '1'
2104 = '1'
2201 = '1'
2210 = '1'
2406 = '1'
2407 = '1'
2408 = '1'
OTHER = '0' ;

/* DRGS CLASS =4, TYPE OF DRGS = LIKELY INFECTED                    */

VALUE DRG4C
0605 = '1'
1801 = '1'
1802 = '1'
1899 = '1'
OTHER = '0' ;

/* DRGS CLASS =9, TYPE OF DRGS = SURGICAL PROCEDURES NOT SPECIFIED  */

VALUE DRG9C
1707 = '1'
1708 = '1'
1709 = '1'
1710 = '1'
1799 = '1'
1909 = '1'
2301 = '1'
2501 = '1'
OTHER = '0' ;


 /* -------------------------------- */
 /* POST-OPERATIVE WOUND DEHISCENCE  */
 /*   PROVIDER INDICATOR / PDI # 11  */
 /*   AREA     INDICATOR / PDI # TBD */
 /* -------------------------------- */

 /* ABDOMINOPELVIC */;
 /* ICD-9-CM PROCEDURE CODES: */;

VALUE $ABDOMIP
"1731" = "1" /* LAP MUL SEG RES LG INTES */
"1732" = "1" /* LAPAROSCOPIC CECECTOMY */
"1733" = "1" /* LAP RIGHT HEMICOLECTOMY */
"1734" = "1" /* LAP RES TRANSVERSE COLON */
"1735" = "1" /* LAP LEFT HEMICOLECTOMY */
"1736" = "1" /* LAP SIGMOIDECTOMY */
"1739" = "1" /* LAP PT EX LRG INTEST NEC */
"3804" = "1" /* INCISION OF AORTA */
"3806" = "1" /* INCISION OF ABDOMINAL ARTERIES */
"3807" = "1" /* INCISION OF ABDOMINAL VEINS */
"3814" = "1" /* ENDARTERECTOMY OF AORTA */
"3816" = "1" /* ENDARTERECTOMY OF ABDOMINAL ARTERIES */
"3834" = "1" /* RESECTION OF AORTA WITH ANASTOMOSIS */
"3836" = "1" /* RESECTION OF ABDOMINAL ARTERIES WITH ANASTOMOSIS */
"3837" = "1" /* RESECTION OF ABDOMINAL VEINS WITH ANASTOMOSIS */
"3844" = "1" /* RESECTION OF AORTA, ABDOMINAL WITH REPLACEMENT */
"3846" = "1" /* RESECTION OF ABDOMINAL ARTERIES WITH REPLACEMENT */
"3847" = "1" /* RESECTION OF ABDOMINAL VEINS WITH REPLACEMENT */
"3857" = "1" /* LIGATION AND STRIPPING OF VARICOSE VEINS, ABDOMINCAL VEINS */
"3864" = "1" /* OTHER EXCISION OF AORTA, ABDOMINAL */
"3866" = "1" /* OTHER EXCISION OF ABDOMINAL ARTERIES */
"3867" = "1" /* OTHER EXCISION OF ABDOMINAL VEINS */
"3884" = "1" /* OTHER SURGICAL OCCLUSION OF AORTA, ABDOMINAL */
"3886" = "1" /* OTHER SURGICAL OCCLUSION OF ABDOMINAL ARTERIES */
"3887" = "1" /* OTHER SURGICAL OCCLUSION OF ABDOMINAL VEINS */
"391"  = "1" /* INTRA-ABDOMINAL VENOUS SHUNT */
"3924" = "1" /* AORTA-RENAL BYPASS */
"3925" = "1" /* AORTA-ILIAC-FEMORAL BYPASS */
"3926" = "1" /* OTHER INTRA-ABDOMINAL VASCULAR SHUNT OR BYPASS */
"4052" = "1" /* RADICAL EXCISION OF PERIAORTIC LYMPH NODES */
"4053" = "1" /* RADICAL EXCISION OF ILIAC LYMPH NODES */
"412"  = "1" /* SPLENOTOMY */
"4133" = "1" /* OPEN BIOPSY OF SPLEEN */
"4141" = "1" /* MARSUPIALIZATION OF SPLENIC CYST */
"4142" = "1" /* EXCISION OF LESION OR TISSUE OF SPLEEN */
"4143" = "1" /* PARTIAL SPLENECTOMY */
"415"  = "1" /* TOTAL SPLENECTOMY */
"4193" = "1" /* EXCISION OF ACCESSORY SPLEEN */
"4194" = "1" /* TRANSPLANTATION OF SPLEEN */
"4195" = "1" /* REPAIR AND PLASTIC OPERATIONS ON SPLEEN */
"4199" = "1" /* OTHER OPERATIONS ON SPLEEN */
"4240" = "1" /* ESOPHAGECTOMY, NOS */
"4241" = "1" /* PARTIAL EXOPHAGECTOMY */
"4242" = "1" /* TOTAL ESOPHAGECTOMY */
"4253" = "1" /* INTRATHORACIC ESOPHAGEAL ANASTOMOSIS WITH INTERPOSITION OF SMALL BOWEL */
"4254" = "1" /* OTHER INTRATHORACIC ESOPHAGOENTEROSTOMY */
"4255" = "1" /* INTRATHORACIC ESOPHAGEAL ANASTOMOSIS WITH INTERPOSITION OF COLON */
"4256" = "1" /* OTHER INTRATHORACIC ESOPHAGOCOLOSTOMY */
"4263" = "1" /* ANTESTERNAL ESOPHAGEAL ANASTOMOSIS WITH INTERPOSITION OF SMALL BOWEL */
"4264" = "1" /* OTHER ANTESTERNAL ESOPHAGOENTEROSTOMY */
"4265" = "1" /* ANTESTERNAL ESOPHAGEAL ANASTOMOSIS WITH INTERPOSITION OF COLON */
"4266" = "1" /* OTHER ANTESTERNAL ESOPHAGOCOLOSTOMY */
"4291" = "1" /* LIGATION OF ESOPHAGEAL VARICES */
"430"  = "1" /* GASTROSTOMY */
"433"  = "1" /* PYLOROMYOTOMY */
"4342" = "1" /* LOCAL EXCISION OF OTHER LESION OR TISSUE OF STOMACH */
"4349" = "1" /* OTHER DESTRUCTION OF LESION OR TISSUE OF STOMACH */
"435"  = "1" /* PARTIAL GASTRECTOMY WITH ANASTOMOSIS TO ESOPHAGUS */
"436"  = "1" /* PARTIAL GASTRECTOMY WITH ANASTOMOSIS TO DUODENUM */
"437"  = "1" /* PARTIAL GASTRECTOMY WITH ANASTOMOSIS TO JEJUNUM */
"4381" = "1" /* PARTIAL GASTRECTOMY WITH JEJUNA TRANSPOSITION */
"4382" = "1" /* LAPAROSCOPIC VERTICAL SLEEVE GASTRECTOMY */
"4389" = "1" /* OTHER PARTIAL GASTRECTOMY */
"4391" = "1" /* TOTAL GASTRECTOMY WITH INTESTINAL INTERPOSITION */
"4399" = "1" /* OTHER TOTAL GASTRECTOMY */
"4400" = "1" /* VAGOTOMY, NOS */
"4401" = "1" /* TRUNCAL VAGOTOMY */
"4402" = "1" /* HIGHLY SELECTIVE VAGOTOMY */
"4403" = "1" /* OTHER SELECTIVE VAGOTOMOY */
"4411" = "1" /* TRANSABDOMINAL GASTROSCOPY */
"4415" = "1" /* OPEN BIOPSY OF STOMACH */
"4421" = "1" /* DILATION OF PYLORUS BY INCISION */
"4429" = "1" /* OTHER PYLOROPLASTY */
"4431" = "1" /* HIGH GASTRIC BYPASS */
"4439" = "1" /* OTHER GASTROENTEROSTOMY */
"4440" = "1" /* SUTURE OF PEPTIC ULCER, NOS */
"4441" = "1" /* SUTURE OF GASTRIC ULCER SITE */
"4442" = "1" /* SUTURE OF DUODENAL ULCER SITE */
"445"  = "1" /* REVISION OF GASTRIC ANASTOMOSIS */
"4461" = "1" /* SUTURE OF LACERATION OF STOMACH */
"4463" = "1" /* CLOSURE OF OTHER GASTRIC FISTULA */
"4464" = "1" /* GASTROPEXY */
"4465" = "1" /* ESOPHAGOGASTROPLASTY */
"4466" = "1" /* OTHER PROCEDURES FOR CREATION OF ESOPHAGOGASTRIC SPHINCTERIC COMPETENCE */
"4469" = "1" /* OTHER REPAIR OF STOMACH */
"4491" = "1" /* LIGATION OF GASTRIC VARICES */
"4492" = "1" /* INTRAOPERATIVE MANIPULATION OF STOMACH */
"4499" = "1" /* GASTRIC OPERATION NEC */
"4500" = "1" /* INCISION OF INTESTINE, NOS */
"4501" = "1" /* INCISION OF DUODENUM */
"4502" = "1" /* OTHER INCISION OF SMALL INTESTINE */
"4503" = "1" /* INCISION OF LARGE INTESTINE */
"4531" = "1" /* OTHER LOCAL EXCISION OF LESION OF DUODENUM */
"4532" = "1" /* OTHER DESTRUCTION OF LESION OF DUODENUM */
"4533" = "1" /* LOCAL EXCISION OF LESION OR TISSUE OF SMALL INTESTINE, EXCEPT DUODENUM */
"4534" = "1" /* OTHER DESTRUCTION OF LESION OF SMALL INTESTINE, EXCEPT DUODENUM */
"4541" = "1" /* EXCISION OF LESION OR TISSUE OF LARGE INTESTINE */
"4549" = "1" /* OTHER DESTRUCTION OF LESION OF LARGE INTESTINE */
"4550" = "1" /* ISOLATION OF INTESTINAL SEGMENT, NOS */
"4551" = "1" /* ISOLATION OF SEGMENT OF SMALL INTESTINE */
"4552" = "1" /* ISOLATION OF SEGMENT OF LARGE INTESTINE */
"4561" = "1" /* MULTIPLE SEGMENTAL RESECTION OF SMALL INTESTINE */
"4562" = "1" /* OTHER PARTIAL RESECTION OF SMALL INTESTINE */
"4563" = "1" /* TOTAL REMOVAL OF SMALL INTESTINE */
"4571" = "1" /* MULTIPLE SEGMENTAL RESECTION OF LARGE INTESTINE */
"4572" = "1" /* CESECTOMY */
"4573" = "1" /* RIGHT HEMICOLECTOMY */
"4574" = "1" /* RESECTION OF TRANSVERSE COLON */
"4575" = "1" /* LEFT HEMICOLECTOMY */
"4576" = "1" /* SIGMOIDECTOMY */
"4579" = "1" /* OTHER PARTIAL EXCISION OF LARGE INTESTINE */
"458"  = "1" /* TOTAL INTRA-ABDOMINAL COLECTOMY */
"4581" = "1" /* LAP TOT INTR-AB COLECTMY */
"4582" = "1" /* OP TOT INTR-ABD COLECTMY */
"4583" = "1" /* TOT ABD COLECTMY NEC/NOS */
"4590" = "1" /* INTESTINAL ANASTOMOSIS, NOS */
"4591" = "1" /* SMALL-TO-SMALL INTESTINAL ANASTOMOSIS */
"4592" = "1" /* ANASTOMOSIS OF SMALL INTESTINE TO RECTAL STUMP */
"4593" = "1" /* OTHER SMALL-TO-LARGE INTESTINAL ANASTOMOSIS */
"4594" = "1" /* LARGE-TO-LARGE INTESTINAL ANASTOMOSIS */
"4595" = "1" /* ANASTOMOSIS TO ANUS */
"4601" = "1" /* EXTERIORIZATION OF SMALL INTESTINE */
"4603" = "1" /* EXTERIORIZATION OF LARGE INTESTINE */
"4610" = "1" /* COLOSTOMY, NOS */
"4611" = "1" /* TEMPORARY COLOSTOMY */
"4613" = "1" /* PERMANENT COLOSTOMY */
"4620" = "1" /* ILEOSTOMY, NOS */
"4621" = "1" /* TEMPORARY ILESOSTOMY */
"4622" = "1" /* CONTINENT ILEOSTOMY */
"4623" = "1" /* OTHER PERMANENT ILEOSTOMY */
"4640" = "1" /* REVISION OF INTESTINA STOMA, NOS */
"4641" = "1" /* REVISION OF STOMA OF SMALL INTESTINE */
"4642" = "1" /* REPAIR OF PERICOLOSTOMY HERNIA */
"4643" = "1" /* OTHER REVISION OF STOMA OF LARGE INTESTINE */
"4650" = "1" /* CLOSURE OF INTESTINAL STOMA, NOS */
"4651" = "1" /* CLOSURE OF STOMA OF SMALL INTESTINE */
"4652" = "1" /* CLOSURE OF STOMA OF LARGE INTESTINE */
"4660" = "1" /* FIXATION OF INTESTINE, NOS */
"4661" = "1" /* FIXATION OF SMALL INTESTINE TO ABDOMINAL WALL */
"4662" = "1" /* OTHER FIXATION OF SMALL INTESTINE */
"4663" = "1" /* FIXATION OF LARGE INTESTINE TO ABDOMINAL WALL */
"4664" = "1" /* OTHER FIXATION OF LARGE INTESTINE */
"4672" = "1" /* CLOSURE OF FISTULA OF DUODENUM */
"4674" = "1" /* CLOSURE OF FISTULA OF SMALL INTESTINE, EXCEPT DUODENUM */
"4676" = "1" /* CLOSURE OF FISTULA OF LARGE INTESTINE */
"4680" = "1" /* INTRA-ABDOMINAL MANIPULATION OF INTESTINE, NOS */
"4681" = "1" /* INTRA-ABDOMINAL MANIPULATION OF SMALL INTESTINE */
"4682" = "1" /* INTRA-ABDOMINAL MANIPULATION OF LARGE INTESTINE */
"4691" = "1" /* MYOTOMY OF SIGMOID COLON */
"4692" = "1" /* MYOTOMY OF OTHER PARTS OF COLON */
"4693" = "1" /* REVISION OF ANASTOMOSIS OF SMALL INTESTINE */
"4694" = "1" /* REVISION OF ANASTOMOSIS OF LARGE INTESTINE */
"4699" = "1" /* OTHER OPERATIONS ON INTESTINES */
"4709" = "1" /* OTHER APPENDECTOMY */
"4719" = "1" /* OTHER INCIDENTAL APPENDECTOMY */
"472"  = "1" /* DRAINAGE OF APPENDICEAL ABSCESS */
"4791" = "1" /* APPENDECTOMY */
"4792" = "1" /* CLOSURE OF APPENDICEAL FISTULA */
"4799" = "1" /* OTHER */
"4840" = "1" /* PULL-THRU RES RECTUM NOS */
"4841" = "1" /* SUBMUCOSAL RESECTION OF RECTUM */
"4843" = "1" /* OPN PULL-THRU RES RECTUM */
"4849" = "1" /* OTHER PULL-THROUGH RESECTION OF RECTUM */
"485"  = "1" /* ABDOMINOPERINEAL RESECTION OF RECTUM */
"4850" = "1" /* ABDPERNEAL RES RECTM NOS */
"4852" = "1" /* OPN ABDPERNEAL RESC REC */
"4859" = "1" /* ABDPERNEAL RESC RECT NEC */
"4875" = "1" /* ABDOMINAL PROCTOPEXY */
"500"  = "1" /* HEPATOTOMY */
"5012" = "1" /* OPEN BIOPSY OF LIVER */
"5021" = "1" /* MARSUPIALIZATION OF LESION OF LIVER */
"5022" = "1" /* PARTIAL HEPATECTOMY */
"5023" = "1" /* OPN ABLTN LIVER LES/TISS */ 
"5026" = "1" /* ABLTN LIVER LES/TISS NEC */ 
"5029" = "1" /* OTHER DESTRUCTION OF LESION OF LIVER */
"503"  = "1" /* LOBECTOMY OF LIVER */
"504"  = "1" /* TOTAL HEPATECTOMY */
"5051" = "1" /* AUXILIARY LIVER TRANSPLANT */
"5059" = "1" /* OTHER TRANSPLANT OF LIVER */
"5069" = "1" /* OTHER REPAIR OF LIVER */
"5103" = "1" /* OTHER CHOLECYSTOTSTOMY */
"5104" = "1" /* OTHER CHOLECYSTOTOMY */
"5113" = "1" /* OPEN BIOPSY OF GALLBLADDER OR BILE DUCTS */
"5121" = "1" /* OTHER PARTIAL CHOLECYSTECTOMY */
"5122" = "1" /* CHOLECYSTECTOMY */
"5131" = "1" /* ANASTOMOSIS OF GALLBLADDER TO HEPATIC DUCTS */
"5132" = "1" /* ANASTOMOSIS OF GALLBLADDER TO INTESTINE */
"5133" = "1" /* ANASTOMOSIS OF GALLBLADDER TO PANCREAS */
"5134" = "1" /* ANASTOMOSIS OF GALLBLADDER TO STOMACH */
"5135" = "1" /* OTHER GALLBLADDER ANASTOMOSIS */
"5136" = "1" /* CHOLEDOCHOENTEROSTOMY */
"5137" = "1" /* ANASTOMOSIS OF HEPATIC DUCT TO GASTROINTESTINAL TRACT */
"5139" = "1" /* OTHER BILE DUCT ANASTOMOSIS */
"5141" = "1" /* COMMON DUCT EXPLORATION FOR REMOVAL OF CALCULUS */
"5142" = "1" /* COMMON DUCT EXPLORATION FOR RELIEF OF OTHER OBSTRUCTION */
"5143" = "1" /* INSERTION OF CHOLEDOCHOHEPATIC TUBE FOR DECOMPRESSION */
"5149" = "1" /* INCISION OF OTHER BILE DUCTS FOR RELIEF OF OBSTRUCTION */
"5151" = "1" /* EXPLORATION OF COMMON DUCT */
"5159" = "1" /* INCISION OF OTHER BILE DUCT */
"5161" = "1" /* EXCISION OF CYSTIC DUCT REMNANT */
"5162" = "1" /* EXCISION OF AMPULLA OF VATER WITH REIMPLANTATION OF COMMON DUCT */
"5163" = "1" /* OTHER EXCISION OF COMMON DUCT */
"5169" = "1" /* EXCISION OF OTHER BILE DUCT */
"5171" = "1" /* SIMPLE SUTURE OF COMMON BILE DUCT */
"5172" = "1" /* CHOLEDOCHOPLASTY */
"5179" = "1" /* REPAIR OF OTHER BILE DUCTS */
"5181" = "1" /* DILATION OF SPHINCTER OF ODDI */
"5182" = "1" /* PANCREATIC SPHINCTEROTOMY */
"5183" = "1" /* PANCREATIC SPHINCTEROPLSTY */
"5189" = "1" /* OTHER OPERATIONS ON SPHINCTER OF ODDI */
"5192" = "1" /* CLOSURE OF CHOLECYSTOSTOMY */
"5193" = "1" /* CLOSURE OF OTHER BILIARY FISTULA */
"5194" = "1" /* REVISION OF ANASTOMOSIS OF BILIARY TRACT */
"5195" = "1" /* REMOVAL OF PROSTHETIC DEVICE FROM BILE DUCT */
"5199" = "1" /* OTHER OPERATIONS ON BILIARY TRACT */
"5201" = "1" /* DRAINAGE OF PANCREATIC CYST BY CATHETER */
"5209" = "1" /* OTHER PANCREATOTOMY */
"5212" = "1" /* OPEN BIOPSY OF PANCREAS */
"5222" = "1" /* OTHER EXCISION OR DESTRUCTION OF LESION OR TISSUE OF PANCREAS OR PANCREATIC DUCT */
"523"  = "1" /* GINGIVAL AND PERIODONTAL DISEASES */
"524"  = "1" /* INTERNAL DRAINAGE OF PANCREATIC CYST */
"5251" = "1" /* PROXIMAL PANCREATECTOMY */
"5252" = "1" /* DISTAL PANCREATECTOMY */
"5253" = "1" /* RADIAL SUBTOTAL PANCREATECTOMY */
"5259" = "1" /* OTHER PARTIAL PANCREATECTOMY */
"526"  = "1" /* TOTAL PANCREATECTOMY */
"527"  = "1" /* RADICAL PANCREATICODUODENCECTOMY */
"5280" = "1" /* PANCREATIC TRANSPLANT, NOS */
"5281" = "1" /* REIMPLANTATION */
"5282" = "1" /* HOMOTRANSPLANT OF PANCREAS */
"5283" = "1" /* HETEROTRANSPLANT OF PANCREAS */
"5292" = "1" /* CANNULATION OF PANCREATIC DUCT */
"5295" = "1" /* OTHER REPAIR OF PANCREAS */
"5296" = "1" /* ANASTOMOSIS OF PANCREAS */
"5299" = "1" /* OTHER OPERATIONS ON PANCREAS */
"5300" = "1" /* UNILATERAL REPAIR OF INGUINAL HERNIA, NOS */
"5301" = "1" /* REPAIR OF DIRECT INGUINAL HERNIA */
"5302" = "1" /* REPAIR OF INDIRECT INGUINAL HERNIA */
"5303" = "1" /* REPAIR OF DIRECT INGUINAL HERNIA WITH GRAFT OR PROSTHESIS */
"5304" = "1" /* REPAIR OF INDIRECT INGUINAL HERNIA WITH GRAFT OR PROSTHESIS */
"5305" = "1" /* REAPIR OF INGUINAL HERNIA WITH GRAFT OR PROSTHESIS, NOS */
"5310" = "1" /* BILATERAL REPAIR OF INGUINAL HERNIA, NOS */
"5311" = "1" /* BILATERAL REPAIR OF DIRECT INGUINAL YERNIA */
"5312" = "1" /* BILATERAL REPAIR OF INDIRECT INGUINAL HERNIA */
"5313" = "1" /* BILATERAL REPAIR OF INGUINAL HERNIA, ONE DIRECT AND ONE INDIRECT */
"5314" = "1" /* BILATERAL REPAIR OF DIRECT INGUINAL HERNIA WITH GRAFT OR PROSTHESIS */
"5315" = "1" /* BILATERAL REPAIR OF INDIRECT INGUINAL HERNIA WITH GRAFT OR PROSTHESIS */
"5316" = "1" /* BILATERAL REPAIR OF INGUINAL HERNIA, ONE DIRECT AND ONE INDIRECT, WITH GRAFT OR PROSTHESIS */
"5317" = "1" /* BILATERAL INGUINAL HERNIA REPAIR WITH GRAFT OR PROSTHESIS, NOS */
"5321" = "1" /* UNILATERAL REPAIR OF FEMORAL HERNIA */
"5329" = "1" /* OTHER UNILATERAL FEMORAL HERNIORHAPHY */
"5331" = "1" /* BILATERAL REPAIR OF FEMORAL HERNIA WITH GRAFT OR PROSTHESIS */
"5339" = "1" /* OTHER BILATERAL FEMORAL HERNIORRHAPHY */
"5341" = "1" /* REPAIR OF UMBILICAL HERNIA WITH PROSTHESIS */
"5349" = "1" /* OTHER UMBILICAL HERNIORRHAPHY */
"5351" = "1" /* INCISIONAL HERNIA REPAIR */
"5359" = "1" /* REPAIR OF OTHER HERNIA OF ANTERIOR ABDOMINAL WALL */
"5361" = "1" /* INCISIONAL HERNIA REPAIR WITH PROSTHESIS */
"5369" = "1" /* REPAIR OF OTHER HERNIA OF ANTERIOR ABDOMINAL WALL WITH PROSTHESIS */
"537"  = "1" /* REPAIR OF DIAPHRAGMATIC HERNIA, ABDOMINAL APPROACH */
"5375" = "1" /* ABD REP-DIAPHR HERN NOS */
"540"  = "1" /* INCISION OF ABDOMINAL WALL */
"5411" = "1" /* EXPLORATORY LAPAROTOMY */
"5419" = "1" /* OTHER LAPAROTOMY */
"5422" = "1" /* BIOPSY OF ABDOMINAL WALL OR UMBILICUS */
"5423" = "1" /* BIOPSY OF ABDOMINAL WALL OR UMBILICUS */
"543"  = "1" /* EXCISION OR DESTRUCTION OF LESION OR TISSUE OF ABDOMINAL WALL OR UMBILICUS */
"544"  = "1" /* EXCISION OR DESTRUCTION OF PERITONEAL TISSUE */
"5459" = "1" /* OTHER LYSIS OF PERITONEAL ADHESIONS */
"5463" = "1" /* OTHER SUTURE OF ABDOMINAL WALL */
"5464" = "1" /* SUTURE OF PERITONEUM */
"5471" = "1" /* REPAIR OF GASTROSCHISIS */
"5472" = "1" /* OTHER REPAIRE OF ABDOMINAL WALLS */
"5473" = "1" /* OTHER REPAIR OF PERITONEUM */
"5474" = "1" /* OTHER REPAIR OF OMENTUM */
"5475" = "1" /* OTHER REPAIR OF MESENTERY */
"5492" = "1" /* REMOVAL OF FOREIGN BODY FROM PERITONEAL CAVITY */
"5493" = "1" /* CREATION OF CUTANEOPERITONEAL FISTULA */
"5494" = "1" /* CREATION OF PERITONEOVASCULAR SHUNT */
"5495" = "1" /* INCISION OF PERITONEUM */
"5532" = "1" /* OPN ABLTN RENAL LES/TISS */ 
"5535" = "1" /* ABLTN RENAL LES/TISS NEC */ 
"5551" = "1" /* NEPHROURETERECTOMY */
"5552" = "1" /* NEPHRECTOMY OF REMAINING KIDNEY */
"5553" = "1" /* REMOVAL OF TRANSPLANTED OR REGECTED KDINEY */
"5554" = "1" /* BILATERAL NEPHRECTOMY */
"5561" = "1" /* RENAL AUTOTRANSPLANTATION */
"5569" = "1" /* ULCERATIVE COLITIS, UNSPECIFIED */
"557"  = "1" /* NEPHROPEXY */
"5583" = "1" /* CLOSURE OF OTHER FISTULA OF KIDNEY */
"5584" = "1" /* REDUCTION OF TORSION OF RENAL */
"5585" = "1" /* SYMPHYSIOTOMY FOR HORESHOE KIDNEY */
"5586" = "1" /* ANASTOMOSIS OF KIDNEY */
"5587" = "1" /* CORRECTION OF URETEROPELVIC JUNCTION */
"5591" = "1" /* DECAPSULATION OF KEDNEY */
"5597" = "1" /* IMPLANTATION OR REPLACEMENT OF MECHANICAL KIDNEY */
"5598" = "1" /* REMOVAL OF MECHANICAL KIDNEY */
"5651" = "1" /* FORMATION OF CUTANEOUS URETEROILEOSTOMY */
"5652" = "1" /* REVISION OF CUTANEOUS URETER OILEOSTOMY */
"5661" = "1" /* FORMATION OF OTHER CUTANEOUS URETEROSTOMY */
"5662" = "1" /* REVISION OF OTHER CUTANEOUS URETEROSTOMY */
"5671" = "1" /* URINARY DIVERSION TO INTESTINE */
"5672" = "1" /* REVISION OF URETEROINTESTINAL ANASTOMOSIS */
"5673" = "1" /* NEPHROCYSTANASTOMOSIS, NO */
"5674" = "1" /* URETERONEOXYSTOSTOMY */
"5675" = "1" /* TRANSURETEROURETEROSTOMY */
"5683" = "1" /* CLOSURE OF URETEROSTOMY */
"5684" = "1" /* CLOSURE OF OTHER FISTULA OF URETER */
"5685" = "1" /* URETEROPEXY */
"5686" = "1" /* REMOVAL OF LIGATURE FORM URETER */
"5689" = "1" /* OTHER REPAIR OF URETER */
"5695" = "1" /* LIGATION OF URETER */
"5771" = "1" /* RADICAL CYSTECTOMY */
"5779" = "1" /* OTHER TOTAL CYSTECTOMY */
"5782" = "1" /* CLOSRUE OF CYSTOSTOMY */
"5787" = "1" /* RECONSTRUCTION OF URNIARY BLADDER */
"5900" = "1" /* RETROPERITONEAL DISSECTION, NOS */
"5902" = "1" /* OTHER LYSIS OF PERIRENAL OR PERIURETERAL ADHESIONS */
"5909" = "1" /* OTHER INCISION OF PERIRENAL OR PERIURETERAL TISSUE */
"6012" = "1" /* OPEN BIOPSY OF PROSTATE */
"6014" = "1" /* OPEN BIOPSY OF SEMINAL VESICLES */
"6015" = "1" /* BIOPSY OF PERIPROSTATIC TISSUE */
"603"  = "1" /* SUPRAPUBIC PROSTATECTOMY */
"604"  = "1" /* RETROPUBIC PROSTATECTOMY */
"605"  = "1" /* RADICAL PROSTATECTOMY */
"6061" = "1" /* LOCAL EXCISION OF LESION OF PROSTATE */
"6072" = "1" /* INCISION OF SEMINAL VESICLE */
"6073" = "1" /* EXCISION OF SEMINAL VESICLE */
"6079" = "1" /* OTHER OPERATIONS ON SEMINAL VESICLES */
"6093" = "1" /* REPAIR OF PROSTATE */
"6509" = "1" /* OTHER OOPHORECTOMY */
"6512" = "1" /* OTHER BIOPSY OF OVARY */
"6521" = "1" /* MARSUPIALIZATION OF OVARIAN CYST */
"6522" = "1" /* WEDGE RESECTION OF OVARY*/
"6529" = "1" /* OTHER LOCAL EXCISION OR DESTRUCTION OF OVARY */
"6539" = "1" /* OTHER UNLILATERAL OOPHORECTOMY */
"6549" = "1" /* OTHER UNLIATERAL SALPINGOOPHORECTOMY */
"6551" = "1" /* OTHER REMOVAL OF BOTH OVARIES AT SAME OPERATIVE EPISODE */
"6552" = "1" /* OTHER REMOVAL OF REMAINING OVARY */
"6561" = "1" /* OTHER REMOVAL OF BOTH OVARIES AND TUBES AT SAME OPERATIVE EPISODE */
"6562" = "1" /* OTHER REMOVAL OF REMAINING OVARY AND TUBE */
"6571" = "1" /* OTHER SIMPLE SUTURE OF OVARY */
"6572" = "1" /* OTHER REIMPLANTATION OF OVARY */
"6573" = "1" /* OTHER SALPINGO OOPHOROPLASTY */
"6579" = "1" /* OTHER REPAIR OF OVARY */
"6589" = "1" /* OTHER LYSIS OF ADHESIONS OF AVARY AND FALLOPIAN TUBE */
"6592" = "1" /* TRANSPLANTATION OF OVARY */
"6593" = "1" /* MANUAL RUPTURE OF OVARIAN CYST */
"6594" = "1" /* OVARIAN DENERVATION */
"6595" = "1" /* RELEASE OF TORSION OF OVARY */
"6599" = "1" /* OTHER OPERATIONS ON OVARY */
"6601" = "1" /* SALPINGOTOMY */
"6602" = "1" /* SALPINGOSTOMY */
"6631" = "1" /* OTHER BILATERAL LIGATION AND CRUSHING OF FALLOPIAN TUBES */
"6632" = "1" /* OTHER BILATERAL LIGATION AND DIVISION OF FALLOPIAN TUBES */
"6639" = "1" /* OTHER BILATERAL DESTRUCTION OR OCCLUSION OF FALLOPIAN TUBES */
"664"  = "1" /* TOTAL UNILATERAL SALPINGECTOMY */
"6651" = "1" /* REMOVAL OF BOTH FALLOPIAN TUBES AT SAME OPERATIVE EPISODE */
"6652" = "1" /* REMOVAL OF REMAINING FALLOPIAN TUBE */
"6661" = "1" /* EXCISION OR DESTRUCTION OF LESION OF FALLOPIAN TUBE */
"6662" = "1" /* SALPINGECTOMY WITH REMOVAL OF TUBAL PREGNANCY */
"6663" = "1" /* BILATERAL PARTIAL SALPINGECTOMY, NOS */
"6669" = "1" /* OTHER PARTIAL SALPINGECTOMY */
"6671" = "1" /* SIMPLE SUTURE OF FALLOPIAN TUBE */
"6672" = "1" /* SALPINGO-OOPHOROSTOMY*/
"6673" = "1" /* SALPINGO-SALPINGOSTOMY */
"6674" = "1" /* SALPING0-UTEROSTOMY */
"6679" = "1" /* OTHER REPAIR OF FALLOPIAN TUBE */
"6692" = "1" /* UNILATERAL DESTRUCTION OR OCCLUSION OF FALLOPIAN TUBE */
"6697" = "1" /* BURYING OF FIMBRIAE IN UTERINE WALL */
"680"  = "1" /* OTHER INCISION AND EXCISION OF UTERUS */
"6813" = "1" /* OPEN BIOPSY OF UTERUS */
"6814" = "1" /* OPEN BIOPSY OF UTERINE LIGAMENTS */
"683"  = "1" /* SUBTOTAL ABDOMINAL HYSTERECTOMY */
"6839" = "1" /* OTH SUBTOT ABD HYSTERECT */
"684"  = "1" /* TOTAL ABDOMINAL HYSTERECTOMY */
"6841" = "1" /* LAP TOTAL ABDOMINAL HYST */ 
"6849" = "1" /* TOTAL ABD HYST NEC/NOS */   
"686"  = "1" /* RADICAL ABDOMINAL HYSTERECTOMY */
"6861" = "1" /* LAP RADICAL ABDOMNL HYST */ 
"6869" = "1" /* RADICAL ABD HYST NEC/NOS */ 
"688"  = "1" /* PELVIC EVISCERATION */
"6922" = "1" /* OTHER UTERINE SUSPENSION */
"693"  = "1" /* PARACERVICAL UTERINE DENERVATION */
"6941" = "1" /* SUTURE OF LACERATION OF UTERUS */
"6942" = "1" /* CLOSURE OF FISTULA OF UTERUS */
"6949" = "1" /* OTHER REPAIR OF UTERUS */
OTHER  = "0" ;

VALUE $ABDOM2P
OTHER  = "0" ;

 /* RECLOSURE OF POSTOPERATIVE DISRUPTION OF ABDOMINAL WALL */;
 /* ICD-9-CM PROCEDURE CODE: */

VALUE $RECLOIP
"5461"  = "1"  /* RECLOSURE OF POSTOPERATIVE DISRUPTION OF ABDOMINAL WALL */
OTHER   = "0" ;

 /* REPAIR OF GASTROSCHISIS OR UMBILICAL HERNIA */;
 /* ICD-9-CM PROCEDURE CODE: */

VALUE $REPGAST
"5341"  = "1" /* REPAIR OF UMBILICAL HERNIA WITH PROSTHESIS */
"5349"  = "1" /* OTHER UMBILICAL HERNIORRHAPHY */
"5471"  = "1"  /* REPAIR OF GASTROSCHISIS */
OTHER   = "0" ;

/* EXCLUDE: */
/* HIGH RISK GROUP */
/* ICD-9-CM DIAGNOSIS CODES: */

VALUE $IMMUNHD
'042'   =  '1' /* HUMAN IMMUNODEFICIENCY VIRUS (HIV) DISEASE */
'1363'  =  '1' /* PNEUMOCYSTOSIS*/
'1992'  = '1' /* MALIG NEOPL-TRANSP ORGAN */
'20000' =  '1' /* RETCLSRC UNSP XTRNDL ORG */
'20001' =  '1' /* RETICULOSARCOMA HEAD */
'20002' =  '1' /* RETICULOSARCOMA THORAX */
'20003' =  '1' /* RETICULOSARCOMA ABDOM */
'20004' =  '1' /* RETICULOSARCOMA AXILLA */
'20005' =  '1' /* RETICULOSARCOMA INGUIN */
'20006' =  '1' /* RETICULOSARCOMA PELVIC */
'20007' =  '1' /* RETICULOSARCOMA SPLEEN */
'20008' =  '1' /* RETICULOSARCOMA MULT */
'20010' =  '1' /* LYMPHSRC UNSP XTRNDL ORG */
'20011' =  '1' /* LYMPHOSARCOMA HEAD */
'20012' =  '1' /* LYMPHOSARCOMA THORAX */
'20013' =  '1' /* LYMPHOSARCOMA ABDOM */
'20014' =  '1' /* LYMPHOSARCOMA AXILLA */
'20015' =  '1' /* LYMPHOSARCOMA INGUIN */
'20016' =  '1' /* LYMPHOSARCOMA PELVIC */
'20017' =  '1' /* LYMPHOSARCOMA SPLEEN */
'20018' =  '1' /* LYMPHOSARCOMA MULT */
'20020' =  '1' /* BRKT TMR UNSP XTRNDL ORG */
'20021' =  '1' /* BURKITTS TUMOR HEAD */
'20022' =  '1' /* BURKITTS TUMOR THORAX */
'20023' =  '1' /* BURKITTS TUMOR ABDOM */
'20024' =  '1' /* BURKITTS TUMOR AXILLA */
'20025' =  '1' /* BURKITTS TUMOR INGUIN */
'20026' =  '1' /* BURKITTS TUMOR PELVIC */
'20027' =  '1' /* BURKITTS TUMOR SPLEEN */
'20028' =  '1' /* BURKITTS TUMOR MULT */
'20080' =  '1' /* OTH VARN UNSP XTRNDL ORG */
'20081' =  '1' /* MIXED LYMPHOSARC HEAD */
'20082' =  '1' /* MIXED LYMPHOSARC THORAX */
'20083' =  '1' /* MIXED LYMPHOSARC ABDOM */
'20084' =  '1' /* MIXED LYMPHOSARC AXILLA */
'20085' =  '1' /* MIXED LYMPHOSARC INGUIN */
'20086' =  '1' /* MIXED LYMPHOSARC PELVIC */
'20087' =  '1' /* MIXED LYMPHOSARC SPLEEN */
'20088' =  '1' /* MIXED LYMPHOSARC MULT */
'20302' = '1' /* MULT MYELOMA IN RELAPSE */
'20312' = '1' /* PLSM CEL LEUK IN RELAPSE */
'20382' = '1' /* OTH IMNPRLF NEO-RELAPSE */
'20402' = '1' /* ACT LYMP LEUK IN RELAPSE */
'20412' = '1' /* CHR LYMP LEUK IN RELAPSE */
'20422' = '1' /* SBAC LYM LEUK IN RELAPSE */
'20482' = '1' /* OTH LYM LEUK IN RELAPSE */
'20492' = '1' /* LYMP LEUK NOS RELAPSE */
'2050'  =  '1' /* ACUTE MYELOID LEUKEMIA */
'20500' =  '1' /* ACT MYL LEUK W/O RMSION */
'20501' =  '1' /* ACT MYL LEUK W RMSION */
'20502' = '1' /* ACT MYEL LEUK IN RELAPSE */
'2051'  =  '1' /* CHRONIC MYELOID LEUKEMIA */
'20510' =  '1' /* CHR MYL LEUK W/O RMSION */
'20511' =  '1' /* CHR MYL LEUK W RMSION */
'20512' = '1' /* CHR MYEL LEUK IN RELAPSE */
'2052'  =  '1' /* SUBACUT MYELOID LEUKEMIA */
'20520' =  '1' /* SBAC MYL LEUK W/O RMSION */
'20521' =  '1' /* SBAC MYL LEUK W RMSION */
'20522' = '1' /* SBAC MYL LEUK IN RELAPSE */
'2053'  =  '1' /* MYELOID SARCOMA */
'20530' =  '1' /* MYL SRCOMA W/O RMSION */
'20531' =  '1' /* MYL SRCOMA W RMSION */
'20532' = '1' /* MYEL SARCOMA IN RELAPSE */
'2058'  =  '1' /* MYELOID LEUKEMIA NEC */
'20580' =  '1' /* OTH MYL LEUK W/O RMSION */
'20581' =  '1' /* OTH MYL LEUK W RMSION */
'20582' = '1' /* OTH MYEL LEUK IN RELAPSE */
'2059'  =  '1' /* MYELOID LEUKEMIA NOS */
'20590' =  '1' /* UNS MYL LEUK W/O RMSION */
'20591' =  '1' /* UNS MYL LEUK W RMSION */
'20592' = '1' /* MYEL LEUK NOS IN RELAPSE */
'2060'  =  '1' /* ACUTE MONOCYTIC LEUKEMIA */
'20600' =  '1' /* ACT MONO LEUK W/O RMSION */
'20601' =  '1' /* ACT MONO LEUK W RMSION */
'20602' = '1' /* ACT MONO LEUK IN RELAPSE */
'2061'  =  '1' /* CHR MONOCYTIC LEUKEMIA */
'20610' =  '1' /* CHR MONO LEUK W/O RMSION */
'20611' =  '1' /* CHR MONO LEUK W RMSION */
'20612' = '1' /* CHR MONO LEUK IN RELAPSE */
'2062'  =  '1' /* SUBAC MONOCYTIC LEUKEMIA */
'20620' =  '1' /* SBAC MONO LEUK W/O RMSON */
'20621' =  '1' /* SBAC MONO LEUK W RMSION */
'20622' = '1' /* SBAC MONO LEU IN RELAPSE */
'2068'  =  '1' /* MONOCYTIC LEUKEMIA NEC */
'20680' =  '1' /* OTH MONO LEUK W/O RMSION */
'20681' =  '1' /* OTH MONO LEUK W RMSION */
'20682' = '1' /* OTH MONO LEUK IN RELAPSE */
'2069'  =  '1' /* MONOCYTIC LEUKEMIA NOS */
'20690' =  '1' /* UNS MONO LEUK W/O RMSION */
'20691' =  '1' /* UNS MONO LEUK W RMSION */
'20692' = '1' /* MONO LEUK NOS RELAPSE */
'2070'  =  '1' /* ACUTE ERYTHREMIA */
'20700' =  '1' /* ACT ERTH/ERYLK W/O RMSON */
'20701' =  '1' /* ACT ERTH/ERYLK W RMSON */
'20702' = '1' /* AC ERTH/ERYLK IN RELAPSE */
'2071'  =  '1' /* CHRONIC ERYTHREMIA */
'20710' =  '1' /* CHR ERYTHRM W/O REMISION */
'20711' =  '1' /* CHR ERYTHRM W REMISION */
'20712' = '1' /* CHR ERYTHRMIA IN RELAPSE */
'2072'  =  '1' /* MEGAKARYOCYTIC LEUKEMIA */
'20720' =  '1' /* MGKRYCYT LEUK W/O RMSION */
'20721' =  '1' /* MGKRYCYT LEUK W RMSION */
'20722' = '1' /* MGKRYCYT LEUK IN RELAPSE */
'2078'  =  '1' /* SPECIFIED LEUKEMIA NEC */
'20780' =  '1' /* OTH SPF LEUK W/O REMSION */
'20781' =  '1' /* OTH SPF LEUK W REMSION */
'20782' = '1' /* OTH SPF LEUK IN RELAPSE */
'2080'  =  '1' /* ACT LEUK UNS CL W/O RMSN */
'20800' =  '1' /* ACT LEUK UNS CL W/O RMSN */
'20801' =  '1' /* ACT LEUK UNS CL W RMSON */
'20802' = '1' /* AC LEUK UNS CL RELAPSE */
'2081'  =  '1' /* CHRONIC LEUKEMIA NOS */
'20810' =  '1' /* CHR LEUK UNS CL W/O RMSN */
'20811' =  '1' /* CHR LEUK UNS CL W RMSON */
'20812' = '1' /* CH LEU UNS CL IN RELAPSE */
'2082'  =  '1' /* SUBACUTE LEUKEMIA NOS */
'20820' =  '1' /* SBAC LEUK UNS CL W/O RMS */
'20821' =  '1' /* SBAC LEUK UNS CL W RMSON */
'20822' = '1' /* SBAC LEU UNS CL-RELAPSE */
'2088'  =  '1' /* LEUKEMIA-UNSPEC CELL NEC */
'20880' =  '1' /* OTH LEUK UNS CL W/O RMSN */
'20881' =  '1' /* OTH LEUK UNS CL W RMSON */
'20882' = '1' /* OTH LEUK UNS CL-RELAPSE */
'2089'  =  '1' /* LEUKEMIA-UNSPEC CELL NOS */
'20890' =  '1' /* LEUKEMIA NOS W/O REMSION */
'20891' =  '1' /* LEUKEMIA NOS W REMISSIO */
'20892' = '1' /* LEUKEMIA NOS IN RELAPSE */
'23873' =  '1' /* HI GRDE MYELODYS SYN LES */
'23876' =  '1' /* MYELOFI W MYELO METAPLAS */
'23877' = '1' /* POST TP LYMPHPROLIF DIS */
'23879' = '1' /* LYMPH/HEMATPOITC TIS NEC */
'260'   =  '1' /* KWASHIORKOR */
'261'   =  '1' /* NUTRITIONAL MARASMUS */
'262'   =  '1' /* OTHER SEVERE PROTEIN CALORIE MALNUTRITION */
'27900' =  '1' /* HYPOGAMMAGLOBULINEMIA NOS */
'27901' =  '1' /* SELECTIVE IGA IMMUNODEFICIENCY */
'27902' =  '1' /* SELECTIVE IGM IMMUNODEFICIENCY */
'27903' =  '1' /* OTHER SELECTIVE IMMUNOGLOBULIN DEFICIENCIES */
'27904' =  '1' /* CONGENITAL HYPOGAMMAGLOBULINEMIA */
'27905' =  '1' /* IMMUNODEFICIENCY WITH INCREASED IGM */
'27906' =  '1' /* COMMON VARIABLE IMMUNODEFICIENCY */
'27909' =  '1' /* DEFICIENCY OF HUMORAL IMMUNITY, OTHER*/
'27910' =  '1' /* IMMUNODEFICIENCY WITH PREDOMINANT T-CELL DEFECT NOS */
'27911' =  '1' /* DIGEORGE'S SYNDROME */
'27912' =  '1' /* WISKOTT-ALDRICH SYNDROME */
'27913' =  '1' /* NEZLOF'S SYNDROME */
'27919' =  '1' /* DEFICIENCY OF CELL-MEDIATED IMMUNITY, OTHER */
'2792'  =  '1' /* COMBINED IMMUNITY DEFICIENCY */
'2793'  =  '1' /* UNSPECIFIED IMMUNITY DEFICIENCY */
'2794'  =  '1' /* AUTOIMMUNE DISEASE, NOT ELSEWHERE CLASSIFIED */
'27941' =  '1' /* AUTOIMMUN LYMPHPROF SYND */ 
'27949' =  '1' /* AUTOIMMUNE DISEASE NEC */ 
'27950' = '1' /* GRAFT-VERSUS-HOST NOS */
'27951' = '1' /* AC GRAFT-VERSUS-HOST DIS */
'27952' = '1' /* CHRONC GRAFT-VS-HOST DIS */
'27953' = '1' /* AC ON CHRN GRFT-VS-HOST */
'2798'  =  '1' /* OTHER SPECIFIED DISORDERS INVOLVING THE IMMUNE MECHANISM */
'2799'  =  '1' /* UNDSPECIFIED DISORDER OF IMMUNE MECHANISM */
'28409' =  '1' /* CONST APLASTC ANEMIA NEC */
'2841 ' =  '1' /* PANCYTOPENIA */
'28411 ' =  '1' /* ANTINEOPLASTIC CHEMOTHERAPY INDUCED PANCYTOPENIA */
'28412 ' =  '1' /* OTHER DRUG INDUCED PANCYTOPENIA */
'28419 ' =  '1' /* OTEHR PANCYTOPENIA */
'2880'  =  '1' /* AGRANULOCYTOSIS */
'28800' =  '1' /* NEUTROPENIA NOS */
'28801' =  '1' /* CONGENITAL NEUTROPENIA */
'28802' =  '1' /* CYCLIC NEUTROPENIA */
'28803' =  '1' /* DRUG INDUCED NEUTROPENIA */
'28809' =  '1' /* NEUTROPENIA NEC */
'2881'  =  '1' /* FUNCTIONAL DISORDERS OF POLYMORPHONUCLEAR NEUTROPHILS */
'2882'  =  '1' /* GENETIC ANOMALIES OF LUKOCYTES */
'2884 ' =  '1' /* HEMOPHAGOCYTIC SYNDROMES */
'28850' =  '1' /* LEUKOCYTOPENIA NOS */
'28851' =  '1' /* LYMPHOCYTOPENIA */
'28859' =  '1' /* DECREASED WBC COUNT NEC */
'28953' =  '1' /* NEUTROPENIC SPLENOMEGALY */
'28983' =  '1' /* MYELOFIBROSIS */
'40301' =  '1'  /* HYPERTENSIVE RENAL DISEASE, MALIGNANT W RENAL FAILURE */
'40311' =  '1'  /* HYPERTENSIVE RENAL DISEASE, BENIGH W RENAL FAILURE */
'40391' =  '1'  /* HYPERTENSIVE RENAL DISEASE, NOS W RENAL FAILURE */
'40402' =  '1'  /* HYPERTENSIVE HEART AND RENAL DISEASE MALIGNANT W RENAL FAILURE */
'40403' =  '1'  /* HYPERTENSIVE HEART AND RENAL DISEASE MALIGNANT W CONGESTIVE HEART AND RENAL FAILURE */
'40412' =  '1'  /* HYPERTENSIVE HEART AND RENAL DISEASE BENIGH W RENAL FAILURE */
'40413' =  '1'  /* HYPERTENSIVE HEART AND RENAL DISEASE BENIGH W CONGESTIVE HEART AND RENAL FAILURE*/
'40492' =  '1'  /* HYPERTENSIVE HEART AND RENAL DISEASE NOS W RENAL FAILURE */
'40493' =  '1'  /* HYPERTENSIVE HEART AND RENAL DISEASE NOS W CONGESTIVE HEART AND RENAL FAILURE */
'5793'  =  '1' /* OTHER AND UNSPECIFIED POSTSURGICAL NONABSORPTION */
'585'   =  '1'  /* CHRONIC KIDNEY DISEASE */
'5855'  =  '1'  /* CHRONIC KIDNEY DISEASE STAGE V */
'5856'  =  '1'  /* END STAGE RENAL DISEASE */
'9968'  =  '1' /* COMPLICATIONS OF TRANSPLANTED ORGAN */
'99680' =  '1' /* COMP ORGAN TRANSPLNT NOS */
'99681' =  '1' /* COMPL KIDNEY TRANSPLANT */
'99682' =  '1' /* COMPL LIVER TRANSPLANT */
'99683' =  '1' /* COMPL HEART TRANSPLANT */
'99684' =   '1' /* COMPL LUNG TRANSPLANT */
'99685' =  '1' /* COMPL MARROW TRANSPLANT */
'99686' =  '1' /* COMPL PANCREAS TRANSPLNT */
'99687' =  '1' /* COMP INTESTINE TRANSPLNT */
'99688' =  '1' /* STEM CELL TRANSPLANT COMPLICATIONS */
'99689' =  '1' /* COMP OTH ORGAN TRANSPLNT */
'V420'  =  '1' /* KIDNEY REPLACED BY TRANSPLANT */
'V421'  =  '1' /* HEART REPLACED BY TRANSPLANT */
'V426'  =  '1' /* LUNG REPLACED BY TRANSPLANT */
'V427'  =  '1' /* LIVER REPLACED BY TRANSPLANT */
'V428'  =  '1' /* OTHER SPECIFIED ORGAN OR TISSUE */
'V4281' =  '1' /* BONE MARROW SPECIFIED BY TRANSPLANT */
'V4282' =  '1' /* PERIPHERAL STEM CELLS REPLACED BY TRANSPLANT */
'V4283' =  '1' /* PANCREAS REPLACED BY TRANSPLANT */
'V4284' =  '1' /* INTESTINES REPLACE BY TRANSPLANT */
'V4289' =  '1' /* OTHER REPLACED BY TRANSPLANT */
'V451'  =  '1'  /* RENAL DIALYSIS STATUS */
'V4511' = '1' /* RENAL DIALYSIS STATUS */
'V560'  =  '1'  /* EXTRACORPOREAL DIALYSIS */
'V561'  =  '1'  /* FITTING AND ADJUSTMENT OF EXTRACORPOREAL DIALYSIS CATHETER */
'V562'  =  '1'  /* FITTING AND ADJUSTMENT OF PERITONEAL DIALYSIS CATHETER */
'V563'  =  '1'  /* ENCOUNTER FOR ADEQUACY TESTING FOR DIALYSIS */
'V5631' =  '1'  /* ENCOUNTER FOR ADEQUACY TESTING FOR HEMODIALYSIS */
'V5632' =  '1'  /* ENCOUNTER FOR ADEQUACY TESTING FOR PERIONEAL DIALYSIS */
'V568'  =  '1'  /* OTHER DIALYSIS */
OTHER   = '0' ;

/* ICD-9-CM PROCEDURE CODES: */

VALUE $TRANSPP
"335"  = "1" /* LUNG TRANSPLANT */
"3350" = "1" /* LUNG TRANSPLANT NOS */
"3351" = "1" /* UNILAT LUNG TRANSPLANT */
"3352" = "1" /* BILAT LUNG TRANSPLANT */
"336"  = "1" /* COMBINED HEART-LUNG TRANSPLANTATION */
"375"  = "1" /* HEART TRANSPLANTATION */
"3751" = "1" /* HEART TRANSPLANTATION */
"410"  = "1" /* OPERATIONS ON BONE MAROW AND SPLEEN */
"4100" = "1" /* BONE MARROW TRNSPLNT NOS */
"4101" = "1" /* AUTO BONE MT W/O PURG */
"4102" = "1" /* ALO BONE MARROW TRNSPLNT */
"4103" = "1" /* ALLOGRFT BONE MARROW NOS */
"4104" = "1" /* AUTO HEM STEM CT W/O PUR */
"4105" = "1" /* ALLO HEM STEM CT W/O PUR */
"4106" = "1" /* CORD BLD STEM CELL TRANS */
"4107" = "1" /* AUTO HEM STEM CT W PURG */
"4108" = "1" /* ALLO HEM STEM CT W PURG */
"4109" = "1" /* AUTO BONE MT W PURGING */
"4697" = "1" /* Added 5.0: TRANSPLANT OF INTESTINE */ 
"5051" = "1" /* AUXILIARY LIVER TRANSPL */
"5059" = "1" /* LIVER TRANSPLANT NEC */
"5280" = "1" /* PANCREATIC TRANSPLANT, NOS */
"5281" = "1" /* REIMPLANTATION OF PANCREATIC TISSUE */
"5282" = "1" /* REIMPLANTATION OF PANCREATIC TISSUE */
"5283" = "1" /* HETEROTRANSPLANT OF PANCREAS */
"5285" = "1" /* ALLOTRANSPLANTATION OF CELLS OF ISLETS OF LNGERHANS */
"5286" = "1" /* TRANSPLANTATION OF CELLS OF ISLETS OF LANGERHANS, NOS */
"5569" = "1" /* OTHER KIDNEY TRANSPLANTATION */
OTHER  = "0" ;

/* EXCLUDE: */
/* INTERMEDIATE RISK GROUP */
/* ICD-9-CM DIAGNOSIS CODES: */

VALUE $IMMUITD
"07022" =  "1"   /* VIRAL HEPATITIS B W HEPATIC COMA, CHRONIC WO MENTION OF HEPATITIS DELTA */
"07023" =  "1"   /* VIRAL HEPATITIS B W HEPACTIC COMA, CHRONIC W HEPATITIS DELTA */
"07044" =  "1"   /* CHRONIC HEPATITIS C WITH HEPACTIC COMMA */
"2894"  =  "1"   /* HYPERSPLENISM */
"28950" =  "1"   /* DISEASE OF SPLEEN NOS */
"28951" =  "1"   /* CHRONIC DIGESTIVE SPLENOMEGALY */
"28952" =  "1"   /* SPLENIC SEQUESTRATION */
"28959" =  "1"   /* OTHER DISEASE OF SPLEEN, OTHER */
"4560"  =  "1"   /* ESOPHAGEAL VARICES W BLEEDING */
"4561"  =  "1"   /* ESOPHAGEAL VARICES WO MENTION OF BLEEDING */
"45620" =  "1"   /* ESOPHAGEAL VARICES IN DISEASE CLASSIFIED ELSEWHERE, W BLEEDING */
"45621" =  "1"   /* ESOPHAGEAL VARICES IN DISEASE CLASSIFIED ELSEWHERE, WO MENTION OF BLEEDING */
"5723"  =  "1"   /* PORTAL HYPERTENSION */
"5728"  =  "1"   /* OTHER SEQUELAE OF CHRONIC LIVER DISEASE */
"5735"  =  "1"   /* HEPATOPULMONARY SYNDROME*/
"580"   =  "1"   /* ACUTE GLOMERULONEPHRITIS */
"5800"  =  "1"   /* WITH LESION OF PROLIFERATIVE GLOMERULONEPHRITIS */
"5804"  =  "1"   /* WITH LESION OF RAPIDLY PROGRESSIVE GLOMERULONEPHRITIS */
"5808"  =  "1"   /* WITH OTHER SPECIFIED PATHOLOGICAL LESION IN KIDNEY */
"58081" =  "1"   /* ACUTE GLOMERULONEPHRITIS IN DISEASES CLASSIFIED ELSEWHERE */
"58089" =  "1"   /* WITH OTHER SPECIFIED PATHOLOGICAL LESION IN KIDNEY, OTHER   */
"5809"  =  "1"   /* ACUTE GLOMERULONEPHRITIS WITH UNSPECIFIED PATHOLOGICAL LESION IN KIDNEY  */
"581"   =  "1"   /* NEPHROTIC SYNDROME */
"5810"  =  "1"   /* WITH LESION OF PROLIFERATIVE GLOMERULONEPHRITIS */
"5811"  =  "1"   /* WITH LESION OF MEMBRANOUS GLOMERULONEPHRITIS */
"5812"  =  "1"   /* WITH LESION OF MEMBRANOPROLIFERATIVE GLOMERULONEPHRITIS */
"5813"  =  "1"   /* WITH LESION OF MINIMAL CHANGE GLOMERULONEPHRITIS */
"5818"  =  "1"   /* WITH OTHER SPECIFIED PATHOLOGICAL LESION IN KIDNEY  */
"58181" =  "1"   /* NEPHROTIC SYNDROME IN DISEASE CLASSIFIED ELSEWHERE  */
"58189" =  "1"   /* WITH OTHER SPECIFIED PATHOLOGICAL LESION IN KIDNEY,OTHER  */
"5819"  =  "1"   /* NEPHROTIC SYNDROME WITH UNSPECIFIED PATHOLOGICAL LESION IN KIDNEY */
"582"   =  "1"   /* CHRONIC GLOMERULONEPHRITIS  */
"5820"  =  "1"   /* WITH LESION OF PROLIFERATIVE GLOMERULONEPHRITIS */
"5821"  =  "1"   /* WITH LESION OF MEMBRANOUS GLOMERULONEPHRITIS */
"5822"  =  "1"   /* WITH LESION OF MEMBRANEPROLIFERATIVE GLOMERULONEPHRITIS */
"5824"  =  "1"   /* WITH LESION OF RAPIDLY PROGRESSIVE GLOMERULONEPHRITIS */
"5828"  =  "1"   /* WITH OTHER SPECIFIED PATHOLOGICAL LESION IN KIDNEY */
"58281" =  "1"   /* CHRONIC GLOMERULONEPHRITIS IN DISEASES CLASSIFIED ELSEWHERE */
"58289" =  "1"   /* WITH OTHER SPECIFIED PATHOLOGICAL LESION IN KIDNEY, OTHER   */
"5829"  =  "1"   /* CHORNIC GLOMERULONEPHRITIS WITH UNSPECIFIED PATHOLOGICAL LESION IN KIDNEY  */
"583"   =  "1"   /* NEPHRITIS AND NEPHROPATHY, NOT SPECFIED AS ACUTE OR CHRONIC  */
"5830"  =  "1"   /* WITH LESION OF PROLIFERATIVE GLOMERULONEPHRITIS */
"5831"  =  "1"   /* WITH LESION OF MEMBRANOUS GLOMERULONEPHRITIS */
"5832"  =  "1"   /* WITH LESION OF MEMBRANEPROLIFERATIVE GLOMERULONEPHRITIS */
"5834"  =  "1"   /* WITH LESION OF RAPIDLY PROGRESSIVE GLOMERULONEPHRITIS */
"5836"  =  "1"   /* WITH LESION OF RENAL CORTICAL NECROSIS */
"5837"  =  "1"   /* WITH LESION OF RENAL MEDULLARY NECROSIS */
"5838"  =  "1"   /* WITH OTHER SPECIFIED PATHOLOGICAL LESION IN KIDNEY */
"58381" =  "1"   /* NEPHRITIS AND NEPHROPATHY, NOT SPECIFIED AS ACUTE OR CHRONIC, IN DISEASE CLASSIFIED ELSEWHERE */
"58389" =  "1"   /* WITH OTHER SPECIFIED PATHOLOGICAL LESION IN KIDNEY, OTHER   */
"5839"  =  "1"   /* WITH UNSPECIFIED PATHOLOGICAL LESION IN KIDNEY */
"7100"  =  "1"   /* SYSTEMIC LUPUS ERYTHEMATOSUS */
"7101"  =  "1"   /* SYSTEMIC SCLEROSIS */
"7102"  =  "1"   /* SICCA SYNDROME */
"7103"  =  "1"   /* DERMATOMYOSITIS */
"7104"  =  "1"   /* POLYMYOSITIS */
"7105"  =  "1"   /* EOSINOPHILIA MYALGIA SYNDROME */
"7108"  =  "1"   /* OTHER SPECIFIED DIFFUSE DISEASE OF CONNECTIVE TISSUE */
"7109"  =  "1"   /* UNSPECIFIED DIFFUSE CONNECTIVE TISSUE DISEASE */
"7590"  =  "1"   /* ANOMALIES OF SPLEEN */
"7994"  =  "1"   /* CACHEXIA */
"86500" =  "1"   /* INJURY TO SPLEEN,WO MENTION OF OPEN WOUND INTO CAVITY NOS INJURY */
"86501" =  "1"   /* INJURY TO SPLEEN,WO MENTION OF OPEN WOUND INTO CAVITY HEMATOMA WO RUPTURE OF CAPSULE */
"86502" =  "1"   /* INJURY TO SPLEEN,WO MENTION OF OPEN WOUND INTO CAVITY CAPSULE TEARS WO MAJOR DISRUPTION OF PARENCHYMA */
"86503" =  "1"   /* INJURY TO SPLEEN,WO MENTION OF OPEN WOUND INTO CAVITY LACERATION EXTENDING INTO PARENCHYMA */
"86504" =  "1"   /* INJURY TO SPLEEN,WO MENTION OF OPEN WOUND INTO CAVITY MASSIVE PARENCHYMAL DISRUPTION */
"86509" =  "1"   /* INJURY TO SPLEEN,WO MENTION OF OPEN WOUND INTO CAVITY OTHER */
"86510" =  "1"   /* INJURY TO SPLEEN,W OPEN WOUND INTO CAVITY NOS INJURY */
"86511" =  "1"   /* INJURY TO SPLEEN,W OPEN WOUND INTO CAVITY HEMATOMA WO RUPTURE OF CAPSULE */
"86512" =  "1"   /* INJURY TO SPLEEN,W OPEN WOUND INTO CAVITY CAPSULAR TEARS WO MAJOR DISRUPTION OF PARENCHYMA */
"86513" =  "1"   /* INJURY TO SPLEEN,W OPEN WOUND INTO CAVITY LACERATION EXTENDING INTO PARENCHYMA */
"86514" =  "1"   /* INJURY TO SPLEEN,W OPEN WOUND INTO CAVITY MASSIVE PARENCHYMAL DISRUPTION */
"86519" =  "1"   /* INJURY TO SPLEEN,W OPEN WOUND INTO CAVITY OTHER */
"V427"  =  "1"   /* ORGAN OR TISSUE REPLACED BY TRANSPLANT, LIVER */
OTHER   = "0" ;

/* HEPTIC FAILURE CONDITION PART II */
VALUE $HEPFA2D
"5712"   = "1"    /* ALCOHOLIC CIRRHOSIS OF LIVER */
"5715"   = "1"    /* CIRRHOSIS OF LIVER WITHOUT MENTION OF ALCOHOL */
"5716"   = "1"    /* BILIARY CIRRHOSIS */
OTHER   = "0" ;

VALUE $HEPFA3D
"5722"   = "1"    /* HEPATIC COMA */
"5724"   = "1"    /* HEPATORENAL SYNDROME */
OTHER   = "0" ;

 /*Central Venous Catheter-Related Blood Stream Infections (PSI 7, PSI 23 and PDI 12) */
 /* ---------------------------------------------------------*/
 /* CENTRAL VENOUS CATHETER-RELATED BLOOD STREAM INFECTIONS  */
 /*   PROVIDER INDICATOR / PDI#  12                          */
 /* ---------------------------------------------------------*/

 /* ICD-9-CM DIAGNOSIS CODES: HOSPITAL ASSOCIATED INFECTION DIAGNOSIS CODES 
    FOR DISCHARGES BEFORE OCTOBER 1, 2007  */;

VALUE $IDTMCID
"99662" = "1" /* DUE TO OTHER VASCULAR DEVICE, IMPLANT, AND GRAFT */
"9993"  = "1" /* OTHER INFECTION */
OTHER   = "0" ;

 /* ICD-9-CM DIAGNOSIS CODES: BLOODSTREAM INFECTION INFECTION DIAGNOSIS CODES 
    FOR DISCHARGES ON OR AFTER OCTOBER 1, 2007 BUT BEFORE OCTOBER 1, 2011 */;

VALUE $IDTMC2D
"99931" = "1" /* INFECTION DUE TO CENTRAL VENOUS CATHETER */
OTHER   = "0" ;

 /* ICD-9-CM DIAGNOSIS CODES: CENTRAL LINE-ASSOCIATED BLOODSTREAM INFECTION DIAGNOSIS CODES 
    FOR DISCHARGES ON OR AFTER OCTOBER 1, 2011  */;

VALUE $IDTMC3D            
"99931" = "1" /* OTHER AND UNSPECIFIED INFECTION DUE TO CENTRAL VENOUS CATHETER */
"99932" = "1" /* BLOODSTREAM INFECTION DUE TO CENTRAL VENOUS CATHETER */ 
OTHER   = "0" ;

/* STRATIFY BY: HIGH RISK GROUP */
/* ICD-9-CM DIAGNOSIS CODES: */

VALUE $CANITD
"1400 " = "1" /* MAL NEO UPPER VERMILION*/
"1401 " = "1" /* MAL NEO LOWER VERMILION */
"1403 " = "1" /* MAL NEO UPPER LIP, INNER */
"1404 " = "1" /* MAL NEO LOWER LIP, INNER */
"1405 " = "1" /* MAL NEO LIP, INNER NOS */
"1406 " = "1" /* MAL NEO LIP, COMMISSURE */
"1408 " = "1" /* MAL NEO LIP NEC */
"1409 " = "1" /* MAL NEO LIP/VERMIL NOS */
"1410 " = "1" /* MAL NEO TONGUE BASE */
"1411 " = "1" /* MAL NEO DORSAL TONGUE */
"1412 " = "1" /* MAL NEO TIP/LAT TONGUE */
"1413 " = "1" /* MAL NEO VENTRAL TONGUE */
"1414 " = "1" /* MAL NEO ANT 2/3 TONGUE */
"1415 " = "1" /* MAL NEO TONGUE JUNCTION */
"1416 " = "1" /* MAL NEO LINGUAL TONSIL */
"1418 " = "1" /* MALIG NEO TONGUE NEC */
"1419 " = "1" /* MALIG NEO TONGUE NOS */
"1420 " = "1" /* MALIG NEO PAROTID */
"1421 " = "1" /* MALIG NEO SUBMANDIBULAR */
"1422 " = "1" /* MALIG NEO SUBLINGUAL */
"1428 " = "1" /* MAL NEO MAJ SALIVARY NEC */
"1429 " = "1" /* MAL NEO SALIVARY NOS */
"1430 " = "1" /* MALIG NEO UPPER GUM */
"1431 " = "1" /* MALIG NEO LOWER GUM */
"1438 " = "1" /* MALIG NEO GUM NEC */
"1439 " = "1" /* MALIG NEO GUM NOS */
"1440 " = "1" /* MAL NEO ANT FLOOR MOUTH */
"1441 " = "1" /* MAL NEO LAT FLOOR MOUTH */
"1448 " = "1" /* MAL NEO MOUTH FLOOR NEC */
"1449 " = "1" /* MAL NEO MOUTH FLOOR NOS */
"1450 " = "1" /* MAL NEO CHEEK MUCOSA */
"1451 " = "1" /* MAL NEO MOUTH VESTIBULE */
"1452 " = "1" /* MALIG NEO HARD PALATE */
"1453 " = "1" /* MALIG NEO SOFT PALATE */
"1454 " = "1" /* MALIGNANT NEOPLASM UVULA */
"1455 " = "1" /* MALIGNANT NEO PALATE NOS */
"1456 " = "1" /* MALIG NEO RETROMOLAR */
"1458 " = "1" /* MALIG NEOPLASM MOUTH NEC */
"1459 " = "1" /* MALIG NEOPLASM MOUTH NOS */
"1460 " = "1" /* MALIGNANT NEOPL TONSIL */
"1461 " = "1" /* MAL NEO TONSILLAR FOSSA */
"1462 " = "1" /*  MAL NEO TONSIL PILLARS */
"1463 " = "1" /* MALIGN NEOPL VALLECULA */
"1464 " = "1" /* MAL NEO ANT EPIGLOTTIS */
"1465 " = "1" /* MAL NEO EPIGLOTTIS JUNCT */
"1466 " = "1" /* MAL NEO LAT OROPHARYNX */
"1467 " = "1" /* MAL NEO POST OROPHARYNX */
"1468 " = "1" /* MAL NEO OROPHARYNX NEC */
"1469 " = "1" /* MALIG NEO OROPHARYNX NOS */
"1470 " = "1" /* MAL NEO SUPER NASOPHARYN */
"1471 " = "1" /* MAL NEO POST NASOPHARYNX */
"1472 " = "1" /* MAL NEO LAT NASOPHARYNX */
"1473 " = "1" /* MAL NEO ANT NASOPHARYNX */
"1478 " = "1" /* MAL NEO NASOPHARYNX NEC */
"1479 " = "1" /* MAL NEO NASOPHARYNX NOS */
"1480 " = "1" /* MAL NEO POSTCRICOID */
"1481 " = "1" /* MAL NEO PYRIFORM SINUS */
"1482 " = "1" /* MAL NEO ARYEPIGLOTT FOLD */
"1483 " = "1" /* MAL NEO POST HYPOPHARYNX */
"1488 " = "1" /* MAL NEO HYPOPHARYNX NEC */
"1489 " = "1" /* MAL NEO HYPOPHARYNX NOS */
"1490 " = "1" /* MAL NEO PHARYNX NOS */
"1491 " = "1" /* MAL NEO WALDEYERS RING */
"1498 " = "1" /* MAL NEO ORAL/PHARYNX NEC */
"1499 " = "1" /* MAL NEO OROPHRYN ILL-DEF */
"1500 " = "1" /* MAL NEO CERVICAL ESOPHAG */
"1501 " = "1" /* MAL NEO THORACIC ESOPHAG */
"1502 " = "1" /* MAL NEO ABDOMIN ESOPHAG */
"1503 " = "1" /* MAL NEO UPPER 3RD ESOPH */
"1504 " = "1" /* MAL NEO MIDDLE 3RD ESOPH */
"1505 " = "1" /* MAL NEO LOWER 3RD ESOPH */
"1508 " = "1" /* MAL NEO ESOPHAGUS NEC */
"1509 " = "1" /* MAL NEO ESOPHAGUS NOS */
"1510 " = "1" /* MAL NEO STOMACH CARDIA */
"1511 " = "1" /* MALIGNANT NEO PYLORUS */
"1512 " = "1" /* MAL NEO PYLORIC ANTRUM */
"1513 " = "1" /* MAL NEO STOMACH FUNDUS */
"1514 " = "1" /* MAL NEO STOMACH BODY */
"1515 " = "1" /* MAL NEO STOM LESSER CURV */
"1516 " = "1" /* MAL NEO STOM GREAT CURV */
"1518 " = "1" /* MALIG NEOPL STOMACH NEC */
"1519 " = "1" /* MALIG NEOPL STOMACH NOS */
"1520 " = "1" /* MALIGNANT NEOPL DUODENUM */
"1521 " = "1" /* MALIGNANT NEOPL JEJUNUM */
"1522 " = "1" /* MALIGNANT NEOPLASM ILEUM */
"1523 " = "1" /* MAL NEO MECKELS DIVERT */
"1528 " = "1" /* MAL NEO SMALL BOWEL NEC */
"1529 " = "1" /* MAL NEO SMALL BOWEL NOS */
"1530 " = "1" /* MAL NEO HEPATIC FLEXURE */
"1531 " = "1" /* MAL NEO TRANSVERSE COLON */
"1532 " = "1" /* MAL NEO DESCEND COLON */
"1533 " = "1" /* MAL NEO SIGMOID COLON */
"1534 " = "1" /* MALIGNANT NEOPLASM CECUM */
"1535 " = "1" /* MALIGNANT NEO APPENDIX */
"1536 " = "1" /* MALIG NEO ASCEND COLON */
"1537 " = "1" /* MAL NEO SPLENIC FLEXURE */
"1538 " = "1" /* MALIGNANT NEO COLON NEC */
"1539 " = "1" /* MALIGNANT NEO COLON NOS */
"1540 " = "1" /* MAL NEO RECTOSIGMOID JCT */
"1541 " = "1" /* MALIGNANT NEOPL RECTUM */
"1542 " = "1" /* MALIG NEOPL ANAL CANAL */
"1543 " = "1" /* MALIGNANT NEO ANUS NOS */
"1548 " = "1" /* MAL NEO RECTUM/ANUS NEC */
"1550 " = "1" /* MAL NEO LIVER, PRIMARY */
"1551 " = "1" /* MAL NEO INTRAHEPAT DUCTS */
"1552 " = "1" /* MALIGNANT NEO LIVER NOS */
"1560 " = "1" /* MALIG NEO GALLBLADDER */
"1561 " = "1" /* MAL NEO EXTRAHEPAT DUCTS */
"1562 " = "1" /* MAL NEO AMPULLA OF VATER */
"1568 " = "1" /* MALIG NEO BILIARY NEC */
"1569 " = "1" /* MALIG NEO BILIARY NOS */
"1570 " = "1" /* MAL NEO PANCREAS HEAD */
"1571 " = "1" /* MAL NEO PANCREAS BODY */
"1572 " = "1" /* MAL NEO PANCREAS TAIL */
"1573 " = "1" /* MAL NEO PANCREATIC DUCT */
"1574 " = "1" /* MAL NEO ISLET LANGERHANS */
"1578 " = "1" /* MALIG NEO PANCREAS NEC */
"1579 " = "1" /* MALIG NEO PANCREAS NOS */
"1580 " = "1" /* MAL NEO RETROPERITONEUM */
"1588 " = "1" /* MAL NEO PERITONEUM NEC */
"1589 " = "1" /* MAL NEO PERITONEUM NOS */
"1590 " = "1" /* MALIG NEO INTESTINE NOS */
"1591 " = "1" /* MALIGNANT NEO SPLEEN NEC */
"1598 " = "1" /* MAL NEO GI/INTRA-ABD NEC */
"1599 " = "1" /* MAL NEO GI TRACT ILL-DEF */
"1600 " = "1" /* MAL NEO NASAL CAVITIES */
"1601 " = "1" /* MALIG NEO MIDDLE EAR */
"1602 " = "1" /* MAL NEO MAXILLARY SINUS */
"1603 " = "1" /* MAL NEO ETHMOIDAL SINUS */
"1604 " = "1" /* MALIG NEO FRONTAL SINUS */
"1605 " = "1" /* MAL NEO SPHENOID SINUS */
"1608 " = "1" /* MAL NEO ACCESS SINUS NEC */
"1609 " = "1" /* MAL NEO ACCESS SINUS NOS */
"1610 " = "1" /* MALIGNANT NEO GLOTTIS */
"1611 " = "1" /* MALIG NEO SUPRAGLOTTIS */
"1612 " = "1" /* MALIG NEO SUBGLOTTIS */
"1613 " = "1" /* MAL NEO CARTILAGE LARYNX */
"1618 " = "1" /* MALIGNANT NEO LARYNX NEC */
"1619 " = "1" /* MALIGNANT NEO LARYNX NOS */
"1620 " = "1" /* MALIGNANT NEO TRACHEA */
"1622 " = "1" /* MALIG NEO MAIN BRONCHUS */
"1623 " = "1" /* MAL NEO UPPER LOBE LUNG */
"1624 " = "1" /* MAL NEO MIDDLE LOBE LUNG */
"1625 " = "1" /* MAL NEO LOWER LOBE LUNG */
"1628 " = "1" /* MAL NEO BRONCH/LUNG NEC */
"1629 " = "1" /* MAL NEO BRONCH/LUNG NOS */
"1630 " = "1" /* MAL NEO PARIETAL PLEURA */
"1631 " = "1" /* MAL NEO VISCERAL PLEURA */
"1638 " = "1" /* MALIG NEOPL PLEURA NEC */
"1639 " = "1" /* MALIG NEOPL PLEURA NOS */
"1640 " = "1" /* MALIGNANT NEOPL THYMUS */
"1641 " = "1" /* MALIGNANT NEOPL HEART */
"1642 " = "1" /* MAL NEO ANT MEDIASTINUM */
"1643 " = "1" /* MAL NEO POST MEDIASTINUM */
"1648 " = "1" /* MAL NEO MEDIASTINUM NEC */
"1649 " = "1" /* MAL NEO MEDIASTINUM NOS */
"1650 " = "1" /* MAL NEO UPPER RESP NOS */
"1658 " = "1" /* MAL NEO THORAX/RESP NEC */
"1659 " = "1" /* MAL NEO RESP SYSTEM NOS */
"1700 " = "1" /* MAL NEO SKULL/FACE BONE */
"1701 " = "1" /* MALIGNANT NEO MANDIBLE */
"1702 " = "1" /* MALIG NEO VERTEBRAE */
"1703 " = "1" /* MAL NEO RIBS/STERN/CLAV */
"1704 " = "1" /* MAL NEO LONG BONES ARM */
"1705 " = "1" /* MAL NEO BONES WRIST/HAND */
"1706 " = "1" /* MAL NEO PELVIC GIRDLE */
"1707 " = "1" /* MAL NEO LONG BONES LEG */
"1708 " = "1" /* MAL NEO BONES ANKLE/FOOT */
"1709 " = "1" /* MALIG NEOPL BONE NOS */
"1710 " = "1" /* MAL NEO SOFT TISSUE HEAD */
"1712 " = "1" /* MAL NEO SOFT TISSUE ARM */
"1713 " = "1" /* MAL NEO SOFT TISSUE LEG */
"1714 " = "1" /* MAL NEO SOFT TIS THORAX */
"1715 " = "1" /* MAL NEO SOFT TIS ABDOMEN */
"1716 " = "1" /* MAL NEO SOFT TIS PELVIS */
"1717 " = "1" /* MAL NEOPL TRUNK NOS */
"1718 " = "1" /* MAL NEO SOFT TISSUE NEC */
"1719 " = "1" /* MAL NEO SOFT TISSUE NOS */
"1720 " = "1" /* MALIG MELANOMA LIP */
"1721 " = "1" /* MALIG MELANOMA EYELID */
"1722 " = "1" /* MALIG MELANOMA EAR */
"1723 " = "1" /* MAL MELANOM FACE NEC NOS */
"1724 " = "1" /* MAL MELANOMA SCALP/NECK */
"1725 " = "1" /* MALIG MELANOMA TRUNK */
"1726 " = "1" /* MALIG MELANOMA ARM */
"1727 " = "1" /* MALIG MELANOMA LEG */
"1728 " = "1" /* MALIG MELANOMA SKIN NEC */
"1729 " = "1" /* MALIG MELANOMA SKIN NOS */
"1740 " = "1" /* MALIG NEO NIPPLE */
"1741 " = "1" /* MAL NEO BREAST-CENTRAL */
"1742 " = "1" /* MAL NEO BREAST UP-INNER */
"1743 " = "1" /* MAL NEO BREAST LOW-INNER */
"1744 " = "1" /* MAL NEO BREAST UP-OUTER */
"1745 " = "1" /* MAL NEO BREAST LOW-OUTER */
"1746 " = "1" /* MAL NEO BREAST-AXILLARY */
"1748 " = "1" /* MALIGN NEOPL BREAST NEC */
"1749 " = "1" /* MALIGN NEOPL BREAST NOS */
"1750 " = "1" /* MAL NEO MALE NIPPLE */
"1759 " = "1" /* MAL NEO MALE BREAST NEC */
"1760 " = "1" /* SKIN - KAPOSIS SARCOMA */
"1761 " = "1" /* SFT TISUE - KPSIS SRCMA */
"1762 " = "1" /* PALATE - KPSIS SARCOMA */
"1763 " = "1" /* GI SITES - KPSIS SRCOMA */
"1764 " = "1" /* LUNG - KAPOSIS SARCOMA */
"1765 " = "1" /* LYM NDS - KPSIS SARCOMA */
"1768 " = "1" /* SPF STS - KPSIS SARCOMA */
"1769 " = "1" /* KAPOSIS SARCOMA NOS */
"179  " = "1" /* MALIG NEOPL UTERUS NOS */
"1800 " = "1" /* MALIG NEO ENDOCERVIX */
"1801 " = "1" /* MALIG NEO EXOCERVIX */
"1808 " = "1" /* MALIG NEO CERVIX NEC */
"1809 " = "1" /* MAL NEO CERVIX UTERI NOS */
"181  " = "1" /* MALIGNANT NEOPL PLACENTA */
"1820 " = "1" /* MALIG NEO CORPUS UTERI */
"1821 " = "1" /* MAL NEO UTERINE ISTHMUS */
"1828 " = "1" /* MAL NEO BODY UTERUS NEC */
"1830 " = "1" /* MALIGN NEOPL OVARY */
"1832 " = "1" /* MAL NEO FALLOPIAN TUBE */
"1833 " = "1" /* MAL NEO BROAD LIGAMENT */
"1834 " = "1" /* MALIG NEO PARAMETRIUM */
"1835 " = "1" /* MAL NEO ROUND LIGAMENT */
"1838 " = "1" /* MAL NEO ADNEXA NEC */
"1839 " = "1" /* MAL NEO ADNEXA NOS */
"1840 " = "1" /* MALIGN NEOPL VAGINA */
"1841 " = "1" /* MAL NEO LABIA MAJORA */
"1842 " = "1" /* MAL NEO LABIA MINORA */
"1843 " = "1" /* MALIGN NEOPL CLITORIS */
"1844 " = "1" /* MALIGN NEOPL VULVA NOS */
"1848 " = "1" /* MAL NEO FEMALE GENIT NEC */
"1849 " = "1" /* MAL NEO FEMALE GENIT NOS */
"185  " = "1" /* MALIGN NEOPL PROSTATE */
"1860 " = "1" /* MAL NEO UNDESCEND TESTIS */
"1869 " = "1" /* MALIG NEO TESTIS NEC */
"1871 " = "1" /* MALIGN NEOPL PREPUCE */
"1872 " = "1" /* MALIG NEO GLANS PENIS */
"1873 " = "1" /* MALIG NEO PENIS BODY */
"1874 " = "1" /* MALIG NEO PENIS NOS */
"1875 " = "1" /* MALIG NEO EPIDIDYMIS */
"1876 " = "1" /* MAL NEO SPERMATIC CORD */
"1877 " = "1" /* MALIGN NEOPL SCROTUM */
"1878 " = "1" /* MAL NEO MALE GENITAL NEC */
"1879 " = "1" /* MAL NEO MALE GENITAL NOS */
"1880 " = "1" /* MAL NEO BLADDER-TRIGONE */
"1881 " = "1" /* MAL NEO BLADDER-DOME */
"1882 " = "1" /* MAL NEO BLADDER-LATERAL */
"1883 " = "1" /* MAL NEO BLADDER-ANTERIOR */
"1884 " = "1" /* MAL NEO BLADDER-POST */
"1885 " = "1" /* MAL NEO BLADDER NECK */
"1886 " = "1" /* MAL NEO URETERIC ORIFICE */
"1887 " = "1" /* MALIG NEO URACHUS */
"1888 " = "1" /* MALIG NEO BLADDER NEC */
"1889 " = "1" /* MALIG NEO BLADDER NOS */
"1890 " = "1" /* MALIG NEOPL KIDNEY */
"1891 " = "1" /* MALIG NEO RENAL PELVIS */
"1892 " = "1" /* MALIGN NEOPL URETER */
"1893 " = "1" /* MALIGN NEOPL URETHRA */
"1894 " = "1" /* MAL NEO PARAURETHRAL */
"1898 " = "1" /* MAL NEO URINARY NEC */
"1899 " = "1" /* MAL NEO URINARY NOS */
"1900 " = "1" /* MALIGN NEOPL EYEBALL */
"1901 " = "1" /* MALIGN NEOPL ORBIT */
"1902 " = "1" /* MAL NEO LACRIMAL GLAND */
"1903 " = "1" /* MAL NEO CONJUNCTIVA */
"1904 " = "1" /* MALIGN NEOPL CORNEA */
"1905 " = "1" /* MALIGN NEOPL RETINA */
"1906 " = "1" /* MALIGN NEOPL CHOROID */
"1907 " = "1" /* MAL NEO LACRIMAL DUCT */
"1908 " = "1" /* MALIGN NEOPL EYE NEC */
"1909 " = "1" /* MALIGN NEOPL EYE NOS */
"1910 " = "1" /* MALIGN NEOPL CEREBRUM */
"1911 " = "1" /* MALIG NEO FRONTAL LOBE */
"1912 " = "1" /* MAL NEO TEMPORAL LOBE */
"1913 " = "1" /* MAL NEO PARIETAL LOBE */
"1914 " = "1" /* MAL NEO OCCIPITAL LOBE */
"1915 " = "1" /* MAL NEO CEREB VENTRICLE */
"1916 " = "1" /* MAL NEO CEREBELLUM NOS */
"1917 " = "1" /* MAL NEO BRAIN STEM */
"1918 " = "1" /* MALIG NEO BRAIN NEC */
"1919 " = "1" /* MALIG NEO BRAIN NOS */
"1920 " = "1" /* MAL NEO CRANIAL NERVES */
"1921 " = "1" /* MAL NEO CEREBRAL MENING */
"1922 " = "1" /* MAL NEO SPINAL CORD */
"1923 " = "1" /* MAL NEO SPINAL MENINGES */
"1928 " = "1" /* MAL NEO NERVOUS SYST NEC */
"1929 " = "1" /* MAL NEO NERVOUS SYST NOS */
"193  " = "1" /* MALIGN NEOPL THYROID */
"1940 " = "1" /* MALIGN NEOPL ADRENAL */
"1941 " = "1" /* MALIG NEO PARATHYROID */
"1943 " = "1" /* MALIG NEO PITUITARY */
"1944 " = "1" /* MALIGN NEO PINEAL GLAND */
"1945 " = "1" /* MAL NEO CAROTID BODY */
"1946 " = "1" /* MAL NEO PARAGANGLIA NEC */
"1948 " = "1" /* MAL NEO ENDOCRINE NEC */
"1949 " = "1" /* MAL NEO ENDOCRINE NOS */
"1950 " = "1" /* MAL NEO HEAD/FACE/NECK */
"1951 " = "1" /* MALIGN NEOPL THORAX */
"1952 " = "1" /* MALIG NEO ABDOMEN */
"1953 " = "1" /* MALIGN NEOPL PELVIS */
"1954 " = "1" /* MALIGN NEOPL ARM */
"1955 " = "1" /* MALIGN NEOPL LEG */
"1958 " = "1" /* MALIG NEO SITE NEC */
"1960 " = "1" /* MAL NEO LYMPH-HEAD/NECK */
"1961 " = "1" /* MAL NEO LYMPH-INTRATHOR */
"1962 " = "1" /* MAL NEO LYMPH INTRA-ABD */
"1963 " = "1" /* MAL NEO LYMPH-AXILLA/ARM */
"1965 " = "1" /* MAL NEO LYMPH-INGUIN/LEG */
"1966 " = "1" /* MAL NEO LYMPH-INTRAPELV */
"1968 " = "1" /* MAL NEO LYMPH NODE-MULT */
"1969 " = "1" /* MAL NEO LYMPH NODE NOS */
"1970 " = "1" /* SECONDARY MALIG NEO LUNG */
"1971 " = "1" /* SEC MAL NEO MEDIASTINUM */
"1972 " = "1" /* SECOND MALIG NEO PLEURA */
"1973 " = "1" /* SEC MALIG NEO RESP NEC */
"1974 " = "1" /* SEC MALIG NEO SM BOWEL */
"1975 " = "1" /* SEC MALIG NEO LG BOWEL */
"1976 " = "1" /* SEC MAL NEO PERITONEUM */
"1977 " = "1" /* SECOND MALIG NEO LIVER */
"1978 " = "1" /* SEC MAL NEO GI NEC */
"1980 " = "1" /* SECOND MALIG NEO KIDNEY */
"1981 " = "1" /* SEC MALIG NEO URIN NEC */
"1982 " = "1" /* SECONDARY MALIG NEO SKIN */
"1983 " = "1" /* SEC MAL NEO BRAIN/SPINE */
"1984 " = "1" /* SEC MALIG NEO NERVE NEC */
"1985 " = "1" /* SECONDARY MALIG NEO BONE */
"1986 " = "1" /* SECOND MALIG NEO OVARY */
"1987 " = "1" /* SECOND MALIG NEO ADRENAL */
"19881" = "1" /* SECOND MALIG NEO BREAST */
"19882" = "1" /* SECOND MALIG NEO GENITAL */
"19889" = "1" /* SECONDARY MALIG NEO NEC */
"1990 " = "1" /* MALIG NEO DISSEMINATED */
"1991 " = "1" /* MALIGNANT NEOPLASM NOS */
"20100" = "1" /* HDGK PRG UNSP XTRNDL ORG */
"20101" = "1" /* HODGKINS PARAGRAN HEAD */
"20102" = "1" /* HODGKINS PARAGRAN THORAX */
"20103" = "1" /* HODGKINS PARAGRAN ABDOM */
"20104" = "1" /* HODGKINS PARAGRAN AXILLA */
"20105" = "1" /* HODGKINS PARAGRAN INGUIN */
"20106" = "1" /* HODGKINS PARAGRAN PELVIC */
"20107" = "1" /* HODGKINS PARAGRAN SPLEEN */
"20108" = "1" /* HODGKINS PARAGRAN MULT */
"20110" = "1" /* HDGK GRN UNSP XTRNDL ORG */
"20111" = "1" /* HODGKINS GRANULOM HEAD */
"20112" = "1" /* HODGKINS GRANULOM THORAX */
"20113" = "1" /* HODGKINS GRANULOM ABDOM */
"20114" = "1" /* HODGKINS GRANULOM AXILLA */
"20115" = "1" /* HODGKINS GRANULOM INGUIN */
"20116" = "1" /* HODGKINS GRANULOM PELVIC */
"20117" = "1" /* HODGKINS GRANULOM SPLEEN */
"20118" = "1" /* HODGKINS GRANULOM MULT */
"20120" = "1" /* HDGK SRC UNSP XTRNDL ORG */
"20121" = "1" /* HODGKINS SARCOMA HEAD */
"20122" = "1" /* HODGKINS SARCOMA THORAX */
"20123" = "1" /* HODGKINS SARCOMA ABDOM */
"20124" = "1" /* HODGKINS SARCOMA AXILLA */
"20125" = "1" /* HODGKINS SARCOMA INGUIN */
"20126" = "1" /* HODGKINS SARCOMA PELVIC */
"20127" = "1" /* HODGKINS SARCOMA SPLEEN */
"20128" = "1" /* HODGKINS SARCOMA MULT */
"20140" = "1" /* LYM-HST UNSP XTRNDL ORGN */
"20141" = "1" /* HODG LYMPH-HISTIO HEAD */
"20142" = "1" /* HODG LYMPH-HISTIO THORAX */
"20143" = "1" /* HODG LYMPH-HISTIO ABDOM */
"20144" = "1" /* HODG LYMPH-HISTIO AXILLA */
"20145" = "1" /* HODG LYMPH-HISTIO INGUIN */
"20146" = "1" /* HODG LYMPH-HISTIO PELVIC */
"20147" = "1" /* HODG LYMPH-HISTIO SPLEEN */
"20148" = "1" /* HODG LYMPH-HISTIO MULT */
"20150" = "1" /* NDR SCLR UNSP XTRNDL ORG */
"20151" = "1" /* HODG NODUL SCLERO HEAD */
"20152" = "1" /* HODG NODUL SCLERO THORAX */
"20153" = "1" /* HODG NODUL SCLERO ABDOM */
"20154" = "1" /* HODG NODUL SCLERO AXILLA */
"20155" = "1" /* HODG NODUL SCLERO INGUIN */
"20156" = "1" /* HODG NODUL SCLERO PELVIC */
"20157" = "1" /* HODG NODUL SCLERO SPLEEN */
"20158" = "1" /* HODG NODUL SCLERO MULT */
"20160" = "1" /* MXD CELR UNSP XTRNDL ORG */
"20161" = "1" /* HODGKINS MIX CELL HEAD */
"20162" = "1" /* HODGKINS MIX CELL THORAX */
"20163" = "1" /* HODGKINS MIX CELL ABDOM */
"20164" = "1" /* HODGKINS MIX CELL AXILLA */
"20165" = "1" /* HODGKINS MIX CELL INGUIN */
"20166" = "1" /* HODGKINS MIX CELL PELVIC */
"20167" = "1" /* HODGKINS MIX CELL SPLEEN */
"20168" = "1" /* HODGKINS MIX CELL MULT */
"20170" = "1" /* LYM DPLT UNSP XTRNDL ORG */
"20171" = "1" /* HODG LYMPH DEPLET HEAD */
"20172" = "1" /* HODG LYMPH DEPLET THORAX */
"20173" = "1" /* HODG LYMPH DEPLET ABDOM */
"20174" = "1" /* HODG LYMPH DEPLET AXILLA */
"20175" = "1" /* HODG LYMPH DEPLET INGUIN */
"20176" = "1" /* HODG LYMPH DEPLET PELVIC */
"20177" = "1" /* HODG LYMPH DEPLET SPLEEN */
"20178" = "1" /* HODG LYMPH DEPLET MULT */
"20190" = "1" /* HDGK DIS UNSP XTRNDL ORG */
"20191" = "1" /* HODGKINS DIS NOS HEAD */
"20192" = "1" /* HODGKINS DIS NOS THORAX */
"20193" = "1" /* HODGKINS DIS NOS ABDOM */
"20194" = "1" /* HODGKINS DIS NOS AXILLA */
"20195" = "1" /* HODGKINS DIS NOS INGUIN */
"20196" = "1" /* HODGKINS DIS NOS PELVIC */
"20197" = "1" /* HODGKINS DIS NOS SPLEEN */
"20198" = "1" /* HODGKINS DIS NOS MULT */
"20200" = "1" /* NDLR LYM UNSP XTRNDL ORG */
"20201" = "1" /* NODULAR LYMPHOMA HEAD */
"20202" = "1" /* NODULAR LYMPHOMA THORAX */
"20203" = "1" /* NODULAR LYMPHOMA ABDOM */
"20204" = "1" /* NODULAR LYMPHOMA AXILLA */
"20205" = "1" /* NODULAR LYMPHOMA INGUIN */
"20206" = "1" /* NODULAR LYMPHOMA PELVIC */
"20207" = "1" /* NODULAR LYMPHOMA SPLEEN */
"20208" = "1" /* NODULAR LYMPHOMA MULT */
"20210" = "1" /* MYCS FNG UNSP XTRNDL ORG */
"20211" = "1" /* MYCOSIS FUNGOIDES HEAD */
"20212" = "1" /* MYCOSIS FUNGOIDES THORAX */
"20213" = "1" /* MYCOSIS FUNGOIDES ABDOM */
"20214" = "1" /* MYCOSIS FUNGOIDES AXILLA */
"20215" = "1" /* MYCOSIS FUNGOIDES INGUIN */
"20216" = "1" /* MYCOSIS FUNGOIDES PELVIC */
"20217" = "1" /* MYCOSIS FUNGOIDES SPLEEN */
"20218" = "1" /* MYCOSIS FUNGOIDES MULT */
"20220" = "1" /* SZRY DIS UNSP XTRNDL ORG */
"20221" = "1" /* SEZARYS DISEASE HEAD */
"20222" = "1" /* SEZARYS DISEASE THORAX */
"20223" = "1" /* SEZARYS DISEASE ABDOM */
"20224" = "1" /* SEZARYS DISEASE AXILLA */
"20225" = "1" /* SEZARYS DISEASE INGUIN */
"20226" = "1" /* SEZARYS DISEASE PELVIC */
"20227" = "1" /* SEZARYS DISEASE SPLEEN */
"20228" = "1" /* SEZARYS DISEASE MULT */
"20230" = "1" /* MLG HIST UNSP XTRNDL ORG */
"20231" = "1" /* MAL HISTIOCYTOSIS HEAD */
"20232" = "1" /* MAL HISTIOCYTOSIS THORAX */
"20233" = "1" /* MAL HISTIOCYTOSIS ABDOM */
"20234" = "1" /* MAL HISTIOCYTOSIS AXILLA */
"20235" = "1" /* MAL HISTIOCYTOSIS INGUIN */
"20236" = "1" /* MAL HISTIOCYTOSIS PELVIC */
"20237" = "1" /* MAL HISTIOCYTOSIS SPLEEN */
"20238" = "1" /* MAL HISTIOCYTOSIS MULT */
"20240" = "1" /* LK RTCTL UNSP XTRNDL ORG */
"20241" = "1" /* HAIRY-CELL LEUKEM HEAD */
"20242" = "1" /* HAIRY-CELL LEUKEM THORAX */
"20243" = "1" /* HAIRY-CELL LEUKEM ABDOM */
"20244" = "1" /* HAIRY-CELL LEUKEM AXILLA */
"20245" = "1" /* HAIRY-CELL LEUKEM INGUIN */
"20246" = "1" /* HAIRY-CELL LEUKEM PELVIC */
"20247" = "1" /* HAIRY-CELL LEUKEM SPLEEN */
"20248" = "1" /* HAIRY-CELL LEUKEM MULT */
"20250" = "1" /* LTR-SIWE UNSP XTRNDL ORG */
"20251" = "1" /* LETTERER-SIWE DIS HEAD */
"20252" = "1" /* LETTERER-SIWE DIS THORAX */
"20253" = "1" /* LETTERER-SIWE DIS ABDOM */
"20254" = "1" /* LETTERER-SIWE DIS AXILLA */
"20255" = "1" /* LETTERER-SIWE DIS INGUIN */
"20256" = "1" /* LETTERER-SIWE DIS PELVIC */
"20257" = "1" /* LETTERER-SIWE DIS SPLEEN */
"20258" = "1" /* LETTERER-SIWE DIS MULT */
"20260" = "1" /* MLG MAST UNSP XTRNDL ORG */
"20261" = "1" /* MAL MASTOCYTOSIS HEAD */
"20262" = "1" /* MAL MASTOCYTOSIS THORAX */
"20263" = "1" /* MAL MASTOCYTOSIS ABDOM */
"20264" = "1" /* MAL MASTOCYTOSIS AXILLA */
"20265" = "1" /* MAL MASTOCYTOSIS INGUIN */
"20266" = "1" /* MAL MASTOCYTOSIS PELVIC */
"20267" = "1" /* MAL MASTOCYTOSIS SPLEEN */
"20268" = "1" /* MAL MASTOCYTOSIS MULT */
"20280" = "1" /* OTH LYMP UNSP XTRNDL ORG */
"20281" = "1" /* LYMPHOMAS NEC HEAD */
"20282" = "1" /* LYMPHOMAS NEC THORAX */
"20283" = "1" /* LYMPHOMAS NEC ABDOM */
"20284" = "1" /* LYMPHOMAS NEC AXILLA */
"20285" = "1" /* LYMPHOMAS NEC INGUIN */
"20286" = "1" /* LYMPHOMAS NEC PELVIC */
"20287" = "1" /* LYMPHOMAS NEC SPLEEN */
"20288" = "1" /* LYMPHOMAS NEC MULT */
"20290" = "1" /* UNSP LYM UNSP XTRNDL ORG */
"20291" = "1" /* LYMPHOID MAL NEC HEAD */
"20292" = "1" /* LYMPHOID MAL NEC THORAX */
"20293" = "1" /* LYMPHOID MAL NEC ABDOM */
"20294" = "1" /* LYMPHOID MAL NEC AXILLA */
"20295" = "1" /* LYMPHOID MAL NEC INGUIN */
"20296" = "1" /* LYMPHOID MAL NEC PELVIC */
"20297" = "1" /* LYMPHOID MAL NEC SPLEEN */
"20298" = "1" /* LYMPHOID MAL NEC MULT */
"2030 " = "1" /* MULTIPLE MYELOMA */
"20300" = "1" /* MULT MYELM W/O REMISSION */
"20301" = "1" /* MULT MYELM W REMISSION */
"2031 " = "1" /* PLASMA CELL LEUKEMIA */
"20310" = "1" /* PLSM CELL LEUK W/O RMSON */
"20311" = "1" /* PLSM CELL LEUK W RMSON */
"2038 " = "1" /* IMMUNOPROLIFERAT NEO NEC */
"20380" = "1" /* OTH IMNPRFL NPL W/O RMSN */
"20381" = "1" /* OTH IMNPRFL NPL W RMSN */
"2040 " = "1" /* ACUTE LYMPHOID LEUKEMIA */
"20400" = "1" /* ACT LYM LEUK W/O RMSION */
"20401" = "1" /* ACT LYM LEUK W RMSION */
"2041 " = "1" /* CHR LYMPHOID LEUKEMIA */
"20410" = "1" /* CHR LYM LEUK W/O RMSION */
"20411" = "1" /* CHR LYM LEUK W RMSION */
"2042 " = "1" /* SUBAC LYMPHOID LEUKEMIA */
"20420" = "1" /* SBAC LYM LEUK W/O RMSION */
"20421" = "1" /* SBAC LYM LEUK W RMSION */
"2048 " = "1" /* LYMPHOID LEUKEMIA NEC */
"20480" = "1" /* OTH LYM LEUK W/O RMSION */
"20481" = "1" /* OTH LYM LEUK W RMSION */
"2049 " = "1" /* LYMPHOID LEUKEMIA NOS */
"20490" = "1" /* UNS LYM LEUK W/O RMSION */
"20491" = "1" /* UNS LYM LEUK W RMSION */
"2386 " = "1" /* NEOPLASM OF UNCERTAIN BEHAVIOR OF OTHER AND UNSPECIFIED SITES AND TISSUES, PLASMA CELLS */
"2733 " = "1" /* DISORDERS OF PLASMA PROTEIN METABOLISM-MACROGLOBULINEMIA */
OTHER  = "0" ;

/* STRATIFY BY: INTERMEDIATE RISK GROUP */
/* ICD-9-CM DIAGNOSIS CODES: */

/* HEMOPHILIA */

VALUE $HEMOPHD
"2860" = "1" /* CONG FACTOR VIII DIORD */
"2861" = "1" /* CONG FACTOR IX DISORDER */
"2862" = "1" /* CONG FACTOR XI DISORDER */
"2863" = "1" /* CONG DEF CLOT FACTOR NEC */
"2864" = "1" /* VON WILLEBRAND'S DISEASE */
OTHER  = "0" ;


 /* -------------------------------- */
 /* TRANSFUSION REACTION             */
 /*   PROVIDER INDICATOR / PDI # 13  */
 /*   AREA     INDICATOR / PSI # TBD */
 /* -------------------------------- */

 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $TRANFID
"9996"   = "1" /* ABO INCOMPATIBILITY REACTION */
"99960"  = "1" /* ABO INCOMPAT REACT NOS */
"99961"  = "1" /* ABO INCOMP/HTR NEC */
"99962"  = "1" /* ABO INCOMPAT/ACUTE HTR */
"99963"  = "1" /* ABO INCOMPAT/DELAY HTR */
"99969"  = "1" /* ABO INCOMPAT REACTN NEC */
"9997"   = "1" /* RH INCOMPATIBILITY REACTION */
"99970"  = "1" /* RH INCOMPAT REACTION NOS */
"99971"  = "1" /* RH INCOMP/HTR NEC */
"99972"  = "1" /* RH INCOMPAT/ACUTE HTR */
"99973"  = "1" /* RH INCOMPAT/DELAY HTR */
"99974"  = "1" /* RH INCOMPAT REACTION NEC */
OTHER   = "0" ;

 /* ------------------------------- */
 /* BIRTH TRAUMA                    */
 /*   PROVIDER INDICATOR / PSI # 17 */
 /* ------------------------------- */

 /* BIRTH TRAUMA */
 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $BIRTHID
"7670 " = "1" /* SUBDURAL AND CEREBRAL HEMORRHAGE (DUE TO TRAUMA OR TO INTRAPARTUM 
                 ANOXIA OR HYPOXIA) */
"76711" = "1" /* EPICRANIAL SUBAPO HEMORR */
"7673 " = "1" /* INJURIES TO SKELETON (EXCLUDES CLAVICLE) */
"7674 " = "1" /* INJURY TO SPINE AND SPINAL CORD */
"7675 " = "1" /* FACIAL NERVE INJ-BIRTH */
"7677 " = "1" /* OTHER CRANIAL AND PERIPHERAL NERVE INJURIES */
"7678 " = "1" /* OTHER SPECIFIED BIRTH TRAUMA */
OTHER   = "0" ;

 /* LIVEBORN */
 /* ICD-9-CM DIAGNOSIS CODES */

VALUE $LIVEBND
'V3000' = 1  /* SINGLE LB IN-HOSP W/O CS */
'V3001' = 1  /* SINGLE LB IN-HOSP W CS */
'V3100' = 1  /* TWIN-MATE LB-HOSP W/O CS */
'V3101' = 1  /* TWIN-MATE LB-IN HOS W CS */
'V3200' = 1  /* TWIN-MATE SB-HOSP W/O CS */
'V3201' = 1  /* TWIN-MATE SB-HOSP W CS */
'V3300' = 1  /* TWIN-NOS-IN HOSP W/O CS */
'V3301' = 1  /* TWIN-NOS-IN HOSP W CS */
'V3400' = 1  /* OTH MULT LB-HOSP W/O CS */
'V3401' = 1  /* OTH MULT LB-IN HOSP W CS */
'V3500' = 1  /* OTH MULT SB-HOSP W/O CS */
'V3501' = 1  /* OTH MULT SB-IN HOSP W CS */
'V3600' = 1  /* MULT LB/SB-IN HOS W/O CS */
'V3601' = 1  /* MULT LB/SB-IN HOSP W CS */
'V3700' = 1  /* MULT BRTH NOS-HOS W/O CS */
'V3701' = 1  /* MULT BIRTH NOS-HOSP W CS */
'V3900' = 1  /* LIVEBORN NOS-HOSP W/O CS */
'V3901' = 1  /* LIVEBORN NOS-HOSP W CS */
OTHER   = 0 ;

VALUE $V29D
"V290"  = "1" /* OBSERVATIONS FOR SUSPECTED INFECTIOUS CONDITION */
"V291"  = "1" /* OBSERVATIONS FOR SUSPECTED NEUROLOGICAL CONDITION */
"V292"  = "1" /* OBSERVATIONS FOR SUSPECTED RESPIRATORY CONDITION */
"V293"  = "1" /* OBSERVATIONS FOR SUSPECTED GENETIC OR METABOLIC CONDITION */
"V298"  = "1" /* OBSERVATIONS FOR OTHER SPECIFIED SUSPECTED CONDITION */
"V299"  = "1" /* OBSERVATIONS FOR UNSPECIFIED SUSPECTED CONDITION */
OTHER   = "0";

VALUE $LIVEB2D
'V301 ' = 1  /* SINGL LIVEBRN-BEFORE ADM */
'V302 ' = 1  /* SINGLE LIVEBORN-NONHOSP */
'V311 ' = 1  /* TWIN, MATE LB-BEFORE ADM */
'V312 ' = 1  /* TWIN, MATE LB-NONHOSP */
'V321 ' = 1  /* TWIN, MATE SB-BEFORE ADM */
'V322 ' = 1  /* TWIN, MATE SB-NONHOSP */
'V331 ' = 1  /* TWIN NOS-BEFORE ADMISSN */
'V332 ' = 1  /* TWIN NOS-NONHOSP */
'V341 ' = 1  /* OTH MULT NB-BEFORE ADM */
'V342 ' = 1  /* OTH MULTIPLE NB-NONHOSP */
'V351 ' = 1  /* OTH MULT SB-BEFORE ADM */
'V352 ' = 1  /* OTH MULTIPLE SB-NONHOSP */
'V361 ' = 1  /* MULT NB/SB-BEFORE ADM */
'V362 ' = 1  /* MULTIPLE NB/SB-NONHOSP */
'V371 ' = 1  /* MULT BRTH NOS-BEFORE ADM */
'V372 ' = 1  /* MULT BIRTH NOS-NONHOSP */
'V391 ' = 1  /* LIVEBORN NOS-BEFORE ADM */
'V392 ' = 1  /* LIVEBORN NOS-NONHOSP */
OTHER   = 0 ;

 /* BIRTH TRAUMA */
 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $BIRTIDA
"7670"  = "1" /* SUBDURAL AND CEREBRAL HEMORRHAGE (DUE TO TRAUMA OR TO INTRAPARTUM 
                 ANOXIA OR HYPOXIA) */
OTHER   = "0" ;

 /* EXCLUDE: PRETERM INFANT */
 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $PRETEID
"76500" = "1" /* EXTREME IMMATUR WTNOS */
"76501" = "1" /* EXTREME IMMATURITY, LESS THAN 500 GRAMS  */
"76502" = "1" /* EXTREME IMMATURITY, 500 - 749 GRAMS */
"76503" = "1" /* EXTREME IMMATURITY, 750 - 999 GRAMS  */
"76504" = "1" /* EXTREME IMMATURITY, 1000 - 1249 GRAMS  */
"76505" = "1" /* EXTREME IMMATURITY, 1250 - 1499 GRAMS */
"76506" = "1" /* EXTREME IMMATURITY, 1500 - 1749 GRAMS  */
"76507" = "1" /* EXTREME IMMATURITY, 1750 - 1999 GRAMS  */
"76511" = "1" /* OTHER PRETERM INFANTS, LESS THAN 500 GRAMS  */
"76512" = "1" /* OTHER PRETERM INFANTS, 500 - 749 GRAMS  */
"76513" = "1" /* OTHER PRETERM INFANTS, 750 - 999 GRAMS  */
"76514" = "1" /* OTHER PRETERM INFANTS, 1000 - 1249 GRAMS  */
"76515" = "1" /* OTHER PRETERM INFANTS, 1250 - 1499 GRAMS  */
"76516" = "1" /* OTHER PRETERM INFANTS, 1500 - 1749 GRAMS */
"76517" = "1" /* OTHER PRETERM INFANTS, 1750 - 1999 GRAMS  */
OTHER   = "0" ;

 /* BIRTH TRAUMA */
 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $BIRTIDB
"7673"  = "1" /* INJURIES TO SKELETON (EXCLUDES CLAVICLE) */
"7674"  = "1" /* INJURY TO SPINE AND SPINAL CORD */
OTHER   = "0" ;

 /* EXCLUDE: INJURY BRACHIAL PLEXUS */;
 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $BRACHID
"7676 "  = "1" /* BRACH PLEXUS INJ-BIRTH */
OTHER   = "0" ;

 /* EXCLUDE: OSTEOGENESIS IMPERFECTA */;
 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $OSTEOID
"75651" = "1" /* OSTEOGENESIS IMPERFECTA */
OTHER   = "0" ;

 /* BIRTH TRAUMA */
 /* ICD-9-CM DIAGNOSIS CODES: */

VALUE $BIRTIDC
"76711" = "1" /* EPICRANIAL SUBAPO HEMORR */
"7677"  = "1" /* OTHER CRANIAL AND PERIPHERAL NERVE INJURIES */
"7678"  = "1" /* OTHER SPECIFIED BIRTH TRAUMA */
"7679"  = "1" /* BIRTH TRAUMA, UNSPECIFIED */
OTHER   = "0" ;


 /* --------------------------------------------------------------- */
 /* ---   NEONATAL MORTALITY                                      - */
 /*          PROVIDER INDICATOR / NQI # 2                         - */
 /* --------------------------------------------------------------- */

VALUE $NEOMTDX
"7400"  = "1" /* ANENCEPHALUS */ 
"7401"  = "1" /* CRANIORACHISCHISIS */ 
"7402"  = "1" /* INIENCEPHALY */
"75314" = "1" /* Added 5.0: POLYCYST KID-AUTOSOM RECESSIVE */  
"7581"  = "1" /* Trisomy 13 (PATAUS SYNDROME) */
"7582"  = "1" /* Trisomy 18 (EDWARDS SYNDROME) */ 
OTHER   = "0";

 /* ---------------------------------------------------------------- */
 /* --- BLOOD STREAM INFECTION NEONATES                            - */
 /*        PROVIDER INDICATOR / NQI # 3                            - */
 /* ---------------------------------------------------------------- */

VALUE $GESTCD
"76522" = "1" /* 24 COMPLETED WEEKS OF GESTATION  */
"76523" = "1" /* 25-26 COMPLETED WEEKS OF GESTATION */
"76524" = "1" /* 27-28 COMPLETED WEEKS OF GESTATION */
"76525" = "1" /* 29-30 COMPLETED WEEKS OF GESTATION */
OTHER   = "0";

VALUE $GESTC1D
"76521" = "1" /* Less than 24 completed weeks of gestation  */
OTHER   = "0";
     
VALUE $GESTC2D
"76522" = "1" /* 24 COMPLETED WEEKS OF GESTATION  */
OTHER   = "0";

VALUE $GESTC3D
"76523" = "1" /* 25-26 COMPLETED WEEKS OF GESTATION */
OTHER   = "0";

VALUE $GESTC4D
"76524" = "1" /* 27-28 COMPLETED WEEKS OF GESTATION */
OTHER   = "0";

VALUE $GESTC5D
"76525" = "1" /* 29-30 COMPLETED WEEKS OF GESTATION */
OTHER   = "0";

VALUE $GESTC6D
"76526" = "1" /* 31-32 completed weeks of gestation */
OTHER   = "0";

VALUE $GESTC7D
"76527" = "1" /* 33-34 completed weeks of gestation */
OTHER   = "0";

VALUE $GESTC8D
"76528" = "1" /* 35-36 completed weeks of gestation */
OTHER   = "0";

VALUE $GESTC9D
"76529" = "1" /* 37 or more completed weeks of gestation */
OTHER   = "0";

VALUE $MECHVCD
"9670" = "1" /* CONTINUOUS MECHANICAL VENTILATION OF UNSPEC DURATION */
"9671" = "1" /* CONTINUOUS MECHANICAL VENTILATION FOR LESS THAN 96 CONSECUTIVE HRS */
"9672" = "1" /* CONTINUOUS MECHANICAL VENTILATION FOR 96 CONSECUTIVE HOURS OR MORE */
OTHER   = "0";


VALUE $BSI1DX
"03810" = "1" /* STAPHYLCOCC SEPTICEM NOS */
"03811" = "1" /* METH SUSC STAPH AUR SEPT */
"03812" = "1" /* MRSA SEPTICEMIA */
"03819" = "1" /* STAPHYLCOCC SEPTICEM NEC */
"03840" = "1" /* GRAM-NEG SEPTICEMIA NOS */
"03842" = "1" /* E COLI SEPTICEMIA */
"03843" = "1" /* PSEUDOMONAS SEPTICEMIA */
"03844" = "1" /* SERRATIA SEPTICEMIA */
"03849" = "1" /* GRAM-NEG SEPTICEMIA NEC */
"1125 " = "1" /* DISSEMINATED CANDIDIASIS */
OTHER   = "0" ;

VALUE $BSI2DX
"77181" = "1" /* NB SEPTICEMIA [SEPSIS] */
"77183" = "1" /* BACTEREMIA OF NEWBORN */
OTHER   = "0" ;

/* BACTERIAL AGENT                         */
/* ICD-9-CM Diagnosis Codes: */

VALUE $BSI3DX
"04104" = "1" /* ENTEROCOCCUS GROUP D */
"04110" = "1" /* STAPHYLOCOCCUS UNSPCFIED */
"04111" = "1" /* MTH SUS STPH AUR ELS/NOS */
"04112" = "1" /* MRSA ELSEWHERE/NOS */
"04119" = "1" /* OTHER STAPHYLOCOCCUS */
"0413 " = "1" /* KLEBSIELLA INFECT NOS */
"0414 " = "1" /* E. COLI INFECT NOS */
"04141" = "1" /* SHIGA TXN-PRODUCE E.COLI */
"04142" = "1" /* SHGA TXN PROD E.COLI NEC */
"04143" = "1" /* SHGA TXN PROD E.COLI NOS */
"04149" = "1" /* E.COLI INFECTION NEC/NOS */
"0417 " = "1" /* PSEUDOMONAS INFECT NOS */
"04185" = "1" /* OTH GRAM NEGATV BACTERIA */
OTHER   = "0" ;

VALUE $BSI4DX
"1125 " = "1" /* DISSEMINATED CANDIDIASIS */
"77181" = "1" /* NB SEPTICEMIA [SEPSIS] */
"77183" = "1" /* BACTEREMIA OF NEWBORN */
"7907 " = "1" /* BACTEREMIA */
OTHER   = "0" ;

VALUE $BSI5DX
"77181" = "1" /* NB SEPTICEMIA [SEPSIS] */
"77183" = "1" /* BACTEREMIA OF NEWBORN */
OTHER   = "0" ;


/*  Multiple Birth                    */
/* ICD-9-CM Diagnosis Codes: */

VALUE $MULTIPD
'65100' = '1'  /* TWIN PREGNANCY-UNSPEC */
'65101' = '1'  /* TWIN PREGNANCY-DELIVERED */
'65103' = '1'  /* TWIN PREGNANCY-ANTEPART */
'65110' = '1'  /* TRIPLET PREGNANCY-UNSPEC */
'65111' = '1'  /* TRIPLET PREGNANCY-DELIV */
'65113' = '1'  /* TRIPLET PREG-ANTEPARTUM */
'65120' = '1'  /* QUADRUPLET PREG-UNSPEC */
'65121' = '1'  /* QUADRUPLET PREG-DELIVER */
'65123' = '1'  /* QUADRUPLET PREG-ANTEPART */
'65130' = '1'  /* TWINS W FETAL LOSS-UNSP */
'65131' = '1'  /* TWINS W FETAL LOSS-DEL */
'65133' = '1'  /* TWINS W FETAL LOSS-ANTE */
'65140' = '1'  /* TRIPLETS W FET LOSS-UNSP */
'65141' = '1'  /* TRIPLETS W FET LOSS-DEL */
'65143' = '1'  /* TRIPLETS W FET LOSS-ANTE */
'65150' = '1'  /* QUADS W FETAL LOSS-UNSP */
'65151' = '1'  /* QUADS W FETAL LOSS-DEL */
'65153' = '1'  /* QUADS W FETAL LOSS-ANTE */
'65160' = '1'  /* MULT GES W FET LOSS-UNSP */
'65161' = '1'  /* MULT GES W FET LOSS-DEL */
'65163' = '1'  /* MULT GES W FET LOSS-ANTE */
'65180' = '1'  /* MULTI GESTAT NEC-UNSPEC */
'65181' = '1'  /* MULTI GESTAT NEC-DELIVER */
'65183' = '1'  /* MULTI GEST NEC-ANTEPART */
'65190' = '1'  /* MULTI GESTAT NOS-UNSPEC */
'65191' = '1'  /* MULT GESTATION NOS-DELIV */
'65193' = '1'  /* MULTI GEST NOS-ANTEPART */
'65260' = '1'  /* MULT GEST MALPRESEN-UNSP */
'65261' = '1'  /* MULT GEST MALPRES-DELIV */
'65263' = '1'  /* MULT GES MALPRES-ANTEPAR */
'66050' = '1'  /* LOCKED TWINS-UNSPECIFIED */
'66051' = '1'  /* LOCKED TWINS-DELIVERED */
'66053' = '1'  /* LOCKED TWINS-ANTEPARTUM */
'66230' = '1'  /* DELAY DEL 2ND TWIN-UNSP */
'66231' = '1'  /* DELAY DEL 2ND TWIN-DELIV */
'66233' = '1'  /* DELAY DEL 2 TWIN-ANTEPAR */
'7615 ' = '1'  /* MULT PREGNANCY AFF NB */
'V271 ' = '1'  /* DELIVER-SINGLE STILLBORN */
'V272 ' = '1'  /* DELIVER-TWINS, BOTH LIVE */
'V273 ' = '1'  /* DEL-TWINS, 1 NB, 1 SB */
'V274 ' = '1'  /* DELIVER-TWINS, BOTH SB */
'V275 ' = '1'  /* DEL-MULT BIRTH, ALL LIVE */
'V276 ' = '1'  /* DEL-MULT BRTH, SOME LIVE */
'V277 ' = '1'  /* DEL-MULT BIRTH, ALL SB */
OTHER  = '0' ;

/*  Congenital Anamolies */
/* ICD-9-CM Diagnosis Codes: */

VALUE $CONGN1D
'5602 ' = '1'
'7503 ' = '1'  
'7504 ' = '1'
'7505 ' = '1'
'7507 ' = '1'
'7508 ' = '1'
'7509 ' = '1'
'7510 ' = '1'
'7511 ' = '1'
'7512 ' = '1'
'7513 ' = '1'
'7514 ' = '1'
'7515 ' = '1'
'75160' = '1'
'75161' = '1'
'75169' = '1'
'7517 ' = '1'
'7518 ' = '1'
'7519 ' = '1'
'75670' = '1'
'75679' = '1'
'7711 ' = '1'
OTHER   = '0' ;

VALUE $CONGN2D
'7530 ' = '1'
'75310' = '1'
'75312' = '1'
'75314' = '1'
'75315' = '1'
'75319' = '1'
'75320' = '1'
'75321' = '1'
'75322' = '1'
'75323' = '1'
'7533 ' = '1'
'7534 ' = '1'
'7536 ' = '1'
'7537 ' = '1'
'7538 ' = '1'
'7539 ' = '1'
'75671' = '1'
OTHER   = '0' ;

VALUE $CONGN3D
'74100' = '1'
'74101' = '1'
'74102' = '1'
'74103' = '1'
'74190' = '1'
'74191' = '1'
'74192' = '1'
'74193' = '1'
'7420 ' = '1'
'7421 ' = '1'
'7422 ' = '1'
'7423 ' = '1'
'7424 ' = '1'
'74259' = '1'
'7428 ' = '1'
'7429 ' = '1'
OTHER   = '0' ;

VALUE $CONGN4D
'5194 ' = '1'
'5533 ' = '1'
'7483 ' = '1'
'7484 ' = '1'
'74860' = '1'
'74869' = '1'
'7488 ' = '1'
'7489 ' = '1'
'7506 ' = '1'
'7566 ' = '1'
OTHER   = '0' ;

VALUE $CONGN5D
'4240 ' = '1'
'4241 ' = '1'
'4251 ' = '1'
'4253 ' = '1'
'7450 ' = '1'
'74510' = '1'
'74511' = '1'
'74512' = '1'
'74519' = '1'
'7452 ' = '1'
'7453 ' = '1'
'74560' = '1'
'74561' = '1'
'74569' = '1'
'74601' = '1'
'74609' = '1'
'7461 ' = '1'
'7462 ' = '1'
'7463 ' = '1'
'7464 ' = '1'
'7465 ' = '1'
'7466 ' = '1'
'7467 ' = '1'
'74681' = '1'
'74682' = '1'
'74683' = '1'
'74684' = '1'
'74685' = '1'
'74710' = '1'
'74711' = '1'
'74721' = '1'
'74722' = '1'
'74729' = '1'
'74740' = '1'
'74741' = '1'
'74742' = '1'
'74749' = '1'
OTHER   = '0' ;

VALUE $CONGN6D
'75650' = '1'
'75651' = '1'
'75655' = '1'
'75659' = '1'
OTHER   = '0' ;

VALUE $CONGN7D
'7583 ' = '1'
'7585 ' = '1'
'75889' = '1'
'7589 ' = '1'
'7594 ' = '1'
'7597 ' = '1'
'75989' = '1'
'7599 ' = '1'
OTHER   = '0' ;
 
VALUE $CONGN8D
'7596 ' = '1'
'7765 ' = '1'
'7780 ' = '1'
OTHER   = '0' ;

 /* ---------------------------------------------- */
 /* Asthma rate (ACSAST)                           */
 /*   PDI #14                                      */
 /* ---------------------------------------------- */

 /* Asthma                    */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACSASTD
'49300' = "1"  /* EXT ASTHMA W/O STAT ASTH */
'49301' = "1"  /* EXT ASTHMA W STATUS ASTH */
'49302' = "1"  /* EXT ASTHMA W ACUTE EXAC */
'49310' = "1"  /* INT ASTHMA W/O STAT ASTH */
'49311' = "1"  /* INT ASTHMA W STATUS ASTH */
'49312' = "1"  /* INT ASTHMA W ACUTE EXAC */
'49320' = "1"  /* CH OB ASTH W/O STAT ASTH */
'49321' = "1"  /* CH OB ASTHMA W STAT ASTH */
'49322' = "1"  /* CH OBS ASTH W ACUTE EXAC */
'49381' = "1"  /* EXERCSE IND BRONCHOSPASM */
'49382' = "1"  /* COUGH VARIANT ASTHMA */
'49390' = "1"  /* ASTHMA W/O STATUS ASTHM */
'49391' = "1"  /* ASTHMA W STATUS ASTHMAT */
'49392' = "1"  /* ASTHMA W ACUTE EXACERBTN */
OTHER   = "0" ;

 /* Exclude: CYSTIC FIBROSIS      */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACSCYFD
'27700' = "1"  /* CYSTIC FIBROS W/O ILEUS */
'27701' = "1"  /* CYSTIC FIBROS W ILEUS */
'27702' = "1"  /* CYSTIC FIBROS W PUL MAN */
'27703' = "1"  /* CYSTIC FIBROSIS  W GI MAN */
'27709' = "1"  /* CYSTIC FIBROSIS NEC*/
OTHER   = "0" ;

 /* EXCLUDE: CYSTIC FIBROSIS AND ANOMALIES OF RESPIRATORY SYSTEM */
 /* ICD-9-CM DIAGNOSIS CODES */

VALUE $RESPAN
'27700' = 1  /* CYSTIC FIBROS W/O ILEUS */
'27701' = 1  /* CYSTIC FIBROS W ILEUS */
'27702' = 1  /* CYSTIC FIBROS W PUL MAN */
'27703' = 1  /* CYSTIC FIBROSIS  W GI MAN */
'27709' = 1  /* CYSTIC FIBROSIS NEC */
'51661' = 1  /* NEUROENDOCRINE CELL HYPERPLASIA OF INFANCY */
'51662' = 1  /* PULMONARY INTERSTITIAL GLYCOGENESIS */
'51663' = 1  /* SURFACTANT MUTATIONS OF THE LUNG*/
'51664' = 1  /* ALVEOLAT CAPILLARY DYSPLASIA WITH VEIN MISALIGNMENT*/
'51669' = 1  /* OTHER INTERSTITIAL LUNG DISEASES OF THE CHILDHOOD */
'74721' = 1  /* ANOMALIES OF AORTIC ARCH */
'7483 ' = 1  /* LARYNGOTRACH ANOMALY NEC */
'7484 ' = 1  /* CONGENITAL CYSTIC LUNG */
'7485 ' = 1  /* AGENESIS OF LUNG */
'74860' = 1  /* LUNG ANOMALY NOS */
'74861' = 1  /* CONGEN BRONCHIECTASIS */
'74869' = 1  /* LUNG ANOMALY NEC */
'7488 ' = 1  /* RESPIRATORY ANOMALY NEC */
'7489 ' = 1  /* RESPIRATORY ANOMALY NOS */
'7503 ' = 1  /* CONG ESOPH FISTULA/ATRES */
'7593 ' = 1  /* SITUS INVERSUS */
'7707 ' = 1  /* PERINATAL CHR RESP DIS*/
OTHER   = 0;


 /* ---------------------------------------------- */
 /* Diabetes short term complication rate (ACDIAS) */
 /*   PDI #15                                      */
 /* ---------------------------------------------- */

 /* Diabetes with Short Term Complications */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACDIASD
'25010' = "1"  /* DM KETO T2, DM CONT */
'25011' = "1"  /* DM KETO T1, DM CONT */
'25012' = "1"  /* DM KETO T2, DM UNCONT */
'25013' = "1"  /* DM KETO T1, DM UNCONT */
'25020' = "1"  /* DM W/ HYPROSM T2, DM CONT */
'25021' = "1"  /* DM W/ HYPROSM T1, DM CONT */
'25022' = "1"  /* DM W/ HYPROSM T2, DM UNCNT */
'25023' = "1"  /* DM W/ HYPROSM T1, DM UNCNT */
'25030' = "1"  /* DM COMA NEC TYP II, DM CNT */
'25031' = "1"  /* DM COMA NEC T1, DM CONT */
'25032' = "1"  /* DM COMA NEC T2, DM UNCONT */
'25033' = "1"  /* DM COMA NEC T1, DM UNCONT */
OTHER   = "0" ;


 /* ---------------------------------------------- */
 /* Pediatric Gastroenteritis rate (ACPGAS)        */
 /*   PDI #16                                      */
 /* ---------------------------------------------- */

 /* Gastroenteritis */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACPGASD
'00861' = "1"  /* INTES INFEC ROTAVIRUS */
'00862' = "1"  /* INTES INFEC ADENOVIRUS */
'00863' = "1"  /* INT INF NORWALK VIRUS */
'00864' = "1"  /* INT INF OTH SML RND VRUS */
'00865' = "1"  /* INTES INFEC CALCIVIRUS */
'00866' = "1"  /* INTES INFEC ASTROVIRUS */
'00867' = "1"  /* INT INF ENTEROVIRUS NEC */
'00869' = "1"  /* ENTERITIS NOS  */
'0088 ' = "1"  /* VIRAL ENTERITIS NOS */
'0090 ' = "1"  /* INFECTIOUS ENTERITIS NOS */
'0091 ' = "1"  /* ENTERITIS OF INFECT ORIG */
'0092 ' = "1"  /* INFECTIOUS DIARRHEA NOS */
'0093 ' = "1"  /* DIARRHEA OF INFECT ORIG */
'5589 ' = "1"  /* NONINF GASTROENTERIT NEC */
OTHER   = "0" ;

 /* Dehydration */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACSDEHD
'2765 ' = "1"  /* HYPOVOLEMIA */
'27650' = "1"  /* VOLUME DEPLETION NOS */    
'27651' = "1"  /* DEHYDRATION */             
'27652' = "1"  /* HYPOVOLEMIA */             
OTHER   = "0" ;

/* EXCLUDE: */
/* Gastrintestinal Abnormalities */
/* ICD-9-CM Diagnosis Codes: */

VALUE $ACGDISD
'53570' = "1"  /* EOSINOPHIL GASTRT WO HEM */
'53571' = "1"  /* EOSINOPHILC GASTRT W HEM */
'538  ' = "1"  /* GI MUCOSITIS (ULCERATVE) */
'5550 ' = "1"  /* REGIONAL ENTERITIS, SMALL INTESTINE */
'5551 ' = "1"  /* REGIONAL ENTERITIS, LARGE INTESTINE */
'5552 ' = "1"  /* REGIONAL ENTERITIS, SMALL INTESTINE WITH LARGE INTESTINE */
'5559 ' = "1"  /* REGIONAL ENTERITIS, UNSPECIFIED SITE */
'5560 ' = "1"  /* ULCERATIVE CHRONIC ENTEROCOLITIS */
'5561 ' = "1"  /* ULCERATIVE CHRONIC ILEOCOLITIS */
'5562 ' = "1"  /* ULCERATIVE CHRONIC PROCTITIS */
'5563 ' = "1"  /* ULCERATIVE CHRONIC PROCTOSIGMOIDITIS */
'5564 ' = "1"  /* PSEUDOPOLYPOSIS OF COLON */
'5565 ' = "1"  /* LEFT-SIDED ULCERATIVE CHRONIC COLITIS */
'5566 ' = "1"  /* UNIVERSAL ULCERATIVE CHRONIC COLITIS */
'5568 ' = "1"  /* OTHER ULCERATIVE COLITIS */
'5569 ' = "1"  /* ULCERATIVE COLITIS NOS */
'5581 ' = "1"  /* GASTROENTERITIS AND COLITIS DUE TO RADIATION */
'5582 ' = "1"  /* TOXIC GASTROENTERITIS AND COLITIS */
'5583 ' = "1"  /* ALLERGIC GASTROENTERITIS AND COLITIS */
'55841' = "1"  /* EOSINOPHILIC GASTROENT */
'55842' = "1"  /* EOSINOPHILIC COLITIS */
'5790 ' = "1"  /* CELIAC DISEASE */
'5791 ' = "1"  /* TROPICAL SPRUE */
'5792 ' = "1"  /* BLIND LOOP SYNDROME */
'5793 ' = "1"  /* OTHER AND UNSPECIFIED POSTSURGICAL NONABSORPTION */
'5794 ' = "1"  /* PANCREATIC STEATORRHEA */
'5798 ' = "1"  /* OTHER SPECIFIED INTESTINAL MALABSORPTION */
'5799 ' = "1"  /* UNSPECIFIED INTESTINAL MALABSORPTION */
OTHER   = "0" ;

/* Bacterial Gastoenteritis  */
/* ICD-9-CM Diagnosis Codes: */

VALUE $ACBACGD
'0030 ' = "1"  /* SALMONELLA GASTROENTERITIS */
'0040 ' = "1"  /* SHIGELLA DYSENTERIAE */
'0041 ' = "1"  /* SHIGELLA FLEXNERI */
'0042 ' = "1"  /* SHIGELLA BOYDII */
'0043 ' = "1"  /* SHIGELLA SONNEI */
'0048 ' = "1"  /* OTHER SPECIFIED SHIGELLA INFECTIONS */
'0049 ' = "1"  /* SHIGELLOSIS, NOS */
'0050 ' = "1"  /* STAPHYLOCOCCAL FOOD POISONING */
'0051 ' = "1"  /* BOTULISM */
'0052 ' = "1"  /* FOOD POISONING DUE TO CLOSTRIDIUM PERFRINGENS  */
'0053 ' = "1"  /* FOOD POISONING DUE TO OTHER CLOSTRIDIA */
'0054 ' = "1"  /* FOOD POISONING DUE TO VIBRIO PARAHAEMOLYTICUS */
'0058 ' = "1"  /* OTHER BACTERIAL FOOD POISONING */
'00581' = "1"  /* FOOD POISONING DUE TO VIBRIO VULNIFICUS */
'00589' = "1"  /* OTHER BACTERIAL FOOD POISONING */
'0059 ' = "1"  /* FOOD POISONING NOS */
'0060 ' = "1"  /* ACUTE AMEBIC DYSENTERY WO MENTION OF ABSCESS */
'0061 ' = "1"  /* CHRONIC INTESTINAL AMEBIASIS WO MENTION OF ABSCESS */
'0070 ' = "1"  /* BALANTIDIASIS */
'0071 ' = "1"  /* GIARDIASIS */
'0072 ' = "1"  /* COCCIDIOSIS */
'0073 ' = "1"  /* INTESTINAL TRICHOMONIASIS */
'0074 ' = "1"  /* CRYPTOSPORIDIOSIS */
'0075 ' = "1"  /* CYCLOSPORIASIS */
'0078 ' = "1"  /* OTHER SPECIFIED PROTOZOAL INTESTINAL DISEASES */
'0079 ' = "1"  /* UNSPECIFIED PROTOZOAL INTESTINAL DISEASE */
'0080 ' = "1"  /* ESCHERICHIA COLI */
'00800' = "1"  /* E. COLI NOS */
'00801' = "1"  /* ENTEROPATHOGENIC E. COLI */
'00802' = "1"  /* ENTEROTOXIGENIC E. COLI */
'00803' = "1"  /* ENTEROINVASIVE E. COLI */
'00804' = "1"  /* ENTEROHEMORRHAGE E. COLI */
'00809' = "1"  /* OTHER INTESTINAL E. COLI INFECTIONS */
'0081 ' = "1"  /* ARIZONA GROUP OF PARACOLON BACILLI */
'0082 ' = "1"  /* AEROBACTER AEROGENES */
'0083 ' = "1"  /* PROTEUS  */
'0084 ' = "1"  /* OTHER SPECIFIED BACTERIA  */
'00841' = "1"  /* OTHER SPECIFIED BACTERIA, STAPHYLOCOCCUS */
'00842' = "1"  /* OTHER SPECIFIED BACTERIA, PSEUDOMONAS */
'00843' = "1"  /* OTHER SPECIFIED BACTERIA, CAMPYLOBACTER */
'00844' = "1"  /* OTHER SPECIFIED BACTERIA, YERSINIA ENTEROCOLITICA */
'00845' = "1"  /* OTHER SPECIFIED BACTERIA, CLOSTRIDIUM DIFFICILE */
'00846' = "1"  /* OTHER SPECIFIED BACTERIA, OTHER ANAEROBES */
'00847' = "1"  /* OTHER SPECIFIED BACTERIA, OTHER GRAM-NEGATIVE BACTERIA */
'00849' = "1"  /* OTHER SPECIFIED BACTERIA, OTHER */
'0085 ' = "1"  /* BACTERIAL ENTERITIS, NOS */
'11285' = "1"  /* CANDIDAL ENTERITIS */
OTHER   = "0" ;


 /* ---------------------------------------------- */
 /* Perforated Appendix rate (ACSAPP)              */
 /*   PDI #17                                      */
 /* ---------------------------------------------- */

 /* Perforated Appendix (Outcome of Interest) */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACSAPPD
'5400 ' = "1"  /* AC APPEND W PERITONITIS */
'5401 ' = "1"  /* ABSCESS OF APPENDIX */
OTHER   = "0" ;

 /* Appendicitis (Population at Risk) */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACSAP2D
'5400 ' = "1"  /* AC APPEND W PERITONITIS */
'5401 ' = "1"  /* ABSCESS OF APPENDIX */
'5409 ' = "1"  /* ACUTE APPENDICITIS NOS */
'541  ' = "1"  /* APPENDICITIS NOS */
OTHER   = "0" ;


 /* ---------------------------------------------- */
 /* Urinary Infection rate (ACSUTI)                */
 /*   PDI #18                                      */
 /* ---------------------------------------------- */

 /* Urinary Infection */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACSUTID
'59010' = "1"  /* AC PYELONEPHRITIS NOS */
'59011' = "1"  /* AC PYELONEPHR W MED NECR */
'5902 ' = "1"  /* RENAL/PERIRENAL ABSCESS */
'5903 ' = "1"  /* PYELOURETERITIS CYSTICA */
'59080' = "1"  /* PYELONEPHRITIS NOS */
'59081' = "1"  /* PYELONEPHRIT IN OTH DIS */
'5909 ' = "1"  /* INFECTION OF KIDNEY NOS */
'5950 ' = "1"  /* ACUTE CYSTITIS */
'5959 ' = "1"  /* CYSTITIS NOS */
'5990 ' = "1"  /* URIN TRACT INFECTION NOS */
OTHER   = "0" ;

 /* EXCLUDE: KIDNEY OR URINARY TRACT DISORDER */
 /* ICD-9-CM DIAGNOSIS CODES */

VALUE $KIDNEY
'59000' = 1  /* CHR PYELONEPHRITIS NOS */
'59001' = 1  /* CHR PYELONEPH W MED NECR */
'59370' = 1  /* VESCOURETRL RFLUX UNSPCF */
'59371' = 1  /* VESICOURETERAL REFLUX UNILTRL */
'59372' = 1  /* VESICOURETERAL REFLUX NPHT BLTRL */
'59373' = 1  /* VESICOURETERAL REFLUX W NPHT NOS */
'7530 ' = 1  /*  RENAL AGENESIS */
'75310' = 1  /* CYSTIC KIDNEY DISEAS NOS */
'75311' = 1  /* CONGENITAL RENAL CYST */
'75312' = 1  /* POLYCYSTIC KIDNEY NOS */
'75313' = 1  /* POLYCYST KID-AUTOSOM DOM */
'75314' = 1  /* POLYCYST KID-AUTOSOM REC */
'75315' = 1  /* RENAL DYSPLASIA */
'75316' = 1  /* MEDULLARY CYSTIC KIDNEY */
'75317' = 1  /* MEDULLARY SPONGE KIDNEY */
'75319' = 1  /* CYSTIC KIDNEY DISEAS NEC */
'75320' = 1  /* OBS DFCT REN PLV&URT NOS */
'75321' = 1  /* CONGEN OBST URTROPLV JNC */
'75322' = 1  /* CONG OBST URETEROVES JNC */
'75323' = 1  /* CONGENITAL URETEROCELE */
'75329' = 1  /* OBST DEF REN PLV&URT NEC */
'7533 ' = 1  /*  KIDNEY ANOMALY NEC */
'7534 ' = 1  /*  URETERAL ANOMALY NEC */
'7535 ' = 1  /*  EXSTROPHY OF URNIARY BLADDER */
'7536 ' = 1  /*  ATRESIA AND STENOSIS OF URETHRA AND BLADDER NECK */
'7538 ' = 1  /*  CYSTOURETHRAL ANOM NEC */
'7539 ' = 1  /*  URINARY ANOMALY NOS */
OTHER   = 0;


 /* Low Birth Weight (Outcome of Interest) */
 /* ICD-9-CM Diagnosis Codes:              */

VALUE $ACSLBWD
'76400' = 1  /* LIGHT-FOR-DATES WTNOS */
'76401' = 1  /* LIGHT-FOR-DATES <500G */
'76402' = 1  /* LT-FOR-DATES 500-749G */
'76403' = 1  /* LT-FOR-DATES 750-999G */
'76404' = 1  /* LT-FOR-DATES 1000-1249G */
'76405' = 1  /* LT-FOR-DATES 1250-1499G */
'76406' = 1  /* LT-FOR-DATES 1500-1749G */
'76407' = 1  /* LT-FOR-DATES 1750-1999G */
'76408' = 1  /* LT-FOR-DATES 2000-2499G */
'76410' = 1  /* LT-FOR-DATE W/MAL WTNOS */
'76411' = 1  /* LT-FOR-DATE W/MAL <500G */
'76412' = 1  /* LT-DATE W/MAL 500-749G */
'76413' = 1  /* LT-DATE W/MAL 750-999G */
'76414' = 1  /* LT-DATE W/MAL 1000-1249G */
'76415' = 1  /* LT-DATE W/MAL 1250-1499G */
'76416' = 1  /* LT-DATE W/MAL 1500-1749G */
'76417' = 1  /* LT-DATE W/MAL 1750-1999G */
'76418' = 1  /* LT-DATE W/MAL 2000-2499G */
'76420' = 1  /* FETAL MALNUTRITION WTNOS */
'76421' = 1  /* FETAL MALNUTRITION <500G */
'76422' = 1  /* FETAL MALNUTR 500-749G */
'76423' = 1  /* FETAL MAL 750-999G */
'76424' = 1  /* FETAL MAL 1000-1249G */
'76425' = 1  /* FETAL MAL 1250-1499G */
'76426' = 1  /* FETAL MAL 1500-1749G */
'76427' = 1  /* FETAL MALNUTR 1750-1999G */
'76428' = 1  /* FETAL MALNUTR 2000-2499G */
'76490' = 1  /* FET GROWTH RETARD WTNOS */
'76491' = 1  /* FET GROWTH RETARD <500G */
'76492' = 1  /* FET GROWTH RET 500-749G */
'76493' = 1  /* FET GROWTH RET 750-999G */
'76494' = 1  /* FET GRWTH RET 1000-1249G */
'76495' = 1  /* FET GRWTH RET 1250-1499G */
'76496' = 1  /* FET GRWTH RET 1500-1749G */
'76497' = 1  /* FET GRWTH RET 1750-1999G */
'76498' = 1  /* FET GRWTH RET 2000-2499G */
'76500' = 1  /* EXTREME IMMATUR WTNOS */
'76501' = 1  /* EXTREME IMMATUR <500G */
'76502' = 1  /* EXTREME IMMATUR 500-749G */
'76503' = 1  /* EXTREME IMMATUR 750-999G */
'76504' = 1  /* EXTREME IMMAT 1000-1249G */
'76505' = 1  /* EXTREME IMMAT 1250-1499G */
'76506' = 1  /* EXTREME IMMAT 1500-1749G */
'76507' = 1  /* EXTREME IMMAT 1750-1999G */
'76508' = 1  /* EXTREME IMMAT 2000-2499G */
'76510' = 1  /* PRETERM INFANT NEC WTNOS */
'76511' = 1  /* PRETERM NEC <500G */
'76512' = 1  /* PRETERM NEC 500-749G */
'76513' = 1  /* PRETERM NEC 750-999G */
'76514' = 1  /* PRETERM NEC 1000-1249G */
'76515' = 1  /* PRETERM NEC 1250-1499G */
'76516' = 1  /* PRETERM NEC 1500-1749G */
'76517' = 1  /* PRETERM NEC 1750-1999G */
'76518' = 1  /* PRETERM NEC 2000-2499G */
OTHER   = 0 ;


 * ----------------------------------------------------- ;
 * ---   AREA FORMATS     ------------------------------ ;
 * ---   TRANSLATES FIPS STATE AND COUNTY CODE (SSCCC)   ;
 * ---   TO MSA (METROPOLITAN STATISTICAL AREA)          ;
 * ----------------------------------------------------- ;

/* MODIFIED FIPS */

VALUE $M1AREA
'02013' = '02001'
'02016' = '02001'
'02020' = '02001'
'02050' = '02001'
'02060' = '02001'
'02068' = '02001'
'02070' = '02001'
'02090' = '02001'
'02100' = '02001'
'02110' = '02001'
'02122' = '02001'
'02130' = '02001'
'02150' = '02001'
'02164' = '02001'
'02170' = '02001'
'02180' = '02001'
'02185' = '02001'
'02188' = '02001'
'02201' = '02001'
'02220' = '02001'
'02232' = '02001'
'02240' = '02001'
'02261' = '02001'
'02270' = '02001'
'02280' = '02001'
'02282' = '02001'
'02290' = '02001'
'15005' = '15009'
'24510' = '24007'
'29510' = '29191'
'32510' = '32025'
'51515' = '51019'
'51520' = '51119'
'51530' = '51163'
'51540' = '51003'
'51560' = '51005'
'51570' = '51041'
'51580' = '51005'
'51590' = '51143'
'51595' = '51081'
'51600' = '51059'
'51610' = '51059'
'51620' = '51175'
'51630' = '51177'
'51640' = '51077'
'51660' = '51165'
'51670' = '51149'
'51678' = '51163'
'51680' = '51031'
'51683' = '51153'
'51685' = '51153'
'51690' = '51089'
'51710' = '51129'
'51720' = '51195'
'51730' = '51053'
'51735' = '51199'
'51740' = '51129'
'51750' = '51121'
'51760' = '51087'
'51770' = '51161'
'51775' = '51161'
'51780' = '51083'
'51790' = '51015'
'51800' = '51123'
'51820' = '51015'
'51830' = '51095'
'51840' = '51069'
;

/* OMB 1999 METRO AREA */

VALUE $M2AREA
'01001' = '5240 '
'01003' = '5160 '
'01009' = '1000 '
'01015' = '0450 '
'01033' = '2650 '
'01045' = '2180 '
'01051' = '5240 '
'01055' = '2880 '
'01069' = '2180 '
'01073' = '1000 '
'01077' = '2650 '
'01079' = '2030 '
'01081' = '0580 '
'01083' = '3440 '
'01089' = '3440 '
'01097' = '5160 '
'01101' = '5240 '
'01103' = '2030 '
'01113' = '1800 '
'01115' = '1000 '
'01117' = '1000 '
'01125' = '8600 '
'02020' = '0380 '
'04005' = '2620 '
'04013' = '6200 '
'04015' = '4120 '
'04019' = '8520 '
'04021' = '6200 '
'04027' = '9360 '
'05007' = '2580 '
'05031' = '3700 '
'05033' = '2720 '
'05035' = '4920 '
'05045' = '4400 '
'05069' = '6240 '
'05085' = '4400 '
'05091' = '8360 '
'05119' = '4400 '
'05125' = '4400 '
'05131' = '2720 '
'05143' = '2580 '
'06001' = '5775 '
'06007' = '1620 '
'06013' = '5775 '
'06017' = '6920 '
'06019' = '2840 '
'06029' = '0680 '
'06037' = '4480 '
'06039' = '2840 '
'06041' = '7360 '
'06047' = '4940 '
'06053' = '7120 '
'06055' = '8720 '
'06059' = '5945 '
'06061' = '6920 '
'06065' = '6780 '
'06067' = '6920 '
'06071' = '6780 '
'06073' = '7320 '
'06075' = '7360 '
'06077' = '8120 '
'06079' = '7460 '
'06081' = '7360 '
'06083' = '7480 '
'06085' = '7400 '
'06087' = '7485 '
'06089' = '6690 '
'06095' = '8720 '
'06097' = '7500 '
'06099' = '5170 '
'06101' = '9340 '
'06107' = '8780 '
'06111' = '8735 '
'06113' = '9270 '
'06115' = '9340 '
'08001' = '2080 '
'08005' = '2080 '
'08013' = '1125 '
'08031' = '2080 '
'08035' = '2080 '
'08041' = '1720 '
'08059' = '2080 '
'08069' = '2670 '
'08077' = '2995 '
'08101' = '6560 '
'08123' = '3060 '
'09001' = '5483 '
'09003' = '3283 '
'09007' = '3283 '
'09009' = '5483 '
'09011' = '5523 '
'09013' = '3283 '
'10001' = '2190 '
'10003' = '9160 '
'11001' = '8840 '
'12001' = '2900 '
'12005' = '6015 '
'12009' = '4900 '
'12011' = '2680 '
'12015' = '6580 '
'12019' = '3600 '
'12021' = '5345 '
'12031' = '3600 '
'12033' = '6080 '
'12035' = '2020 '
'12039' = '8240 '
'12053' = '8280 '
'12057' = '8280 '
'12069' = '5960 '
'12071' = '2700 '
'12073' = '8240 '
'12081' = '7510 '
'12083' = '5790 '
'12085' = '2710 '
'12086' = '5000 '
'12089' = '3600 '
'12091' = '2750 '
'12095' = '5960 '
'12097' = '5960 '
'12099' = '8960 '
'12101' = '8280 '
'12103' = '8280 '
'12105' = '3980 '
'12109' = '3600 '
'12111' = '2710 '
'12113' = '6080 '
'12115' = '7510 '
'12117' = '5960 '
'12127' = '2020 '
'13013' = '0520 '
'13015' = '0520 '
'13021' = '4680 '
'13029' = '7520 '
'13045' = '0520 '
'13047' = '1560 '
'13051' = '7520 '
'13053' = '1800 '
'13057' = '0520 '
'13059' = '0500 '
'13063' = '0520 '
'13067' = '0520 '
'13073' = '0600 '
'13077' = '0520 '
'13083' = '1560 '
'13089' = '0520 '
'13095' = '0120 '
'13097' = '0520 '
'13103' = '7520 '
'13113' = '0520 '
'13117' = '0520 '
'13121' = '0520 '
'13135' = '0520 '
'13145' = '1800 '
'13151' = '0520 '
'13153' = '4680 '
'13169' = '4680 '
'13177' = '0120 '
'13189' = '0600 '
'13195' = '0500 '
'13215' = '1800 '
'13217' = '0520 '
'13219' = '0500 '
'13223' = '0520 '
'13225' = '4680 '
'13227' = '0520 '
'13245' = '0600 '
'13247' = '0520 '
'13255' = '0520 '
'13289' = '4680 '
'13295' = '1560 '
'13297' = '0520 '
'15003' = '3320 '
'16001' = '1080 '
'16005' = '6340 '
'16027' = '1080 '
'17007' = '6880 '
'17019' = '1400 '
'17027' = '7040 '
'17031' = '1600 '
'17037' = '1600 '
'17043' = '1600 '
'17063' = '1600 '
'17073' = '1960 '
'17083' = '7040 '
'17089' = '1600 '
'17091' = '3740 '
'17093' = '1600 '
'17097' = '1600 '
'17111' = '1600 '
'17113' = '1040 '
'17115' = '2040 '
'17119' = '7040 '
'17129' = '7880 '
'17133' = '7040 '
'17141' = '6880 '
'17143' = '6120 '
'17161' = '1960 '
'17163' = '7040 '
'17167' = '7880 '
'17179' = '6120 '
'17197' = '1600 '
'17201' = '6880 '
'17203' = '6120 '
'18001' = '2760 '
'18003' = '2760 '
'18011' = '3480 '
'18019' = '4520 '
'18021' = '8320 '
'18023' = '3920 '
'18029' = '1640 '
'18033' = '2760 '
'18035' = '5280 '
'18039' = '2330 '
'18043' = '4520 '
'18057' = '3480 '
'18059' = '3480 '
'18061' = '4520 '
'18063' = '3480 '
'18067' = '3850 '
'18069' = '2760 '
'18081' = '3480 '
'18089' = '2960 '
'18095' = '3480 '
'18097' = '3480 '
'18105' = '1020 '
'18109' = '3480 '
'18115' = '1640 '
'18127' = '2960 '
'18129' = '2440 '
'18141' = '7800 '
'18143' = '4520 '
'18145' = '3480 '
'18157' = '3920 '
'18159' = '3850 '
'18163' = '2440 '
'18165' = '8320 '
'18167' = '8320 '
'18173' = '2440 '
'18179' = '2760 '
'18183' = '2760 '
'19013' = '8920 '
'19049' = '2120 '
'19061' = '2200 '
'19103' = '3500 '
'19113' = '1360 '
'19153' = '2120 '
'19155' = '5920 '
'19163' = '1960 '
'19181' = '2120 '
'19193' = '7720 '
'20015' = '9040 '
'20045' = '4150 '
'20079' = '9040 '
'20091' = '3760 '
'20103' = '3760 '
'20121' = '3760 '
'20173' = '9040 '
'20177' = '8440 '
'20209' = '3760 '
'21015' = '1640 '
'21017' = '4280 '
'21019' = '3400 '
'21029' = '4520 '
'21037' = '1640 '
'21043' = '3400 '
'21047' = '1660 '
'21049' = '4280 '
'21059' = '5990 '
'21067' = '4280 '
'21077' = '1640 '
'21081' = '1640 '
'21089' = '3400 '
'21101' = '2440 '
'21111' = '4520 '
'21113' = '4280 '
'21117' = '1640 '
'21151' = '4280 '
'21185' = '4520 '
'21191' = '1640 '
'21209' = '4280 '
'21239' = '4280 '
'22001' = '3880 '
'22005' = '0760 '
'22015' = '7680 '
'22017' = '7680 '
'22019' = '3960 '
'22033' = '0760 '
'22051' = '5560 '
'22055' = '3880 '
'22057' = '3350 '
'22063' = '0760 '
'22071' = '5560 '
'22073' = '5200 '
'22075' = '5560 '
'22079' = '0220 '
'22087' = '5560 '
'22089' = '5560 '
'22093' = '5560 '
'22095' = '5560 '
'22097' = '3880 '
'22099' = '3880 '
'22103' = '5560 '
'22109' = '3350 '
'22119' = '7680 '
'22121' = '0760 '
'23001' = '4243 '
'23005' = '6403 '
'23019' = '0733 '
'24001' = '1900 '
'24003' = '0720 '
'24005' = '0720 '
'24009' = '8840 '
'24013' = '0720 '
'24015' = '9160 '
'24017' = '8840 '
'24021' = '8840 '
'24025' = '0720 '
'24027' = '0720 '
'24031' = '8840 '
'24033' = '8840 '
'24035' = '0720 '
'24043' = '3180 '
'24510' = '0720 '
'25001' = '0743 '
'25003' = '6323 '
'25005' = '1123 '
'25009' = '1123 '
'25013' = '8003 '
'25015' = '8003 '
'25017' = '1123 '
'25021' = '1123 '
'25023' = '1123 '
'25025' = '1123 '
'25027' = '1123 '
'26005' = '3000 '
'26017' = '6960 '
'26021' = '0870 '
'26025' = '3720 '
'26037' = '4040 '
'26045' = '4040 '
'26049' = '2640 '
'26065' = '4040 '
'26075' = '3520 '
'26077' = '3720 '
'26081' = '3000 '
'26087' = '2160 '
'26091' = '0440 '
'26093' = '0440 '
'26099' = '2160 '
'26111' = '6960 '
'26115' = '2160 '
'26121' = '3000 '
'26125' = '2160 '
'26139' = '3000 '
'26145' = '6960 '
'26147' = '2160 '
'26159' = '3720 '
'26161' = '0440 '
'26163' = '2160 '
'27003' = '5120 '
'27009' = '6980 '
'27019' = '5120 '
'27025' = '5120 '
'27027' = '2520 '
'27037' = '5120 '
'27053' = '5120 '
'27055' = '3870 '
'27059' = '5120 '
'27109' = '6820 '
'27119' = '2985 '
'27123' = '5120 '
'27137' = '2240 '
'27139' = '5120 '
'27141' = '5120 '
'27145' = '6980 '
'27163' = '5120 '
'27171' = '5120 '
'28033' = '4920 '
'28035' = '3285 '
'28045' = '0920 '
'28047' = '0920 '
'28049' = '3560 '
'28059' = '0920 '
'28073' = '3285 '
'28089' = '3560 '
'28121' = '3560 '
'29003' = '7000 '
'29019' = '1740 '
'29021' = '7000 '
'29037' = '3760 '
'29043' = '7920 '
'29047' = '3760 '
'29049' = '3760 '
'29071' = '7040 '
'29077' = '7920 '
'29095' = '3760 '
'29097' = '3710 '
'29099' = '7040 '
'29107' = '3760 '
'29113' = '7040 '
'29145' = '3710 '
'29165' = '3760 '
'29177' = '3760 '
'29183' = '7040 '
'29189' = '7040 '
'29219' = '7040 '
'29225' = '7920 '
'29510' = '7040 '
'30013' = '3040 '
'30063' = '5140 '
'30111' = '0880 '
'31025' = '5920 '
'31043' = '7720 '
'31055' = '5920 '
'31109' = '4360 '
'31153' = '5920 '
'31177' = '5920 '
'32003' = '4120 '
'32023' = '4120 '
'32031' = '6720 '
'33011' = '1123 '
'33015' = '1123 '
'33017' = '1123 '
'34001' = '0560 '
'34003' = '0875 '
'34005' = '6160 '
'34007' = '6160 '
'34009' = '0560 '
'34011' = '8760 '
'34013' = '5640 '
'34015' = '6160 '
'34017' = '3640 '
'34019' = '5015 '
'34021' = '8480 '
'34023' = '5015 '
'34025' = '5190 '
'34027' = '5640 '
'34029' = '5190 '
'34031' = '0875 '
'34033' = '6160 '
'34035' = '5015 '
'34037' = '5640 '
'34039' = '5640 '
'34041' = '5640 '
'35001' = '0200 '
'35013' = '4100 '
'35028' = '7490 '
'35043' = '0200 '
'35049' = '7490 '
'35061' = '0200 '
'36001' = '0160 '
'36005' = '5600 '
'36007' = '0960 '
'36011' = '8160 '
'36013' = '3610 '
'36015' = '2335 '
'36027' = '2281 '
'36029' = '1280 '
'36037' = '6840 '
'36043' = '8680 '
'36047' = '5600 '
'36051' = '6840 '
'36053' = '8160 '
'36055' = '6840 '
'36057' = '0160 '
'36059' = '5380 '
'36061' = '5600 '
'36063' = '1280 '
'36065' = '8680 '
'36067' = '8160 '
'36069' = '6840 '
'36071' = '5660 '
'36073' = '6840 '
'36075' = '8160 '
'36079' = '5600 '
'36081' = '5600 '
'36083' = '0160 '
'36085' = '5600 '
'36087' = '5600 '
'36091' = '0160 '
'36093' = '0160 '
'36095' = '0160 '
'36103' = '5380 '
'36107' = '0960 '
'36113' = '2975 '
'36115' = '2975 '
'36117' = '6840 '
'36119' = '5600 '
'37001' = '3120 '
'37003' = '3290 '
'37019' = '9200 '
'37021' = '0480 '
'37023' = '3290 '
'37025' = '1520 '
'37027' = '3290 '
'37035' = '3290 '
'37037' = '6640 '
'37051' = '2560 '
'37053' = '5720 '
'37057' = '3120 '
'37059' = '3120 '
'37063' = '6640 '
'37065' = '6895 '
'37067' = '3120 '
'37069' = '6640 '
'37071' = '1520 '
'37081' = '3120 '
'37101' = '6640 '
'37109' = '1520 '
'37115' = '0480 '
'37119' = '1520 '
'37127' = '6895 '
'37129' = '9200 '
'37133' = '3605 '
'37135' = '6640 '
'37147' = '3150 '
'37151' = '3120 '
'37159' = '1520 '
'37169' = '3120 '
'37179' = '1520 '
'37183' = '6640 '
'37191' = '2980 '
'37197' = '3120 '
'38015' = '1010 '
'38017' = '2520 '
'38035' = '2985 '
'38059' = '1010 '
'39003' = '4320 '
'39007' = '1680 '
'39011' = '4320 '
'39013' = '9000 '
'39015' = '1640 '
'39017' = '3200 '
'39019' = '1320 '
'39023' = '2000 '
'39025' = '1640 '
'39029' = '9320 '
'39033' = '4800 '
'39035' = '1680 '
'39041' = '1840 '
'39045' = '1840 '
'39049' = '1840 '
'39051' = '8400 '
'39055' = '1680 '
'39057' = '2000 '
'39061' = '1640 '
'39081' = '8080 '
'39085' = '1680 '
'39087' = '3400 '
'39089' = '1840 '
'39093' = '1680 '
'39095' = '8400 '
'39097' = '1840 '
'39099' = '9320 '
'39103' = '1680 '
'39109' = '2000 '
'39113' = '2000 '
'39129' = '1840 '
'39133' = '0080 '
'39139' = '4800 '
'39151' = '1320 '
'39153' = '0080 '
'39155' = '9320 '
'39165' = '1640 '
'39167' = '6020 '
'39173' = '8400 '
'40017' = '5880 '
'40027' = '5880 '
'40031' = '4200 '
'40037' = '8560 '
'40047' = '2340 '
'40083' = '5880 '
'40087' = '5880 '
'40109' = '5880 '
'40113' = '8560 '
'40125' = '5880 '
'40131' = '8560 '
'40135' = '2720 '
'40143' = '8560 '
'40145' = '8560 '
'41003' = '1890 '
'41005' = '6440 '
'41009' = '6440 '
'41029' = '4890 '
'41039' = '2400 '
'41047' = '7080 '
'41051' = '6440 '
'41053' = '7080 '
'41067' = '6440 '
'41071' = '6440 '
'42003' = '6280 '
'42007' = '6280 '
'42011' = '6680 '
'42013' = '0280 '
'42017' = '6160 '
'42019' = '6280 '
'42021' = '3680 '
'42025' = '0240 '
'42027' = '8050 '
'42029' = '6160 '
'42037' = '7560 '
'42041' = '3240 '
'42043' = '3240 '
'42045' = '6160 '
'42049' = '2360 '
'42051' = '6280 '
'42069' = '7560 '
'42071' = '4000 '
'42075' = '3240 '
'42077' = '0240 '
'42079' = '7560 '
'42081' = '9140 '
'42085' = '7610 '
'42091' = '6160 '
'42095' = '0240 '
'42099' = '3240 '
'42101' = '6160 '
'42103' = '5660 '
'42111' = '3680 '
'42125' = '6280 '
'42129' = '6280 '
'42131' = '7560 '
'42133' = '9280 '
'44001' = '6483 '
'44003' = '6483 '
'44007' = '6483 '
'44009' = '6483 '
'45003' = '0600 '
'45007' = '3160 '
'45015' = '1440 '
'45019' = '1440 '
'45021' = '3160 '
'45035' = '1440 '
'45037' = '0600 '
'45041' = '2655 '
'45045' = '3160 '
'45051' = '5330 '
'45063' = '1760 '
'45077' = '3160 '
'45079' = '1760 '
'45083' = '3160 '
'45085' = '8140 '
'45091' = '1520 '
'46083' = '7760 '
'46099' = '7760 '
'46103' = '6660 '
'47001' = '3840 '
'47009' = '3840 '
'47019' = '3660 '
'47021' = '5360 '
'47023' = '3580 '
'47037' = '5360 '
'47043' = '5360 '
'47047' = '4920 '
'47065' = '1560 '
'47073' = '3660 '
'47093' = '3840 '
'47105' = '3840 '
'47113' = '3580 '
'47115' = '1560 '
'47125' = '1660 '
'47147' = '5360 '
'47149' = '5360 '
'47155' = '3840 '
'47157' = '4920 '
'47163' = '3660 '
'47165' = '5360 '
'47167' = '4920 '
'47171' = '3660 '
'47173' = '3840 '
'47179' = '3660 '
'47187' = '5360 '
'47189' = '5360 '
'48009' = '9080 '
'48021' = '0640 '
'48027' = '3810 '
'48029' = '7240 '
'48037' = '8360 '
'48039' = '1145 '
'48041' = '1260 '
'48055' = '0640 '
'48061' = '1240 '
'48071' = '3360 '
'48085' = '1920 '
'48091' = '7240 '
'48099' = '3810 '
'48113' = '1920 '
'48121' = '1920 '
'48135' = '5800 '
'48139' = '1920 '
'48141' = '2320 '
'48157' = '3360 '
'48167' = '2920 '
'48181' = '7640 '
'48183' = '4420 '
'48187' = '7240 '
'48199' = '0840 '
'48201' = '3360 '
'48203' = '4420 '
'48209' = '0640 '
'48213' = '1920 '
'48215' = '4880 '
'48221' = '2800 '
'48231' = '1920 '
'48245' = '0840 '
'48251' = '2800 '
'48257' = '1920 '
'48291' = '3360 '
'48303' = '4600 '
'48309' = '8800 '
'48329' = '5800 '
'48339' = '3360 '
'48355' = '1880 '
'48361' = '0840 '
'48367' = '2800 '
'48375' = '0320 '
'48381' = '0320 '
'48397' = '1920 '
'48409' = '1880 '
'48423' = '8640 '
'48439' = '2800 '
'48441' = '0040 '
'48451' = '7200 '
'48453' = '0640 '
'48459' = '4420 '
'48469' = '8750 '
'48473' = '3360 '
'48479' = '4080 '
'48485' = '9080 '
'48491' = '0640 '
'48493' = '7240 '
'49011' = '7160 '
'49025' = '2620 '
'49035' = '7160 '
'49049' = '6520 '
'49057' = '7160 '
'50007' = '1303 '
'50011' = '1303 '
'50013' = '1303 '
'51003' = '1540 '
'51009' = '4640 '
'51013' = '8840 '
'51019' = '4640 '
'51023' = '6800 '
'51031' = '4640 '
'51036' = '6760 '
'51041' = '6760 '
'51043' = '8840 '
'51047' = '8840 '
'51053' = '6760 '
'51059' = '8840 '
'51061' = '8840 '
'51065' = '1540 '
'51073' = '5720 '
'51075' = '6760 '
'51079' = '1540 '
'51085' = '6760 '
'51087' = '6760 '
'51093' = '5720 '
'51095' = '5720 '
'51099' = '8840 '
'51107' = '8840 '
'51115' = '5720 '
'51127' = '6760 '
'51143' = '1950 '
'51145' = '6760 '
'51149' = '6760 '
'51153' = '8840 '
'51161' = '6800 '
'51169' = '3660 '
'51177' = '8840 '
'51179' = '8840 '
'51187' = '8840 '
'51191' = '3660 '
'51199' = '5720 '
'51510' = '8840 '
'51515' = '4640 '
'51520' = '3660 '
'51540' = '1540 '
'51550' = '5720 '
'51570' = '6760 '
'51590' = '1950 '
'51600' = '8840 '
'51610' = '8840 '
'51630' = '8840 '
'51650' = '5720 '
'51670' = '6760 '
'51680' = '4640 '
'51683' = '8840 '
'51685' = '8840 '
'51700' = '5720 '
'51710' = '5720 '
'51730' = '6760 '
'51735' = '5720 '
'51740' = '5720 '
'51760' = '6760 '
'51770' = '6800 '
'51775' = '6800 '
'51800' = '5720 '
'51810' = '5720 '
'51830' = '5720 '
'53005' = '6740 '
'53011' = '6440 '
'53021' = '6740 '
'53029' = '7600 '
'53033' = '7600 '
'53035' = '1150 '
'53053' = '8200 '
'53061' = '7600 '
'53063' = '7840 '
'53067' = '5910 '
'53073' = '0860 '
'53077' = '9260 '
'54003' = '8840 '
'54009' = '8080 '
'54011' = '3400 '
'54029' = '8080 '
'54037' = '8840 '
'54039' = '1480 '
'54051' = '9000 '
'54057' = '1900 '
'54069' = '9000 '
'54079' = '1480 '
'54099' = '3400 '
'54107' = '6020 '
'55009' = '3080 '
'55015' = '0460 '
'55017' = '2290 '
'55025' = '4720 '
'55031' = '2240 '
'55035' = '2290 '
'55059' = '3800 '
'55063' = '3870 '
'55073' = '8940 '
'55079' = '5080 '
'55087' = '0460 '
'55089' = '5080 '
'55093' = '5120 '
'55101' = '6600 '
'55105' = '3620 '
'55109' = '5120 '
'55117' = '7620 '
'55131' = '5080 '
'55133' = '5080 '
'55139' = '0460 '
'56021' = '1580 '
'56025' = '1350 '
;

/* OMB 2003 METRO AREA */

VALUE $M3AREA
'01001' = '33860'
'01003' = '19300'
'01005' = '21640'
'01007' = '13820'
'01009' = '13820'
'01015' = '11500'
'01017' = '46740'
'01021' = '13820'
'01031' = '21460'
'01033' = '22520'
'01037' = '10760'
'01043' = '18980'
'01045' = '21460'
'01047' = '42820'
'01049' = '22840'
'01051' = '33860'
'01055' = '23460'
'01061' = '20020'
'01063' = '46220'
'01065' = '46220'
'01067' = '20020'
'01069' = '20020'
'01071' = '42460'
'01073' = '13820'
'01077' = '22520'
'01079' = '19460'
'01081' = '12220'
'01083' = '26620'
'01085' = '33860'
'01087' = '46260'
'01089' = '26620'
'01095' = '10700'
'01097' = '33660'
'01101' = '33860'
'01103' = '19460'
'01109' = '45980'
'01113' = '17980'
'01115' = '13820'
'01117' = '13820'
'01121' = '45180'
'01123' = '10760'
'01125' = '46220'
'01127' = '13820'
'02020' = '11260'
'02090' = '21820'
'02110' = '27940'
'02130' = '28540'
'02150' = '28980'
'02170' = '11260'
'04003' = '43420'
'04005' = '22380'
'04007' = '37740'
'04009' = '40940'
'04011' = '40940'
'04013' = '38060'
'04015' = '29420'
'04019' = '46060'
'04021' = '38060'
'04023' = '35700'
'04025' = '39140'
'04027' = '49740'
'05005' = '34260'
'05007' = '22220'
'05009' = '25460'
'05013' = '15780'
'05019' = '11660'
'05025' = '38220'
'05027' = '31620'
'05031' = '27860'
'05033' = '22900'
'05035' = '32820'
'05045' = '30780'
'05047' = '22900'
'05051' = '26300'
'05053' = '30780'
'05055' = '37500'
'05057' = '26260'
'05063' = '12900'
'05069' = '38220'
'05079' = '38220'
'05085' = '30780'
'05087' = '22220'
'05091' = '45500'
'05093' = '14180'
'05099' = '26260'
'05101' = '25460'
'05103' = '15780'
'05105' = '30780'
'05107' = '48340'
'05111' = '27860'
'05115' = '40780'
'05119' = '30780'
'05123' = '22620'
'05125' = '30780'
'05131' = '22900'
'05139' = '20980'
'05143' = '22220'
'05145' = '42620'
'05149' = '40780'
'06001' = '41860'
'06007' = '17020'
'06013' = '41860'
'06015' = '18860'
'06017' = '40900'
'06019' = '23420'
'06023' = '21700'
'06025' = '20940'
'06027' = '13860'
'06029' = '12540'
'06031' = '25260'
'06033' = '17340'
'06035' = '45000'
'06037' = '31100'
'06039' = '31460'
'06041' = '41860'
'06045' = '46380'
'06047' = '32900'
'06053' = '41500'
'06055' = '34900'
'06057' = '46020'
'06059' = '31100'
'06061' = '40900'
'06065' = '40140'
'06067' = '40900'
'06069' = '41940'
'06071' = '40140'
'06073' = '41740'
'06075' = '41860'
'06077' = '44700'
'06079' = '42020'
'06081' = '41860'
'06083' = '42060'
'06085' = '41940'
'06087' = '42100'
'06089' = '39820'
'06095' = '46700'
'06097' = '42220'
'06099' = '33700'
'06101' = '49700'
'06103' = '39780'
'06107' = '47300'
'06109' = '38020'
'06111' = '37100'
'06113' = '40900'
'06115' = '49700'
'08001' = '19740'
'08005' = '19740'
'08013' = '14500'
'08014' = '19740'
'08019' = '19740'
'08031' = '19740'
'08035' = '19740'
'08037' = '20780'
'08039' = '19740'
'08041' = '17820'
'08043' = '15860'
'08047' = '19740'
'08059' = '19740'
'08065' = '20780'
'08067' = '20420'
'08069' = '22660'
'08075' = '44540'
'08077' = '24300'
'08085' = '33940'
'08087' = '22820'
'08093' = '19740'
'08101' = '39380'
'08117' = '43540'
'08119' = '17820'
'08123' = '24540'
'09001' = '14860'
'09003' = '25540'
'09005' = '45860'
'09007' = '25540'
'09009' = '35300'
'09011' = '35980'
'09013' = '25540'
'09015' = '48740'
'10001' = '20100'
'10003' = '37980'
'10005' = '42580'
'11001' = '47900'
'12001' = '23540'
'12003' = '27260'
'12005' = '37460'
'12009' = '37340'
'12011' = '33100'
'12015' = '39460'
'12017' = '26140'
'12019' = '27260'
'12021' = '34940'
'12023' = '29380'
'12027' = '11580'
'12031' = '27260'
'12033' = '37860'
'12035' = '37380'
'12039' = '45220'
'12041' = '23540'
'12049' = '48100'
'12051' = '17500'
'12053' = '45300'
'12055' = '42700'
'12057' = '45300'
'12061' = '46940'
'12065' = '45220'
'12069' = '36740'
'12071' = '15980'
'12073' = '45220'
'12081' = '42260'
'12083' = '36100'
'12085' = '38940'
'12086' = '33100'
'12087' = '28580'
'12089' = '27260'
'12091' = '23020'
'12093' = '36380'
'12095' = '36740'
'12097' = '36740'
'12099' = '33100'
'12101' = '45300'
'12103' = '45300'
'12105' = '29460'
'12107' = '37260'
'12109' = '27260'
'12111' = '38940'
'12113' = '37860'
'12115' = '42260'
'12117' = '36740'
'12119' = '45540'
'12127' = '19660'
'12129' = '45220'
'13003' = '20060'
'13007' = '10500'
'13009' = '33300'
'13013' = '12060'
'13015' = '12060'
'13017' = '22340'
'13021' = '31420'
'13025' = '15260'
'13027' = '46660'
'13029' = '42340'
'13031' = '44340'
'13033' = '12260'
'13035' = '12060'
'13039' = '41220'
'13045' = '12060'
'13047' = '16860'
'13051' = '42340'
'13053' = '17980'
'13055' = '44900'
'13057' = '12060'
'13059' = '12020'
'13063' = '12060'
'13067' = '12060'
'13069' = '20060'
'13071' = '34220'
'13073' = '12260'
'13077' = '12060'
'13079' = '31420'
'13081' = '18380'
'13083' = '16860'
'13085' = '12060'
'13087' = '12460'
'13089' = '12060'
'13095' = '10500'
'13097' = '12060'
'13101' = '46660'
'13103' = '42340'
'13113' = '12060'
'13115' = '40660'
'13117' = '12060'
'13121' = '12060'
'13127' = '15260'
'13129' = '15660'
'13135' = '12060'
'13137' = '18460'
'13139' = '23580'
'13141' = '33300'
'13143' = '12060'
'13145' = '17980'
'13149' = '12060'
'13151' = '12060'
'13153' = '47580'
'13155' = '22340'
'13159' = '12060'
'13167' = '20140'
'13169' = '31420'
'13171' = '12060'
'13173' = '46660'
'13175' = '20140'
'13177' = '10500'
'13179' = '25980'
'13183' = '25980'
'13185' = '46660'
'13189' = '12260'
'13191' = '15260'
'13195' = '12020'
'13197' = '17980'
'13199' = '12060'
'13207' = '31420'
'13209' = '47080'
'13213' = '19140'
'13215' = '17980'
'13217' = '12060'
'13219' = '12020'
'13221' = '12020'
'13223' = '12060'
'13225' = '22980'
'13227' = '12060'
'13229' = '48180'
'13231' = '12060'
'13233' = '16340'
'13239' = '21640'
'13245' = '12260'
'13247' = '12060'
'13249' = '11140'
'13255' = '12060'
'13257' = '45740'
'13261' = '11140'
'13273' = '10500'
'13275' = '45620'
'13277' = '45700'
'13279' = '47080'
'13285' = '29300'
'13289' = '31420'
'13293' = '45580'
'13295' = '16860'
'13297' = '12060'
'13299' = '48180'
'13305' = '27700'
'13313' = '19140'
'13321' = '10500'
'15001' = '25900'
'15003' = '26180'
'15007' = '28180'
'15009' = '27980'
'16001' = '14260'
'16005' = '38540'
'16011' = '13940'
'16015' = '14260'
'16019' = '26820'
'16027' = '14260'
'16031' = '15420'
'16039' = '34300'
'16041' = '30860'
'16043' = '39940'
'16045' = '14260'
'16051' = '26820'
'16053' = '46300'
'16055' = '17660'
'16057' = '34140'
'16065' = '39940'
'16067' = '15420'
'16069' = '30300'
'16073' = '14260'
'16075' = '36620'
'16077' = '38540'
'16081' = '27220'
'16083' = '46300'
'17001' = '39500'
'17003' = '16020'
'17005' = '41180'
'17007' = '40420'
'17011' = '36860'
'17013' = '41180'
'17019' = '16580'
'17021' = '45380'
'17027' = '41180'
'17029' = '16660'
'17031' = '16980'
'17035' = '16660'
'17037' = '16980'
'17043' = '16980'
'17049' = '20820'
'17053' = '16580'
'17057' = '15900'
'17063' = '16980'
'17065' = '34500'
'17071' = '15460'
'17073' = '19340'
'17077' = '16060'
'17081' = '34500'
'17083' = '41180'
'17089' = '16980'
'17091' = '28100'
'17093' = '16980'
'17095' = '23660'
'17097' = '16980'
'17099' = '36860'
'17103' = '19940'
'17105' = '38700'
'17107' = '30660'
'17109' = '31380'
'17111' = '16980'
'17113' = '14060'
'17115' = '19500'
'17117' = '41180'
'17119' = '41180'
'17121' = '16460'
'17123' = '37900'
'17127' = '37140'
'17129' = '44100'
'17131' = '19340'
'17133' = '41180'
'17137' = '27300'
'17141' = '40300'
'17143' = '37900'
'17147' = '16580'
'17155' = '36860'
'17161' = '19340'
'17163' = '41180'
'17165' = '25380'
'17167' = '44100'
'17171' = '27300'
'17175' = '37900'
'17177' = '23300'
'17179' = '37900'
'17183' = '19180'
'17187' = '23660'
'17195' = '44580'
'17197' = '16980'
'17199' = '32060'
'17201' = '40420'
'17203' = '37900'
'18001' = '19540'
'18003' = '23060'
'18005' = '18020'
'18007' = '29140'
'18011' = '26900'
'18013' = '26900'
'18015' = '29140'
'18017' = '30900'
'18019' = '31140'
'18021' = '45460'
'18023' = '23140'
'18027' = '47780'
'18029' = '17140'
'18031' = '24700'
'18033' = '12140'
'18035' = '34620'
'18037' = '27540'
'18039' = '21140'
'18041' = '18220'
'18043' = '31140'
'18047' = '17140'
'18051' = '21780'
'18053' = '31980'
'18055' = '14020'
'18057' = '26900'
'18059' = '26900'
'18061' = '31140'
'18063' = '26900'
'18065' = '35220'
'18067' = '29020'
'18069' = '26540'
'18071' = '42980'
'18073' = '16980'
'18077' = '31500'
'18079' = '35860'
'18081' = '26900'
'18083' = '47180'
'18085' = '47700'
'18089' = '16980'
'18091' = '33140'
'18093' = '13260'
'18095' = '11300'
'18097' = '26900'
'18099' = '38500'
'18103' = '37940'
'18105' = '14020'
'18107' = '18820'
'18109' = '26900'
'18111' = '16980'
'18113' = '28340'
'18115' = '17140'
'18119' = '14020'
'18125' = '27540'
'18127' = '16980'
'18129' = '21780'
'18133' = '26900'
'18141' = '43780'
'18143' = '42500'
'18145' = '26900'
'18151' = '11420'
'18153' = '45460'
'18157' = '29140'
'18159' = '29020'
'18163' = '21780'
'18165' = '45460'
'18167' = '45460'
'18169' = '47340'
'18173' = '21780'
'18175' = '31140'
'18177' = '39980'
'18179' = '23060'
'18183' = '23060'
'19011' = '16300'
'19013' = '47940'
'19015' = '14340'
'19017' = '47940'
'19021' = '44740'
'19033' = '32380'
'19041' = '43980'
'19045' = '17540'
'19049' = '19780'
'19057' = '15460'
'19059' = '44020'
'19061' = '20220'
'19075' = '47940'
'19077' = '19780'
'19085' = '36540'
'19099' = '35500'
'19103' = '26980'
'19105' = '16300'
'19111' = '28460'
'19113' = '16300'
'19115' = '34700'
'19121' = '19780'
'19123' = '36820'
'19125' = '37800'
'19127' = '32260'
'19129' = '36540'
'19139' = '34700'
'19153' = '19780'
'19155' = '36540'
'19163' = '19340'
'19169' = '11180'
'19179' = '36900'
'19181' = '19780'
'19183' = '26980'
'19187' = '22700'
'19193' = '43580'
'19195' = '32380'
'20005' = '11860'
'20009' = '24460'
'20015' = '48620'
'20017' = '21380'
'20035' = '49060'
'20037' = '38260'
'20043' = '41140'
'20045' = '29940'
'20051' = '25700'
'20055' = '23780'
'20057' = '19980'
'20059' = '28140'
'20061' = '31740'
'20079' = '48620'
'20085' = '45820'
'20087' = '45820'
'20091' = '28140'
'20099' = '37660'
'20103' = '28140'
'20107' = '28140'
'20111' = '21380'
'20113' = '32700'
'20121' = '28140'
'20125' = '17700'
'20139' = '45820'
'20143' = '41460'
'20149' = '31740'
'20155' = '26740'
'20161' = '31740'
'20169' = '41460'
'20173' = '48620'
'20175' = '30580'
'20177' = '45820'
'20191' = '48620'
'20197' = '45820'
'20209' = '28140'
'21005' = '23180'
'21007' = '37140'
'21009' = '23980'
'21011' = '34460'
'21013' = '33180'
'21015' = '17140'
'21017' = '30460'
'21019' = '26580'
'21021' = '19220'
'21023' = '17140'
'21029' = '31140'
'21035' = '34660'
'21037' = '17140'
'21047' = '17300'
'21049' = '30460'
'21059' = '36980'
'21061' = '14540'
'21067' = '30460'
'21073' = '23180'
'21075' = '46460'
'21077' = '17140'
'21081' = '17140'
'21083' = '32460'
'21089' = '26580'
'21091' = '36980'
'21093' = '21060'
'21101' = '21780'
'21103' = '31140'
'21107' = '31580'
'21111' = '31140'
'21113' = '30460'
'21117' = '17140'
'21123' = '21060'
'21125' = '30940'
'21135' = '32500'
'21137' = '19220'
'21139' = '37140'
'21145' = '37140'
'21149' = '36980'
'21151' = '40080'
'21161' = '32500'
'21163' = '31140'
'21165' = '34460'
'21169' = '23980'
'21173' = '34460'
'21177' = '16420'
'21179' = '31140'
'21185' = '31140'
'21191' = '17140'
'21199' = '43700'
'21203' = '40080'
'21209' = '30460'
'21211' = '31140'
'21215' = '31140'
'21217' = '15820'
'21221' = '17300'
'21223' = '31140'
'21227' = '14540'
'21233' = '21780'
'21235' = '18340'
'21239' = '30460'
'22001' = '18940'
'22005' = '12940'
'22007' = '38200'
'22011' = '19760'
'22015' = '43340'
'22017' = '43340'
'22019' = '29340'
'22023' = '29340'
'22029' = '35020'
'22031' = '43340'
'22033' = '12940'
'22037' = '12940'
'22043' = '10780'
'22045' = '35340'
'22047' = '12940'
'22049' = '40820'
'22051' = '35380'
'22053' = '27660'
'22055' = '29180'
'22057' = '26380'
'22061' = '40820'
'22063' = '12940'
'22065' = '45260'
'22067' = '12820'
'22069' = '35060'
'22071' = '35380'
'22073' = '33740'
'22075' = '35380'
'22077' = '12940'
'22079' = '10780'
'22087' = '35380'
'22089' = '35380'
'22091' = '12940'
'22095' = '35380'
'22097' = '36660'
'22099' = '29180'
'22101' = '34020'
'22103' = '35380'
'22105' = '25220'
'22109' = '26380'
'22111' = '33740'
'22113' = '10020'
'22115' = '22860'
'22117' = '14220'
'22119' = '33380'
'22121' = '12940'
'22125' = '12940'
'23001' = '30340'
'23005' = '38860'
'23011' = '12300'
'23013' = '40500'
'23019' = '12620'
'23023' = '38860'
'23031' = '38860'
'24001' = '19060'
'24003' = '12580'
'24005' = '12580'
'24009' = '47900'
'24013' = '12580'
'24015' = '37980'
'24017' = '47900'
'24019' = '15700'
'24021' = '47900'
'24025' = '12580'
'24027' = '12580'
'24031' = '47900'
'24033' = '47900'
'24035' = '12580'
'24037' = '30500'
'24039' = '41540'
'24041' = '20660'
'24043' = '25180'
'24045' = '41540'
'24047' = '36180'
'24510' = '12580'
'25001' = '12700'
'25003' = '38340'
'25005' = '39300'
'25009' = '14460'
'25011' = '44140'
'25013' = '44140'
'25015' = '44140'
'25017' = '14460'
'25021' = '14460'
'25023' = '14460'
'25025' = '14460'
'25027' = '49340'
'26005' = '10880'
'26007' = '10980'
'26015' = '24340'
'26017' = '13020'
'26019' = '45900'
'26021' = '35660'
'26023' = '17740'
'26025' = '12980'
'26027' = '43780'
'26033' = '42300'
'26037' = '29620'
'26041' = '21540'
'26043' = '27020'
'26045' = '29620'
'26049' = '22420'
'26055' = '45900'
'26057' = '10940'
'26061' = '26340'
'26065' = '29620'
'26067' = '24340'
'26073' = '34380'
'26075' = '27100'
'26077' = '28020'
'26079' = '45900'
'26081' = '24340'
'26083' = '26340'
'26087' = '19820'
'26089' = '45900'
'26091' = '10300'
'26093' = '19820'
'26099' = '19820'
'26103' = '32100'
'26107' = '13660'
'26109' = '31940'
'26111' = '33220'
'26113' = '15620'
'26115' = '33780'
'26121' = '34740'
'26123' = '24340'
'26125' = '19820'
'26139' = '26100'
'26145' = '40980'
'26147' = '19820'
'26149' = '44780'
'26155' = '37020'
'26159' = '28020'
'26161' = '11460'
'26163' = '19820'
'26165' = '15620'
'27003' = '33460'
'27007' = '13420'
'27009' = '41060'
'27013' = '31860'
'27015' = '35580'
'27017' = '20260'
'27019' = '33460'
'27021' = '14660'
'27025' = '33460'
'27027' = '22020'
'27035' = '14660'
'27037' = '33460'
'27039' = '40340'
'27041' = '10820'
'27047' = '10660'
'27049' = '39860'
'27053' = '33460'
'27055' = '29100'
'27059' = '33460'
'27067' = '48820'
'27083' = '32140'
'27085' = '26780'
'27091' = '21860'
'27099' = '12380'
'27103' = '31860'
'27105' = '49380'
'27109' = '40340'
'27111' = '22260'
'27119' = '24220'
'27123' = '33460'
'27131' = '22060'
'27137' = '20260'
'27139' = '33460'
'27141' = '33460'
'27145' = '41060'
'27147' = '36940'
'27157' = '40340'
'27163' = '33460'
'27167' = '47420'
'27169' = '49100'
'27171' = '33460'
'28001' = '35020'
'28003' = '18420'
'28005' = '32620'
'28011' = '17380'
'28015' = '24900'
'28023' = '32940'
'28025' = '48500'
'28027' = '17260'
'28029' = '27140'
'28033' = '32820'
'28035' = '25620'
'28039' = '37700'
'28043' = '24980'
'28045' = '25060'
'28047' = '25060'
'28049' = '27140'
'28057' = '46180'
'28059' = '37700'
'28061' = '29860'
'28067' = '29860'
'28069' = '32940'
'28071' = '37060'
'28073' = '25620'
'28075' = '32940'
'28081' = '46180'
'28083' = '24900'
'28085' = '15020'
'28087' = '18060'
'28089' = '27140'
'28093' = '32820'
'28105' = '44260'
'28109' = '38100'
'28111' = '25620'
'28113' = '32620'
'28115' = '46180'
'28121' = '27140'
'28127' = '27140'
'28131' = '25060'
'28133' = '26940'
'28137' = '32820'
'28143' = '32820'
'28149' = '46980'
'28151' = '24740'
'28163' = '49540'
'29001' = '28860'
'29003' = '41140'
'29007' = '33020'
'29013' = '28140'
'29017' = '16020'
'29019' = '17860'
'29021' = '41140'
'29023' = '38740'
'29025' = '28140'
'29027' = '27620'
'29031' = '16020'
'29037' = '28140'
'29043' = '44180'
'29045' = '28460'
'29047' = '28140'
'29049' = '28140'
'29051' = '27620'
'29059' = '44180'
'29063' = '41140'
'29069' = '28380'
'29071' = '41180'
'29077' = '44180'
'29089' = '17860'
'29091' = '48460'
'29095' = '28140'
'29097' = '27900'
'29099' = '41180'
'29101' = '47660'
'29105' = '30060'
'29107' = '28140'
'29111' = '39500'
'29113' = '41180'
'29119' = '22220'
'29127' = '25300'
'29135' = '27620'
'29145' = '27900'
'29147' = '32340'
'29151' = '27620'
'29159' = '42740'
'29161' = '40620'
'29165' = '28140'
'29167' = '44180'
'29169' = '22780'
'29173' = '25300'
'29175' = '33620'
'29177' = '28140'
'29183' = '41180'
'29187' = '22100'
'29189' = '41180'
'29195' = '32180'
'29197' = '28860'
'29201' = '43460'
'29209' = '14700'
'29213' = '14700'
'29219' = '41180'
'29221' = '41180'
'29225' = '44180'
'29510' = '41180'
'30009' = '13740'
'30013' = '24500'
'30029' = '28060'
'30031' = '14580'
'30041' = '25660'
'30043' = '25740'
'30049' = '25740'
'30063' = '33540'
'30093' = '15580'
'30111' = '13740'
'31001' = '25580'
'31007' = '42420'
'31019' = '28260'
'31025' = '36540'
'31035' = '25580'
'31043' = '43580'
'31047' = '30420'
'31051' = '43580'
'31053' = '23340'
'31055' = '36540'
'31067' = '13100'
'31073' = '30420'
'31079' = '24260'
'31093' = '24260'
'31099' = '28260'
'31109' = '30700'
'31111' = '35820'
'31113' = '35820'
'31117' = '35820'
'31119' = '35740'
'31121' = '24260'
'31139' = '35740'
'31141' = '18100'
'31153' = '36540'
'31155' = '36540'
'31157' = '42420'
'31159' = '30700'
'31167' = '35740'
'31177' = '36540'
'32001' = '21980'
'32003' = '29820'
'32005' = '23820'
'32007' = '21220'
'32011' = '21220'
'32023' = '37220'
'32029' = '39900'
'32031' = '39900'
'32510' = '16180'
'33001' = '29060'
'33005' = '28300'
'33007' = '13620'
'33009' = '30100'
'33011' = '31700'
'33013' = '18180'
'33015' = '14460'
'33017' = '14460'
'33019' = '17200'
'34001' = '12100'
'34003' = '35620'
'34005' = '37980'
'34007' = '37980'
'34009' = '36140'
'34011' = '47220'
'34013' = '35620'
'34015' = '37980'
'34017' = '35620'
'34019' = '35620'
'34021' = '45940'
'34023' = '35620'
'34025' = '35620'
'34027' = '35620'
'34029' = '35620'
'34031' = '35620'
'34033' = '37980'
'34035' = '35620'
'34037' = '35620'
'34039' = '35620'
'34041' = '10900'
'35001' = '10740'
'35005' = '40740'
'35006' = '24380'
'35009' = '17580'
'35013' = '29740'
'35015' = '16100'
'35017' = '43500'
'35025' = '26020'
'35028' = '31060'
'35029' = '19700'
'35031' = '23700'
'35035' = '10460'
'35039' = '21580'
'35041' = '38780'
'35043' = '10740'
'35045' = '22140'
'35047' = '29780'
'35049' = '42140'
'35055' = '45340'
'35057' = '10740'
'35061' = '10740'
'36001' = '10580'
'36005' = '35620'
'36007' = '13780'
'36009' = '36460'
'36011' = '12180'
'36013' = '27460'
'36015' = '21300'
'36019' = '38460'
'36021' = '26460'
'36023' = '18660'
'36027' = '39100'
'36029' = '15380'
'36033' = '31660'
'36035' = '24100'
'36037' = '12860'
'36043' = '46540'
'36045' = '48060'
'36047' = '35620'
'36051' = '40380'
'36053' = '45060'
'36055' = '40380'
'36057' = '11220'
'36059' = '35620'
'36061' = '35620'
'36063' = '15380'
'36065' = '46540'
'36067' = '45060'
'36069' = '40380'
'36071' = '39100'
'36073' = '40380'
'36075' = '45060'
'36077' = '36580'
'36079' = '35620'
'36081' = '35620'
'36083' = '10580'
'36085' = '35620'
'36087' = '35620'
'36089' = '36300'
'36091' = '10580'
'36093' = '10580'
'36095' = '10580'
'36099' = '42900'
'36101' = '18500'
'36103' = '35620'
'36107' = '13780'
'36109' = '27060'
'36111' = '28740'
'36113' = '24020'
'36115' = '24020'
'36117' = '40380'
'36119' = '35620'
'37001' = '15500'
'37003' = '25860'
'37007' = '16740'
'37013' = '47820'
'37019' = '48900'
'37021' = '11700'
'37023' = '25860'
'37025' = '16740'
'37027' = '25860'
'37029' = '21020'
'37031' = '33980'
'37035' = '25860'
'37037' = '20500'
'37045' = '43140'
'37049' = '35100'
'37051' = '22180'
'37053' = '47260'
'37055' = '28620'
'37057' = '45640'
'37059' = '49180'
'37063' = '20500'
'37065' = '40580'
'37067' = '49180'
'37069' = '39580'
'37071' = '16740'
'37079' = '24780'
'37081' = '24660'
'37083' = '40260'
'37085' = '20380'
'37087' = '11700'
'37089' = '11700'
'37093' = '22180'
'37097' = '44380'
'37101' = '39580'
'37103' = '35100'
'37105' = '41820'
'37107' = '28820'
'37109' = '30740'
'37115' = '11700'
'37119' = '16740'
'37125' = '43860'
'37127' = '40580'
'37129' = '48900'
'37131' = '40260'
'37133' = '27340'
'37135' = '20500'
'37137' = '35100'
'37139' = '21020'
'37141' = '48900'
'37143' = '21020'
'37145' = '20500'
'37147' = '24780'
'37151' = '24660'
'37153' = '40460'
'37155' = '31300'
'37157' = '24660'
'37159' = '41580'
'37161' = '22580'
'37165' = '29900'
'37167' = '10620'
'37169' = '49180'
'37171' = '34340'
'37175' = '14820'
'37179' = '16740'
'37181' = '25780'
'37183' = '39580'
'37189' = '14380'
'37191' = '24140'
'37193' = '35900'
'37195' = '48980'
'37197' = '49180'
'38007' = '19860'
'38015' = '13900'
'38017' = '22020'
'38035' = '24220'
'38049' = '33500'
'38059' = '13900'
'38075' = '33500'
'38077' = '47420'
'38089' = '19860'
'38093' = '27420'
'38101' = '33500'
'38105' = '48780'
'39003' = '30620'
'39005' = '11740'
'39007' = '11780'
'39009' = '11900'
'39011' = '47540'
'39013' = '48540'
'39015' = '17140'
'39017' = '17140'
'39019' = '15940'
'39021' = '46500'
'39023' = '44220'
'39025' = '17140'
'39027' = '48940'
'39029' = '20620'
'39031' = '18740'
'39033' = '15340'
'39035' = '17460'
'39037' = '24820'
'39039' = '19580'
'39041' = '18140'
'39043' = '41780'
'39045' = '18140'
'39047' = '47860'
'39049' = '18140'
'39051' = '45780'
'39053' = '38580'
'39055' = '17460'
'39057' = '19380'
'39059' = '15740'
'39061' = '17140'
'39063' = '22300'
'39077' = '35940'
'39081' = '48260'
'39083' = '34540'
'39085' = '17460'
'39087' = '26580'
'39089' = '18140'
'39091' = '13340'
'39093' = '17460'
'39095' = '45780'
'39097' = '18140'
'39099' = '49660'
'39101' = '32020'
'39103' = '17460'
'39107' = '16380'
'39109' = '19380'
'39113' = '19380'
'39117' = '18140'
'39119' = '49780'
'39123' = '45780'
'39129' = '18140'
'39133' = '10420'
'39135' = '19380'
'39139' = '31900'
'39141' = '17060'
'39143' = '23380'
'39145' = '39020'
'39147' = '45660'
'39149' = '43380'
'39151' = '15940'
'39153' = '10420'
'39155' = '49660'
'39157' = '35420'
'39159' = '18140'
'39161' = '46780'
'39165' = '17140'
'39167' = '37620'
'39169' = '49300'
'39173' = '45780'
'40009' = '21120'
'40013' = '20460'
'40017' = '36420'
'40019' = '11620'
'40021' = '45140'
'40027' = '36420'
'40031' = '30020'
'40037' = '46140'
'40047' = '21420'
'40051' = '36420'
'40065' = '11060'
'40071' = '38620'
'40079' = '22900'
'40081' = '36420'
'40083' = '36420'
'40085' = '11620'
'40087' = '36420'
'40101' = '34780'
'40109' = '36420'
'40111' = '46140'
'40113' = '46140'
'40115' = '33060'
'40117' = '46140'
'40119' = '44660'
'40121' = '32540'
'40123' = '10220'
'40125' = '43060'
'40131' = '46140'
'40135' = '22900'
'40137' = '20340'
'40139' = '25100'
'40143' = '46140'
'40145' = '46140'
'40147' = '12780'
'40153' = '49260'
'41003' = '18700'
'41005' = '38900'
'41007' = '11820'
'41009' = '38900'
'41011' = '18300'
'41013' = '39260'
'41015' = '15060'
'41017' = '13460'
'41019' = '40700'
'41027' = '26220'
'41029' = '32780'
'41033' = '24420'
'41035' = '28900'
'41039' = '21660'
'41043' = '10540'
'41045' = '36620'
'41047' = '41420'
'41049' = '37820'
'41051' = '38900'
'41053' = '41420'
'41059' = '37820'
'41061' = '29260'
'41065' = '17180'
'41067' = '38900'
'41071' = '38900'
'42001' = '23900'
'42003' = '38300'
'42005' = '38300'
'42007' = '38300'
'42011' = '39740'
'42013' = '11020'
'42015' = '42380'
'42017' = '37980'
'42019' = '38300'
'42021' = '27780'
'42025' = '10900'
'42027' = '44300'
'42029' = '37980'
'42033' = '20180'
'42035' = '30820'
'42037' = '14100'
'42039' = '32740'
'42041' = '25420'
'42043' = '25420'
'42045' = '37980'
'42047' = '41260'
'42049' = '21500'
'42051' = '38300'
'42055' = '16540'
'42061' = '26500'
'42063' = '26860'
'42069' = '42540'
'42071' = '29540'
'42073' = '35260'
'42075' = '30140'
'42077' = '10900'
'42079' = '42540'
'42081' = '48700'
'42083' = '14620'
'42085' = '49660'
'42087' = '30380'
'42089' = '20700'
'42091' = '37980'
'42093' = '14100'
'42095' = '10900'
'42097' = '44980'
'42099' = '25420'
'42101' = '37980'
'42103' = '35620'
'42107' = '39060'
'42109' = '42780'
'42111' = '43740'
'42119' = '30260'
'42121' = '36340'
'42123' = '47620'
'42125' = '38300'
'42129' = '38300'
'42131' = '42540'
'42133' = '49620'
'44001' = '39300'
'44003' = '39300'
'44005' = '39300'
'44007' = '39300'
'44009' = '39300'
'45003' = '12260'
'45007' = '11340'
'45013' = '25940'
'45015' = '16700'
'45017' = '17900'
'45019' = '16700'
'45021' = '23500'
'45023' = '16900'
'45029' = '47500'
'45031' = '22500'
'45033' = '19900'
'45035' = '16700'
'45037' = '12260'
'45039' = '17900'
'45041' = '22500'
'45043' = '23860'
'45045' = '24860'
'45047' = '24940'
'45051' = '34820'
'45053' = '25940'
'45055' = '17900'
'45057' = '29580'
'45059' = '24860'
'45063' = '17900'
'45069' = '13500'
'45071' = '35140'
'45073' = '42860'
'45075' = '36700'
'45077' = '24860'
'45079' = '17900'
'45081' = '17900'
'45083' = '43900'
'45085' = '44940'
'45087' = '46420'
'45091' = '16740'
'46005' = '26700'
'46011' = '15100'
'46013' = '10100'
'46027' = '46820'
'46029' = '47980'
'46035' = '33580'
'46045' = '10100'
'46057' = '47980'
'46061' = '33580'
'46065' = '38180'
'46081' = '43940'
'46083' = '43620'
'46087' = '43620'
'46093' = '39660'
'46099' = '43620'
'46103' = '39660'
'46117' = '38180'
'46125' = '43620'
'46127' = '43580'
'46135' = '49460'
'47001' = '28940'
'47003' = '43180'
'47009' = '28940'
'47011' = '17420'
'47013' = '29220'
'47015' = '34980'
'47019' = '27740'
'47021' = '34980'
'47023' = '27180'
'47029' = '35460'
'47031' = '46100'
'47035' = '18900'
'47037' = '34980'
'47043' = '34980'
'47045' = '20540'
'47047' = '32820'
'47051' = '46100'
'47053' = '26480'
'47057' = '34100'
'47059' = '24620'
'47063' = '34100'
'47065' = '16860'
'47073' = '28700'
'47075' = '15140'
'47079' = '37540'
'47081' = '34980'
'47087' = '18260'
'47089' = '34100'
'47093' = '28940'
'47099' = '29980'
'47105' = '28940'
'47107' = '11940'
'47111' = '34980'
'47113' = '27180'
'47115' = '16860'
'47117' = '30280'
'47119' = '17940'
'47125' = '17300'
'47127' = '46100'
'47131' = '46460'
'47133' = '18260'
'47139' = '17420'
'47141' = '18260'
'47145' = '25340'
'47147' = '34980'
'47149' = '34980'
'47153' = '16860'
'47155' = '42940'
'47157' = '32820'
'47159' = '34980'
'47161' = '17300'
'47163' = '28700'
'47165' = '34980'
'47167' = '32820'
'47169' = '34980'
'47171' = '27740'
'47173' = '28940'
'47177' = '32660'
'47179' = '27740'
'47183' = '32280'
'47187' = '34980'
'47189' = '34980'
'48001' = '37300'
'48003' = '11380'
'48005' = '31260'
'48007' = '18580'
'48009' = '48660'
'48011' = '11100'
'48013' = '41700'
'48015' = '26420'
'48019' = '41700'
'48021' = '12420'
'48025' = '13300'
'48027' = '28660'
'48029' = '41700'
'48037' = '45500'
'48039' = '26420'
'48041' = '17780'
'48049' = '15220'
'48051' = '17780'
'48055' = '12420'
'48057' = '47020'
'48059' = '10180'
'48061' = '15180'
'48065' = '11100'
'48071' = '26420'
'48073' = '27380'
'48077' = '48660'
'48085' = '19100'
'48091' = '41700'
'48097' = '23620'
'48099' = '28660'
'48107' = '31180'
'48113' = '19100'
'48115' = '29500'
'48117' = '25820'
'48119' = '19100'
'48121' = '19100'
'48135' = '36220'
'48139' = '19100'
'48141' = '21340'
'48143' = '44500'
'48147' = '14300'
'48157' = '26420'
'48167' = '26420'
'48175' = '47020'
'48179' = '37420'
'48181' = '43300'
'48183' = '30980'
'48187' = '41700'
'48189' = '38380'
'48199' = '13140'
'48201' = '26420'
'48203' = '32220'
'48209' = '12420'
'48213' = '11980'
'48215' = '32580'
'48219' = '30220'
'48221' = '24180'
'48223' = '44860'
'48227' = '13700'
'48231' = '19100'
'48233' = '14420'
'48235' = '41660'
'48245' = '13140'
'48249' = '10860'
'48251' = '19100'
'48253' = '10180'
'48257' = '19100'
'48259' = '41700'
'48261' = '28780'
'48265' = '28500'
'48273' = '28780'
'48277' = '37580'
'48281' = '28660'
'48291' = '26420'
'48303' = '31180'
'48309' = '47380'
'48321' = '13060'
'48323' = '20580'
'48325' = '41700'
'48329' = '33260'
'48339' = '26420'
'48341' = '20300'
'48347' = '34860'
'48349' = '18620'
'48353' = '45020'
'48355' = '18580'
'48361' = '13140'
'48363' = '33420'
'48367' = '19100'
'48375' = '11100'
'48381' = '11100'
'48389' = '37780'
'48393' = '37420'
'48395' = '17780'
'48397' = '19100'
'48401' = '30980'
'48407' = '26420'
'48409' = '18580'
'48415' = '43660'
'48423' = '46340'
'48425' = '24180'
'48427' = '40100'
'48439' = '19100'
'48441' = '10180'
'48449' = '34420'
'48451' = '41660'
'48453' = '12420'
'48459' = '30980'
'48463' = '46620'
'48465' = '19620'
'48469' = '47020'
'48471' = '26660'
'48473' = '26420'
'48477' = '14780'
'48479' = '29700'
'48481' = '20900'
'48485' = '48660'
'48487' = '46900'
'48489' = '39700'
'48491' = '12420'
'48493' = '41700'
'48497' = '19100'
'49003' = '14940'
'49005' = '30860'
'49007' = '39220'
'49011' = '36260'
'49021' = '16260'
'49023' = '39340'
'49029' = '36260'
'49035' = '41620'
'49043' = '41620'
'49045' = '41620'
'49047' = '46860'
'49049' = '39340'
'49051' = '25720'
'49053' = '41100'
'49057' = '36260'
'50003' = '13540'
'50007' = '15540'
'50009' = '13620'
'50011' = '15540'
'50013' = '15540'
'50017' = '30100'
'50021' = '40860'
'50023' = '12740'
'50027' = '30100'
'51003' = '16820'
'51007' = '40060'
'51009' = '31340'
'51011' = '31340'
'51013' = '47900'
'51015' = '44420'
'51019' = '31340'
'51023' = '40220'
'51031' = '31340'
'51033' = '40060'
'51036' = '40060'
'51041' = '40060'
'51043' = '47900'
'51045' = '40220'
'51047' = '19020'
'51049' = '40060'
'51053' = '40060'
'51059' = '47900'
'51061' = '47900'
'51065' = '16820'
'51067' = '40220'
'51069' = '49020'
'51071' = '13980'
'51073' = '47260'
'51075' = '40060'
'51079' = '16820'
'51085' = '40060'
'51087' = '40060'
'51089' = '32300'
'51093' = '47260'
'51095' = '47260'
'51097' = '40060'
'51101' = '40060'
'51107' = '47900'
'51109' = '40060'
'51115' = '47260'
'51121' = '13980'
'51125' = '16820'
'51127' = '40060'
'51143' = '19260'
'51145' = '40060'
'51149' = '40060'
'51153' = '47900'
'51155' = '13980'
'51161' = '40220'
'51165' = '25500'
'51169' = '28700'
'51177' = '47900'
'51179' = '47900'
'51181' = '47260'
'51183' = '40060'
'51185' = '14140'
'51187' = '47900'
'51191' = '28700'
'51199' = '47260'
'51510' = '47900'
'51515' = '31340'
'51520' = '28700'
'51540' = '16820'
'51550' = '47260'
'51570' = '40060'
'51590' = '19260'
'51600' = '47900'
'51610' = '47900'
'51630' = '47900'
'51650' = '47260'
'51660' = '25500'
'51670' = '40060'
'51680' = '31340'
'51683' = '47900'
'51685' = '47900'
'51690' = '32300'
'51700' = '47260'
'51710' = '47260'
'51730' = '40060'
'51735' = '47260'
'51740' = '47260'
'51750' = '13980'
'51760' = '40060'
'51770' = '40220'
'51775' = '40220'
'51790' = '44420'
'51800' = '47260'
'51810' = '47260'
'51820' = '44420'
'51830' = '47260'
'51840' = '49020'
'53003' = '30300'
'53005' = '28420'
'53007' = '48300'
'53009' = '38820'
'53011' = '38900'
'53015' = '31020'
'53017' = '48300'
'53021' = '28420'
'53025' = '34180'
'53027' = '10140'
'53029' = '36020'
'53033' = '42660'
'53035' = '14740'
'53037' = '21260'
'53041' = '16500'
'53045' = '43220'
'53053' = '42660'
'53057' = '34580'
'53059' = '38900'
'53061' = '42660'
'53063' = '44060'
'53067' = '36500'
'53071' = '47460'
'53073' = '13380'
'53075' = '39420'
'53077' = '49420'
'54003' = '25180'
'54005' = '16620'
'54009' = '48260'
'54011' = '26580'
'54015' = '16620'
'54017' = '17220'
'54019' = '36060'
'54027' = '49020'
'54029' = '48260'
'54033' = '17220'
'54037' = '47900'
'54039' = '16620'
'54043' = '16620'
'54049' = '21900'
'54051' = '48540'
'54053' = '38580'
'54055' = '14140'
'54057' = '19060'
'54061' = '34060'
'54065' = '25180'
'54069' = '48540'
'54073' = '37620'
'54077' = '34060'
'54079' = '16620'
'54081' = '13220'
'54091' = '17220'
'54099' = '26580'
'54105' = '37620'
'54107' = '37620'
'55009' = '24580'
'55015' = '11540'
'55017' = '20740'
'55021' = '31540'
'55025' = '31540'
'55027' = '13180'
'55031' = '20260'
'55033' = '32860'
'55035' = '20740'
'55037' = '27020'
'55039' = '22540'
'55043' = '38420'
'55045' = '33820'
'55049' = '31540'
'55055' = '48020'
'55059' = '16980'
'55061' = '24580'
'55063' = '29100'
'55069' = '32980'
'55071' = '31820'
'55073' = '48140'
'55075' = '31940'
'55079' = '33340'
'55083' = '24580'
'55087' = '11540'
'55089' = '33340'
'55093' = '33460'
'55097' = '44620'
'55101' = '39540'
'55105' = '27500'
'55109' = '33460'
'55111' = '12660'
'55117' = '43100'
'55127' = '48580'
'55131' = '33340'
'55133' = '33340'
'55139' = '36780'
'55141' = '49220'
'56001' = '29660'
'56005' = '23940'
'56013' = '40180'
'56021' = '16940'
'56025' = '16220'
'56033' = '43260'
'56037' = '40540'
'56039' = '27220'
'56041' = '21740'
;

 /* --------------------------------------------------------------- */
 /* ---   OPERATING ROOM PROCEDURE CODES                           - */
 /* --------------------------------------------------------------- */

VALUE $ORPROC
"0050" = "1" /* IMPL CRT PACEMAKER SYS */
"0051" = "1" /* IMPL CRT DEFIBRILLAT SYS */
"0052" = "1" /* IMP/REP LEAD LF VEN SYS */
"0053" = "1" /* IMP/REP CRT PACEMAKR GEN */
"0054" = "1" /* IMP/REP CRT DEFIB GENAT */
"0056" = "1" /* INS/REP IMPL SENSOR LEAD */
"0057" = "1" /* IMP/REP SUBCUE CARD DEV */
"0061" = "1" /* PERC ANGIO PRECEREB VESS */
"0062" = "1" /* PERC ANGIO INTRACRAN VES */
"0066" = "1" /* PTCA OR CORONARY ATHER */
"0070" = "1" /* REV HIP REPL-ACETAB/FEM */
"0071" = "1" /* REV HIP REPL-ACETAB COMP */
"0072" = "1" /* REV HIP REPL-FEM COMP */
"0073" = "1" /* REV HIP REPL-LINER/HEAD */
"0080" = "1" /* REV KNEE REPLACEMT-TOTAL */
"0081" = "1" /* REV KNEE REPL-TIBIA COMP */
"0082" = "1" /* REV KNEE REPL-FEMUR COMP */
"0083" = "1" /* REV KNEE REPLACE-PATELLA */
"0084" = "1" /* REV KNEE REPL-TIBIA LIN */
"0085" = "1" /* RESRF HIPTOTAL-ACET/FEM */
"0086" = "1" /* RESRF HIPPART-FEM HEAD */
"0087" = "1" /* RESRF HIPPART-ACETABLUM */
"0094" = "1" /* INTRA-OP NEUROPHYS MONTR */
"0110" = "1" /* INTRACRAN PRESSURE MONTR */
"0112" = "1" /* OPEN CEREB MENINGES BX */
"0114" = "1" /* OPEN BRAIN BIOPSY */
"0115" = "1" /* SKULL BIOPSY */
"0116" = "1" /* INTRACRANIAL 02 MONITOR */
"0117" = "1" /* BRAIN TEMP MONITORING */
"0118" = "1" /* OTHER BRAIN DX PROCEDURE */
"0119" = "1" /* OTHER SKULL DX PROCEDURE */
"0120" = "1" /* IMP/REPL BRAIN PULSE GEN */
"0121" = "1" /* CRANIAL SINUS I & D */
"0122" = "1" /* REMOV INTRACRAN STIMULAT */
"0123" = "1" /* REOPEN CRANIOTOMY SITE */
"0124" = "1" /* OTHER CRANIOTOMY */
"0125" = "1" /* OTHER CRANIECTOMY */
"0128" = "1" /* INTRACEREB CTH-BURR HOLE */
"0129" = "1" /* REM BRAIN PULSE GENERATR */
"0131" = "1" /* INCISE CEREBRAL MENINGES */
"0132" = "1" /* LOBOTOMY & TRACTOTOMY */
"0139" = "1" /* OTHER BRAIN INCISION */
"0141" = "1" /* THALAMUS OPERATIONS */
"0142" = "1" /* GLOBUS PALLIDUS OPS */
"0151" = "1" /* EX CEREB MENINGEAL LES */
"0152" = "1" /* HEMISPHERECTOMY */
"0153" = "1" /* BRAIN LOBECTOMY */
"0159" = "1" /* OTHER BRAIN EXCISION */
"016 " = "1" /* EXCISE SKULL LESION */
"0201" = "1" /* LINEAR CRANIECTOMY */
"0202" = "1" /* ELEVATE SKULL FX FRAGMNT */
"0203" = "1" /* SKULL FLAP FORMATION */
"0204" = "1" /* BONE GRAFT TO SKULL */
"0205" = "1" /* SKULL PLATE INSERTION */
"0206" = "1" /* CRANIAL OSTEOPLASTY NEC */
"0207" = "1" /* SKULL PLATE REMOVAL */
"0211" = "1" /* SIMPLE SUTURE OF DURA */
"0212" = "1" /* BRAIN MENINGE REPAIR NEC */
"0213" = "1" /* MENINGE VESSEL LIGATION */
"0214" = "1" /* CHOROID PLEXECTOMY */
"022 " = "1" /* VENTRICULOSTOMY */
"0221" = "1" /*	INSERTION OR REPLACEMENT OF EXTERNAL VENTICULAR DRAIN [EVD] */
"0222" = "1" /*	INTRACRANIAL VENTICULAR SHUNT OR ANASTOMOSIS */
"0231" = "1" /* VENTRICL SHUNT-HEAD/NECK */
"0232" = "1" /* VENTRI SHUNT-CIRCULA SYS */
"0233" = "1" /* VENTRICL SHUNT-THORAX */
"0234" = "1" /* VENTRICL SHUNT-ABDOMEN */
"0235" = "1" /* VENTRI SHUNT-UNINARY SYS */
"0239" = "1" /* OTHER VENTRICULAR SHUNT */
"0242" = "1" /* REPLACE VENTRICLE SHUNT */
"0243" = "1" /* REMOVE VENTRICLE SHUNT */
"0291" = "1" /* LYSIS CORTICAL ADHESION */
"0292" = "1" /* BRAIN REPAIR */
"0293" = "1" /* IMPLANT BRAIN STIMULATOR */
"0294" = "1" /* INSERT/REPLAC SKULL TONG */
"0299" = "1" /* SKULL & BRAIN OP NEC */
"0301" = "1" /* REMOVAL FB SPINAL CANAL */
"0302" = "1" /* REOPEN LAMINECTOMY SITE */
"0309" = "1" /* SPINAL CANAL EXPLOR NEC */
"031 " = "1" /* INTRASPIN NERVE ROOT DIV */
"0321" = "1" /* PERCUTANEOUS CHORDOTOMY */
"0329" = "1" /* OTHER CHORDOTOMY */
"0332" = "1" /* SPINAL CORD/MENINGES BX */
"0339" = "1" /* OTHER SPINAL DX PROC */
"034 " = "1" /* EXCIS SPINAL CORD LESION */
"0351" = "1" /* SPINE MENINGOCELE REPAIR */
"0352" = "1" /* MYELOMENINGOCEL REPAIR */
"0353" = "1" /* VERTEBRAL FX REPAIR */
"0359" = "1" /* SPINAL STRUCT REPAIR NEC */
"036 " = "1" /* SPINAL CORD ADHESIOLYSIS */
"0371" = "1" /* SUBARACH-PERITON SHUNT */
"0372" = "1" /* SUBARACH-URETERAL SHUNT */
"0379" = "1" /* OTH SPINAL THECAL SHUNT */
"0393" = "1" /* INSERT SPINAL STIMULATOR */
"0394" = "1" /* REMOVE SPINAL STIMULATOR */
"0397" = "1" /* REVISE SPINE THECA SHUNT */
"0398" = "1" /* REMOVE SPINE THECA SHUNT */
"0399" = "1" /* SPINE CANAL STRUC OP NEC */
"0401" = "1" /* EXCISION ACOUSTC NEUROMA */
"0402" = "1" /* TRIGEMINAL NERV DIVISION */
"0403" = "1" /* PERIPH NERVE DIV NEC */
"0404" = "1" /* PERIPH NERVE INCIS NEC */
"0405" = "1" /* GASSERIAN GANGLIONECTOMY */
"0406" = "1" /* PERIPH GANGLIONECT NEC */
"0407" = "1" /* PERIPH NERV EXCISION NEC */
"0412" = "1" /* OPEN PERIPH NERVE BIOPSY */
"0419" = "1" /* PERIPH NERVE DX PROC NEC */
"043 " = "1" /* PERIPHERAL NERVE SUTURE */
"0441" = "1" /* DECOMPRESS TRIGEM ROOT */
"0442" = "1" /* CRAN NERV ROOT DECOM NEC */
"0443" = "1" /* CARPAL TUNNEL RELEASE */
"0444" = "1" /* TARSAL TUNNEL RELEASE */
"0449" = "1" /* PER NERVE ADHESIOLYS NEC */
"045 " = "1" /* PERIPHERAL NERVE GRAFT */
"046 " = "1" /* PERIPH NERVE TRANSPOSIT */
"0471" = "1" /* HYPOGLOSS-FACIAL ANASTOM */
"0472" = "1" /* ACCESSORY-FACIAL ANASTOM */
"0473" = "1" /* ACCESS-HYPOGLOSS ANASTOM */
"0474" = "1" /* PERIPH NERV ANASTOM NEC */
"0475" = "1" /* POSTOP REVIS PER NERV OP */
"0476" = "1" /* LATE REPAIR PER NERV INJ */
"0479" = "1" /* OTHER NEUROPLASTY */
"0491" = "1" /* NEURECTASIS */
"0492" = "1" /* IMPLANT PERIPH STIMULAT */
"0493" = "1" /* REMOVE PERIPH STIMULATOR */
"0499" = "1" /* PERIPHERAL NERVE OPS NEC */
"050 " = "1" /* SYMPATH NERVE DIVISION */
"0511" = "1" /* SYMPATHETIC NERVE BIOPSY */
"0519" = "1" /* SYMPATH NRV DX PROC NEC */
"0521" = "1" /* SPHENOPALATIN GANGLIONEC */
"0522" = "1" /* CERVICAL SYMPATHECTOMY */
"0523" = "1" /* LUMBAR SYMPATHECTOMY */
"0524" = "1" /* PRESACRAL SYMPATHECTOMY */
"0525" = "1" /* PERIART SYMPATHECTOMY */
"0529" = "1" /* OTHER SYMPATHECTOMY */
"0581" = "1" /* SYMPATHETIC NERVE REPAIR */
"0589" = "1" /* SYMPATHETIC NERVE OP NEC */
"059 " = "1" /* OTHER NERVOUS SYSTEM OPS */
"0602" = "1" /* REOPEN THYROID FIELD WND */
"0609" = "1" /* INCIS THYROID FIELD NEC */
"0612" = "1" /* OPEN THYROID GLAND BX */
"0613" = "1" /* PARATHYROID BIOPSY */
"0619" = "1" /* THYR/PARATHY DX PROC NEC */
"062 " = "1" /* UNILAT THYROID LOBECTOMY */
"0631" = "1" /* EXCISION THYROID LESION */
"0639" = "1" /* PART THYROIDECTOMY NEC */
"064 " = "1" /* COMPLETE THYROIDECTOMY */
"0650" = "1" /* SUBSTERN THYROIDECT NOS */
"0651" = "1" /* PART SUBSTERN THYROIDECT */
"0652" = "1" /* TOT SUBSTERN THYROIDECT */
"066 " = "1" /* LINGUAL THYROID EXCISION */
"067 " = "1" /* THYROGLOSS DUCT EXCISION */
"0681" = "1" /* TOTAL PARATHYROIDECTOMY */
"0689" = "1" /* OTHER PARATHYROIDECTOMY */
"0691" = "1" /* THYROID ISTHMUS DIVISION */
"0692" = "1" /* THYROID VESSEL LIGATION */
"0693" = "1" /* THYROID SUTURE */
"0694" = "1" /* THYROID REIMPLANTATION */
"0695" = "1" /* PARATHYROID REIMPLANT */
"0698" = "1" /* OTHER THYROID OPERATIONS */
"0699" = "1" /* OTHER PARATHYROID OPS */
"0700" = "1" /* ADRENAL EXPLORATION NOS */
"0701" = "1" /* UNILAT ADRENAL EXPLORAT */
"0702" = "1" /* BILAT ADRENAL EXPLORAT */
"0712" = "1" /* OPEN ADRENAL GLAND BX */
"0713" = "1" /* TRANSFRONT PITUITARY BX */
"0714" = "1" /* TRANSPHEN PITUITARY BX */
"0715" = "1" /* PITUITARY BIOPSY NOS */
"0716" = "1" /* THYMUS BIOPSY */
"0717" = "1" /* PINEAL BIOPSY */
"0719" = "1" /* ENDOCRINE DX PROC NEC */
"0721" = "1" /* ADRENAL LESION EXCISION */
"0722" = "1" /* UNILATERAL ADRENALECTOMY */
"0729" = "1" /* PART ADRENALECTOMY NEC */
"073 " = "1" /* BILATERAL ADRENALECTOMY */
"0741" = "1" /* ADRENAL INCISION */
"0742" = "1" /* ADRENAL NERVE DIVISION */
"0743" = "1" /* ADRENAL VESSEL LIGATION */
"0744" = "1" /* ADRENAL REPAIR */
"0745" = "1" /* ADRENAL REIMPLANTATION */
"0749" = "1" /* ADRENAL OPERATION NEC */
"0751" = "1" /* PINEAL FIELD EXPLORATION */
"0752" = "1" /* PINEAL GLAND INCISION */
"0753" = "1" /* PARTIAL PINEALECTOMY */
"0754" = "1" /* TOTAL PINEALECTOMY */
"0759" = "1" /* PINEAL OPERATION NEC */
"0761" = "1" /* EXC PITUIT LES-TRANSFRON */
"0762" = "1" /* EXC PITUIT LES-TRANSPHEN */
"0763" = "1" /* PART EXCIS PITUITARY NOS */
"0764" = "1" /* TOT EXC PITUIT-TRANSFRON */
"0765" = "1" /* TOT EXC PITUIT-TRANSPHEN */
"0768" = "1" /* TOTAL EXC PITUITARY NEC */
"0769" = "1" /* TOTAL EXC PITUITARY NOS */
"0771" = "1" /* PITUITARY FOSSA EXPLORAT */
"0772" = "1" /* PITUITARY GLAND INCISION */
"0779" = "1" /* PITUITARY OPERATION NEC */
"0780" = "1" /* THYMECTOMY NOS */
"0781" = "1" /* PART EXCISION OF THYMUS */
"0782" = "1" /* TOTAL EXCISION OF THYMUS */
"0783" = "1" /* THORAC PART EXISN THYMUS */
"0784" = "1" /* THORAC TOTAL EXC THYMUS */
"0791" = "1" /* THYMUS FIELD EXPLORATION */
"0792" = "1" /* INCISION OF THYMUS */
"0793" = "1" /* REPAIR OF THYMUS */
"0794" = "1" /* THYMUS TRANSPLANTATION */
"0795" = "1" /* THORAC INCISION THYMUS */
"0798" = "1" /* OTH THORAC OP THYMUS NOS */
"0799" = "1" /* THYMUS OPERATION NEC */
"0811" = "1" /* EYELID BIOPSY */
"0820" = "1" /* REMOVE EYELID LESION NOS */
"0821" = "1" /* CHALAZION EXCISION */
"0822" = "1" /* EXCISE MINOR LES LID NEC */
"0823" = "1" /* EXC MAJ LES LID PRT-THIC */
"0824" = "1" /* EXC MAJ LES LID FUL-THIC */
"0825" = "1" /* DESTRUCTION LID LESION */
"0831" = "1" /* PTOSIS REP-FRONT MUS SUT */
"0832" = "1" /* PTOSIS REP-FRON MUS SLNG */
"0833" = "1" /* PTOSIS REP-LEVAT MUS ADV */
"0834" = "1" /* PTOSIS REP-LEVAT MUS NEC */
"0835" = "1" /* PTOS REP-TARSAL TECHNIQ */
"0836" = "1" /* BLEPHAROPTOS REPAIR NEC */
"0837" = "1" /* REDUC OVERCORRECT PTOSIS */
"0838" = "1" /* CORRECT LID RETRACTION */
"0841" = "1" /* THERMOCAUT/ENTROPION REP */
"0842" = "1" /* SUTURE ENTROPION REPAIR */
"0843" = "1" /* WEDG RESEC ENTROPION REP */
"0844" = "1" /* LID RECONS ENTROPION REP */
"0849" = "1" /* ENTROPION/ECTROP REP NEC */
"0851" = "1" /* CANTHOTOMY */
"0852" = "1" /* BLEPHARORRHAPHY */
"0859" = "1" /* ADJUST LID POSITION NEC */
"0861" = "1" /* LID RECONST W SKIN GRAFT */
"0862" = "1" /* LID RECONST W MUC GRAFT */
"0863" = "1" /* LID RECONST W HAIR GRAFT */
"0864" = "1" /* LID RECON-TARSOCONJ FLAP */
"0869" = "1" /* LID RECONSTR W GRAFT NEC */
"0870" = "1" /* LID RECONSTRUCTION NOS */
"0871" = "1" /* LID MARG RECON-PART THIC */
"0872" = "1" /* LID RECONS-PART THIC NEC */
"0873" = "1" /* LID MARG RECONS FUL THIC */
"0874" = "1" /* LID RECONST-FUL THIC NEC */
"0891" = "1" /* ELECTROSURG LID EPILAT */
"0892" = "1" /* CRYOSURG LID EPILATION */
"0893" = "1" /* EYELID EPILATION NEC */
"0899" = "1" /* EYELID OPERATION NEC */
"090 " = "1" /* LACRIMAL GLAND INCISION */
"0911" = "1" /* LACRIMAL GLAND BIOPSY */
"0912" = "1" /* LACRIMAL SAC BIOPSY */
"0919" = "1" /* LACRIMAL SYS DX PROC NEC */
"0920" = "1" /* EXC LACRIMAL GLAND NOS */
"0921" = "1" /* EXCIS LES LACRIMAL GLAND */
"0922" = "1" /* PART DACRYOADENECT NEC */
"0923" = "1" /* TOTAL DACRYOADENECTOMY */
"093 " = "1" /* OTHER LACRIMAL GLAND OPS */
"0941" = "1" /* LACRIMAL PUNCTUM PROBE */
"0942" = "1" /* LAC CANALICULI PROBE */
"0943" = "1" /* NASOLACRIMAL DUCT PROBE */
"0944" = "1" /* NASOLAC DUCT INTUBAT */
"0949" = "1" /* LAC PASSAGE MANIP NEC */
"0951" = "1" /* LAC PUNCTUM INCISION */
"0952" = "1" /* LAC CANALICULI INCISION */
"0953" = "1" /* LACRIMAL SAC INCISION */
"0959" = "1" /* LACRIM PASSAGE INCIS NEC */
"096 " = "1" /* LACRIM SAC/PASSAGE EXCIS */
"0971" = "1" /* CORRECT EVERTED PUNCTUM */
"0972" = "1" /* PUNCTUM REPAIR NEC */
"0973" = "1" /* CANALICULUS REPAIR */
"0981" = "1" /* DACRYOCYSTORHINOSTOMY */
"0982" = "1" /* CONJUNCTIVOCYSTORHINOST */
"0983" = "1" /* CONJUNCTIVORHINOS W TUBE */
"0991" = "1" /* LAC PUNCTUM OBLITERATION */
"0999" = "1" /* LACRIMAL SYSTEM OP NEC */
"100 " = "1" /* INCISE/REMOV CONJUNCT FB */
"101 " = "1" /* CONJUNCTIVA INCISION NEC */
"1021" = "1" /* CONJUNCTIVAL BIOPSY */
"1029" = "1" /* CONJUNCTIVA DX PROC NEC */
"1031" = "1" /* EXCISE CONJUNCTIV LESION */
"1032" = "1" /* DESTRUCT CONJUNC LES NEC */
"1033" = "1" /* OTH CONJUNC DESTRUC PROC */
"1041" = "1" /* SYMBLEPH REP W FREE GRFT */
"1042" = "1" /* GRAFT CONJUNC CUL-DE-SAC */
"1043" = "1" /* CONJUN CUL-DE-SAC RX NEC */
"1044" = "1" /* CONJUNC FREE GRAFT NEC */
"1049" = "1" /* CONJUNCTIVOPLASTY NEC */
"105 " = "1" /* CONJUNC/LID ADHESIOLYSIS */
"106 " = "1" /* REPAIR CONJUNCT LACERAT */
"1091" = "1" /* SUBCONJUNCTIVAL INJECT */
"1099" = "1" /* CONJUNCTIVAL OP NEC */
"110 " = "1" /* MAGNET REMOVAL CORNEA FB */
"111 " = "1" /* CORNEAL INCISION */
"1121" = "1" /* CORNEAL SCRAPE FOR SMEAR */
"1122" = "1" /* CORNEAL BIOPSY */
"1129" = "1" /* CORNEAL DX PROC NEC */
"1131" = "1" /* PTERYGIUM TRANSPOSITION */
"1132" = "1" /* PTERYG EXC W CORNEA GRFT */
"1139" = "1" /* PTERYGIUM EXCISION NEC */
"1141" = "1" /* MECH REMOV CORNEA EPITH */
"1142" = "1" /* THERMOCAUT CORNEA LESION */
"1143" = "1" /* CRYOTHERAP CORNEA LESION */
"1149" = "1" /* DESTRUCT CORNEA LES NEC */
"1151" = "1" /* SUTURE CORNEA LACERATION */
"1152" = "1" /* REP CORNEA POSTOP DEHISC */
"1153" = "1" /* RX CORNEA LAC W CONJ FLP */
"1159" = "1" /* CORNEAL REPAIR NEC */
"1160" = "1" /* CORNEAL TRANSPLANT NOS */
"1161" = "1" /* LAM KERATPLAST W AUTGRFT */
"1162" = "1" /* LAMELLAR KERATOPLAST NEC */
"1163" = "1" /* PERF KERATOPL W AUTOGRFT */
"1164" = "1" /* PERFORAT KERATOPLAST NEC */
"1169" = "1" /* CORNEAL TRANSPLANT NEC */
"1171" = "1" /* KERATOMILEUSIS */
"1172" = "1" /* KERATOPHAKIA */
"1173" = "1" /* KERATOPROSTHESIS */
"1174" = "1" /* THERMOKERATOPLASTY */
"1175" = "1" /* RADIAL KERATOTOMY */
"1176" = "1" /* EPIKERATOPHAKIA */
"1179" = "1" /* CORNEA RECONSTRUCT NEC */
"1191" = "1" /* CORNEAL TATTOOING */
"1192" = "1" /* REMOVE CORNEAL IMPLANT */
"1199" = "1" /* CORNEAL OPERATION NEC */
"1200" = "1" /* REMOV ANT SEGMNT FB NOS */
"1201" = "1" /* MAGNET REMOV ANT SEG FB */
"1202" = "1" /* NONMAG REMOV ANT SEG FB */
"1211" = "1" /* IRIDOTOMY W TRANSFIXION */
"1212" = "1" /* IRIDOTOMY NEC */
"1213" = "1" /* PROLAPSED IRIS EXCISION */
"1214" = "1" /* IRIDECTOMY NEC */
"1221" = "1" /* DX ASPIRAT-ANT CHAMBER */
"1222" = "1" /* IRIS BIOPSY */
"1229" = "1" /* ANT SEGMENT DX PROC NEC */
"1231" = "1" /* GONIOSYNECHIAE LYSIS */
"1232" = "1" /* ANT SYNECHIA LYSIS NEC */
"1233" = "1" /* POST SYNECHIAE LYSIS */
"1234" = "1" /* CORNEOVITREAL ADHESIOLYS */
"1235" = "1" /* COREOPLASTY */
"1239" = "1" /* IRIDOPLASTY NEC */
"1240" = "1" /* REMOV ANT SEGMNT LES NOS */
"1241" = "1" /* NONEXC DESTRUC IRIS LES */
"1242" = "1" /* EXCISION OF IRIS LESION */
"1243" = "1" /* NONEXC DESTR CIL BOD LES */
"1244" = "1" /* EXCISE CILIARY BODY LES */
"1251" = "1" /* GONIOPUNCTURE */
"1252" = "1" /* GONIOTOMY */
"1253" = "1" /* GONIOTOMY W GONIOPUNCTUR */
"1254" = "1" /* TRABECULOTOMY AB EXTERNO */
"1255" = "1" /* CYCLODIALYSIS */
"1259" = "1" /* FACILIT INTRAOC CIRC NEC */
"1261" = "1" /* TREPHIN SCLERA W IRIDECT */
"1262" = "1" /* THERMCAUT SCLER W IRIDEC */
"1263" = "1" /* IRIDENCLEISIS/IRIDOTASIS */
"1264" = "1" /* TRABECULECTOM AB EXTERNO */
"1265" = "1" /* SCLER FISTULIZ W IRIDECT */
"1266" = "1" /* POSTOP REVIS SCL FISTUL */
"1267" = "1" /*	INSERTION OF AQUEOUS DRAINAGE DEVICE */
"1269" = "1" /* SCLER FISTULIZING OP NEC */
"1271" = "1" /* CYCLODIATHERMY */
"1272" = "1" /* CYCLOCRYOTHERAPY */
"1273" = "1" /* CYCLOPHOTOCOAGULATION */
"1274" = "1" /* CIL BODY DIMINUTION NOS */
"1279" = "1" /* GLAUCOMA PROCEDURE NEC */
"1281" = "1" /* SUTURE SCLERAL LACER */
"1282" = "1" /* SCLERAL FISTULA REPAIR */
"1283" = "1" /* REVIS ANT SEG OP WND NEC */
"1284" = "1" /* DESTRUCT SCLERAL LESION */
"1285" = "1" /* REPAIR STAPHYLOM W GRAFT */
"1286" = "1" /* REP SCLER STAPHYLOMA NEC */
"1287" = "1" /* GRAFT REINFORCE SCLERA */
"1288" = "1" /* SCLERA REINFORCEMENT NEC */
"1289" = "1" /* SCLERAL OPERATION NEC */
"1291" = "1" /* THERAPEUT EVAC ANT CHAMB */
"1292" = "1" /* ANTERIOR CHAMBER INJECT */
"1293" = "1" /* REMOV EPITHEL DOWNGROWTH */
"1297" = "1" /* IRIS OPERATION NEC */
"1298" = "1" /* CILIARY BODY OP NEC */
"1299" = "1" /* ANTERIOR CHAMBER OP NEC */
"1300" = "1" /* REMOVE FB LENS NOS */
"1301" = "1" /* MAGNET REMOVE FB LENS */
"1302" = "1" /* NONMAGNET REMOVE FB LENS */
"1311" = "1" /* TEMP-INF INTRCAP LENS EX */
"1319" = "1" /* INTRACAPSUL LENS EXT NEC */
"132 " = "1" /* LINEAR EXTRACAP LENS EXT */
"133 " = "1" /* SIMPL ASPIR LENS EXTRACT */
"1341" = "1" /* CATARAC PHACOEMULS/ASPIR */
"1342" = "1" /* POST CATARAC FRAG/ASPIR */
"1343" = "1" /* CATARACT FRAG/ASPIR NEC */
"1351" = "1" /* TEMP-INF XTRACAP LENS EX */
"1359" = "1" /* EXTRACAP LENS EXTRAC NEC */
"1361" = "1" /* EXTRACAP LENS EXTRAC NEC */
"1362" = "1" /* EXTRACAP LENS EXTRAC NEC */
"1363" = "1" /* EXTRACAP LENS EXTRAC NEC */
"1364" = "1" /* AFTER-CATAR DISCISSION */
"1365" = "1" /* AFTER-CATARACT EXCISION */
"1366" = "1" /* AFTER CATAR FRAGMNTATION */
"1369" = "1" /* CATARACT EXTRACTION NEC */
"1370" = "1" /* INSERT PSEUDOPHAKOS NOS */
"1371" = "1" /* INSERT LENS AT CATAR EXT */
"1372" = "1" /* SECONDARY INSERT LENS */
"138 " = "1" /* IMPLANTED LENS REMOVAL */
"139 " = "1" /* OTHER OPERATIONS ON LENS */
"1390" = "1" /* OPERATION ON LENS NEC */
"1391" = "1" /* IMPL INTRAOC TELESC PROS */
"1400" = "1" /* REMOV POST SEGMNT FB NOS */
"1401" = "1" /* MAGNET REMOV POST SEG FB */
"1402" = "1" /* NONMAG REMOV POST SEG FB */
"1411" = "1" /* DIAGNOST VITREOUS ASPIR */
"1419" = "1" /* DX PROC POST SEG NEC */
"1421" = "1" /* CHORIORET LES DIATHERMY */
"1422" = "1" /* CHORIORETIN LES CRYOTHER */
"1426" = "1" /* CHORIORET LES RADIOTHER */
"1427" = "1" /* CHORIORET LES RAD IMPLAN */
"1429" = "1" /* CHORIORET LES DESTR NEC */
"1431" = "1" /* RETINAL TEAR DIATHERMY */
"1432" = "1" /* RETINAL TEAR CRYOTHERAPY */
"1439" = "1" /* RETINAL TEAR REPAIR NEC */
"1441" = "1" /* SCLERAL BUCKLE W IMPLANT */
"1449" = "1" /* SCLERAL BUCKLING NEC */
"1451" = "1" /* DETACH RETINA-DIATHERMY */
"1452" = "1" /* DETACH RETINA-CRYOTHERAP */
"1453" = "1" /* DETACH RETINA XENON COAG */
"1454" = "1" /* DETACH RETINA LASER COAG */
"1455" = "1" /* DETACH RET PHOTOCOAG NOS */
"1459" = "1" /* REPAIR RETINA DETACH NEC */
"146 " = "1" /* REMOV PROS MAT POST SEG */
"1471" = "1" /* ANTERIOR REMOV VITREOUS */
"1472" = "1" /* VITREOUS REMOVAL NEC */
"1473" = "1" /* ANTERIOR MECHAN VITRECT */
"1474" = "1" /* MECH VITRECTOMY NEC */
"1475" = "1" /* VITREOUS SUBSTITUT INJEC */
"1479" = "1" /* VITREOUS OPERATION NEC */
"149 " = "1" /* OTHER POST SEGMENT OPS */
"1501" = "1" /* EXTRAOC MUSC-TEND BIOPSY */
"1509" = "1" /* EXTRAOC MUSC DX PROC NEC */
"1511" = "1" /* ONE EXTRAOC MUS RECESS */
"1512" = "1" /* 1 EXTRAOC MUSCL ADVANCE */
"1513" = "1" /* 1 EXTRAOC MUSCL RESECT */
"1519" = "1" /* XTRAOC MUS OP/DETACH NEC */
"1521" = "1" /* LENGTHEN 1 EXTRAOC MUSC */
"1522" = "1" /* SHORTEN 1 EXTRAOC MUSC */
"1529" = "1" /* OP ON 1 EXTRAOC MUSC NEC */
"153 " = "1" /* TEMP DETACH >1 XTROC MUS */
"154 " = "1" /* OTH OP ON >L EXTRAOC MUS */
"155 " = "1" /* EXTRAOCUL MUS TRANSPOSIT */
"156 " = "1" /* REVIS EXTRAOC MUSC SURG */
"157 " = "1" /* EXTRAOC MUSC INJ REPAIR */
"159 " = "1" /* OTH EXTRAOC MUS-TEND OP */
"1601" = "1" /* ORBITOTOMY W BONE FLAP */
"1602" = "1" /* ORBITOTOMY W IMPLANT */
"1609" = "1" /* ORBITOTOMY NEC */
"161 " = "1" /* REMOVE PENETRAT FB EYE */
"1622" = "1" /* DIAGNOSTIC ASP OF ORBIT */
"1623" = "1" /* EYEBALL & ORBIT BIOPSY */
"1629" = "1" /* EYEBAL/ORBIT DX PROC NEC */
"1631" = "1" /* EYE EVISC W SYNCH IMPLAN */
"1639" = "1" /* EYEBALL EVISCERATION NEC */
"1641" = "1" /* EYE ENUC/IMPLAN/MUSC ATT */
"1642" = "1" /* EYE ENUC W IMPLANT NEC */
"1649" = "1" /* EYEBALL ENUCLEATION NEC */
"1651" = "1" /* RADICAL ORBITOMAXILLECT */
"1652" = "1" /* ORBIT EXENT W BONE REMOV */
"1659" = "1" /* ORBITAL EXENTERATION NEC */
"1661" = "1" /* 2NDRY OCULAR IMP INSERT */
"1662" = "1" /* REVIS/REINSERT OCUL IMP */
"1663" = "1" /* REVIS ENUC SOCKET W GRFT */
"1664" = "1" /* ENUC SOCKET REVIS NEC */
"1665" = "1" /* 2NDRY EXENT CAVITY GRAFT */
"1666" = "1" /* REVIS EXENTER CAVITY NEC */
"1669" = "1" /* 2ND OP POST EYE REM NEC */
"1671" = "1" /* REMOVE OCULAR IMPLANT */
"1672" = "1" /* REMOVE ORBITAL IMPLANT */
"1681" = "1" /* REPAIR OF ORBITAL WOUND */
"1682" = "1" /* REPAIR EYEBALL RUPTURE */
"1689" = "1" /* EYE/ORBIT INJ REPAIR NEC */
"1692" = "1" /* EXCISION ORBITAL LESION */
"1693" = "1" /* EXCISION EYE LESION NOS */
"1698" = "1" /* OPERATION ON ORBIT NEC */
"1699" = "1" /* OPERATION ON EYEBALL NEC */
"1711" = "1" /* LAP DIR ING HERN-GRAFT */
"1712" = "1" /* LAP INDIR ING HERN-GRAFT */
"1713" = "1" /* LAP ING HERN-GRAFT NOS */
"1721" = "1" /* LAP BIL DIR ING HRN-GRFT */
"1722" = "1" /* LAP BI INDIR ING HRN-GRF */
"1723" = "1" /* LAP BI DR/IND ING HRN-GR */
"1724" = "1" /* LAP BIL ING HERN-GRF NOS */
"1731" = "1" /* LAP MUL SEG RES LG INTES */
"1732" = "1" /* LAPAROSCOPIC CECECTOMY */
"1733" = "1" /* LAP RIGHT HEMICOLECTOMY */
"1734" = "1" /* LAP RES TRANSVERSE COLON */
"1735" = "1" /* LAP LEFT HEMICOLECTOMY */
"1736" = "1" /* LAP SIGMOIDECTOMY */
"1739" = "1" /* LAP PT EX LRG INTEST NEC */
"1751" = "1" /* IMPLANT CCM,TOTAL SYSTEM */ 
"1752" = "1" /* IMPLANT CCM PULSE GENRTR */
"1753" = "1" /*	PERCUTANEOUS ATHERECTOMY OF EXTRACRANIAL VESSEL(S) */
"1754" = "1" /*	PERCUTANEOUS ATHERECTOMY OF INTRACRANIAL VESSEL(S) */
"1755" = "1" /*	TRANSLUMINAL CORONARY ATHERECTOMY */
"1756" = "1" /*	ATHERECTOMY OF OTHER NON-CORONARY VESSEL(S) */
"1761" = "1" /* LITT LESN BRAIN,GUIDANCE */
"1762" = "1" /* LITT LES HD/NCK,GUIDANCE */
"1763" = "1" /* LITT LESN LIVER,GUIDANCE */ 
"1769" = "1" /* LITT LESN, GUIDE OTH/NOS */ 
"1821" = "1" /* PREAURICULAR SINUS EXCIS */
"1831" = "1" /* RAD EXCIS EXT EAR LES */
"1839" = "1" /* EXCIS EXTERNAL EAR NEC */
"185 " = "1" /* CORRECTION PROMINENT EAR */
"186 " = "1" /* EXT AUDIT CANAL RECONSTR */
"1871" = "1" /* CONSTRUCTION EAR AURICLE */
"1872" = "1" /* REATTACH AMPUTATED EAR */
"1879" = "1" /* PLASTIC REP EXT EAR NEC */
"189 " = "1" /* OTHER EXT EAR OPERATIONS */
"190 " = "1" /* STAPES MOBILIZATION */
"1911" = "1" /* STAPEDECT W REPLAC INCUS */
"1919" = "1" /* STAPEDECTOMY NEC */
"1921" = "1" /* REV STAPDEC W INCUS REPL */
"1929" = "1" /* STAPEDECTOMY REVIS NEC */
"193 " = "1" /* OSSICULAR CHAIN OP NEC */
"194 " = "1" /* MYRINGOPLASTY */
"1952" = "1" /* TYPE 2 TYMPANOPLASTY */
"1953" = "1" /* TYPE 3 TYMPANOPLASTY */
"1954" = "1" /* TYPE 4 TYMPANOPLASTY */
"1955" = "1" /* TYPE 5 TYMPANOPLASTY */
"196 " = "1" /* TYMPANOPLASTY REVISION */
"199 " = "1" /* MIDDLE EAR REPAIR NEC */
"2001" = "1" /* MYRINGOTOMY W INTUBATION */
"2021" = "1" /* MASTOID INCISION */
"2022" = "1" /* PETRUS PYRAM AIR CEL INC */
"2023" = "1" /* MIDDLE EAR INCISION */
"2032" = "1" /* MID & INNER EAR BIOPSY */
"2039" = "1" /* MID/IN EAR DX PROC NEC */
"2041" = "1" /* SIMPLE MASTOIDECTOMY */
"2042" = "1" /* RADICAL MASTOIDECTOMY */
"2049" = "1" /* MASTOIDECTOMY NEC */
"2051" = "1" /* EXCISE MIDDLE EAR LESION */
"2059" = "1" /* MIDDLE EAR EXCISION NEC */
"2061" = "1" /* INNER EAR FENESTRATION */
"2062" = "1" /* REVIS INNER EAR FENESTRA */
"2071" = "1" /* ENDOLYMPHATIC SHUNT */
"2072" = "1" /* INNER EAR INJECTION */
"2079" = "1" /* INC/EXC/DESTR IN EAR NEC */
"2091" = "1" /* TYMPANOSYMPATHECTOMY */
"2092" = "1" /* MASTOIDECTOMY REVISION */
"2093" = "1" /* REPAIR OVAL/ROUND WINDOW */
"2095" = "1" /* ELECMAG HEAR DEV IMPLANT */
"2096" = "1" /* IMPLT COCHLEAR PROST NOS */
"2097" = "1" /* IMP/REP SCHAN COCH PROS */
"2098" = "1" /* IMP/REP MCHAN COCHL PROS */
"2099" = "1" /* MID-INNER EAR OPS NEC */
"2104" = "1" /* ETHMOID ART LIGAT-EPIST */
"2105" = "1" /* MAX ART LIG FOR EPISTAX */
"2106" = "1" /* EXT CAROT ART LIG-EPIST */
"2107" = "1" /* NASAL SEPT GRFT-EPISTAX */
"2109" = "1" /* EPISTAXIS CONTROL NEC */
"214 " = "1" /* RESECTION OF NOSE */
"215 " = "1" /* SUBMUC NASAL SEPT RESECT */
"2161" = "1" /* DIATHER/CRYO TURBINECTOM */
"2162" = "1" /* TURBINATE FRACTURE */
"2169" = "1" /* TURBINECTOMY NEC */
"2172" = "1" /* OPEN REDUCTION NASAL FX */
"2182" = "1" /* NASAL FISTULA CLOSURE */
"2183" = "1" /* TOT NASAL RECONSTRUCTION */
"2184" = "1" /* REVISION RHINOPLASTY */
"2185" = "1" /* AUGMENTATION RHINOPLASTY */
"2186" = "1" /* LIMITED RHINOPLASTY */
"2187" = "1" /* RHINOPLASTY NEC */
"2188" = "1" /* SEPTOPLASTY NEC */
"2189" = "1" /* NASAL REPAIR NEC */
"2199" = "1" /* NASAL OPERATION NEC */
"2212" = "1" /* OPEN BIOPSY NASAL SINUS */
"2231" = "1" /* RADICAL MAXILLARY ANTROT */
"2239" = "1" /* EXT MAXILLARY ANTROT NEC */
"2241" = "1" /* FRONTAL SINUSOTOMY */
"2242" = "1" /* FRONTAL SINUSECTOMY */
"2250" = "1" /* SINUSOTOMY NOS */
"2251" = "1" /* ETHMOIDOTOMY */
"2252" = "1" /* SPHENOIDOTOMY */
"2253" = "1" /* MULTIPLE SINUS INCISION */
"2260" = "1" /* SINUSECTOMY NOS */
"2261" = "1" /* C-LUC EXC MAX SINUS LES */
"2262" = "1" /* EXC MAX SINUS LESION NEC */
"2263" = "1" /* ETHMOIDECTOMY */
"2264" = "1" /* SPHENOIDECTOMY */
"2271" = "1" /* NASAL SINUS FISTULA CLOS */
"2279" = "1" /* NASAL SINUS REPAIR NEC */
"229 " = "1" /* OTHER NASAL SINUS OPS */
"242 " = "1" /* GINGIVOPLASTY */
"244 " = "1" /* EXC OF DENTAL LES OF JAW */
"245 " = "1" /* ALVEOLOPLASTY */
"2502" = "1" /* OPEN BIOPSY OF TONGUE */
"251 " = "1" /* DESTRUCTION TONGUE LES */
"252 " = "1" /* PARTIAL GLOSSECTOMY */
"253 " = "1" /* COMPLETE GLOSSECTOMY */
"254 " = "1" /* RADICAL GLOSSECTOMY */
"2559" = "1" /* REPAIR OF TONGUE NEC */
"2594" = "1" /* OTHER GLOSSOTOMY */
"2599" = "1" /* TONGUE OPERATION NEC */
"2612" = "1" /* OPEN BX SALIV GLAND/DUCT */
"2621" = "1" /* SALIVARY CYST MARSUPIAL */
"2629" = "1" /* SALIV LESION EXCIS NEC */
"2630" = "1" /* SIALOADENECTOMY NOS */
"2631" = "1" /* PARTIAL SIALOADENECTOMY */
"2632" = "1" /* COMPLETE SIALOADENECTOMY */
"2641" = "1" /* SUTURE OF SALIV GLND LAC */
"2642" = "1" /* SALIVARY FISTULA CLOSURE */
"2649" = "1" /* SALIVARY REPAIR NEC */
"2699" = "1" /* SALIVARY OPERATION NEC */
"270 " = "1" /* DRAIN FACE & MOUTH FLOOR */
"271 " = "1" /* INCISION OF PALATE */
"2721" = "1" /* BONY PALATE BIOPSY */
"2722" = "1" /* UVULA AND SOFT PALATE BX */
"2731" = "1" /* LOC EXC BONY PALATE LES */
"2732" = "1" /* WIDE EXC BONY PALATE LES */
"2742" = "1" /* WIDE EXCISION OF LIP LES */
"2743" = "1" /* EXCISION OF LIP LES NEC */
"2749" = "1" /* EXCISION OF MOUTH NEC */
"2753" = "1" /* CLOSURE OF MOUTH FISTULA */
"2754" = "1" /* REPAIR OF CLEFT LIP */
"2755" = "1" /* FULL-THICK GRFT TO MOUTH */
"2756" = "1" /* SKIN GRAFT TO MOUTH NEC */
"2757" = "1" /* PEDICLE ATTACH TO MOUTH */
"2759" = "1" /* MOUTH REPAIR NEC */
"2761" = "1" /* SUTURE OF PALATE LACERAT */
"2762" = "1" /* CLEFT PALATE CORRECTION */
"2763" = "1" /* REVIS CLEFT PALAT REPAIR */
"2769" = "1" /* OTH PLASTIC REPAIR PALAT */
"2771" = "1" /* INCISION OF UVULA */
"2772" = "1" /* EXCISION OF UVULA */
"2773" = "1" /* REPAIR OF UVULA */
"2779" = "1" /* OTHER UVULA OPERATIONS */
"2792" = "1" /* MOUTH INCISION NOS */
"2799" = "1" /* ORAL CAVITY OPS NEC */
"280 " = "1" /* PERITONSILLAR I & D */
"2811" = "1" /* TONSIL&ADENOID BIOPSY */
"2819" = "1" /* TONSIL&ADENOID DX OP NEC */
"282 " = "1" /* TONSILLECTOMY */
"283 " = "1" /* TONSILLECTOMY/ADENOIDEC */
"284 " = "1" /* EXCISION OF TONSIL TAG */
"285 " = "1" /* EXCISION LINGUAL TONSIL */
"286 " = "1" /* ADENOIDECTOMY */
"287 " = "1" /* HEMORR CONTRL POST T & A */
"2891" = "1" /* INCIS TO REMOV TONSIL FB */
"2892" = "1" /* EXCIS TONSIL/ADENOID LES */
"2899" = "1" /* TONSIL/ADENOID OPS NEC */
"290 " = "1" /* PHARYNGOTOMY */
"292 " = "1" /* EXC BRANCHIAL CLEFT CYST */
"293 " = "1" /* EXC BRANCHIAL CLEFT CYST */
"2931" = "1" /* CRICOPHARYNGEAL MYOTOMY */
"2932" = "1" /* PHARYNGEAL DIVERTICULEC */
"2933" = "1" /* PHARYNGECTOMY */
"2939" = "1" /* EXCIS/DESTR LES PHAR NEC */
"294 " = "1" /* PLASTIC OP ON PHARYNX */
"2951" = "1" /* SUTURE OF PHARYNGEAL LAC */
"2952" = "1" /* CLOS BRANCH CLEFT FISTUL */
"2953" = "1" /* CLOS PHARYNX FISTULA NEC */
"2954" = "1" /* LYSIS PHARYNGEAL ADHES */
"2959" = "1" /* PHARYNGEAL REPAIR NEC */
"2992" = "1" /* DIVIS GLOSSOPHARYNG NERV */
"2999" = "1" /* PHARYNGEAL OPERATION NEC */
"3001" = "1" /* LARYNX CYST MARSUPIALIZ */
"3009" = "1" /* DESTRUCT LARYNX LES NEC */
"301 " = "1" /* HEMILARYNGECTOMY */
"3021" = "1" /* EPIGLOTTIDECTOMY */
"3022" = "1" /* VOCAL CORDECTOMY */
"3029" = "1" /* OTHER PART LARYNGECTOMY */
"303 " = "1" /* COMPLETE LARYNGECTOMY */
"304 " = "1" /* RADICAL LARYNGECTOMY */
"3121" = "1" /* MEDIASTINAL TRACHEOSTOMY */
"3129" = "1" /* OTHER PERM TRACHEOSTOMY */
"313 " = "1" /* INCIS LARYNX TRACHEA NEC */
"3145" = "1" /* OPN BX LARYNX OR TRACHEA */
"315 " = "1" /* LOCAL DESTRUC TRACH LES */
"3161" = "1" /* SUTURE OF LARYNGEAL LAC */
"3162" = "1" /* LARYNGEAL FISTULA CLOS */
"3163" = "1" /* LARYNGOSTOMY REVISION */
"3164" = "1" /* LARYNGEAL FX REPAIR */
"3169" = "1" /* OTHER LARYNGEAL REPAIR */
"3171" = "1" /* SUTURE OF TRACHEAL LACER */
"3172" = "1" /* CLOSURE OF TRACHEOSTOMY */
"3173" = "1" /* TRACHEA FISTULA CLOS NEC */
"3174" = "1" /* REVISION OF TRACHEOSTOMY */
"3175" = "1" /* TRACHEAL RECONSTRUCTION */
"3179" = "1" /* OTHER TRACHEAL REPAIR */
"3191" = "1" /* LARYNGEAL NERV DIVISION */
"3192" = "1" /* LYSIS TRACH/LARYNX ADHES */
"3198" = "1" /* OTH LARYNGEAL OPERATION */
"3199" = "1" /* OTHER TRACHEAL OPERATION */
"320 " = "1" /* OTHER TRACHEAL OPERATION */
"3209" = "1" /* OTHER DESTRUC BRONC LES */
"321 " = "1" /* OTHER BRONCHIAL EXCISION */
"3220" = "1" /* THORAC EXC LUNG LESION */
"3221" = "1" /* EMPHYSEMA BLEB PLICATION */
"3222" = "1" /* LUNG VOL REDUCTION SURG */
"3223" = "1" /* OPEN ABLTN LUNG LES/TISS */
"3224" = "1" /* PERC ABLTN LUNG LES/TISS */
"3225" = "1" /* THOR ABLTN LUNG LES/TISS */
"3226" = "1" /* ABLTN LUNG TISS NEC/NOS */
"3227" = "1" /* BRNC THRMPLSTYABLT MSCL	 */ 
"3229" = "1" /* DESTROY LOC LUNG LES NEC */
"323 " = "1" /* SEGMENTAL LUNG RESECTION */
"3230" = "1" /* THORAC SEG LUNG RESECT */
"3239" = "1" /* OTH SEG LUNG RESECT NOS */
"324 " = "1" /* LOBECTOMY OF LUNG */
"3241" = "1" /* THORAC LOBECTOMY LUNG */
"3249" = "1" /* LOBECTOMY OF LUNG NEC */
"325 " = "1" /* COMPLETE PNEUMONECTOMY */
"3250" = "1" /* THORACOSPC PNEUMONECTOMY */
"3259" = "1" /* OTHER PNEUMONECTOMY NOS */
"326 " = "1" /* RAD DISSEC THORAC STRUCT */
"329 " = "1" /* OTHER EXCISION OF LUNG */
"330 " = "1" /* INCISION OF BRONCHUS */
"331 " = "1" /* INCISION OF LUNG */
"3320" = "1" /* THORACOSCOPC LUNG BIOPSY */
"3325" = "1" /* OPEN BRONCHIAL BIOPSY */
"3327" = "1" /* CLOS ENDOSCOPIC LUNG BX */
"3328" = "1" /* OPEN LUNG BIOPSY */
"3329" = "1" /* BRONCH/LUNG DX PROC NEC */
"3334" = "1" /* THORACOPLASTY */
"3339" = "1" /* SURG COLLAPS OF LUNG NEC */
"3341" = "1" /* BRONCHIAL LACERAT SUTURE */
"3342" = "1" /* BRONCHIAL FISTULA CLOS */
"3343" = "1" /* LUNG LACERATION CLOSURE */
"3348" = "1" /* BRONCHIAL REPAIR NEC */
"3349" = "1" /* LUNG REPAIR NEC */
"335 " = "1" /* LUNG REPAIR NEC */
"3350" = "1" /* LUNG TRANSPLANT NOS */
"3351" = "1" /* UNILAT LUNG TRANSPLANT */
"3352" = "1" /* BILAT LUNG TRANSPLANT */
"336 " = "1" /* COMB HEART/LUNG TRANSPLA */
"3392" = "1" /* BRONCHIAL LIGATION */
"3393" = "1" /* PUNCTURE OF LUNG */
"3398" = "1" /* BRONCHIAL OPERATION NEC */
"3399" = "1" /* LUNG OPERATION NEC */
"3402" = "1" /* EXPLORATORY THORACOTOMY */
"3403" = "1" /* REOPEN THORACOTOMY SITE */
"3406" = "1" /* THORAC DRAIN PLEURL CAV */
"341 " = "1" /* INCISION OF MEDIASTINUM */
"3420" = "1" /* THORACOSCOPIC PLEURAL BX */
"3421" = "1" /* TRANSPLEURA THORACOSCOPY */
"3422" = "1" /* MEDIASTINOSCOPY */
"3426" = "1" /* OPEN MEDIASTINAL BIOPSY */
"3427" = "1" /* BIOPSY OF DIAPHRAGM */
"3428" = "1" /* DX PROCEDURE THORAX NEC */
"3429" = "1" /* DX PROC MEDIASTINUM NEC */
"343 " = "1" /* DESTRUCT MEDIASTIN LES */
"344 " = "1" /* DESTRUCT CHEST WALL LES */
"3451" = "1" /* DECORTICATION OF LUNG */
"3452" = "1" /* THORACOSCOPC DECORT LUNG */
"3459" = "1" /* OTHER PLEURAL EXCISION */
"346 " = "1" /* SCARIFICATION OF PLEURA */
"3473" = "1" /* CLOS THORACIC FISTUL NEC */
"3474" = "1" /* PECTUS DEFORMITY REPAIR */
"3479" = "1" /* OTHER CHEST WALL REPAIR */
"3481" = "1" /* EXCISE DIAPHRAGM LESION */
"3482" = "1" /* SUTURE DIAPHRAGM LACERAT */
"3483" = "1" /* CLOSE DIAPHRAGM FISTULA */
"3484" = "1" /* OTHER DIAPHRAGM REPAIR */
"3485" = "1" /* IMPLANT DIAPHRA PACEMAKE */
"3489" = "1" /* DIAPHRAGM OPERATION NEC */
"3493" = "1" /* REPAIR OF PLEURA */
"3499" = "1" /* THORACIC OPERATION NEC */
"3500" = "1" /* CLOSED VALVOTOMY NOS */
"3501" = "1" /* CLOSED AORTIC VALVOTOMY */
"3502" = "1" /* CLOSED MITRAL VALVOTOMY */
"3503" = "1" /* CLOSED PULMON VALVOTOMY */
"3504" = "1" /* CLOSED TRICUSP VALVOTOMY */
"3505" = "1" /*	ENDOVASCULAR REPLACEMENT OF AORTIC VALVE */
"3506" = "1" /*	TRANSAPICAL REPLACEMENT OF AORTIC VALVE */
"3507" = "1" /*	ENDOVASCULAR REPLACEMENT OF PULMONARY  VALVE  */
"3508" = "1" /*	TRANSAPICAL REPLACEMENT OF PULMONARY VALVE  */
"3509" = "1" /*	ENDOVASCULAR REPLACEMENT OF UNSPECIFIED HEART VALVE */
"3510" = "1" /* OPEN VALVULOPLASTY NOS */
"3511" = "1" /* OPN AORTIC VALVULOPLASTY */
"3512" = "1" /* OPN MITRAL VALVULOPLASTY */
"3513" = "1" /* OPN PULMON VALVULOPLASTY */
"3514" = "1" /* OPN TRICUS VALVULOPLASTY */
"3520" = "1" /* REPLACE HEART VALVE NOS */
"3521" = "1" /* REPLACE AORT VALV-TISSUE */
"3522" = "1" /* REPLACE AORTIC VALVE NEC */
"3523" = "1" /* REPLACE MITR VALV-TISSUE */
"3524" = "1" /* REPLACE MITRAL VALVE NEC */
"3525" = "1" /* REPLACE PULM VALV-TISSUE */
"3526" = "1" /* REPLACE PULMON VALVE NEC */
"3527" = "1" /* REPLACE TRIC VALV-TISSUE */
"3528" = "1" /* REPLACE TRICUSP VALV NEC */
"3531" = "1" /* PAPILLARY MUSCLE OPS */
"3532" = "1" /* CHORDAE TENDINEAE OPS */
"3533" = "1" /* ANNULOPLASTY */
"3534" = "1" /* INFUNDIBULECTOMY */
"3535" = "1" /* TRABECUL CARNEAE CORD OP */
"3539" = "1" /* TISS ADJ TO VALV OPS NEC */
"3542" = "1" /* CREATE SEPTAL DEFECT */
"3550" = "1" /* PROSTH REP HRT SEPTA NOS */
"3551" = "1" /* PROS REP ATRIAL DEF-OPN */
"3552" = "1" /* PROS REPAIR ATRIA DEF-CL */
"3553" = "1" /* PROST REPAIR VENTRIC DEF */
"3554" = "1" /* PROS REP ENDOCAR CUSHION */
"3555" = "1" /* PROS REP VENTRC DEF-CLOS */
"3560" = "1" /* GRFT REPAIR HRT SEPT NOS */
"3561" = "1" /* GRAFT REPAIR ATRIAL DEF */
"3562" = "1" /* GRAFT REPAIR VENTRIC DEF */
"3563" = "1" /* GRFT REP ENDOCAR CUSHION */
"3570" = "1" /* HEART SEPTA REPAIR NOS */
"3571" = "1" /* ATRIA SEPTA DEF REP NEC */
"3572" = "1" /* VENTR SEPTA DEF REP NEC */
"3573" = "1" /* ENDOCAR CUSHION REP NEC */
"3581" = "1" /* TOT REPAIR TETRAL FALLOT */
"3582" = "1" /* TOTAL REPAIR OF TAPVC */
"3583" = "1" /* TOT REP TRUNCUS ARTERIOS */
"3584" = "1" /* TOT COR TRANSPOS GRT VES */
"3591" = "1" /* INTERAT VEN RETRN TRANSP */
"3592" = "1" /* CONDUIT RT VENT-PUL ART */
"3593" = "1" /* CONDUIT LEFT VENTR-AORTA */
"3594" = "1" /* CONDUIT ARTIUM-PULM ART */
"3595" = "1" /* HEART REPAIR REVISION */
"3596" = "1" /* PERC HEART VALVULOPLASTY */
"3597" = "1" /* PERC MTRL VLV REPR W IMP */	
"3598" = "1" /* OTHER HEART SEPTA OPS */
"3599" = "1" /* OTHER HEART VALVE OPS */
"3600" = "1" /* OTHER HEART VALVE OPS */
"3601" = "1" /* PTCA-1 VES/ATH W/O AGENT */
"3602" = "1" /* PTCA-1 VES/ATH W AGENT */
"3603" = "1" /* OPEN CORONRY ANGIOPLASTY */
"3605" = "1" /* PTCA-MULTIPLE VESSEL/ATH */
"3609" = "1" /* REM OF COR ART OBSTR NEC */
"3610" = "1" /* AORTOCORONARY BYPASS NOS */
"3611" = "1" /* AORTOCOR BYPAS-1 COR ART */
"3612" = "1" /* AORTOCOR BYPAS-2 COR ART */
"3613" = "1" /* AORTOCOR BYPAS-3 COR ART */
"3614" = "1" /* AORTCOR BYPAS-4+ COR ART */
"3615" = "1" /* 1 INT MAM-COR ART BYPASS */
"3616" = "1" /* 2 INT MAM-COR ART BYPASS */
"3617" = "1" /* ABD-CORON ARTERY BYPASS */
"3619" = "1" /* HRT REVAS BYPS ANAS NEC */
"362 " = "1" /* ARTERIAL IMPLANT REVASC */
"363 " = "1" /* ARTERIAL IMPLANT REVASC */
"3631" = "1" /* OPEN CHEST TRANS REVASC */
"3632" = "1" /* OTH TRANSMYO REVASCULAR */
"3633" = "1" /* ENDO TRANSMYO REVASCULAR */
"3634" = "1" /* PERC TRANSMYO REVASCULAR */
"3639" = "1" /* OTH HEART REVASCULAR */
"3691" = "1" /* CORON VESS ANEURYSM REP */
"3699" = "1" /* HEART VESSEL OP NEC */
"3710" = "1" /* INCISION OF HEART NOS */
"3711" = "1" /* CARDIOTOMY */
"3712" = "1" /* PERICARDIOTOMY */
"3724" = "1" /* PERICARDIAL BIOPSY */
"3731" = "1" /* PERICARDIECTOMY */
"3732" = "1" /* HEART ANEURYSM EXCISION */
"3733" = "1" /* EXC/DEST HRT LESION OPEN */
"3734" = "1" /* EXC/DEST HRT LES OTHER */
"3735" = "1" /* PARTIAL VENTRICULECTOMY */
"3737" = "1" /* EXC/DEST HRT LES THRSPC	 */   
"374 " = "1" /* HEART & PERICARD REPAIR */
"3741" = "1" /* IMPL CARDIAC SUPPORT DEV */
"3749" = "1" /* HEART/PERICARD REPR NEC */
"375 " = "1" /* HEART & PERICARD REPAIR */
"3751" = "1" /* HEART TRANSPLANTATION */
"3752" = "1" /* IMPLANT TOT REP HRT SYS */
"3753" = "1" /* REPL/REP THORAC UNIT HRT */
"3754" = "1" /* REPL/REP OTH TOT HRT SYS */
"3755" = "1" /* REM INT BIVENT HRT SYS */
"3760" = "1" /* IMP BIVN EXT HRT AST SYS */ 
"3761" = "1" /* PULSATION BALLOON IMPLAN */
"3762" = "1" /* IMPLANT HRT ASST SYS NEC */
"3763" = "1" /* REPLACE HRT ASSIST SYST */
"3764" = "1" /* REMOVE HEART ASSIST SYS */
"3765" = "1" /* IMP EXT PUL HRT ASST SYS */
"3766" = "1" /* IMP IMP PUL HRT ASST SYS */
"3767" = "1" /* IMP CARDIOMYOSTIMUL SYS */
"3768" = "1" /* PERCUTAN HRT ASSIST SYST */
"3774" = "1" /* INT OR REPL LEAD EPICAR */
"3775" = "1" /* REVISION OF LEAD */
"3776" = "1" /* REPL TV ATRI-VENT LEAD */
"3777" = "1" /* REMOVAL OF LEAD W/O REPL */
"3779" = "1" /* REVIS OR RELOCATE POCKET */
"3780" = "1" /* INT OR REPL PERM PACEMKR */
"3785" = "1" /* REPL PACEM W 1-CHAM, NON */
"3786" = "1" /* REPL PACEM 1-CHAM, RATE */
"3787" = "1" /* REPL PACEM W DUAL-CHAM */
"3789" = "1" /* REVISE OR REMOVE PACEMAK */
"3791" = "1" /* OPN CHEST CARDIAC MASSAG */
"3794" = "1" /* IMPLT/REPL CARDDEFIB TOT */
"3795" = "1" /* IMPLT CARDIODEFIB LEADS */
"3796" = "1" /* IMPLT CARDIODEFIB GENATR */
"3797" = "1" /* REPL CARDIODEFIB LEADS */
"3798" = "1" /* REPL CARDIODEFIB GENRATR */
"3799" = "1" /* OTHER HEART/PERICARD OPS */
"3800" = "1" /* INCISION OF VESSEL NOS */
"3801" = "1" /* INTRACRAN VESSEL INCIS */
"3802" = "1" /* HEAD/NECK VES INCIS NEC */
"3803" = "1" /* UPPER LIMB VESSEL INCIS */
"3804" = "1" /* INCISION OF AORTA */
"3805" = "1" /* THORACIC VESSEL INC NEC */
"3806" = "1" /* ABDOMEN ARTERY INCISION */
"3807" = "1" /* ABDOMINAL VEIN INCISION */
"3808" = "1" /* LOWER LIMB ARTERY INCIS */
"3809" = "1" /* LOWER LIMB VEIN INCISION */
"3810" = "1" /* ENDARTERECTOMY NOS */
"3811" = "1" /* INTRACRAN ENDARTERECTOMY */
"3812" = "1" /* HEAD & NECK ENDARTER NEC */
"3813" = "1" /* UPPER LIMB ENDARTERECTOM */
"3814" = "1" /* ENDARTERECTOMY OF AORTA */
"3815" = "1" /* THORACIC ENDARTERECTOMY */
"3816" = "1" /* ABDOMINAL ENDARTERECTOMY */
"3818" = "1" /* LOWER LIMB ENDARTERECT */
"3821" = "1" /* BLOOD VESSEL BIOPSY */
"3826" = "1" /* INSERTION OF IMPLANTABLE PRESSURE SENSOR WITHOUT LEAD FOR INTRACARDIAC OR GREAT VESSEL HEMODYNAMIC MONITORING */
"3829" = "1" /* BLOOD VESSEL DX PROC NEC */
"3830" = "1" /* VESSEL RESECT/ANAST NOS */
"3831" = "1" /* INTRACRAN VES RESEC-ANAS */
"3832" = "1" /* HEAD/NECK VES RESEC-ANAS */
"3833" = "1" /* ARM VESSEL RESECT/ANAST */
"3834" = "1" /* AORTA RESECTION & ANAST */
"3835" = "1" /* THOR VESSEL RESECT/ANAST */
"3836" = "1" /* ABD VESSEL RESECT/ANAST */
"3837" = "1" /* ABD VEIN RESECT & ANAST */
"3838" = "1" /* LEG ARTERY RESECT/ANAST */
"3839" = "1" /* LEG VEIN RESECT/ANASTOM */
"3840" = "1" /* VESSEL RESECT/REPLAC NOS */
"3841" = "1" /* INTRACRAN VES RESEC-REPL */
"3842" = "1" /* HEAD/NECK VES RESEC-REPL */
"3843" = "1" /* ARM VES RESECT W REPLACE */
"3844" = "1" /* RESECT ABDM AORTA W REPL */
"3845" = "1" /* RESECT THORAC VES W REPL */
"3846" = "1" /* ABD ARTERY RESEC W REPLA */
"3847" = "1" /* ABD VEIN RESECT W REPLAC */
"3848" = "1" /* LEG ARTERY RESEC W REPLA */
"3849" = "1" /* LEG VEIN RESECT W REPLAC */
"3850" = "1" /* VARICOSE V LIG-STRIP NOS */
"3851" = "1" /* INTCRAN VAR V LIG-STRIP */
"3852" = "1" /* HEAD/NECK VAR V LIG-STR */
"3853" = "1" /* ARM VARICOSE V LIG-STRIP */
"3855" = "1" /* THORAC VAR V LIG-STRIP */
"3857" = "1" /* ABD VARICOS V LIGA-STRIP */
"3859" = "1" /* LEG VARICOS V LIGA-STRIP */
"3860" = "1" /* EXCISION OF VESSEL NOS */
"3861" = "1" /* INTRACRAN VESSEL EXCIS */
"3862" = "1" /* HEAD/NECK VESSEL EXCIS */
"3863" = "1" /* ARM VESSEL EXCISION */
"3864" = "1" /* EXCISION OF AORTA */
"3865" = "1" /* THORACIC VESSEL EXCISION */
"3866" = "1" /* ABDOMINAL ARTERY EXCIS */
"3867" = "1" /* ABDOMINAL VEIN EXCISION */
"3868" = "1" /* LEG ARTERY EXCISION */
"3869" = "1" /* LEG VEIN EXCISION */
"3880" = "1" /* SURG VESSEL OCCLUS NEC */
"3881" = "1" /* OCCLUS INTRACRAN VES NEC */
"3882" = "1" /* OCCLUS HEAD/NECK VES NEC */
"3883" = "1" /* OCCLUDE ARM VESSEL NEC */
"3884" = "1" /* OCCLUDE AORTA NEC */
"3885" = "1" /* OCCLUDE THORACIC VES NEC */
"3886" = "1" /* OCCLUDE ABD ARTERY NEC */
"3887" = "1" /* OCCLUDE ABD VEIN NEC */
"3888" = "1" /* OCCLUDE LEG ARTERY NEC */
"3889" = "1" /* OCCLUDE LEG VEIN NEC */
"390 " = "1" /* SYSTEMIC-PULM ART SHUNT */
"391 " = "1" /* INTRA-ABD VENOUS SHUNT */
"3921" = "1" /* CAVAL-PULMON ART ANASTOM */
"3922" = "1" /* AORTA-SUBCLV-CAROT BYPAS */
"3923" = "1" /* INTRATHORACIC SHUNT NEC */
"3924" = "1" /* AORTA-RENAL BYPASS */
"3925" = "1" /* AORTA-ILIAC-FEMOR BYPASS */
"3926" = "1" /* INTRA-ABDOMIN SHUNT NEC */
"3927" = "1" /* DIALYSIS ARTERIOVENOSTOM */
"3928" = "1" /* EXTRACRAN-INTRACR BYPASS */
"3929" = "1" /* VASC SHUNT & BYPASS NEC */
"3930" = "1" /* SUTURE OF VESSEL NOS */
"3931" = "1" /* SUTURE OF ARTERY */
"3932" = "1" /* SUTURE OF VEIN */
"3941" = "1" /* POSTOP VASC OP HEM CONTR */
"3942" = "1" /* REVIS REN DIALYSIS SHUNT */
"3943" = "1" /* REMOV REN DIALYSIS SHUNT */
"3949" = "1" /* VASC PROC REVISION NEC */
"3950" = "1" /* ANGIO/ATH NON-CORO VES */
"3951" = "1" /* CLIPPING OF ANEURYSM */
"3952" = "1" /* ANEURYSM REPAIR NEC */
"3953" = "1" /* ARTERIOVEN FISTULA REP */
"3954" = "1" /* RE-ENTRY OPERATION */
"3955" = "1" /* REIMPLAN ABERR RENAL VES */
"3956" = "1" /* REPAIR VESS W TIS PATCH */
"3957" = "1" /* REP VESS W SYNTH PATCH */
"3958" = "1" /* REPAIR VESS W PATCH NOS */
"3959" = "1" /* REPAIR OF VESSEL NEC */
"397 " = "1" /* PER CARDIOPULMON BYPASS */
"3971" = "1" /* ENDO IMPL GRFT ABD AORTA */
"3972" = "1" /* ENDOVASC REPAIR HEAD VES */
"3973" = "1" /* ENDO IMP GRFT THOR AORTA */
"3974" = "1" /* ENDO REM OBS HD/NECK VES */
"3975" = "1" /* ENDO EMB HD/NK,BARE COIL */ 
"3976" = "1" /* ENDO EM HD/NK,BIOAC COIL */
"3977" = "1" /*	TEMPORARY (PARTIAL) THERAPEUTIC ENDOVASCULAR OCCLUSION OF VESSEL */
"3978" = "1" /*	ENDOVASCULAR IMPLANTATION OF BRANCHING OR FENESTRATED GRAFT(S) IN AORTA*/
"3979" = "1" /* ENDO REPAIR OTHER VESSEL */
"398 " = "1" /* CARTD BODY/SINUS/VASC OP */
"3981" = "1" /* IMP CRTD SINUS STMTOTL	 */ 
"3982" = "1" /* IMP/REP CRTD SINUS LEAD	 */         
"3983" = "1" /* IMP/REP CRTD SINUS GNRTR */	         
"3984" = "1" /* REV CRTD SINUS STM LEADS */	         
"3985" = "1" /* REV CRTD SINUS PULSE GEN */	         
"3986" = "1" /* REM CRTD SINUS STM TOTL	 */         
"3987" = "1" /* REM CRTD SINUS STM LEAD	 */         
"3988" = "1" /* REM CRTD SINUS PULSE GEN */	         
"3989" = "1" /* OTH CARTD BODY/SINUS OP	 */ 
"3991" = "1" /* FREEING OF VESSEL */
"3992" = "1" /* VEIN INJECT-SCLEROS AGNT */
"3993" = "1" /* INSERT VES-TO-VES CANNUL */
"3994" = "1" /* REPLAC VES-TO-VES CANNUL */
"3998" = "1" /* HEMORRHAGE CONTROL NOS */
"3999" = "1" /* VESSEL OPERATION NEC */
"400 " = "1" /* INCIS LYMPHATIC STRUCTUR */
"4011" = "1" /* LYMPHATIC STRUCT BIOPSY */
"4019" = "1" /* LYMPHATIC DIAG PROC NEC */
"4021" = "1" /* EXCIS DEEP CERVICAL NODE */
"4022" = "1" /* EXCISE INT MAMMARY NODE */
"4023" = "1" /* EXCISE AXILLARY NODE */
"4024" = "1" /* EXCISE INGUINAL NODE */
"4029" = "1" /* SIMP EXC LYMPH STRUC NEC */
"403 " = "1" /* REGIONAL LYMPH NODE EXC */
"4040" = "1" /* RAD NECK DISSECTION NOS */
"4041" = "1" /* UNILAT RAD NECK DISSECT */
"4042" = "1" /* BILAT RAD NECK DISSECT */
"4050" = "1" /* RAD NODE DISSECTION NOS */
"4051" = "1" /* RAD DISSEC AXILLARY NODE */
"4052" = "1" /* RAD DISSEC PERIAORT NODE */
"4053" = "1" /* RAD DISSECT ILIAC NODES */
"4054" = "1" /* RADICAL GROIN DISSECTION */
"4059" = "1" /* RAD NODE DISSECTION NEC */
"4061" = "1" /* THORAC DUCT CANNULATION */
"4062" = "1" /* THORACIC DUCT FISTULIZAT */
"4063" = "1" /* CLOSE THORACIC DUCT FIST */
"4064" = "1" /* LIGATE THORACIC DUCT */
"4069" = "1" /* THORACIC DUCT OP NEC */
"409 " = "1" /* LYMPH STRUCTURE OP NEC */
"412 " = "1" /* SPLENOTOMY */
"4133" = "1" /* OPEN SPLEEN BIOPSY */
"4141" = "1" /* SPLENIC CYST MARSUPIAL */
"4142" = "1" /* EXC SPLENIC LESION/TISS */
"4143" = "1" /* PARTIAL SPLENECTOMY */
"415 " = "1" /* TOTAL SPLENECTOMY */
"4193" = "1" /* EXC OF ACCESSORY SPLEEN */
"4194" = "1" /* SPLEEN TRANSPLANTATION */
"4195" = "1" /* REPAIR OF SPLEEN */
"4199" = "1" /* SPLEEN OPERATION NEC */
"4201" = "1" /* ESOPHAGEAL WEB INCISION */
"4209" = "1" /* ESOPHAGEAL INCISION NEC */
"4210" = "1" /* ESOPHAGOSTOMY NOS */
"4211" = "1" /* CERVICAL ESOPHAGOSTOMY */
"4212" = "1" /* ESOPH POUCH EXTERIORIZAT */
"4219" = "1" /* EXT FISTULIZAT ESOPH NEC */
"4221" = "1" /* ESOPHAGOSCOPY BY INCIS */
"4225" = "1" /* OPEN BIOPSY OF ESOPHAGUS */
"4231" = "1" /* LOC EXCIS ESOPH DIVERTIC */
"4232" = "1" /* LOCAL EXCIS ESOPHAG NEC */
"4239" = "1" /* DESTRUCT ESOPHAG LES NEC */
"4240" = "1" /* ESOPHAGECTOMY NOS */
"4241" = "1" /* PARTIAL ESOPHAGECTOMY */
"4242" = "1" /* TOTAL ESOPHAGECTOMY */
"4251" = "1" /* THORAC ESOPHAGOESOPHAGOS */
"4252" = "1" /* THORAC ESOPHAGOGASTROST */
"4253" = "1" /* THORAC SM BOWEL INTERPOS */
"4254" = "1" /* THORAC ESOPHAGOENTER NEC */
"4255" = "1" /* THORAC LG BOWEL INTERPOS */
"4256" = "1" /* THORAC ESOPHAGOCOLOS NEC */
"4258" = "1" /* THORAC INTERPOSITION NEC */
"4259" = "1" /* THORAC ESOPHAG ANAST NEC */
"4261" = "1" /* STERN ESOPHAGOESOPHAGOST */
"4262" = "1" /* STERN ESOPHAGOGASTROSTOM */
"4263" = "1" /* STERN SM BOWEL INTERPOS */
"4264" = "1" /* STERN ESOPHAGOENTER NEC */
"4265" = "1" /* STERN LG BOWEL INTERPOS */
"4266" = "1" /* STERN ESOPHAGOCOLOS NEC */
"4268" = "1" /* STERN INTERPOSITION NEC */
"4269" = "1" /* STERN ESOPHAG ANAST NEC */
"427 " = "1" /* ESOPHAGOMYOTOMY */
"4282" = "1" /* SUTURE ESOPHAGEAL LACER */
"4283" = "1" /* ESOPHAGOSTOMY CLOSURE */
"4284" = "1" /* ESOPH FISTULA REPAIR NEC */
"4285" = "1" /* ESOPHAG STRICTURE REPAIR */
"4286" = "1" /* PROD SUBQ TUNNEL NO ANAS */
"4287" = "1" /* ESOPHAGEAL GRAFT NEC */
"4289" = "1" /* ESOPHAGEAL REPAIR NEC */
"4291" = "1" /* LIGATION ESOPH VARIX */
"430 " = "1" /* GASTROTOMY */
"431 " = "1" /* GASTROTOMY */
"432 " = "1" /* OTHER GASTROSTOMY */
"433 " = "1" /* PYLOROMYOTOMY */
"4342" = "1" /* LOCAL GASTR EXCISION NEC */
"4349" = "1" /* LOCAL GASTR DESTRUCT NEC */
"435 " = "1" /* PROXIMAL GASTRECTOMY */
"436 " = "1" /* DISTAL GASTRECTOMY */
"437 " = "1" /* PART GASTREC W JEJ ANAST */
"4381" = "1" /* PART GAST W JEJ TRANSPOS */
"4382" = "1" /*	LAPAROSCOPIC VERTICAL (SLEEVE) GASTERECTOMY  */
"4389" = "1" /* PARTIAL GASTRECTOMY NEC */
"4391" = "1" /* TOT GAST W INTES INTERPO */
"4399" = "1" /* TOTAL GASTRECTOMY NEC */
"4400" = "1" /* VAGOTOMY NOS */
"4401" = "1" /* TRUNCAL VAGOTOMY */
"4402" = "1" /* HIGHLY SELECT VAGOTOMY */
"4403" = "1" /* SELECTIVE VAGOTOMY NEC */
"4411" = "1" /* TRANSABDOMIN GASTROSCOPY */
"4415" = "1" /* OPEN GASTRIC BIOPSY */
"442 " = "1" /* GASTRIC DIAGNOS PROC NEC */
"4421" = "1" /* DILATE PYLORUS, INCISION */
"4429" = "1" /* OTHER PYLOROPLASTY */
"4431" = "1" /* HIGH GASTRIC BYPASS */
"4432" = "1" /* PERCU GASTROJEJUNOSTOMY */
"4438" = "1" /* LAP GASTROENTEROSTOMY */
"4439" = "1" /* GASTROENTEROSTOMY NEC */
"4440" = "1" /* SUTURE PEPTIC ULCER NOS */
"4441" = "1" /* SUT GASTRIC ULCER SITE */
"4442" = "1" /* SUTURE DUODEN ULCER SITE */
"445 " = "1" /* REVISION GASTRIC ANASTOM */
"4461" = "1" /* SUTURE GASTRIC LACERAT */
"4463" = "1" /* CLOSE GASTRIC FISTUL NEC */
"4464" = "1" /* GASTROPEXY */
"4465" = "1" /* ESOPHAGOGASTROPLASTY */
"4466" = "1" /* CREAT ESOPHAGASTR SPHINC */
"4467" = "1" /* LAP CREAT ESOPH SPHINCT */
"4468" = "1" /* LAPAROSCOP GASTROPLASTY */
"4469" = "1" /* GASTRIC REPAIR NEC */
"4491" = "1" /* LIGATE GASTRIC VARICES */
"4492" = "1" /* INTRAOP GASTRIC MANIPUL */
"4495" = "1" /* LAP GASTRIC RESTRIC PROC */
"4496" = "1" /* LAP REV GAST RESTRI PROC */
"4497" = "1" /* LAP REM GAST RESTRIC DEV */
"4498" = "1" /* ADJUST GAST RESTRICT DEV */
"4499" = "1" /* GASTRIC OPERATION NEC */
"4500" = "1" /* INTESTINAL INCISION NOS */
"4501" = "1" /* DUODENAL INCISION */
"4502" = "1" /* SMALL BOWEL INCISION NEC */
"4503" = "1" /* LARGE BOWEL INCISION */
"4511" = "1" /* TRANSAB SM BOWEL ENDOSC */
"4515" = "1" /* OPEN SMALL BOWEL BIOPSY */
"4521" = "1" /* TRANSAB LG BOWEL ENDOSC */
"4526" = "1" /* OPEN LARGE BOWEL BIOPSY */
"4531" = "1" /* OTH EXCISE DUODENUM LES */
"4532" = "1" /* DESTRUCT DUODEN LES NEC */
"4533" = "1" /* LOCAL EXCIS SM BOWEL NEC */
"4534" = "1" /* DESTR SM BOWEL LES NEC */
"4541" = "1" /* EXCISE LG INTESTINE LES */
"4549" = "1" /* DESTRUC LG BOWEL LES NEC */
"4550" = "1" /* INTEST SEG ISOLAT NOS */
"4551" = "1" /* SM BOWEL SEGMENT ISOLAT */
"4552" = "1" /* LG BOWEL SEGMENT ISOLAT */
"4561" = "1" /* MULT SEG SM BOWEL EXCIS */
"4562" = "1" /* PART SM BOWEL RESECT NEC */
"4563" = "1" /* TOTAL REMOVAL SM BOWEL */
"4571" = "1" /* MULT SEG LG BOWEL EXCIS */
"4572" = "1" /* CECECTOMY */
"4573" = "1" /* RIGHT HEMICOLECTOMY */
"4574" = "1" /* TRANSVERSE COLON RESECT */
"4575" = "1" /* LEFT HEMICOLECTOMY */
"4576" = "1" /* SIGMOIDECTOMY */
"4579" = "1" /* PART LG BOWEL EXCIS NEC */
"458 " = "1" /* TOT INTRA-ABD COLECTOMY */
"4581" = "1" /* LAP TOT INTR-AB COLECTMY */
"4582" = "1" /* OP TOT INTR-ABD COLECTMY */
"4583" = "1" /* TOT ABD COLECTMY NEC/NOS */
"4590" = "1" /* INTESTINAL ANASTOM NOS */
"4591" = "1" /* SM-TO-SM BOWEL ANASTOM */
"4592" = "1" /* SM BOWEL-RECT STUMP ANAS */
"4593" = "1" /* SMALL-TO-LARGE BOWEL NEC */
"4594" = "1" /* LG-TO-LG BOWEL ANASTOM */
"4595" = "1" /* ANAL ANASTOMOSIS */
"4601" = "1" /* SM BOWEL EXTERIORIZATION */
"4602" = "1" /* RESECT EXT SEG SM BOWEL */
"4603" = "1" /* LG BOWEL EXTERIORIZATION */
"4604" = "1" /* RESECT EXT SEG LG BOWEL */
"4610" = "1" /* COLOSTOMY NOS */
"4611" = "1" /* TEMPORARY COLOSTOMY */
"4612" = "1" /* TEMPORARY COLOSTOMY */
"4613" = "1" /* PERMANENT COLOSTOMY */
"4620" = "1" /* ILEOSTOMY NOS */
"4621" = "1" /* TEMPORARY ILEOSTOMY */
"4622" = "1" /* CONTINENT ILEOSTOMY */
"4623" = "1" /* PERMANENT ILEOSTOMY NEC */
"4640" = "1" /* INTEST STOMA REVIS NOS */
"4641" = "1" /* SM BOWEL STOMA REVISION */
"4642" = "1" /* PERICOLOST HERNIA REPAIR */
"4643" = "1" /* LG BOWEL STOMA REVIS NEC */
"4650" = "1" /* INTEST STOMA CLOSURE NOS */
"4651" = "1" /* SM BOWEL STOMA CLOSURE */
"4652" = "1" /* LG BOWEL STOMA CLOSURE */
"4660" = "1" /* INTESTINAL FIXATION NOS */
"4661" = "1" /* SM BOWEL-ABD WALL FIXAT */
"4662" = "1" /* SMALL BOWEL FIXATION NEC */
"4663" = "1" /* LG BOWEL-ABD WALL FIXAT */
"4664" = "1" /* LARGE BOWEL FIXATION NEC */
"4671" = "1" /* DUODENAL LACERAT SUTURE */
"4672" = "1" /* DUODENAL FISTULA CLOSURE */
"4673" = "1" /* SMALL BOWEL SUTURE NEC */
"4674" = "1" /* CLOSE SM BOWEL FIST NEC */
"4675" = "1" /* SUTURE LG BOWEL LACERAT */
"4676" = "1" /* CLOSE LG BOWEL FISTULA */
"4679" = "1" /* REPAIR OF INTESTINE NEC */
"4680" = "1" /* INTRA-AB BOWEL MANIP NOS */
"4681" = "1" /* INTRA-ABD SM BOWEL MANIP */
"4682" = "1" /* INTRA-ABD LG BOWEL MANIP */
"4691" = "1" /* MYOTOMY OF SIGMOID COLON */
"4692" = "1" /* MYOTOMY OF COLON NEC */
"4693" = "1" /* REVISE SM BOWEL ANASTOM */
"4694" = "1" /* REVISE LG BOWEL ANASTOM */
"4697" = "1" /* TRANSPLANT OF INTESTINE */
"4699" = "1" /* INTESTINAL OP NEC */
"470 " = "1" /* INTESTINAL OP NEC */
"4701" = "1" /* LAP APPENDECTOMY */
"4709" = "1" /* OTHER APPENDECTOMY */
"471 " = "1" /* OTHER APPENDECTOMY */
"4711" = "1" /* LAP INCID APPENDECTOMY */
"4719" = "1" /* OTHER INCID APPENDECTOMY */
"472 " = "1" /* DRAIN APPENDICEAL ABSC */
"4791" = "1" /* APPENDICOSTOMY */
"4792" = "1" /* CLOSE APPENDICEAL FISTUL */
"4799" = "1" /* APPENDICEAL OPS NEC */
"480 " = "1" /* PROCTOTOMY */
"481 " = "1" /* PROCTOSTOMY */
"4821" = "1" /* TRANSAB PROCTOSIGMOIDOSC */
"4825" = "1" /* OPEN RECTAL BIOPSY */
"4835" = "1" /* LOCAL EXCIS RECTAL LES */
"4840" = "1" /* PULL-THRU RES RECTUM NOS */ 
"4841" = "1" /* SOAVE SUBMUC RECT RESECT */
"4842" = "1" /* LAP PULL-THRU RES RECTUM */
"4843" = "1" /* OPN PULL-THRU RES RECTUM */
"4849" = "1" /* PULL-THRU RECT RESEC NEC */
"485 " = "1" /* ABD-PERINEAL RECT RESECT */
"4850" = "1" /* ABDPERNEAL RES RECTM NOS */
"4851" = "1" /* LAP ABDPERNEAL RESC REC */
"4852" = "1" /* OPN ABDPERNEAL RESC REC */
"4859" = "1" /* ABDPERNEAL RESC RECT NEC */
"4861" = "1" /* TRANSSAC RECTOSIGMOIDECT */
"4862" = "1" /* ANT RECT RESECT W COLOST */
"4863" = "1" /* ANTERIOR RECT RESECT NEC */
"4864" = "1" /* POSTERIOR RECT RESECTION */
"4865" = "1" /* DUHAMEL RECTAL RESECTION */
"4866" = "1" /* DUHAMEL RECTAL RESECTION */
"4869" = "1" /* RECTAL RESECTION NEC */
"4871" = "1" /* SUTURE OF RECTAL LACER */
"4872" = "1" /* CLOSURE OF PROCTOSTOMY */
"4873" = "1" /* CLOSE RECTAL FIST NEC */
"4874" = "1" /* RECTORECTOSTOMY */
"4875" = "1" /* ABDOMINAL PROCTOPEXY */
"4876" = "1" /* PROCTOPEXY NEC */
"4879" = "1" /* REPAIR OF RECTUM NEC */
"4881" = "1" /* PERIRECTAL INCISION */
"4882" = "1" /* PERIRECTAL EXCISION */
"4891" = "1" /* INCIS RECTAL STRICTURE */
"4892" = "1" /* ANORECTAL MYOMECTOMY */
"4893" = "1" /* REPAIR PERIRECT FISTULA */
"4899" = "1" /* RECTAL PERIRECT OP NEC */
"4901" = "1" /* INCIS PERIANAL ABSCESS */
"4902" = "1" /* PERIANAL INCISION NEC */
"4904" = "1" /* PERIANAL EXCISION NEC */
"4911" = "1" /* ANAL FISTULOTOMY */
"4912" = "1" /* ANAL FISTULECTOMY */
"493 " = "1" /* ANAL/PERIAN DX PROC NEC */
"4939" = "1" /* OTHER DESTRUC ANUS LES */
"4944" = "1" /* HEMORRHOID CRYOTHERAPY */
"4945" = "1" /* HEMORRHOID LIGATION */
"4946" = "1" /* HEMORRHOIDECTOMY */
"4949" = "1" /* HEMORRHOID PROCEDURE NEC */
"4951" = "1" /* LEFT LAT SPHINCTEROTOMY */
"4952" = "1" /* POST SPHINCTEROTOMY */
"4959" = "1" /* ANAL SPHINCTEROTOMY NEC */
"496 " = "1" /* EXCISION OF ANUS */
"4971" = "1" /* SUTURE ANAL LACERATION */
"4972" = "1" /* ANAL CERCLAGE */
"4973" = "1" /* CLOSURE OF ANAL FISTULA */
"4974" = "1" /* GRACILIS MUSC TRANSPLAN */
"4975" = "1" /* IMPL OR REV ART ANAL SPH */
"4976" = "1" /* REMOV ART ANAL SPHINCTER */
"4979" = "1" /* ANAL SPHINCT REPAIR NEC */
"4991" = "1" /* INCISION OF ANAL SEPTUM */
"4992" = "1" /* INSERT SUBQ ANAL STIMUL */
"4993" = "1" /* ANAL INCISION NEC */
"4994" = "1" /* REDUCTION ANAL PROLAPSE */
"4995" = "1" /* CONTROL ANAL HEMORRHAGE */
"4999" = "1" /* ANAL OPERATION NEC */
"500 " = "1" /* HEPATOTOMY */
"5012" = "1" /* OPEN LIVER BIOPSY */
"5013" = "1" /* TRANSJUGULAR LIVER BX */
"5014" = "1" /* LAPAROSCOPIC LIVER BX */
"5019" = "1" /* HEPATIC DX PROC NEC */
"5021" = "1" /* MARSUPIALIZAT LIVER LES */
"5022" = "1" /* PARTIAL HEPATECTOMY */
"5023" = "1" /* OPN ABLTN LIVER LES/TISS */
"5024" = "1" /* PERC ABLTN LIVER LES/TIS */
"5025" = "1" /* LAP ABLTN LIVER LES/TISS */
"5026" = "1" /* ABLTN LIVER LES/TISS NEC */
"5029" = "1" /* DESTRUC HEPATIC LES NEC */
"503 " = "1" /* HEPATIC LOBECTOMY */
"504 " = "1" /* TOTAL HEPATECTOMY */
"5051" = "1" /* AUXILIARY LIVER TRANSPL */
"5059" = "1" /* LIVER TRANSPLANT NEC */
"5061" = "1" /* CLOSURE LIVER LACERAT */
"5069" = "1" /* LIVER REPAIR NEC */
"5102" = "1" /* TROCAR CHOLECYSTOSTOMY */
"5103" = "1" /* CHOLECYSTOSTOMY NEC */
"5104" = "1" /* CHOLECYSTOTOMY NEC */
"5113" = "1" /* OPEN BILIARY TRACT BX */
"5119" = "1" /* BILIARY TR DX PROC NEC */
"5121" = "1" /* OTH PART CHOLECYSTECTOMY */
"5122" = "1" /* CHOLECYSTECTOMY */
"5123" = "1" /* LAPAROSCOPIC CHOLECYSTEC */
"5124" = "1" /* LAP PART CHOLECYSTECTOMY */
"5131" = "1" /* GB-TO-HEPAT DUCT ANAST */
"5132" = "1" /* GB-TO-INTESTINE ANASTOM */
"5133" = "1" /* GB-TO-PANCREAS ANASTOM */
"5134" = "1" /* GB-TO-STOMACH ANASTOMOS */
"5135" = "1" /* GALLBLADDER ANASTOM NEC */
"5136" = "1" /* CHOLEDOCHOENTEROSTOMY */
"5137" = "1" /* HEPATIC DUCT-GI ANASTOM */
"5139" = "1" /* BILE DUCT ANASTOMOS NEC */
"5141" = "1" /* CDE FOR CALCULUS REMOV */
"5142" = "1" /* CDE FOR OBSTRUCTION NEC */
"5143" = "1" /* CHOLEDOCHOHEPAT INTUBAT */
"5149" = "1" /* INCIS OBSTR BILE DUC NEC */
"5151" = "1" /* COMMON DUCT EXPLORATION */
"5159" = "1" /* BILE DUCT INCISION NEC */
"5161" = "1" /* EXCIS CYST DUCT REMNANT */
"5162" = "1" /* EXCIS AMPULLA OF VATER */
"5163" = "1" /* COMMON DUCT EXCIS NEC */
"5169" = "1" /* BILE DUCT EXCISION NEC */
"5171" = "1" /* SIMPLE SUT-COMMON DUCT */
"5172" = "1" /* CHOLEDOCHOPLASTY */
"5179" = "1" /* BILE DUCT REPAIR NEC */
"5181" = "1" /* SPHINCTER OF ODDI DILAT */
"5182" = "1" /* PANCREAT SPHINCTEROTOM */
"5183" = "1" /* PANCREAT SPHINCTEROPLAS */
"5189" = "1" /* SPHINCT OF ODDI OP NEC */
"5191" = "1" /* REPAIR GB LACERATION */
"5192" = "1" /* CLOSURE CHOLECYSTOSTOMY */
"5193" = "1" /* CLOS BILIARY FISTUL NEC */
"5194" = "1" /* REVIS BILE TRACT ANASTOM */
"5195" = "1" /* REMOVE BILE DUCT PROSTH */
"5199" = "1" /* BILIARY TRACT OP NEC */
"5201" = "1" /* CATH DRAIN-PANCREAT CYST */
"5209" = "1" /* PANCREATOTOMY NEC */
"5212" = "1" /* OPEN PANCREATIC BIOPSY */
"5219" = "1" /* PANCREATIC DX PROC NEC */
"522 " = "1" /* PANCREATIC DX PROC NEC */
"5222" = "1" /* OTHER DESTRU PANCREA LES */
"523 " = "1" /* PANCREAT CYST MARSUPIALI */
"524 " = "1" /* INT DRAIN PANCREAT CYST */
"5251" = "1" /* PROXIMAL PANCREATECTOMY */
"5252" = "1" /* DISTAL PANCREATECTOMY */
"5253" = "1" /* RAD SUBTOT PANCREATECTOM */
"5259" = "1" /* PARTIAL PANCREATECT NEC */
"526 " = "1" /* TOTAL PANCREATECTOMY */
"527 " = "1" /* RAD PANCREATICODUODENECT */
"5280" = "1" /* PANCREAT TRANSPLANT NOS */
"5281" = "1" /* REIMPLANT PANCREATIC TIS */
"5282" = "1" /* PANCREATIC HOMOTRANSPLAN */
"5283" = "1" /* PANCREATIC HETEROTRANSPL */
"5291" = "1" /* TRNSPLNT ISLETS LANG NOS */
"5292" = "1" /* CANNULATION PANCREA DUC */
"5295" = "1" /* PANCREATIC REPAIR NEC */
"5296" = "1" /* PANCREATIC ANASTOMOSIS */
"5299" = "1" /* PANCREATIC OPERATION NEC */
"5300" = "1" /* UNILAT ING HERN REP NOS */
"5301" = "1" /* REPAIR DIRECT ING HERNIA */
"5302" = "1" /* REPAIR INDIR ING HERNIA */
"5303" = "1" /* DIR ING HERNIA REP-GRAFT */
"5304" = "1" /* IND ING HERNIA REP-GRAFT */
"5305" = "1" /* ING HERNIA REP-GRAFT NOS */
"5310" = "1" /* BILAT ING HERNIA REP NOS */
"5311" = "1" /* BILAT DIR ING HERN REP */
"5312" = "1" /* BILAT IND ING HERN REP */
"5313" = "1" /* BIL DIR/IND ING HRN REP */
"5314" = "1" /* BIL DIR ING HRN REP-GRFT */
"5315" = "1" /* BIL IND ING HRN REP-GRFT */
"5316" = "1" /* BIL DIR/IND ING HERN-PRO */
"5317" = "1" /* BIL ING HRN REP-GRFT NOS */
"5321" = "1" /* UNIL FEMOR HRN REP-GRFT */
"5329" = "1" /* UNIL FEMOR HERN REP NEC */
"5331" = "1" /* BIL FEM HERN REPAIR-GRFT */
"5339" = "1" /* BIL FEM HERN REPAIR NEC */
"5341" = "1" /* UMBIL HERNIA REPAIR-GRFT */
"5342" = "1" /* LAP UMBIL HERNIA-GRAFT */
"5343" = "1" /* LAP UMBILICAL HERNIA NEC */
"5349" = "1" /* UMBIL HERNIA REPAIR NEC */
"5351" = "1" /* INCISIONAL HERNIA REPAIR */
"5359" = "1" /* ABD WALL HERN REPAIR NEC */
"5361" = "1" /* INCIS HERNIA REPAIR-GRFT */
"5362" = "1" /* LAP INCIS HERN REPR-GRFT */
"5363" = "1" /* LAP HERN ANT ABD-GFT NEC */
"5369" = "1" /* ABD HERN REPAIR-GRFT NEC */
"537 " = "1" /* ABD REPAIR-DIAPHR HERNIA */
"5371" = "1" /* LAP ABD REP-DIAPHR HERN */
"5372" = "1" /* OPN ABD DIAPHRM HERN NEC */
"5375" = "1" /* ABD REP-DIAPHR HERN NOS */
"5380" = "1" /* THOR REP-DIAPH HERN NOS */
"5381" = "1" /* DIAPHRAGMATIC PLICATION */
"5382" = "1" /* PARASTERN HERNIA REPAIR */
"5383" = "1" /* LAP THORC APP-DIAPH HERN */
"5384" = "1" /* OPN THORC DIAPH HERN NEC */
"539 " = "1" /* OTHER HERNIA REPAIR */
"540 " = "1" /* ABDOMINAL WALL INCISION */
"5411" = "1" /* EXPLORATORY LAPAROTOMY */
"5412" = "1" /* REOPEN RECENT LAP SITE */
"5419" = "1" /* LAPAROTOMY NEC */
"5421" = "1" /* LAPAROSCOPY */
"5422" = "1" /* ABDOMINAL WALL BIOPSY */
"5423" = "1" /* PERITONEAL BIOPSY */
"5429" = "1" /* ABD REGION DX PROC NEC */
"543 " = "1" /* DESTRUCT ABD WALL LESION */
"544 " = "1" /* DESTRUCT PERITONEAL TISS */
"545 " = "1" /* DESTRUCT PERITONEAL TISS */
"5451" = "1" /* LAP PERITON ADHESIOLYSIS */
"5459" = "1" /* OTH PERITON ADHESIOLYSIS */
"5461" = "1" /* RECLOSE POST OP DISRUPT */
"5462" = "1" /* DELAYED CLOS ABD WOUND */
"5463" = "1" /* ABD WALL SUTURE NEC */
"5464" = "1" /* PERITONEAL SUTURE */
"5471" = "1" /* REPAIR OF GASTROSCHISIS */
"5472" = "1" /* ABDOMEN WALL REPAIR NEC */
"5473" = "1" /* PERITONEAL REPAIR NEC */
"5474" = "1" /* OMENTAL REPAIR NEC */
"5475" = "1" /* MESENTERIC REPAIR NEC */
"5492" = "1" /* REMOVE FB FROM PERITON */
"5493" = "1" /* CREATE CUTANPERITON FIST */
"5494" = "1" /* CREAT PERITONEOVAS SHUNT */
"5495" = "1" /* PERITONEAL INCISION */
"5501" = "1" /* NEPHROTOMY */
"5502" = "1" /* NEPHROSTOMY */
"5503" = "1" /* PERCU NEPHROSTM W/O FRAG */
"5504" = "1" /* PERCU NEPHROSTMY W FRAG */
"5511" = "1" /* PYELOTOMY */
"5512" = "1" /* PYELOSTOMY */
"5524" = "1" /* OPEN RENAL BIOPSY */
"5529" = "1" /* RENAL DIAGNOST PROC NEC */
"5531" = "1" /* RENAL LES MARSUPIALIZAT */
"5532" = "1" /* OPN ABLTN RENAL LES/TISS */
"5533" = "1" /* PERC ABLTN RENL LES/TISS */
"5534" = "1" /* LAP ABLTN RENAL LES/TISS */
"5535" = "1" /* ABLTN RENAL LES/TISS NEC */
"5539" = "1" /* LOC DESTR RENAL LES NEC */
"554 " = "1" /* PARTIAL NEPHRECTOMY */
"5551" = "1" /* NEPHROURETERECTOMY */
"5552" = "1" /* SOLITARY KIDNEY NEPHRECT */
"5553" = "1" /* REJECTED KIDNEY NEPHRECT */
"5554" = "1" /* BILATERAL NEPHRECTOMY */
"5561" = "1" /* RENAL AUTOTRANSPLANT */
"5569" = "1" /* KIDNEY TRANSPLANT NEC */
"557 " = "1" /* NEPHROPEXY */
"5581" = "1" /* SUTURE KIDNEY LACERATION */
"5582" = "1" /* CLOSE NEPHROST & PYELOST */
"5583" = "1" /* CLOSE RENAL FISTULA NEC */
"5584" = "1" /* REDUCE RENAL PEDICL TORS */
"5585" = "1" /* SYMPHYSIOTOMY */
"5586" = "1" /* RENAL ANASTOMOSIS */
"5587" = "1" /* CORRECT URETEROPELV JUNC */
"5589" = "1" /* RENAL REPAIR NEC */
"5591" = "1" /* RENAL DECAPSULATION */
"5597" = "1" /* IMPLANT MECHANIC KIDNEY */
"5598" = "1" /* REMOV MECHANICAL KIDNEY */
"5599" = "1" /* RENAL OPERATION NEC */
"560 " = "1" /* TU REMOV URETER OBSTRUCT */
"561 " = "1" /* URETERAL MEATOTOMY */
"562 " = "1" /* URETEROTOMY */
"5634" = "1" /* OPEN URETERAL BIOPSY */
"5639" = "1" /* URETERAL DX PROCEDUR NEC */
"5640" = "1" /* URETERECTOMY NOS */
"5641" = "1" /* PARTIAL URETERECTOMY */
"5642" = "1" /* TOTAL URETERECTOMY */
"5651" = "1" /* FORM CUTAN ILEOURETEROST */
"5652" = "1" /* REVIS CUTAN ILEOURETEROS */
"5661" = "1" /* FORM CUTAN URETEROSTOMY */
"5662" = "1" /* REVIS CUTAN URETEROS NEC */
"5671" = "1" /* URIN DIVERSION TO BOWEL */
"5672" = "1" /* REVIS URETEROENTEROSTOMY */
"5673" = "1" /* NEPHROCYSTANASTOMOSI NOS */
"5674" = "1" /* URETERONEOCYSTOSTOMY */
"5675" = "1" /* TRANSURETEROURETEROSTOMY */
"5679" = "1" /* URETERAL ANASTOMOSIS NEC */
"5681" = "1" /* INTRALUM URETE ADHESIOLY */
"5682" = "1" /* SUTURE URETERAL LACERAT */
"5683" = "1" /* URETEROSTOMY CLOSURE */
"5684" = "1" /* CLOSE URETER FISTULA NEC */
"5685" = "1" /* URETEROPEXY */
"5686" = "1" /* REMOVE URETERAL LIGATURE */
"5689" = "1" /* REPAIR OF URETER NEC */
"5692" = "1" /* IMPLANT URETERAL STIMUL */
"5693" = "1" /* REPLACE URETERAL STIMUL */
"5694" = "1" /* REMOVE URETERAL STIMULAT */
"5695" = "1" /* LIGATION OF URETER */
"5699" = "1" /* URETERAL OPERATION NEC */
"5712" = "1" /* CYSTOTOMY & ADHESIOLYSIS */
"5718" = "1" /* OTHER SUPRAPU CYSTOSTOMY */
"5719" = "1" /* CYSTOTOMY NEC */
"5721" = "1" /* VESICOSTOMY */
"5722" = "1" /* REVISE CLO VESICOSTOMY */
"5733" = "1" /* CLOS TRANSURETH BLADD BX */
"5734" = "1" /* OPEN BLADDER BIOPSY */
"5739" = "1" /* BLADDER DIAGNOS PROC NEC */
"5741" = "1" /* TU ADHESIOLYSIS BLADDER */
"5749" = "1" /* TU DESTRUC BLADD LES NEC */
"5751" = "1" /* EXCISION OF URACHUS */
"5759" = "1" /* BLADDER LES DESTRUCT NEC */
"576 " = "1" /* PARTIAL CYSTECTOMY */
"5771" = "1" /* RADICAL CYSTECTOMY */
"5779" = "1" /* TOTAL CYSTECTOMY NEC */
"5781" = "1" /* SUTURE BLADDER LACERAT */
"5782" = "1" /* CYSTOSTOMY CLOSURE */
"5783" = "1" /* ENTEROVESICO FIST REPAIR */
"5784" = "1" /* VESIC FISTULA REPAIR NEC */
"5785" = "1" /* CYSTOURETHROPLASTY */
"5786" = "1" /* BLADDER EXSTROPHY REPAIR */
"5787" = "1" /* BLADDER RECONSTRUCTION */
"5788" = "1" /* BLADDER ANASTOMOSIS NEC */
"5789" = "1" /* BLADDER REPAIR NEC */
"5791" = "1" /* BLADDER SPHINCTEROTOMY */
"5793" = "1" /* CONTROL BLADD HEMORRHAGE */
"5796" = "1" /* IMPLANT BLADDER STIMULAT */
"5797" = "1" /* REPLACE BLADDER STIMULAT */
"5798" = "1" /* REMOVE BLADDER STIMULAT */
"5799" = "1" /* BLADDER OPERATION NEC */
"580 " = "1" /* URETHROTOMY */
"581 " = "1" /* URETHRAL MEATOTOMY */
"5841" = "1" /* SUTURE URETHRAL LACERAT */
"5842" = "1" /* URETHROSTOMY CLOSURE */
"5843" = "1" /* CLOSE URETH FISTULA NEC */
"5844" = "1" /* URETHRAL REANASTOMOSIS */
"5845" = "1" /* HYPO-EPISPADIUS REPAIR */
"5846" = "1" /* URETH RECONSTRUCTION NEC */
"5847" = "1" /* URETHRAL MEATOPLASTY */
"5849" = "1" /* URETHRAL REPAIR NEC */
"585 " = "1" /* URETH STRICTURE RELEASE */
"5891" = "1" /* PERIURETHRAL INCISION */
"5892" = "1" /* PERIURETHRAL EXCISION */
"5893" = "1" /* IMPLT ARTF URIN SPHINCT */
"5899" = "1" /* URETH/PERIURETH OP NEC */
"5900" = "1" /* RETROPERIT DISSECT NOS */
"5901" = "1" /* RETROPERIT DISSECT NOS */
"5902" = "1" /* PERIREN ADHESIOLYS NEC */
"5903" = "1" /* LAP LYS PERIREN/URET ADH */
"5909" = "1" /* PERIREN/URETER INCIS NEC */
"5911" = "1" /* OTH LYS PERIVES ADHESIO */
"5912" = "1" /* LAP LYS PERIVESURETH ADH */
"5919" = "1" /* PERIVESICAL INCISION NEC */
"5921" = "1" /* PERIREN/URETERAL BIOPSY */
"5929" = "1" /* PERIREN/URET DX PROC NEC */
"593 " = "1" /* URETHROVES JUNCT PLICAT */
"594 " = "1" /* SUPRAPUBIC SLING OP */
"595 " = "1" /* RETROPUBIC URETH SUSPENS */
"596 " = "1" /* PARAURETHRAL SUSPENSION */
"5971" = "1" /* LEVATOR MUSC SUSPENSION */
"5979" = "1" /* URIN INCONTIN REPAIR NEC */
"5991" = "1" /* PERIREN/VESICLE EXCISION */
"5992" = "1" /* PERIREN/VESICLE OP NEC */
"600 " = "1" /* INCISION OF PROSTATE */
"6012" = "1" /* OPEN PROSTATIC BIOPSY */
"6014" = "1" /* OPEN SEMINAL VESICLES BX */
"6015" = "1" /* PERIPROSTATIC BIOPSY */
"6018" = "1" /* PROSTATIC DX PROCED NEC */
"6019" = "1" /* SEMIN VES DX PROCED NEC */
"602 " = "1" /* SEMIN VES DX PROCED NEC */
"6021" = "1" /* TRANSURETH PROSTATECTOMY */
"6029" = "1" /* OTH TRANSURETH PROSTATEC */
"603 " = "1" /* SUPRAPUBIC PROSTATECTOMY */
"604 " = "1" /* RETROPUBIC PROSTATECTOMY */
"605 " = "1" /* RADICAL PROSTATECTOMY */
"6061" = "1" /* LOS EXCIS PROSTATIC LES */
"6062" = "1" /* PERINEAL PROSTATECTOMY */
"6069" = "1" /* PROSTATECTOMY NEC */
"6072" = "1" /* SEMINAL VESICLE INCISION */
"6073" = "1" /* SEMINAL VESICLE EXCISION */
"6079" = "1" /* SEMINAL VESICLE OP NEC */
"6081" = "1" /* PERIPROSTATIC INCISION */
"6082" = "1" /* PERIPROSTATIC EXCISION */
"6093" = "1" /* REPAIR OF PROSTATE */
"6094" = "1" /* CONTROL PROSTATE HEMORR */
"6095" = "1" /* TRANS BAL DIL PROS URETH */
"6096" = "1" /* TU DESTR PROSTATE BY MT */
"6097" = "1" /* OTH TU DESTR PROS - RT */
"6099" = "1" /* PROSTATIC OPERATION NEC */
"612 " = "1" /* EXCISION OF HYDROCELE */
"6142" = "1" /* SCROTAL FISTULA REPAIR */
"6149" = "1" /* SCROTUM/TUNIC REPAIR NEC */
"6192" = "1" /* EXCISION TUNICA LES NEC */
"6199" = "1" /* SCROTUM & TUNICA OP NEC */
"620 " = "1" /* INCISION OF TESTES */
"6212" = "1" /* OPEN TESTICULAR BIOPSY */
"6219" = "1" /* TESTES DX PROCEDURE NEC */
"622 " = "1" /* TESTICULAR LES DESTRUCT */
"623 " = "1" /* UNILATERAL ORCHIECTOMY */
"6241" = "1" /* REMOVE BOTH TESTES */
"6242" = "1" /* REMOVE SOLITARY TESTIS */
"625 " = "1" /* ORCHIOPEXY */
"6261" = "1" /* SUTURE TESTICULAR LACER */
"6269" = "1" /* TESTICULAR REPAIR NEC */
"627 " = "1" /* INSERT TESTICULAR PROSTH */
"6299" = "1" /* TESTICULAR OPERATION NEC */
"6309" = "1" /* SPERMAT CORD/VAS DX NEC */
"631 " = "1" /* EXC SPERMATIC VARICOCELE */
"632 " = "1" /* EXCISE EPIDIDYMIS CYST */
"633 " = "1" /* EXCISE CORD/EPID LES NEC */
"634 " = "1" /* EPIDIDYMECTOMY */
"6351" = "1" /* SUTURE CORD & EPID LACER */
"6353" = "1" /* TRANSPLANT SPERMAT CORD */
"6359" = "1" /* CORD & EPIDID REPAIR NEC */
"6381" = "1" /* SUTURE VAS & EPIDID LAC */
"6382" = "1" /* POSTOP VAS RECONSTRUCT */
"6383" = "1" /* EPIDIDYMOVASOSTOMY */
"6385" = "1" /* REMOV VAS DEFERENS VALVE */
"6389" = "1" /* VAS & EPIDIDY REPAIR NEC */
"6392" = "1" /* EPIDIDYMOTOMY */
"6393" = "1" /* SPERMATIC CORD INCISION */
"6394" = "1" /* SPERM CORD ADHESIOLYSIS */
"6395" = "1" /* INSERT VALVE IN VAS DEF */
"6399" = "1" /* CORD/EPID/VAS OPS NEC */
"6411" = "1" /* PENILE BIOPSY */
"642 " = "1" /* LOCAL EXCIS PENILE LES */
"643 " = "1" /* AMPUTATION OF PENIS */
"6441" = "1" /* SUTURE PENILE LACERATION */
"6442" = "1" /* RELEASE OF CHORDEE */
"6443" = "1" /* CONSTRUCTION OF PENIS */
"6444" = "1" /* RECONSTRUCTION OF PENIS */
"6445" = "1" /* REPLANTATION OF PENIS */
"6449" = "1" /* PENILE REPAIR NEC */
"645 " = "1" /* SEX TRANSFORMAT OP NEC */
"6492" = "1" /* INCISION OF PENIS */
"6493" = "1" /* DIVISION OF PENILE ADHES */
"6495" = "1" /* INS NONINFL PENIS PROSTH */
"6496" = "1" /* REMOVE INT PENILE PROSTH */
"6497" = "1" /* INS INFLATE PENIS PROSTH */
"6498" = "1" /* PENILE OPERATION NEC */
"6499" = "1" /* MALE GENITAL OP NEC */
"650 " = "1" /* MALE GENITAL OP NEC */
"6501" = "1" /* LAPAROSCOPIC OOPHOROTOMY */
"6509" = "1" /* OTHER OOPHOROTOMY */
"6511" = "1" /* OVARIAN ASPIRAT BIOPSY */
"6512" = "1" /* OVARIAN BIOPSY NEC */
"6513" = "1" /* LAP BIOPSY OF OVARY */
"6514" = "1" /* OTH LAP DX PROC OVARIES */
"6519" = "1" /* OVARIAN DX PROCEDURE NEC */
"6521" = "1" /* OVARIAN CYST MARSUPIALIZ */
"6522" = "1" /* OVARIAN WEDGE RESECTION */
"6523" = "1" /* LAP MARSUP OVARIAN CYST */
"6524" = "1" /* LAP WEDGE RESECT OVARY */
"6525" = "1" /* OTH LAP LOC EXC DEST OVA */
"6529" = "1" /* LOCAL DESTR OVA LES NEC */
"653 " = "1" /* LOCAL DESTR OVA LES NEC */
"6531" = "1" /* LAP UNILAT OOPHORECTOMY */
"6539" = "1" /* OTH UNILAT OOPHORECTOMY */
"654 " = "1" /* OTH UNILAT OOPHORECTOMY */
"6541" = "1" /* LAP UNI SALPINGO-OOPHOR */
"6549" = "1" /* OTH UNI SALPINGO-OOPHOR */
"6551" = "1" /* OTH REMOVE BOTH OVARIES */
"6552" = "1" /* OTH REMOVE REMAIN OVARY */
"6553" = "1" /* LAP REMOVE BOTH OVARIES */
"6554" = "1" /* LAP REMOVE REMAIN OVARY */
"6561" = "1" /* OTH REMOVE OVARIES/TUBES */
"6562" = "1" /* OTH REMOVE REM OVA/TUBE */
"6563" = "1" /* LAP REMOVE OVARIES/TUBES */
"6564" = "1" /* LAP REMOVE REM OVA/TUBE */
"6571" = "1" /* OTH SIMPLE SUTURE OVARY */
"6572" = "1" /* OTH REIMPLANT OF OVARY */
"6573" = "1" /* OTH SALPINGO-OOPHOROPLAS */
"6574" = "1" /* LAP SIMPLE SUTURE OVARY */
"6575" = "1" /* LAP REIMPLANT OF OVARY */
"6576" = "1" /* LAP SALPINGO-OOPHOROPLAS */
"6579" = "1" /* REPAIR OF OVARY NEC */
"658 " = "1" /* REPAIR OF OVARY NEC */
"6581" = "1" /* LAP ADHESIOLYS OVA/TUBE */
"6589" = "1" /* ADHESIOLYSIS OVARY/TUBE */
"6591" = "1" /* ASPIRATION OF OVARY */
"6592" = "1" /* TRANSPLANTATION OF OVARY */
"6593" = "1" /* MANUAL RUPT OVARIAN CYST */
"6594" = "1" /* OVARIAN DENERVATION */
"6595" = "1" /* OVARIAN TORSION RELEASE */
"6599" = "1" /* OVARIAN OPERATION NEC */
"660 " = "1" /* OVARIAN OPERATION NEC */
"6601" = "1" /* SALPINGOTOMY */
"6602" = "1" /* SALPINGOSTOMY */
"6611" = "1" /* FALLOPIAN TUBE BIOPSY */
"6619" = "1" /* FALLOP TUBE DX PROC NEC */
"6621" = "1" /* BILAT ENDOSC CRUSH TUBE */
"6622" = "1" /* BILAT ENDOSC DIVIS TUBE */
"6629" = "1" /* BILAT ENDOS OCC TUBE NEC */
"6631" = "1" /* BILAT TUBAL CRUSHING NEC */
"6632" = "1" /* BILAT TUBAL DIVISION NEC */
"6639" = "1" /* BILAT TUBAL DESTRUCT NEC */
"664 " = "1" /* TOTAL UNILAT SALPINGECT */
"6651" = "1" /* REMOVE BOTH FALLOP TUBES */
"6652" = "1" /* REMOVE SOLITARY FAL TUBE */
"6661" = "1" /* DESTROY FALLOP TUBE LES */
"6662" = "1" /* REMOV TUBE & ECTOP PREG */
"6663" = "1" /* BILAT PART SALPINGEC NOS */
"6669" = "1" /* PARTIAL SALPINGECTOM NEC */
"6671" = "1" /* SIMPL SUTURE FALLOP TUBE */
"6672" = "1" /* SALPINGO-OOPHOROSTOMY */
"6673" = "1" /* SALPINGO-SALPINGOSTOMY */
"6674" = "1" /* SALPINGO-UTEROSTOMY */
"6679" = "1" /* FALLOP TUBE REPAIR NEC */
"6692" = "1" /* UNILAT FALLOP TUBE DESTR */
"6693" = "1" /* IMPL FALLOP TUBE PROSTH */
"6694" = "1" /* REMOV FALLOP TUBE PROSTH */
"6695" = "1" /* BLOW THERAPEUT INTO TUBE */
"6696" = "1" /* FALLOPIAN TUBE DILATION */
"6697" = "1" /* BURY FIMBRIAE IN UTERUS */
"6699" = "1" /* FALLOPIAN TUBE OP NEC */
"6711" = "1" /* ENDOCERVICAL BIOPSY */
"6712" = "1" /* CERVICAL BIOPSY NEC */
"6719" = "1" /* CERVICAL DX PROCEDUR NEC */
"672 " = "1" /* CONIZATION OF CERVIX */
"6731" = "1" /* CERVICAL CYST MARSUPIAL */
"6732" = "1" /* CERVICAL LES CAUTERIZAT */
"6733" = "1" /* CERVICAL LES CRYOTHERAPY */
"6739" = "1" /* CERVICAL LES DESTRUC NEC */
"674 " = "1" /* AMPUTATION OF CERVIX */
"675 " = "1" /* AMPUTATION OF CERVIX */
"6751" = "1" /* TRANSAB CERCLAGE CERVIX */
"6759" = "1" /* OTH REP INT CERVICAL OS */
"6761" = "1" /* SUTURE CERVICAL LACERAT */
"6762" = "1" /* CERVICAL FISTULA REPAIR */
"6769" = "1" /* CERVICAL REPAIR NEC */
"680 " = "1" /* HYSTEROTOMY */
"6813" = "1" /* OPEN UTERINE BIOPSY */
"6814" = "1" /* OPEN UTERINE LIGAMENT BX */
"6815" = "1" /* CLOS UTERINE LIGAMENT BX */
"6816" = "1" /* CLOSED UTERINE BIOPSY */
"6819" = "1" /* UTERUS/ADNEX DX PROC NEC */
"6821" = "1" /* ENDOMET SYNECHIAE DIVIS */
"6822" = "1" /* INCISION UTERINE SEPTUM */
"6823" = "1" /* ENDOMETRIAL ABLATION */
"6824" = "1" /*	UTERINE ARTERY EMBOLIZATION [UAE] WITH COILS */
"6825" = "1" /*	UTERINE ARTERY EMBOLIZATION [UAE] WITHOUT COILS  */
"6829" = "1" /* UTERINE LES DESTRUCT NEC */
"683 " = "1" /* UTERINE LES DESTRUCT NEC */
"6831" = "1" /* LAP SCERVIC HYSTERECTOMY */
"6839" = "1" /* OTH SUBTOT ABD HYSTERECT */
"684 " = "1" /* TOTAL ABD HYSTERECTOMY */
"6841" = "1" /* LAP TOTAL ABDOMINAL HYST */
"6849" = "1" /* TOTAL ABD HYST NEC/NOS */
"685 " = "1" /* TOTAL ABD HYSTERECTOMY */
"6851" = "1" /* LAP AST VAG HYSTERECTOMY */
"6859" = "1" /* OTHER VAG HYSTERECTOMY */
"686 " = "1" /* RADICAL ABD HYSTERECTOMY */
"6861" = "1" /* LAP RADICAL ABDOMNL HYST */
"6869" = "1" /* RADICAL ABD HYST NEC/NOS */
"687 " = "1" /* RADICAL VAG HYSTERECTOMY */
"6871" = "1" /* LAP RADICAL VAGINAL HYST */
"6879" = "1" /* RADICAL VAG HYST NEC/NOS */
"688 " = "1" /* PELVIC EVISCERATION */
"689 " = "1" /* HYSTERECTOMY NEC/NOS */
"6901" = "1" /* D & C FOR PREG TERMINAT */
"6902" = "1" /* D & C POST DELIVERY */
"6909" = "1" /* D & C NEC */
"6911" = "1" /* D & C NEC */
"6919" = "1" /* DESTRUC UTER SUPPORT NEC */
"6921" = "1" /* INTERPOSIT OP UTERIN LIG */
"6922" = "1" /* UTERINE SUSPENSION NEC */
"6923" = "1" /* VAG REPAIR INVERS UTERUS */
"6929" = "1" /* UTERUS/ADNEXA REPAIR NEC */
"693 " = "1" /* PARACERV UTERINE DENERV */
"6941" = "1" /* SUTURE UTERINE LACERAT */
"6942" = "1" /* CLOSURE UTERINE FISTULA */
"6949" = "1" /* UTERINE REPAIR NEC */
"6951" = "1" /* ASPIRAT CURET-PREG TERMI */
"6952" = "1" /* ASPIRAT CURET-POST DELIV */
"6995" = "1" /* INCISION OF CERVIX */
"6997" = "1" /* REMOVE PENETRAT CERV FB */
"6998" = "1" /* UTERINE SUPPORT OP NEC */
"6999" = "1" /* UTERINE OPERATION NEC */
"7012" = "1" /* CULDOTOMY */
"7013" = "1" /* INTRALUM VAG ADHESIOLYS */
"7014" = "1" /* VAGINOTOMY NEC */
"7023" = "1" /* CUL-DE-SAC BIOPSY */
"7024" = "1" /* VAGINAL BIOPSY */
"7029" = "1" /* VAGIN/CUL-DE-SAC DX NEC */
"7031" = "1" /* HYMENECTOMY */
"7032" = "1" /* EXCIS CUL-DE-SAC LESION */
"7033" = "1" /* EXCISION VAGINAL LESION */
"704 " = "1" /* VAGINAL OBLITERATION */
"7050" = "1" /* CYSTOCEL/RECTOCEL REPAIR */
"7051" = "1" /* CYSTOCELE REPAIR */
"7052" = "1" /* RECTOCELE REPAIR */
"7053" = "1" /* CYSTO & RECTO W GRF/PROS */
"7054" = "1" /* REP CYSTOCEL W GRFT/PROS */
"7055" = "1" /* REP RECTOCELE W GRF/PROS */
"7061" = "1" /* VAGINAL CONSTRUCTION */
"7062" = "1" /* VAGINAL RECONSTRUCTION */
"7063" = "1" /* VAGINAL CONST W GRF/PROS */
"7064" = "1" /* VAG RECONST W GRFT/PROS */
"7071" = "1" /* SUTURE VAGINA LACERATION */
"7072" = "1" /* REPAIR COLOVAGIN FISTULA */
"7073" = "1" /* REPAIR RECTOVAG FISTULA */
"7074" = "1" /* REP VAGINOENT FISTUL NEC */
"7075" = "1" /* REPAIR VAG FISTULA NEC */
"7076" = "1" /* HYMENORRHAPHY */
"7077" = "1" /* VAGINAL SUSPENS & FIXAT */
"7078" = "1" /* VAG SUSP/FIX W GRFT/PROS */
"7079" = "1" /* VAGINAL REPAIR NEC */
"708 " = "1" /* VAGINAL VAULT OBLITERAT */
"7091" = "1" /* VAGINAL OPERATION NEC */
"7092" = "1" /* CUL-DE-SAC OPERATION NEC */
"7093" = "1" /* CUL-DE-SAC GRF/PROS NEC */
"7101" = "1" /* VULVAR ADHESIOLYSIS */
"7109" = "1" /* INCIS VULVA/PERINEUM NEC */
"7111" = "1" /* VULVAR BIOPSY */
"7119" = "1" /* VULVAR DIAGNOS PROC NEC */
"7122" = "1" /* INCISE BARTHOLIN"S GLAND */
"7123" = "1" /* BARTHOLIN GLAND MARSUP */
"7124" = "1" /* DESTRUC BARTHOLIN GLAND */
"7129" = "1" /* BARTHOLIN"S GLAND OP NEC */
"713 " = "1" /* LOCAL VULVAR EXCIS NEC */
"714 " = "1" /* OPERATIONS ON CLITORIS */
"715 " = "1" /* RADICAL VULVECTOMY */
"7161" = "1" /* UNILATERAL VULVECTOMY */
"7162" = "1" /* BILATERAL VULVECTOMY */
"7171" = "1" /* SUTURE VULVAR LACERATION */
"7172" = "1" /* REPAIR VULVAR FISTULA */
"7179" = "1" /* VULVAR/PERIN REPAIR NEC */
"718 " = "1" /* OTHER VULVAR OPERATIONS */
"719 " = "1" /* OTHER FEMALE GENITAL OPS */
"7394" = "1" /* PUBIOTOMY TO ASSIST DEL */
"7399" = "1" /* OPS ASSISTING DELIV NEC */
"740 " = "1" /* CLASSICAL C-SECTION */
"741 " = "1" /* LOW CERVICAL C-SECTION */
"742 " = "1" /* EXTRAPERITONEAL C-SECT */
"743 " = "1" /* REM EXTRATUB ECTOP PREG */
"744 " = "1" /* CESAREAN SECTION NEC */
"7491" = "1" /* HYSTEROTOMY TO TERMIN PG */
"7499" = "1" /* CESAREAN SECTION NOS */
"7536" = "1" /* CORRECTION FETAL DEFECT */
"7550" = "1" /* REPAIR OB LAC UTERUS NOS */
"7551" = "1" /* REPAIR OB LACERAT CERVIX */
"7552" = "1" /* REPAIR OB LAC CORP UTERI */
"7561" = "1" /* REPAIR OB LAC BLAD/URETH */
"7593" = "1" /* SURG CORR INVERT UTERUS */
"7599" = "1" /* OBSTETRIC OPERATION NEC */
"7601" = "1" /* FACIAL BONE SEQUESTRECT */
"7609" = "1" /* FACIAL BONE INCISION NEC */
"7611" = "1" /* FACIAL BONE BIOPSY */
"7619" = "1" /* FACIAL BONE DX PROC NEC */
"762 " = "1" /* DESTRUCT FACIAL BONE LES */
"7631" = "1" /* PARTIAL MANDIBULECTOMY */
"7639" = "1" /* PART FACIAL OSTECTOM NEC */
"7641" = "1" /* TOT MANDIBULEC W RECONST */
"7642" = "1" /* TOTAL MANDIBULECTOMY NEC */
"7643" = "1" /* MANDIBULAR RECONST NEC */
"7644" = "1" /* TOT FACE OSTECT W RECONS */
"7645" = "1" /* TOT FACE BONE OSTECT NEC */
"7646" = "1" /* FACIAL BONE RECONSTR NEC */
"765 " = "1" /* TEMPOROMAND ARTHROPLASTY */
"7661" = "1" /* CL OSTEOPLASTY MAND RAMI */
"7662" = "1" /* OPEN OSTEOPLAS MAND RAMI */
"7663" = "1" /* OSTEOPLASTY MANDIBLE BDY */
"7664" = "1" /* MAND ORTHOGNATHIC OP NEC */
"7665" = "1" /* SEG OSTEOPLASTY MAXILLA */
"7666" = "1" /* TOT OSTEOPLASTY MAXILLA */
"7667" = "1" /* REDUCTION GENIOPLASTY */
"7668" = "1" /* AUGMENTATION GENIOPLASTY */
"7669" = "1" /* FACIAL BONE REPAIR NEC */
"7670" = "1" /* REDUCTION FACIAL FX NOS */
"7672" = "1" /* OPN REDUCT MALAR/ZYGO FX */
"7674" = "1" /* OPEN REDUCT MAXILLARY FX */
"7676" = "1" /* OPEN REDUCT MANDIBLE FX */
"7677" = "1" /* OPEN REDUCT ALVEOLAR FX */
"7679" = "1" /* OPEN REDUCT FACE FX NEC */
"7691" = "1" /* BONE GRAFT TO FACE BONE */
"7692" = "1" /* SYN IMPLANT TO FACE BONE */
"7694" = "1" /* OPEN REDUCT TM DISLOCAT */
"7697" = "1" /* REMOVE INT FIX FACE BONE */
"7699" = "1" /* FACIAL BONE/JNT OP NEC */
"7700" = "1" /* SEQUESTRECTOMY NOS */
"7701" = "1" /* CHEST CAGE SEQUESTREC */
"7702" = "1" /* HUMERUS SEQUESTRECTOMY */
"7703" = "1" /* RADIUS & ULNA SEQUESTREC */
"7704" = "1" /* METACARP/CARP SEQUESTREC */
"7705" = "1" /* FEMORAL SEQUESTRECTOMY */
"7706" = "1" /* PATELLAR SEQUESTRECTOMY */
"7707" = "1" /* TIBIA/FIBULA SEQUESTREC */
"7708" = "1" /* METATAR/TAR SEQUESTREC */
"7709" = "1" /* SEQUESTRECTOMY NEC */
"7710" = "1" /* OTHER BONE INCISION NOS */
"7711" = "1" /* OTHER CHEST CAGE INCIS */
"7712" = "1" /* OTHER HUMERUS INCISION */
"7713" = "1" /* OTHER RADIUS/ULNA INCIS */
"7714" = "1" /* OTH METACARP/CARP INCIS */
"7715" = "1" /* OTHER FEMORAL INCISION */
"7716" = "1" /* OTHER PATELLAR INCISION */
"7717" = "1" /* OTHER TIBIA/FIBULA INCIS */
"7718" = "1" /* OTH METATARS/TARS INCIS */
"7719" = "1" /* BONE INCIS W/O DIV NEC */
"7720" = "1" /* WEDGE OSTEOTOMY NOS */
"7721" = "1" /* CHEST CAGE WEDG OSTEOTOM */
"7722" = "1" /* HUMERUS WEDGE OSTEOTOMY */
"7723" = "1" /* RADIUS/ULNA WEDG OSTEOTO */
"7724" = "1" /* METACAR/CAR WEDG OSTEOTO */
"7725" = "1" /* FEMORAL WEDGE OSTEOTOMY */
"7726" = "1" /* PATELLAR WEDGE OSTEOTOMY */
"7727" = "1" /* TIBIA/FIBUL WEDG OSTEOT */
"7728" = "1" /* METATAR/TAR WEDG OSTEOT */
"7729" = "1" /* WEDGE OSTEOTOMY NEC */
"7730" = "1" /* OTHER BONE DIVISION NOS */
"7731" = "1" /* CHEST CAGE BONE DIV NEC */
"7732" = "1" /* HUMERUS DIVISION NEC */
"7733" = "1" /* RADIUS/ULNA DIVISION NEC */
"7734" = "1" /* METACAR/CAR DIVISION NEC */
"7735" = "1" /* FEMORAL DIVISION NEC */
"7736" = "1" /* PATELLAR DIVISION NEC */
"7737" = "1" /* TIBIA/FIBULA DIV NEC */
"7738" = "1" /* METATAR/TAR DIVISION NEC */
"7739" = "1" /* BONE DIVISION NEC */
"7740" = "1" /* BONE BIOPSY NOS */
"7741" = "1" /* CHEST CAGE BONE BIOPSY */
"7742" = "1" /* HUMERUS BIOPSY */
"7743" = "1" /* RADIUS & ULNA BIOPSY */
"7744" = "1" /* METACARPAL/CARPAL BIOPSY */
"7745" = "1" /* FEMORAL BIOPSY */
"7746" = "1" /* PATELLAR BIOPSY */
"7747" = "1" /* TIBIA & FIBULA BIOPSY */
"7748" = "1" /* METATARSAL/TARSAL BIOPSY */
"7749" = "1" /* BONE BIOPSY NEC */
"7751" = "1" /* BUNIONECT/SFT/OSTEOTOMY */
"7752" = "1" /* BUNIONECT/SFT/ARTHRODES */
"7753" = "1" /* OTH BUNIONECT W SFT CORR */
"7754" = "1" /* EXC CORRECT BUNIONETTE */
"7756" = "1" /* REPAIR OF HAMMER TOE */
"7757" = "1" /* REPAIR OF CLAW TOE */
"7758" = "1" /* OTH EXC, FUS, REPAIR TOE */
"7759" = "1" /* BUNIONECTOMY NEC */
"7760" = "1" /* LOC EXC BONE LESION NOS */
"7761" = "1" /* EXC CHEST CAGE BONE LES */
"7762" = "1" /* LOC EXC BONE LES HUMERUS */
"7763" = "1" /* LOC EXC LES RADIUS/ULNA */
"7764" = "1" /* LOC EXC LES METACAR/CAR */
"7765" = "1" /* LOC EXC BONE LES FEMUR */
"7766" = "1" /* LOC EXC BONE LES PATELLA */
"7767" = "1" /* LOC EXC LES TIBIA/FIBULA */
"7768" = "1" /* LOC EXC LES METATAR/TAR */
"7769" = "1" /* LOC EXC BONE LESION NEC */
"7770" = "1" /* EXCISE BONE FOR GRFT NOS */
"7771" = "1" /* EX CHEST CAGE BONE-GFT */
"7772" = "1" /* EXCISE HUMERUS FOR GRAFT */
"7773" = "1" /* EXCIS RADIUS/ULNA-GRAFT */
"7774" = "1" /* EXCIS METACAR/CAR-GRAFT */
"7775" = "1" /* EXCISE FEMUR FOR GRAFT */
"7776" = "1" /* EXCISE PATELLA FOR GRAFT */
"7777" = "1" /* EXCISE TIB/FIB FOR GRAFT */
"7778" = "1" /* EXCIS METATAR/TAR-GRAFT */
"7779" = "1" /* EXCISE BONE FOR GFT NEC */
"7780" = "1" /* OTH PART OSTECTOMY NOS */
"7781" = "1" /* OTH CHEST CAGE OSTECTOMY */
"7782" = "1" /* PARTIAL HUMERECTOMY NEC */
"7783" = "1" /* PART OSTECT-RADIUS/ULNA */
"7784" = "1" /* PART OSTECT-METACAR/CAR */
"7785" = "1" /* PART OSTECTOMY-FEMUR */
"7786" = "1" /* PARTIAL PATELLECTOMY */
"7787" = "1" /* PART OSTECT-TIBIA/FIBULA */
"7788" = "1" /* PART OSTECT-METATAR/TAR */
"7789" = "1" /* PARTIAL OSTECTOMY NEC */
"7790" = "1" /* TOTAL OSTECTOMY NOS */
"7791" = "1" /* TOT CHEST CAGE OSTECTOMY */
"7792" = "1" /* TOTAL OSTECTOMY-HUMERUS */
"7793" = "1" /* TOT OSTECT-RADIUS/ULNA */
"7794" = "1" /* TOT OSTECT-METACARP/CARP */
"7795" = "1" /* TOT OSTECTOMY-FEMUR */
"7796" = "1" /* TOTAL PATELLECTOMY */
"7797" = "1" /* TOT OSTECT-TIBIA/FIBULA */
"7798" = "1" /* TOT OSTECT-METATARS/TARS */
"7799" = "1" /* TOTAL OSTECTOMY NEC */
"7800" = "1" /* BONE GRAFT NOS */
"7801" = "1" /* BONE GRAFT TO CHEST CAGE */
"7802" = "1" /* BONE GRAFT TO HUMERUS */
"7803" = "1" /* BONE GRAFT-RADIUS/ULNA */
"7804" = "1" /* BONE GRFT TO METACAR/CAR */
"7805" = "1" /* BONE GRAFT TO FEMUR */
"7806" = "1" /* BONE GRAFT TO PATELLA */
"7807" = "1" /* BONE GRAFT-TIBIA/FIBULA */
"7808" = "1" /* BONE GRAFT-METATAR/TAR */
"7809" = "1" /* BONE GRAFT NEC */
"7810" = "1" /* APPLIC EXT FIX DEV NOS */
"7811" = "1" /* APPL EXT FIX-CHEST CAGE */
"7812" = "1" /* APPLIC EXT FIX-HUMERUS */
"7813" = "1" /* APPL EXT FIX-RADIUS/ULNA */
"7814" = "1" /* APPL EXT FIX-METACAR/CAR */
"7815" = "1" /* APPLIC EXT FIX DEV-FEMUR */
"7816" = "1" /* APPL EXT FIX DEV-PATELLA */
"7817" = "1" /* APPL EXT FIX-TIB/FIBULA */
"7818" = "1" /* APPL EXT FIX-METATAR/TAR */
"7819" = "1" /* APPLIC EXT FIX DEV NEC */
"7820" = "1" /* LIMB SHORTEN PROC NOS */
"7822" = "1" /* LIMB SHORT PROC-HUMERUS */
"7823" = "1" /* LIMB SHORTEN-RADIUS/ULNA */
"7824" = "1" /* LIMB SHORTEN-METACAR/CAR */
"7825" = "1" /* LIMB SHORT PROC-FEMUR */
"7827" = "1" /* LIMB SHORTEN-TIB/FIBULA */
"7828" = "1" /* LIMB SHORTEN-METATAR/TAR */
"7829" = "1" /* LIMB SHORTEN PROC NEC */
"7830" = "1" /* LIMB LENGTHEN PROC NOS */
"7831" = "1" /* LIMB LENGTHEN PROC NOS */
"7832" = "1" /* LIMB LENGTH PROC-HUMERUS */
"7833" = "1" /* LIMB LENGTH-RADIUS/ULNA */
"7834" = "1" /* LIMB LENGTH-METACAR/CAR */
"7835" = "1" /* LIMB LENGTH PROC-FEMUR */
"7837" = "1" /* LIMB LENGTHEN-TIB/FIBULA */
"7838" = "1" /* LIMB LENGTHN-METATAR/TAR */
"7839" = "1" /* LIMB LENGTHEN PROC NEC */
"7840" = "1" /* OTH BONE REPAIR/PLAST OP */
"7841" = "1" /* OTH CHEST CAGE REP/PLAST */
"7842" = "1" /* OTH HUMERUS REPAIR/PLAST */
"7843" = "1" /* OTH RAD/ULN REPAIR/PLAST */
"7844" = "1" /* OTH METAC/CARP REP/PLAST */
"7845" = "1" /* OTH FEMUR REPAIR/PLASTIC */
"7846" = "1" /* OTH PATELLA REPAIR/PLAST */
"7847" = "1" /* OTH TIB/FIB REPAIR/PLAST */
"7848" = "1" /* OTH META/TAR REPA/PLAST */
"7849" = "1" /* OTH BONE REPA/PLAST NEC */
"7850" = "1" /* INT FIX W/O FX REDUC NOS */
"7851" = "1" /* INT FIXATION-CHEST CAGE */
"7852" = "1" /* INT FIXATION-HUMERUS */
"7853" = "1" /* INT FIXATION-RADIUS/ULNA */
"7854" = "1" /* INT FIXATION-METACAR/CAR */
"7855" = "1" /* INTERNAL FIXATION-FEMUR */
"7856" = "1" /* INTERNAL FIX-PATELLA */
"7857" = "1" /* INT FIXATION-TIBIA/FIBUL */
"7858" = "1" /* INT FIXATION-METATAR/TAR */
"7859" = "1" /* INT FIX-NO FX REDUCT NEC */
"7860" = "1" /* REMOVE IMP DEVICE NOS */
"7861" = "1" /* REMOV IMP DEV-CHEST CAGE */
"7862" = "1" /* REMOVE IMPL DEV-HUMERUS */
"7863" = "1" /* REMOV IMP DEV-RADIUS/ULN */
"7864" = "1" /* REMOV IMP DEV-METAC/CARP */
"7865" = "1" /* REMOVE IMP DEVICE-FEMUR */
"7866" = "1" /* REMOV IMP DEVICE-PATELLA */
"7867" = "1" /* REMOV IMP DEV-TIB/FIBULA */
"7868" = "1" /* REMOVE IMP DEV-METAT/TAR */
"7869" = "1" /* REMOVE IMPL DEVICE NEC */
"7870" = "1" /* OSTEOCLASIS NOS */
"7871" = "1" /* OSTEOCLASIS-CHEST CAGE */
"7872" = "1" /* OSTEOCLASIS-HUMERUS */
"7873" = "1" /* OSTEOCLASIS-RADIUS/ULNA */
"7874" = "1" /* OSTEOCLASIS-METACAR/CAR */
"7875" = "1" /* OSTEOCLASIS-FEMUR */
"7876" = "1" /* OSTEOCLASIS-PATELLA */
"7877" = "1" /* OSTEOCLASIS-TIBIA/FIBULA */
"7878" = "1" /* OSTEOCLASIS-METATAR/TAR */
"7879" = "1" /* OSTEOCLASIS NEC */
"7880" = "1" /* OTHER BONE DX PROC NOS */
"7881" = "1" /* OTH DX PROCED-CHEST CAGE */
"7882" = "1" /* OTH DX PROCED-HUMERUS */
"7883" = "1" /* OTH DX PROC-RADIUS/ULNA */
"7884" = "1" /* OTH DX PROC-METACAR/CAR */
"7885" = "1" /* OTH DX PROCED-FEMUR */
"7886" = "1" /* OTH DX PROCED-PATELLA */
"7887" = "1" /* OTH DX PROC-TIBIA/FIBULA */
"7888" = "1" /* OTH DX PROC-METATAR/TAR */
"7889" = "1" /* OTHER BONE DX PROC NEC */
"7890" = "1" /* INSERT BONE STIMUL NOS */
"7891" = "1" /* INSERT BONE STIMUL-CHEST */
"7892" = "1" /* INSERT BONE STIM-HUMERUS */
"7893" = "1" /* INSER BONE STIM-RAD/ULNA */
"7894" = "1" /* INSER BONE STIM-META/CAR */
"7895" = "1" /* INSERT BONE STIM-FEMUR */
"7896" = "1" /* INSERT BONE STIM-PATELLA */
"7897" = "1" /* INSER BONE STIM-TIB/FIB */
"7898" = "1" /* INSER BONE STIM-META/TAR */
"7899" = "1" /* INSERT BONE STIMUL NEC */
"7910" = "1" /* CL FX REDUC-INT FIX NOS */
"7911" = "1" /* CLOS RED-INT FIX HUMERUS */
"7912" = "1" /* CL RED-INT FIX RAD/ULNA */
"7913" = "1" /* CL RED-INT FIX METAC/CAR */
"7914" = "1" /* CLOSE RED-INT FIX FINGER */
"7915" = "1" /* CLOSED RED-INT FIX FEMUR */
"7916" = "1" /* CL RED-INT FIX TIB/FIBU */
"7917" = "1" /* CL RED-INT FIX METAT/TAR */
"7918" = "1" /* CLOSE RED-INT FIX TOE FX */
"7919" = "1" /* CL FX REDUC-INT FIX NEC */
"7920" = "1" /* OPEN FX REDUCTION NOS */
"7921" = "1" /* OPEN REDUC-HUMERUS FX */
"7922" = "1" /* OPEN REDUC-RADIUS/ULN FX */
"7923" = "1" /* OPEN REDUC-METAC/CAR FX */
"7924" = "1" /* OPEN REDUCTION-FINGER FX */
"7925" = "1" /* OPEN REDUCTION-FEMUR FX */
"7926" = "1" /* OPEN REDUC-TIBIA/FIB FX */
"7927" = "1" /* OPEN REDUC-METAT/TARS FX */
"7928" = "1" /* OPEN REDUCTION-TOE FX */
"7929" = "1" /* OPEN FX REDUCTION NEC */
"7930" = "1" /* OPN FX RED W INT FIX NOS */
"7931" = "1" /* OPEN RED-INT FIX HUMERUS */
"7932" = "1" /* OP RED-INT FIX RAD/ULNA */
"7933" = "1" /* OP RED-INT FIX METAC/CAR */
"7934" = "1" /* OPEN RED-INT FIX FINGER */
"7935" = "1" /* OPEN REDUC-INT FIX FEMUR */
"7936" = "1" /* OP RED-INT FIX TIB/FIBUL */
"7937" = "1" /* OP RED-INT FIX METAT/TAR */
"7938" = "1" /* OPEN REDUCT-INT FIX TOE */
"7939" = "1" /* OPN FX RED W INT FIX NEC */
"7940" = "1" /* CLS REDUC-SEP EPIPHY NOS */
"7941" = "1" /* CLOSE RED-HUMERUS EPIPHY */
"7942" = "1" /* CLS RED-RADIUS/UL EPIPHY */
"7945" = "1" /* CLOSE REDUC-FEMUR EPIPHY */
"7946" = "1" /* CLS RED-TIBIA/FIB EPIPHY */
"7949" = "1" /* CLS REDUC-SEP EPIPHY NEC */
"7950" = "1" /* OPEN RED-SEP EPIPHY NOS */
"7951" = "1" /* OPN RED-SEP EPIPHY-HUMER */
"7952" = "1" /* OP RED-RADIUS/ULN EPIPHY */
"7955" = "1" /* OPN RED-SEP EPIPHY-FEMUR */
"7956" = "1" /* OP RED-TIBIA/FIB EPIPHYS */
"7959" = "1" /* OPEN RED-SEP EPIPHY NEC */
"7960" = "1" /* OPEN FX SITE DEBRIDE NOS */
"7961" = "1" /* DEBRID OPEN FX-HUMERUS */
"7962" = "1" /* DEBRID OPN FX-RADIUS/ULN */
"7963" = "1" /* DEBRID OPN FX-METAC/CAR */
"7964" = "1" /* DEBRID OPN FX-FINGER */
"7965" = "1" /* DEBRID OPN FX-FEMUR */
"7966" = "1" /* DEBRID OPN FX-TIBIA/FIB */
"7967" = "1" /* DEBRID OPN FX-METAT/TAR */
"7968" = "1" /* DEBRID OPN FX-TOE */
"7969" = "1" /* OPEN FX SITE DEBRIDE NEC */
"7980" = "1" /* OPEN REDUC-DISLOCAT NOS */
"7981" = "1" /* OPN REDUC DISLOC-SHOULDR */
"7982" = "1" /* OPEN REDUC-ELBOW DISLOC */
"7983" = "1" /* OPEN REDUC-WRIST DISLOC */
"7984" = "1" /* OPN REDUC DISLOC-HAND */
"7985" = "1" /* OPEN REDUC-HIP DISLOCAT */
"7986" = "1" /* OPEN REDUC-KNEE DISLOCAT */
"7987" = "1" /* OPEN REDUC-ANKLE DISLOC */
"7988" = "1" /* OPN REDUC DISLOC-FT/TOE */
"7989" = "1" /* OPEN REDUC-DISLOCAT NEC */
"7990" = "1" /* UNSPEC OP BONE INJ NOS */
"7991" = "1" /* HUMERUS INJURY OP NOS */
"7992" = "1" /* RADIUS/ULNA INJ OP NOS */
"7993" = "1" /* METACARP/CARP INJ OP NOS */
"7994" = "1" /* FINGER INJURY OP NOS */
"7995" = "1" /* FEMUR INJURY OP NOS */
"7996" = "1" /* TIBIA/FIBULA INJ OP NOS */
"7997" = "1" /* METATARS/TARS INJ OP NOS */
"7998" = "1" /* TOE INJURY OPERATION NOS */
"7999" = "1" /* UNSPEC OP-BONE INJ NEC */
"8000" = "1" /* ARTHROT & PROS REMOV NOS */
"8001" = "1" /* ARTHROT/PROS REMOV-SHLDR */
"8002" = "1" /* ARTHROT/PROS REMOV-ELBOW */
"8003" = "1" /* ARTHROT/PROS REMOV-WRIST */
"8004" = "1" /* ARTHROT/PROS REMOV-HAND */
"8005" = "1" /* ARTHROT/PROS REMOV-HIP */
"8006" = "1" /* ARTHROT/PROS REMOV-KNEE */
"8007" = "1" /* ARTHROT/PROS REMOV-ANKLE */
"8008" = "1" /* ARTHROT/PROS REMOV-FOOT */
"8009" = "1" /* ARTHROT & PROS REMOV NEC */
"8010" = "1" /* OTHER ARTHROTOMY NOS */
"8011" = "1" /* OTH ARTHROTOMY-SHOULDER */
"8012" = "1" /* OTH ARTHROTOMY-ELBOW */
"8013" = "1" /* OTH ARTHROTOMY-WRIST */
"8014" = "1" /* OTH ARTHROTOMY-HAND/FNGR */
"8015" = "1" /* OTH ARTHROTOMY-HIP */
"8016" = "1" /* OTH ARTHROTOMY-KNEE */
"8017" = "1" /* OTH ARTHROTOMY-ANKLE */
"8018" = "1" /* OTH ARTHROTOMY-FOOT/TOE */
"8019" = "1" /* OTHER ARTHROTOMY NEC */
"8020" = "1" /* ARTHROSCOPY NOS */
"8021" = "1" /* SHOULDER ARTHROSCOPY */
"8022" = "1" /* ELBOW ARTHROSCOPY */
"8023" = "1" /* WRIST ARTHROSCOPY */
"8024" = "1" /* HAND & FINGER ARTHROSCOP */
"8025" = "1" /* HIP ARTHROSCOPY */
"8026" = "1" /* KNEE ARTHROSCOPY */
"8027" = "1" /* ANKLE ARTHROSCOPY */
"8028" = "1" /* FOOT & TOE ARTHROSCOPY */
"8029" = "1" /* ARTHROSCOPY NEC */
"8040" = "1" /* JT STRUCTUR DIVISION NOS */
"8041" = "1" /* SHOULDER STRUCT DIVISION */
"8042" = "1" /* ELBOW STRUCTURE DIVISION */
"8043" = "1" /* WRIST STRUCTURE DIVISION */
"8044" = "1" /* HAND JOINT STRUCT DIVIS */
"8045" = "1" /* HIP STRUCTURE DIVISION */
"8046" = "1" /* KNEE STRUCTURE DIVISION */
"8047" = "1" /* ANKLE STRUCTURE DIVISION */
"8048" = "1" /* FOOT JOINT STRUCT DIVIS */
"8049" = "1" /* JT STRUCTUR DIVISION NEC */
"805 " = "1" /* JT STRUCTUR DIVISION NEC */
"8050" = "1" /* EXC/DEST INTVRT DISC NOS */
"8051" = "1" /* EXCISION INTERVERT DISC */
"8053" = "1" /* REP ANULUS FIBROSUS-GRFT */
"8054" = "1" /* REP ANULS FIBROS NEC/NOS */
"8059" = "1" /* OTH EXC/DEST INTVRT DISC */
"806 " = "1" /* EXCIS KNEE SEMILUN CARTL */
"8070" = "1" /* SYNOVECTOMY-SITE NOS */
"8071" = "1" /* SHOULDER SYNOVECTOMY */
"8072" = "1" /* ELBOW SYNOVECTOMY */
"8073" = "1" /* WRIST SYNOVECTOMY */
"8074" = "1" /* HAND SYNOVECTOMY */
"8075" = "1" /* HIP SYNOVECTOMY */
"8076" = "1" /* KNEE SYNOVECTOMY */
"8077" = "1" /* ANKLE SYNOVECTOMY */
"8078" = "1" /* FOOT SYNOVECTOMY */
"8079" = "1" /* SYNOVECTOMY-SITE NEC */
"8080" = "1" /* DESTRUCT JOINT LES NOS */
"8081" = "1" /* DESTRUC-SHOULDER LES NEC */
"8082" = "1" /* DESTRUC-ELBOW LESION NEC */
"8083" = "1" /* DESTRUC-WRIST LESION NEC */
"8084" = "1" /* DESTRUC-HAND JT LES NEC */
"8085" = "1" /* DESTRUCT-HIP LESION NEC */
"8086" = "1" /* DESTRUCT-KNEE LESION NEC */
"8087" = "1" /* DESTRUC-ANKLE LESION NEC */
"8088" = "1" /* DESTRUC-FOOT JT LES NEC */
"8089" = "1" /* DESTRUCT JOINT LES NEC */
"8090" = "1" /* EXCISION OF JOINT NOS */
"8091" = "1" /* EXCISION OF SHOULDER NEC */
"8092" = "1" /* EXCISION OF ELBOW NEC */
"8093" = "1" /* EXCISION OF WRIST NEC */
"8094" = "1" /* EXCISION HAND JOINT NEC */
"8095" = "1" /* EXCISION OF HIP NEC */
"8096" = "1" /* EXCISION OF KNEE NEC */
"8097" = "1" /* EXCISION OF ANKLE NEC */
"8098" = "1" /* EXCISION FOOT JOINT NEC */
"8099" = "1" /* EXCISION OF JOINT NEC */
"8100" = "1" /* SPINAL FUSION NOS */
"8101" = "1" /* ATLAS-AXIS FUSION */
"8102" = "1" /* OTHER CERVICAL FUS ANT */
"8103" = "1" /* OTHER CERVICAL FUS POST */
"8104" = "1" /* DORSAL/DORSOLUM FUS ANT */
"8105" = "1" /* DORSAL/DORSOLUM FUS POST */
"8106" = "1" /* LUMBAR/LUMBOSAC FUS ANT */
"8107" = "1" /* LUMBAR/LUMBOSAC FUS LAT */
"8108" = "1" /* LUMBAR/LUMBOSAC FUS POST */
"8109" = "1" /* LUMBAR/LUMBOSAC FUS POST */
"8111" = "1" /* ANKLE FUSION */
"8112" = "1" /* TRIPLE ARTHRODESIS */
"8113" = "1" /* SUBTALAR FUSION */
"8114" = "1" /* MIDTARSAL FUSION */
"8115" = "1" /* TARSOMETATARSAL FUSION */
"8116" = "1" /* METATARSOPHALANGEAL FUS */
"8117" = "1" /* OTHER FUSION OF FOOT */
"8118" = "1" /* OTHER FUSION OF FOOT */
"8120" = "1" /* ARTHRODESIS NOS */
"8121" = "1" /* ARTHRODESIS OF HIP */
"8122" = "1" /* ARTHRODESIS OF KNEE */
"8123" = "1" /* ARTHRODESIS OF SHOULDER */
"8124" = "1" /* ARTHRODESIS OF ELBOW */
"8125" = "1" /* CARPORADIAL FUSION */
"8126" = "1" /* METACARPOCARPAL FUSION */
"8127" = "1" /* METACARPOPHALANGEAL FUS */
"8128" = "1" /* INTERPHALANGEAL FUSION */
"8129" = "1" /* ARTHRODESIS NEC */
"8130" = "1" /* SPINAL REFUSION NOS */
"8131" = "1" /* REFUSION OF ATLAS-AXIS */
"8132" = "1" /* REFUSION OF OTH CERV ANT */
"8133" = "1" /* REFUS OF OTH CERV POST */
"8134" = "1" /* REFUSION OF DORSAL ANT */
"8135" = "1" /* REFUSION OF DORSAL POST */
"8136" = "1" /* REFUSION OF LUMBAR ANT */
"8137" = "1" /* REFUSION OF LUMBAR LAT */
"8138" = "1" /* REFUSION OF LUMBAR POST */
"8139" = "1" /* REFUSION OF SPINE NEC */
"8140" = "1" /* REPAIR OF HIP, NEC */
"8141" = "1" /* REPAIR OF HIP, NEC */
"8142" = "1" /* FIVE-IN-ONE KNEE REPAIR */
"8143" = "1" /* TRIAD KNEE REPAIR */
"8144" = "1" /* PATELLAR STABILIZATION */
"8145" = "1" /* CRUCIATE LIG REPAIR NEC */
"8146" = "1" /* COLLATERL LIG REPAIR NEC */
"8147" = "1" /* OTHER REPAIR OF KNEE */
"8148" = "1" /* OTHER REPAIR OF KNEE */
"8149" = "1" /* OTHER REPAIR OF ANKLE */
"8151" = "1" /* TOTAL HIP REPLACEMENT */
"8152" = "1" /* PARTIAL HIP REPLACEMENT */
"8153" = "1" /* REVISE HIP REPLACEMENT */
"8154" = "1" /* TOTAL KNEE REPLACEMENT */
"8155" = "1" /* REVISE KNEE REPLACEMENT */
"8156" = "1" /* TOTAL ANKLE REPLACEMENT */
"8157" = "1" /* REPL JOINT OF FOOT, TOE */
"8159" = "1" /* REV JT REPL LOW EXT NEC */
"8161" = "1" /* 360 SPINAL FUSION */
"8162" = "1" /* FUS/REFUS 2-3 VERTEBRAE */
"8163" = "1" /* FUS/REFUS 4-8 VERTEBRAE */
"8164" = "1" /* FUS/REFUS 9 VERTEBRAE */
"8165" = "1" /* VERTEBROPLASTY */
"8166" = "1" /* KYPHOPLASTY */
"8169" = "1" /* OTH HIP REPAIR  JAN80--SEP89 */
"8171" = "1" /* ARTHROPLAS METACARP WIT */
"8172" = "1" /* ARTHROPLASTY METACAR W/O */
"8173" = "1" /* TOTAL WRIST REPLACEMENT */
"8174" = "1" /* ARTHROPLASTY CARPAL WIT */
"8175" = "1" /* ARTHROPLASTY CARPAL W/O */
"8179" = "1" /* OTH REPAIR HAN/FIN/WRIS */
"8180" = "1" /* TOTAL SHOULDER REPLACE */
"8181" = "1" /* PARTIAL SHOULDER REPLACE */
"8182" = "1" /* REP RECUR SHLDER DISLOC */
"8183" = "1" /* SHOULDER ARTHROPLAST NEC */
"8184" = "1" /* TOTAL ELBOW REPLACEMENT */
"8185" = "1" /* ELBOW ARTHROPLASTY NEC */
"8186" = "1" /* ELBOW ARTHROPLASTY NEC */
"8187" = "1" /* ELBOW ARTHROPLASTY NEC */
"8188" = "1" /* RVRS TOTL SHLDR REPLACMT */	
"8193" = "1" /* SUTUR CAPSUL/LIGAMEN ARM */
"8194" = "1" /* SUTURE CAPSUL/LIG ANK/FT */
"8195" = "1" /* SUTUR CAPSUL/LIG LEG NEC */
"8196" = "1" /* OTHER REPAIR OF JOINT */
"8197" = "1" /* REV JT REPL UPPER EXTREM */
"8198" = "1" /* OTHER JOINT DX PROCEDURE */
"8199" = "1" /* JOINT STRUCTURE OP NEC */
"8201" = "1" /* EXPLOR TEND SHEATH-HAND */
"8202" = "1" /* MYOTOMY OF HAND */
"8203" = "1" /* BURSOTOMY OF HAND */
"8209" = "1" /* INC SOFT TISSUE HAND NEC */
"8211" = "1" /* TENOTOMY OF HAND */
"8212" = "1" /* FASCIOTOMY OF HAND */
"8219" = "1" /* DIV SOFT TISSUE HAND NEC */
"8221" = "1" /* EXC LES TEND SHEATH HAND */
"8222" = "1" /* EXCISION HAND MUSCLE LES */
"8229" = "1" /* EXC LES SFT TISS HND NEC */
"8231" = "1" /* BURSECTOMY OF HAND */
"8232" = "1" /* EXCIS HAND TEND FOR GRFT */
"8233" = "1" /* HAND TENONECTOMY NEC */
"8234" = "1" /* EXC HND MUS/FAS FOR GRFT */
"8235" = "1" /* HAND FASCIECTOMY NEC */
"8236" = "1" /* OTHER MYECTOMY OF HAND */
"8239" = "1" /* HAND SOFT TISSUE EXC NEC */
"8241" = "1" /* SUTURE TENDN SHEATH HAND */
"8242" = "1" /* DELAY SUT FLEX TEND HAND */
"8243" = "1" /* DELAY SUT HAND TEND NEC */
"8244" = "1" /* SUTUR FLEX TEND HAND NEC */
"8245" = "1" /* SUTURE HAND TENDON NEC */
"8246" = "1" /* SUTURE HAND MUSCLE/FASC */
"8251" = "1" /* HAND TENDON ADVANCEMENT */
"8252" = "1" /* HAND TENDON RECESSION */
"8253" = "1" /* HAND TENDON REATTACHMENT */
"8254" = "1" /* HAND MUSCLE REATTACHMENT */
"8255" = "1" /* CHNG HND MUS/TEN LNG NEC */
"8256" = "1" /* TRANSPLANT HAND TEND NEC */
"8257" = "1" /* TRANSPOSIT HAND TEND NEC */
"8258" = "1" /* TRANSPLANT HAND MUSC NEC */
"8259" = "1" /* TRANSPOSIT HAND MUSC NEC */
"8261" = "1" /* POLLICIZATION OPERATION */
"8269" = "1" /* THUMB RECONSTRUCTION NEC */
"8271" = "1" /* HAND TEND PULLEY RECONST */
"8272" = "1" /* PLAST OP HND-MUS/FAS GRF */
"8279" = "1" /* PLAST OP HAND W GRFT NEC */
"8281" = "1" /* TRANSFER OF FINGER */
"8282" = "1" /* REPAIR OF CLEFT HAND */
"8283" = "1" /* REPAIR OF MACRODACTYLY */
"8284" = "1" /* REPAIR OF MALLET FINGER */
"8285" = "1" /* OTHER TENODESIS OF HAND */
"8286" = "1" /* OTHER TENOPLASTY OF HAND */
"8289" = "1" /* HAND PLASTIC OP NEC */
"8291" = "1" /* LYSIS OF HAND ADHESIONS */
"8299" = "1" /* HAND MUS/TEN/FAS/OPS NEC */
"8301" = "1" /* TENDON SHEATH EXPLORAT */
"8302" = "1" /* MYOTOMY */
"8303" = "1" /* BURSOTOMY */
"8309" = "1" /* SOFT TISSUE INCISION NEC */
"8311" = "1" /* ACHILLOTENOTOMY */
"8312" = "1" /* ADDUCTOR TENOTOMY OF HIP */
"8313" = "1" /* OTHER TENOTOMY */
"8314" = "1" /* FASCIOTOMY */
"8319" = "1" /* SOFT TISSUE DIVISION NEC */
"8321" = "1" /* SOFT TISSUE BIOPSY */
"8329" = "1" /* SOFT TISSUE DX PROC NEC */
"8331" = "1" /* EXCIS LES TENDON SHEATH */
"8332" = "1" /* EXCIS LESION OF MUSCLE */
"8339" = "1" /* EXC LES SOFT TISSUE NEC */
"8341" = "1" /* TENDON EXCISION FOR GRFT */
"8342" = "1" /* OTHER TENONECTOMY */
"8343" = "1" /* MUSC/FASC EXCIS FOR GRFT */
"8344" = "1" /* OTHER FASCIECTOMY */
"8345" = "1" /* OTHER MYECTOMY */
"8349" = "1" /* OTHER SOFT TISSUE EXCIS */
"835 " = "1" /* BURSECTOMY */
"8361" = "1" /* TENDON SHEATH SUTURE */
"8362" = "1" /* DELAYED TENDON SUTURE */
"8363" = "1" /* ROTATOR CUFF REPAIR */
"8364" = "1" /* OTHER SUTURE OF TENDON */
"8365" = "1" /* OTHER MUSCLE/FASC SUTURE */
"8371" = "1" /* TENDON ADVANCEMENT */
"8372" = "1" /* TENDON RECESSION */
"8373" = "1" /* TENDON REATTACHMENT */
"8374" = "1" /* MUSCLE REATTACHMENT */
"8375" = "1" /* TENDON TRNSFR/TRANSPLANT */
"8376" = "1" /* OTHER TENDON TRANSPOSIT */
"8377" = "1" /* MUSCLE TRNSFR/TRANSPLANT */
"8379" = "1" /* OTHER MUSCLE TRANSPOSIT */
"8381" = "1" /* TENDON GRAFT */
"8382" = "1" /* MUSCLE OR FASCIA GRAFT */
"8383" = "1" /* TENDON PULLEY RECONSTRUC */
"8384" = "1" /* CLUBFOOT RELEASE NEC */
"8385" = "1" /* MUSC/TEND LNG CHANGE NEC */
"8386" = "1" /* QUADRICEPSPLASTY */
"8387" = "1" /* OTHER PLASTIC OPS MUSCLE */
"8388" = "1" /* OTHER PLASTIC OPS TENDON */
"8389" = "1" /* OTHER PLASTIC OPS FASCIA */
"8391" = "1" /* ADHESIOLYSIS MUS/TEN/FAS */
"8392" = "1" /* INSERT SKEL MUSC STIMULA */
"8393" = "1" /* REMOV SKEL MUSC STIMULAT */
"8399" = "1" /* MUS/TEN/FAS/BUR OP NEC */
"8400" = "1" /* UPPER LIMB AMPUTAT NOS */
"8401" = "1" /* FINGER AMPUTATION */
"8402" = "1" /* THUMB AMPUTATION */
"8403" = "1" /* AMPUTATION THROUGH HAND */
"8404" = "1" /* DISARTICULATION OF WRIST */
"8405" = "1" /* AMPUTATION THRU FOREARM */
"8406" = "1" /* DISARTICULATION OF ELBOW */
"8407" = "1" /* AMPUTATION THRU HUMERUS */
"8408" = "1" /* SHOULDER DISARTICULATION */
"8409" = "1" /* FOREQUARTER AMPUTATION */
"8410" = "1" /* LOWER LIMB AMPUTAT NOS */
"8411" = "1" /* TOE AMPUTATION */
"8412" = "1" /* AMPUTATION THROUGH FOOT */
"8413" = "1" /* DISARTICULATION OF ANKLE */
"8414" = "1" /* AMPUTAT THROUGH MALLEOLI */
"8415" = "1" /* BELOW KNEE AMPUTAT NEC */
"8416" = "1" /* DISARTICULATION OF KNEE */
"8417" = "1" /* ABOVE KNEE AMPUTATION */
"8418" = "1" /* DISARTICULATION OF HIP */
"8419" = "1" /* HINDQUARTER AMPUTATION */
"8421" = "1" /* THUMB REATTACHMENT */
"8422" = "1" /* FINGER REATTACHMENT */
"8423" = "1" /* FOREARM/WRIST/HAND REATT */
"8424" = "1" /* UPPER ARM REATTACHMENT */
"8425" = "1" /* TOE REATTACHMENT */
"8426" = "1" /* FOOT REATTACHMENT */
"8427" = "1" /* LOWER LEG/ANKLE REATTACH */
"8428" = "1" /* THIGH REATTACHMENT */
"8429" = "1" /* REATTACHMENT NEC */
"843 " = "1" /* AMPUTATION STUMP REVIS */
"8440" = "1" /* IMPLNT/FIT PROS LIMB NOS */
"8444" = "1" /* IMPLANT ARM PROSTHESIS */
"8448" = "1" /* IMPLANT LEG PROSTHESIS */
"8458" = "1" /* IMP INTRSPINE DECOMP DEV */
"8459" = "1" /* INSERT OTHR SPIN DEVICE */
"8460" = "1" /* INSERT DISC PROS NOS */
"8461" = "1" /* INS PART DISC PROS CERV */
"8462" = "1" /* INS TOT DISC PROST CERV */
"8463" = "1" /* INS SPIN DISC PROS THOR */
"8464" = "1" /* INS PART DISC PROS LUMB */
"8465" = "1" /* INS TOTL DISC PROS LUMB */
"8466" = "1" /* REVISE DISC PROST CERV */
"8467" = "1" /* REVISE DISC PROST THORA */
"8468" = "1" /* REVISE DISC PROSTH LUMB */
"8469" = "1" /* REVISE DISC PROSTH NOS */
"8480" = "1" /* INS/REPL INTERSPINE DEV */
"8481" = "1" /* REV INTERSPINE DEVICE */
"8482" = "1" /* INS/REPL PDCL STABIL DEV */
"8483" = "1" /* REV PEDCL DYN STABIL DEV */
"8484" = "1" /* INS/REPL FACET REPLC DEV */
"8485" = "1" /* REV FACET REPLACE DEVICE */
"8491" = "1" /* AMPUTATION NOS */
"8492" = "1" /* SEPARAT EQUAL JOIN TWIN */
"8493" = "1" /* SEPARAT UNEQUL JOIN TWIN */
"8494" = "1" /* INS STRN FIX W RGD PLATE */	    
"8499" = "1" /* MUSCULOSKELETAL OP NEC */
"8512" = "1" /* OPEN BREAST BIOPSY */
"8520" = "1" /* BREAST TISSU DESTRUC NOS */
"8521" = "1" /* LOCAL EXCIS BREAST LES */
"8522" = "1" /* QUADRANT RESECT BREAST */
"8523" = "1" /* SUBTOTAL MASTECTOMY */
"8524" = "1" /* EXC ECTOPIC BREAST TISSU */
"8525" = "1" /* EXCISION OF NIPPLE */
"8531" = "1" /* UNILAT REDUCT MAMMOPLAST */
"8532" = "1" /* BILAT REDUCT MAMMOPLASTY */
"8533" = "1" /* UNIL SUBQ MAMMECT-IMPLNT */
"8534" = "1" /* UNILAT SUBQ MAMMECT NEC */
"8535" = "1" /* BIL SUBQ MAMMECT-IMPLANT */
"8536" = "1" /* BILAT SUBQ MAMMECTOM NEC */
"8541" = "1" /* UNILAT SIMPLE MASTECTOMY */
"8542" = "1" /* BILAT SIMPLE MASTECTOMY */
"8543" = "1" /* UNILAT EXTEN SIMP MASTEC */
"8544" = "1" /* BILAT EXTEND SIMP MASTEC */
"8545" = "1" /* UNILAT RADICAL MASTECTOM */
"8546" = "1" /* BILAT RADICAL MASTECTOMY */
"8547" = "1" /* UNIL EXT RAD MASTECTOMY */
"8548" = "1" /* BIL EXTEN RAD MASTECTOMY */
"8550" = "1" /* AUGMENT MAMMOPLASTY NOS */
"8553" = "1" /* UNILAT BREAST IMPLANT */
"8554" = "1" /* BILATERAL BREAST IMPLANT */
"8555" = "1" /* FAT GRAFT TO BREAST	  	 */  
"856 " = "1" /* MASTOPEXY */
"857 " = "1" /* TOTAL BREAST RECONSTRUCT */
"8570" = "1" /* TOTL RECONSTC BREAST NOS */ 
"8571" = "1" /* LATISS DORSI MYOCUT FLAP */
"8572" = "1" /* TRAM FLAP, PEDICLED */
"8573" = "1" /* TRAM FLAP, FREE */
"8574" = "1" /* DIEP FLAP, FREE */
"8575" = "1" /* SIEA FLAP, FREE */
"8576" = "1" /* GAP FLAP, FREE */
"8579" = "1" /* TOTL RECONST BREAST NEC */
"8582" = "1" /* BREAST SPLIT-THICK GRAFT */
"8583" = "1" /* BREAST FULL-THICK GRAFT */
"8584" = "1" /* BREAST PEDICLE GRAFT */
"8585" = "1" /* BREAST MUSCLE FLAP GRAFT */
"8586" = "1" /* TRANSPOSITION OF NIPPLE */
"8587" = "1" /* NIPPLE REPAIR NEC */
"8589" = "1" /* MAMMOPLASTY NEC */
"8593" = "1" /* BREAST IMPLANT REVISION */
"8594" = "1" /* BREAST IMPLANT REMOVAL */
"8595" = "1" /* INSER BREAST TISSU EXPAN */
"8596" = "1" /* REMOV BREAST TISSU EXPAN */
"8599" = "1" /* BREAST OPERATION NEC */
"8606" = "1" /* INSERT INFUSION PUMP */
"8621" = "1" /* EXCISION OF PILONID CYST */
"8622" = "1" /* EXC WOUND DEBRIDEMENT */
"8625" = "1" /* DERMABRASION */
"864 " = "1" /* RADICAL EXCIS SKIN LES */
"8660" = "1" /* FREE SKIN GRAFT NOS */
"8661" = "1" /* FULL-THICK HAND SKIN GRF */
"8662" = "1" /* HAND SKIN GRAFT NEC */
"8663" = "1" /* FULL-THICK SKIN GRFT NEC */
"8665" = "1" /* HETEROGRAFT TO SKIN */
"8666" = "1" /* HOMOGRAFT TO SKIN */
"8667" = "1" /* DERMAL REGENER GRAFT */
"8669" = "1" /* FREE SKIN GRAFT NEC */
"8670" = "1" /* PEDICLE GRAFT/FLAP NOS */
"8671" = "1" /* CUT & PREP PEDICLE GRAFT */
"8672" = "1" /* PEDICLE GRAFT ADVANCEMEN */
"8673" = "1" /* ATTACH PEDICLE TO HAND */
"8674" = "1" /* ATTACH PEDICLE GRAFT NEC */
"8675" = "1" /* REVISION OF PEDICLE GRFT */
"8681" = "1" /* REPAIR FACIAL WEAKNESS */
"8682" = "1" /* FACIAL RHYTIDECTOMY */
"8683" = "1" /* SIZE REDUCT PLASTIC OP */
"8684" = "1" /* RELAXATION OF SCAR */
"8685" = "1" /* SYNDACTYLY CORRECTION */
"8686" = "1" /* ONYCHOPLASTY */
"8687" = "1" /* FAT GRFT SKIN/SUBQ TISS	 */         
"8689" = "1" /* SKIN REPAIR & PLASTY NEC */
"8690" = "1" /* EXT FAT FOR GRFT/BANKING */
"8691" = "1" /* SKIN EXCISION FOR GRAFT */
"8693" = "1" /* INSERT TISSUE EXPANDER */
"8694" = "1" /* INS/REPL SINGLE PUL GEN */
"8695" = "1" /* INS/REPL DUAL PULSE GEN */
"8696" = "1" /* INSERT/REPL OTH NEUROST */
"8697" = "1" /* INS/REP 1 PUL GEN */
"8698" = "1" /* INS/REP 2 PUL GEN */
"8753" = "1" /* INTRAOPER CHOLANGIOGRAM */
"9227" = "1" /* RADIOACTIVE ELEM IMPLANT */
"9504" = "1" /* ANESTHETIZED EYE EXAM */
OTHER  = "0" ;

VALUE $PRCLASS
'0001' = 2
'0002' = 2
'0003' = 2
'0009' = 2
'0010' = 2
'0011' = 2
'0012' = 2
'0013' = 2
'0014' = 2
'0015' = 2
'0016' = 2
'0017' = 2
'0018' = 2
'0021' = 1
'0022' = 1
'0023' = 1
'0024' = 1
'0025' = 1
'0028' = 1
'0029' = 1
'0031' = 1
'0032' = 1
'0033' = 1
'0034' = 1
'0035' = 1
'0039' = 1
'0040' = 2
'0041' = 2
'0042' = 2
'0043' = 2
'0044' = 2  
'0045' = 2
'0046' = 2
'0047' = 2
'0048' = 2
'0049' = 2
'0050' = 4
'0051' = 4
'0052' = 4
'0053' = 4
'0054' = 4
'0055' = 2
'0056' = 4
'0057' = 4
'0058' = 3
'0059' = 3
'0060' = 2
'0061' = 4
'0062' = 4
'0063' = 2
'0064' = 2
'0065' = 2
'0066' = 4
'0067' = 3
'0068' = 3
'0069' = 3
'0070' = 4
'0071' = 4
'0072' = 4
'0073' = 4
'0074' = 2 
'0075' = 2 
'0076' = 2 
'0077' = 2 
'0080' = 4
'0081' = 4
'0082' = 4
'0083' = 4
'0084' = 4
'0085' = 4
'0086' = 4
'0087' = 4
'0091' = 2
'0092' = 2
'0093' = 2
'0094' = 1 
'0095' = 2  /** ADDED FOR V4.5 **/
'0101' = 2
'0102' = 2
'0109' = 2
'0110' = 1 
'0111' = 1
'0112' = 3
'0113' = 1
'0114' = 3
'0115' = 3
'0116' = 1 
'0117' = 1 
'0118' = 3
'0119' = 3
'0120' = 4
'0121' = 4
'0122' = 4
'0123' = 4
'0124' = 4
'0125' = 4
'0126' = 2
'0127' = 2 
'0128' = 4
'0129' = 4
'0131' = 4
'0132' = 4
'0139' = 4
'0141' = 4
'0142' = 4
'0151' = 4
'0152' = 4
'0153' = 4
'0159' = 4
'016' = 4
'0201' = 4
'0202' = 4
'0203' = 4
'0204' = 4
'0205' = 4
'0206' = 4
'0207' = 4
'0211' = 4
'0212' = 4
'0213' = 4
'0214' = 4
'022'  = 4
'0221' = 4  
'0222' = 4 
'0231' = 4
'0232' = 4
'0233' = 4
'0234' = 4
'0235' = 4
'0239' = 4
'0241' = 2
'0242' = 4
'0243' = 4
'0291' = 4
'0292' = 4
'0293' = 4
'0294' = 4
'0295' = 2
'0296' = 2
'0299' = 4
'0301' = 4
'0302' = 4
'0309' = 4
'031' = 4
'0321' = 4
'0329' = 4
'0331' = 1
'0332' = 3
'0339' = 3
'034' = 4
'0351' = 4
'0352' = 4
'0353' = 4
'0359' = 4
'036' = 4
'0371' = 4
'0372' = 4
'0379' = 4
'038' = 2
'0390' = 2
'0391' = 2
'0392' = 2
'0393' = 4
'0394' = 4
'0395' = 2
'0396' = 2
'0397' = 4
'0398' = 4
'0399' = 4
'0401' = 4
'0402' = 4
'0403' = 4
'0404' = 4
'0405' = 4
'0406' = 4
'0407' = 4
'0411' = 1
'0412' = 3
'0419' = 3
'042' = 2
'043' = 4
'0441' = 4
'0442' = 4
'0443' = 4
'0444' = 4
'0449' = 4
'045' = 4
'046' = 4
'0471' = 4
'0472' = 4
'0473' = 4
'0474' = 4
'0475' = 4
'0476' = 4
'0479' = 4
'0480' = 2
'0481' = 2
'0489' = 2
'0491' = 4
'0492' = 4
'0493' = 4
'0499' = 4
'050' = 4
'0511' = 3
'0519' = 3
'0521' = 4
'0522' = 4
'0523' = 4
'0524' = 4
'0525' = 4
'0529' = 4
'0531' = 2
'0532' = 2
'0539' = 2
'0581' = 4
'0589' = 4
'059' = 4
'0601' = 2
'0602' = 4
'0609' = 4
'0611' = 1
'0612' = 3
'0613' = 3
'0619' = 3
'062' = 4
'0631' = 4
'0639' = 4
'064' = 4
'0650' = 4
'0651' = 4
'0652' = 4
'066' = 4
'067' = 4
'0681' = 4
'0689' = 4
'0691' = 4
'0692' = 4
'0693' = 4
'0694' = 4
'0695' = 4
'0698' = 4
'0699' = 4
'0700' = 4
'0701' = 4
'0702' = 4
'0711' = 1
'0712' = 3
'0713' = 3
'0714' = 3
'0715' = 3
'0716' = 3
'0717' = 3
'0719' = 3
'0721' = 4
'0722' = 4
'0729' = 4
'073' = 4
'0741' = 4
'0742' = 4
'0743' = 4
'0744' = 4
'0745' = 4
'0749' = 4
'0751' = 4
'0752' = 4
'0753' = 4
'0754' = 4
'0759' = 4
'0761' = 4
'0762' = 4
'0763' = 4
'0764' = 4
'0765' = 4
'0768' = 4
'0769' = 4
'0771' = 4
'0772' = 4
'0779' = 4
'0780' = 4
'0781' = 4
'0782' = 4
'0791' = 4
'0792' = 4
'0793' = 4
'0794' = 4
'0799' = 4
'0801' = 2
'0802' = 2
'0809' = 2
'0811' = 3
'0819' = 1
'0820' = 4
'0821' = 4
'0822' = 4
'0823' = 4
'0824' = 4
'0825' = 4
'0831' = 4
'0832' = 4
'0833' = 4
'0834' = 4
'0835' = 4
'0836' = 4
'0837' = 4
'0838' = 4
'0841' = 4
'0842' = 4
'0843' = 4
'0844' = 4
'0849' = 4
'0851' = 4
'0852' = 4
'0859' = 4
'0861' = 4
'0862' = 4
'0863' = 4
'0864' = 4
'0869' = 4
'0870' = 4
'0871' = 4
'0872' = 4
'0873' = 4
'0874' = 4
'0881' = 2
'0882' = 2
'0883' = 2
'0884' = 2
'0885' = 2
'0886' = 2
'0887' = 2
'0889' = 2
'0891' = 4
'0892' = 4
'0893' = 4
'0899' = 4
'090' = 4
'0911' = 3
'0912' = 3
'0919' = 3
'0920' = 4
'0921' = 4
'0922' = 4
'0923' = 4
'093' = 4
'0941' = 4
'0942' = 4
'0943' = 4
'0944' = 4
'0949' = 4
'0951' = 4
'0952' = 4
'0953' = 4
'0959' = 4
'096' = 4
'0971' = 4
'0972' = 4
'0973' = 4
'0981' = 4
'0982' = 4
'0983' = 4
'0991' = 4
'0999' = 4
'100' = 4
'101' = 4
'1021' = 3
'1029' = 3
'1031' = 4
'1032' = 4
'1033' = 4
'1041' = 4
'1042' = 4
'1043' = 4
'1044' = 4
'1049' = 4
'105' = 4
'106' = 4
'1091' = 4
'1099' = 4
'110' = 4
'111' = 4
'1121' = 3
'1122' = 3
'1129' = 3
'1131' = 4
'1132' = 4
'1139' = 4
'1141' = 4
'1142' = 4
'1143' = 4
'1149' = 4
'1151' = 4
'1152' = 4
'1153' = 4
'1159' = 4
'1160' = 4
'1161' = 4
'1162' = 4
'1163' = 4
'1164' = 4
'1169' = 4
'1171' = 4
'1172' = 4
'1173' = 4
'1174' = 4
'1175' = 4
'1176' = 4
'1179' = 4
'1191' = 4
'1192' = 4
'1199' = 4
'1200' = 4
'1201' = 4
'1202' = 4
'1211' = 4
'1212' = 4
'1213' = 4
'1214' = 4
'1221' = 3
'1222' = 3
'1229' = 3
'1231' = 4
'1232' = 4
'1233' = 4
'1234' = 4
'1235' = 4
'1239' = 4
'1240' = 4
'1241' = 4
'1242' = 4
'1243' = 4
'1244' = 4
'1251' = 4
'1252' = 4
'1253' = 4
'1254' = 4
'1255' = 4
'1259' = 4
'1261' = 4
'1262' = 4
'1263' = 4
'1264' = 4
'1265' = 4
'1266' = 4
'1267' = 4   /** Added new in V4.4 (Nov 2011)  **/
'1269' = 4
'1271' = 4
'1272' = 4
'1273' = 4
'1274' = 4
'1279' = 4
'1281' = 4
'1282' = 4
'1283' = 4
'1284' = 4
'1285' = 4
'1286' = 4
'1287' = 4
'1288' = 4
'1289' = 4
'1291' = 4
'1292' = 4
'1293' = 4
'1297' = 4
'1298' = 4
'1299' = 4
'1300' = 4
'1301' = 4
'1302' = 4
'1311' = 4
'1319' = 4
'132' = 4
'133' = 4
'1341' = 4
'1342' = 4
'1343' = 4
'1351' = 4
'1359' = 4
'1361' = 4
'1362' = 4
'1363' = 4
'1364' = 4
'1365' = 4
'1366' = 4
'1369' = 4
'1370' = 4
'1371' = 4
'1372' = 4
'138' = 4
'139' = 4
'1390' = 4
'1391' = 4
'1400' = 4
'1401' = 4
'1402' = 4
'1411' = 3
'1419' = 3
'1421' = 4
'1422' = 4
'1423' = 2
'1424' = 2
'1425' = 2
'1426' = 4
'1427' = 4
'1429' = 4
'1431' = 4
'1432' = 4
'1433' = 2
'1434' = 2
'1435' = 2
'1439' = 4
'1441' = 4
'1449' = 4
'1451' = 4
'1452' = 4
'1453' = 4
'1454' = 4
'1455' = 4
'1459' = 4
'146' = 4
'1471' = 4
'1472' = 4
'1473' = 4
'1474' = 4
'1475' = 4
'1479' = 4
'149' = 4
'1501' = 3
'1509' = 3
'1511' = 4
'1512' = 4
'1513' = 4
'1519' = 4
'1521' = 4
'1522' = 4
'1529' = 4
'153' = 4
'154' = 4
'155' = 4
'156' = 4
'157' = 4
'159' = 4
'1601' = 4
'1602' = 4
'1609' = 4
'161' = 4
'1621' = 1
'1622' = 3
'1623' = 3
'1629' = 3
'1631' = 4
'1639' = 4
'1641' = 4
'1642' = 4
'1649' = 4
'1651' = 4
'1652' = 4
'1659' = 4
'1661' = 4
'1662' = 4
'1663' = 4
'1664' = 4
'1665' = 4
'1666' = 4
'1669' = 4
'1671' = 4
'1672' = 4
'1681' = 4
'1682' = 4
'1689' = 4
'1691' = 2
'1692' = 4
'1693' = 4
'1698' = 4
'1699' = 4
'1741' = 2 
'1742' = 2 
'1743' = 2 
'1744' = 2 
'1745' = 2 
'1749' = 2 
'1751' = 4
'1752' = 4
'1753' = 4   /** Added new in V4.4 (Nov 2011)  **/
'1754' = 4   /** Added new in V4.4 (Nov 2011)  **/
'1755' = 4   /** Added new in V4.4 (Nov 2011)  **/
'1756' = 4   /** Added new in V4.4 (Nov 2011)  **/
'1761' = 4
'1762' = 4
'1763' = 4
'1769' = 4
'1770' = 2
'1771' = 1
'1781' = 2   /** Added new in V4.4 (Nov 2011)  **/
'1801' = 2
'1802' = 2
'1809' = 2
'1811' = 1
'1812' = 1
'1819' = 1
'1821' = 4
'1829' = 2
'1831' = 4
'1839' = 4
'184'  = 2
'185'  = 4
'186'  = 4
'1871' = 4
'1872' = 4
'1879' = 4
'189' = 4
'190' = 4
'1911' = 4
'1919' = 4
'1921' = 4
'1929' = 4
'193' = 4
'194' = 4
'1952' = 4
'1953' = 4
'1954' = 4
'1955' = 4
'196' = 4
'199' = 4
'2001' = 4
'2009' = 2
'201' = 2
'2021' = 4
'2022' = 4
'2023' = 4
'2031' = 1
'2032' = 3
'2039' = 3
'2041' = 4
'2042' = 4
'2049' = 4
'2051' = 4
'2059' = 4
'2061' = 4
'2062' = 4
'2071' = 4
'2072' = 4
'2079' = 4
'208' = 2
'2091' = 4
'2092' = 4
'2093' = 4
'2094' = 2
'2095' = 4
'2096' = 4
'2097' = 4
'2098' = 4
'2099' = 4
'2100' = 2
'2101' = 2
'2102' = 2
'2103' = 2
'2104' = 4
'2105' = 4
'2106' = 4
'2107' = 4
'2109' = 4
'211' = 2
'2121' = 1
'2122' = 1
'2129' = 1
'2130' = 2
'2131' = 2
'2132' = 2
'214' = 4
'215' = 4
'2161' = 4
'2162' = 4
'2169' = 4
'2171' = 2
'2172' = 4
'2181' = 2
'2182' = 4
'2183' = 4
'2184' = 4
'2185' = 4
'2186' = 4
'2187' = 4
'2188' = 4
'2189' = 4
'2191' = 2
'2199' = 4
'2200' = 2
'2201' = 2
'2202' = 2
'2211' = 1
'2212' = 3
'2219' = 1
'222' = 2
'2231' = 4
'2239' = 4
'2241' = 4
'2242' = 4
'2250' = 4
'2251' = 4
'2252' = 4
'2253' = 4
'2260' = 4
'2261' = 4
'2262' = 4
'2263' = 4
'2264' = 4
'2271' = 4
'2279' = 4
'229' = 4
'2301' = 2
'2309' = 2
'2311' = 2
'2319' = 2
'232' = 2
'233' = 2
'2341' = 2
'2342' = 2
'2343' = 2
'2349' = 2
'235' = 2
'236' = 2
'2370' = 2
'2371' = 2
'2372' = 2
'2373' = 2
'240' = 2
'2411' = 1
'2412' = 1
'2419' = 1
'242' = 4
'2431' = 2
'2432' = 2
'2439' = 2
'244' = 4
'245' = 4
'246' = 2
'247' = 2
'248' = 2
'2491' = 2
'2499' = 2
'2501' = 1
'2502' = 3
'2509' = 1
'251' = 4
'252' = 4
'253' = 4
'254' = 4
'2551' = 2
'2559' = 4
'2591' = 2
'2592' = 2
'2593' = 2
'2594' = 4
'2599' = 4
'260' = 2
'2611' = 1
'2612' = 3
'2619' = 1
'2621' = 4
'2629' = 4
'2630' = 4
'2631' = 4
'2632' = 4
'2641' = 4
'2642' = 4
'2649' = 4
'2691' = 2
'2699' = 4
'270' = 4
'271' = 4
'2721' = 3
'2722' = 3
'2723' = 1
'2724' = 1
'2729' = 1
'2731' = 4
'2732' = 4
'2741' = 2
'2742' = 4
'2743' = 4
'2749' = 4
'2751' = 2
'2752' = 2
'2753' = 4
'2754' = 4
'2755' = 4
'2756' = 4
'2757' = 4
'2759' = 4
'2761' = 4
'2762' = 4
'2763' = 4
'2764' = 2
'2769' = 4
'2771' = 4
'2772' = 4
'2773' = 4
'2779' = 4
'2791' = 2
'2792' = 4
'2799' = 4
'280' = 4
'2811' = 3
'2819' = 3
'282' = 4
'283' = 4
'284' = 4
'285' = 4
'286' = 4
'287' = 4
'2891' = 4
'2892' = 4
'2899' = 4
'290' = 4
'2911' = 1
'2912' = 1
'2919' = 1
'292' = 4
'293' = 4
'2931' = 4
'2932' = 4
'2933' = 4
'2939' = 4
'294' = 4
'2951' = 4
'2952' = 4
'2953' = 4
'2954' = 4
'2959' = 4
'2991' = 2
'2992' = 4
'2999' = 4
'3001' = 4
'3009' = 4
'301' = 4
'3021' = 4
'3022' = 4
'3029' = 4
'303' = 4
'304' = 4
'310' = 2
'311' = 2
'3121' = 4
'3129' = 4
'313' = 4
'3141' = 1
'3142' = 1
'3143' = 1
'3144' = 1
'3145' = 3
'3148' = 1
'3149' = 1
'315' = 4
'3161' = 4
'3162' = 4
'3163' = 4
'3164' = 4
'3169' = 4
'3171' = 4
'3172' = 4
'3173' = 4
'3174' = 4
'3175' = 4
'3179' = 4
'3191' = 4
'3192' = 4
'3193' = 2
'3194' = 2
'3195' = 2
'3198' = 4
'3199' = 4
'320' = 4
'3201' = 2
'3209' = 4
'321' = 4
'3221' = 4
'3222' = 4
'3223' = 4
'3224' = 4
'3225' = 4
'3226' = 4
'3227' = 4
'3228' = 2
'3229' = 4
'323' = 4
'324' = 4
'325' = 4
'326' = 4
'329' = 4
'330' = 4
'331' = 4
'3321' = 1
'3322' = 1
'3323' = 1
'3324' = 1
'3325' = 3
'3326' = 1
'3327' = 3
'3328' = 3
'3329' = 3
'3331' = 2
'3332' = 2
'3333' = 2
'3334' = 4
'3339' = 4
'3341' = 4
'3342' = 4
'3343' = 4
'3348' = 4
'3349' = 4
'335' = 4
'3350' = 4
'3351' = 4
'3352' = 4
'336' = 4
'3371' = 2
'3372' = 2 
'3373' = 2
'3378' = 2
'3379' = 2
'3391' = 2
'3392' = 4
'3393' = 4
'3398' = 4
'3399' = 4
'3401' = 2
'3402' = 4
'3403' = 4
'3404' = 2
'3405' = 2
'3409' = 2
'341' = 4
'3421' = 3
'3422' = 3
'3423' = 1
'3424' = 1
'3425' = 1
'3426' = 3
'3427' = 3
'3428' = 3
'3429' = 3
'343' = 4
'344' = 4
'3451' = 4
'3459' = 4
'346' = 4
'3471' = 2
'3472' = 2
'3473' = 4
'3474' = 4
'3479' = 4
'3481' = 4
'3482' = 4
'3483' = 4
'3484' = 4
'3485' = 4
'3489' = 4
'3491' = 2
'3492' = 2
'3493' = 4
'3499' = 4
'3500' = 4
'3501' = 4
'3502' = 4
'3503' = 4
'3504' = 4
'3505' = 4   /** Added new in V4.4 (Nov 2011)  **/
'3506' = 4   /** Added new in V4.4 (Nov 2011)  **/
'3507' = 4   /** Added new in V4.4 (Nov 2011)  **/
'3508' = 4   /** Added new in V4.4 (Nov 2011)  **/
'3509' = 4   /** Added new in V4.4 (Nov 2011)  **/
'3510' = 4
'3511' = 4
'3512' = 4
'3513' = 4
'3514' = 4
'3520' = 4
'3521' = 4
'3522' = 4
'3523' = 4
'3524' = 4
'3525' = 4
'3526' = 4
'3527' = 4
'3528' = 4
'3531' = 4
'3532' = 4
'3533' = 4
'3534' = 4
'3535' = 4
'3539' = 4
'3541' = 2
'3542' = 4
'3550' = 4
'3551' = 4
'3552' = 4
'3553' = 4
'3554' = 4
'3555' = 4
'3560' = 4
'3561' = 4
'3562' = 4
'3563' = 4
'3570' = 4
'3571' = 4
'3572' = 4
'3573' = 4
'3581' = 4
'3582' = 4
'3583' = 4
'3584' = 4
'3591' = 4
'3592' = 4
'3593' = 4
'3594' = 4
'3595' = 4
'3596' = 4
'3597' = 4
'3598' = 4
'3599' = 4
'3600' = 4
'3601' = 4
'3602' = 4
'3603' = 4
'3604' = 2
'3605' = 4
'3606' = 2
'3607' = 2
'3609' = 4
'3610' = 4
'3611' = 4
'3612' = 4
'3613' = 4
'3614' = 4
'3615' = 4
'3616' = 4
'3617' = 4
'3619' = 4
'362' = 4
'363' = 4
'3631' = 4
'3632' = 4
'3633' = 4
'3634' = 4
'3639' = 4
'3691' = 4
'3699' = 4
'370' = 2
'3710' = 4
'3711' = 4
'3712' = 4
'3720' = 1
'3721' = 1
'3722' = 1
'3723' = 1
'3724' = 3
'3725' = 1
'3726' = 1
'3727' = 1
'3728' = 1
'3729' = 1
'3731' = 4
'3732' = 4
'3733' = 4
'3734' = 4
'3735' = 4
'3736' = 2 
'3737' = 4
'374' = 4
'3741' = 4
'3749' = 4
'375' = 4
'3751' = 4
'3752' = 4
'3753' = 4
'3754' = 4
'3760' = 4
'3761' = 4
'3762' = 4
'3763' = 4
'3764' = 4
'3765' = 4
'3766' = 4
'3767' = 4
'3768' = 4 
'3770' = 2
'3771' = 2
'3772' = 2
'3773' = 2
'3774' = 4
'3775' = 4
'3776' = 4
'3777' = 4
'3778' = 2
'3779' = 4
'3780' = 4
'3781' = 2
'3782' = 2
'3783' = 2
'3785' = 4
'3786' = 4
'3787' = 4
'3789' = 4
'3790' = 2 
'3791' = 4
'3792' = 2
'3793' = 2
'3794' = 4
'3795' = 4
'3796' = 4
'3797' = 4
'3798' = 4
'3799' = 4
'3800' = 4
'3801' = 4
'3802' = 4
'3803' = 4
'3804' = 4
'3805' = 4
'3806' = 4
'3807' = 4
'3808' = 4
'3809' = 4
'3810' = 4
'3811' = 4
'3812' = 4
'3813' = 4
'3814' = 4
'3815' = 4
'3816' = 4
'3818' = 4
'3821' = 3
'3822' = 1
'3823' = 1 
'3824' = 1
'3825' = 1
'3826' = 4   /** Added new in V4.4 (Nov 2011)  **/
'3829' = 3
'3830' = 4
'3831' = 4
'3832' = 4
'3833' = 4
'3834' = 4
'3835' = 4
'3836' = 4
'3837' = 4
'3838' = 4
'3839' = 4
'3840' = 4
'3841' = 4
'3842' = 4
'3843' = 4
'3844' = 4
'3845' = 4
'3846' = 4
'3847' = 4
'3848' = 4
'3849' = 4
'3850' = 4
'3851' = 4
'3852' = 4
'3853' = 4
'3855' = 4
'3857' = 4
'3859' = 4
'3860' = 4
'3861' = 4
'3862' = 4
'3863' = 4
'3864' = 4
'3865' = 4
'3866' = 4
'3867' = 4
'3868' = 4
'3869' = 4
'387' = 4
'3880' = 4
'3881' = 4
'3882' = 4
'3883' = 4
'3884' = 4
'3885' = 4
'3886' = 4
'3887' = 4
'3888' = 4
'3889' = 4
'3891' = 2
'3892' = 2
'3893' = 2
'3894' = 2
'3895' = 2
'3897' = 2
'3898' = 2
'3899' = 2
'390' = 4
'391'  = 4
'3921' = 4
'3922' = 4
'3923' = 4
'3924' = 4
'3925' = 4
'3926' = 4
'3927' = 4
'3928' = 4
'3929' = 4
'3930' = 4
'3931' = 4
'3932' = 4
'3941' = 4
'3942' = 4
'3943' = 4
'3949' = 4
'3950' = 4
'3951' = 4
'3952' = 4
'3953' = 4
'3954' = 4
'3955' = 4
'3956' = 4
'3957' = 4
'3958' = 4
'3959' = 4
'3961' = 2
'3962' = 2
'3963' = 2
'3964' = 2
'3965' = 4  
'3966' = 2
'397'  = 4
'3971' = 4
'3972' = 4
'3973' = 4
'3974' = 4
'3975' = 4
'3976' = 4
'3977' = 4   
'3978' = 4   
'3979' = 4
'398'  = 4
'3981' = 4
'3982' = 4
'3983' = 4
'3984' = 4
'3985' = 4
'3986' = 4
'3987' = 4
'3988' = 4
'3989' = 4
'3990' = 2
'3991' = 4
'3992' = 4
'3993' = 4
'3994' = 4
'3995' = 2
'3996' = 2
'3997' = 2
'3998' = 4
'3999' = 4
'400'  = 4
'4011' = 3
'4019' = 3
'4021' = 4
'4022' = 4
'4023' = 4
'4024' = 4
'4029' = 4
'403' = 4
'4040' = 4
'4041' = 4
'4042' = 4
'4050' = 4
'4051' = 4
'4052' = 4
'4053' = 4
'4054' = 4
'4059' = 4
'4061' = 4
'4062' = 4
'4063' = 4
'4064' = 4
'4069' = 4
'409' = 4
'410' = 2  
'4100' = 2 
'4101' = 2
'4102' = 2 
'4103' = 2 
'4104' = 2 
'4105' = 2 
'4106' = 2 
'4107' = 2 
'4108' = 2 
'4109' = 2 
'411' = 2
'412' = 4
'4131' = 1
'4132' = 1
'4133' = 3
'4138' = 1
'4139' = 1
'4141' = 4
'4142' = 4
'4143' = 4
'415' = 4
'4191' = 2
'4192' = 2
'4193' = 4
'4194' = 4
'4195' = 4
'4198' = 2
'4199' = 4
'4201' = 4
'4209' = 4
'4210' = 4
'4211' = 4
'4212' = 4
'4219' = 4
'4221' = 3
'4222' = 1
'4223' = 1
'4224' = 1
'4225' = 3
'4229' = 1
'4231' = 4
'4232' = 4
'4233' = 2
'4239' = 4
'4240' = 4
'4241' = 4
'4242' = 4
'4251' = 4
'4252' = 4
'4253' = 4
'4254' = 4
'4255' = 4
'4256' = 4
'4258' = 4
'4259' = 4
'4261' = 4
'4262' = 4
'4263' = 4
'4264' = 4
'4265' = 4
'4266' = 4
'4268' = 4
'4269' = 4
'427' = 4
'4281' = 2
'4282' = 4
'4283' = 4
'4284' = 4
'4285' = 4
'4286' = 4
'4287' = 4
'4289' = 4
'4291' = 4
'4292' = 2
'4299' = 2
'430' = 4
'431' = 4
'4311' = 2
'4319' = 2
'432' = 4
'433' = 4
'4341' = 2
'4342' = 4
'4349' = 4
'435' = 4
'436' = 4
'437' = 4
'4381' = 4
'4382' = 4   /** Added new in V4.4 (Nov 2011)  **/
'4389' = 4
'4391' = 4
'4399' = 4
'4400' = 4
'4401' = 4
'4402' = 4
'4403' = 4
'4411' = 3
'4412' = 1
'4413' = 1
'4414' = 1
'4415' = 3
'4419' = 1
'442' = 4
'4421' = 4
'4422' = 2
'4429' = 4
'4431' = 4
'4432' = 4
'4438' = 4
'4439' = 4
'4440' = 4
'4441' = 4
'4442' = 4
'4443' = 2
'4444' = 2
'4449' = 2
'445' = 4
'4461' = 4
'4462' = 2
'4463' = 4
'4464' = 4
'4465' = 4
'4466' = 4
'4467' = 4
'4468' = 4
'4469' = 4
'4491' = 4
'4492' = 4
'4493' = 2
'4494' = 2
'4495' = 4
'4496' = 4
'4497' = 4
'4498' = 4
'4499' = 4
'4500' = 4
'4501' = 4
'4502' = 4
'4503' = 4
'4511' = 3
'4512' = 1
'4513' = 1
'4514' = 1
'4515' = 3
'4516' = 1
'4519' = 1
'4521' = 3
'4522' = 1
'4523' = 1
'4524' = 1
'4525' = 1
'4526' = 3
'4527' = 1
'4528' = 1
'4529' = 1
'4530' = 2
'4531' = 4
'4532' = 4
'4533' = 4
'4534' = 4
'4541' = 4
'4542' = 2
'4543' = 2
'4549' = 4
'4550' = 4
'4551' = 4
'4552' = 4
'4561' = 4
'4562' = 4
'4563' = 4
'4571' = 4
'4572' = 4
'4573' = 4
'4574' = 4
'4575' = 4
'4576' = 4
'4579' = 4
'458' = 4
'4590' = 4
'4591' = 4
'4592' = 4
'4593' = 4
'4594' = 4
'4595' = 4
'4601' = 4
'4602' = 4
'4603' = 4
'4604' = 4
'4610' = 4
'4611' = 4
'4612' = 4
'4613' = 4
'4614' = 2
'4620' = 4
'4621' = 4
'4622' = 4
'4623' = 4
'4624' = 2
'4631' = 2
'4632' = 2
'4639' = 2
'4640' = 4
'4641' = 4
'4642' = 4
'4643' = 4
'4650' = 4
'4651' = 4
'4652' = 4
'4660' = 4
'4661' = 4
'4662' = 4
'4663' = 4
'4664' = 4
'4671' = 4
'4672' = 4
'4673' = 4
'4674' = 4
'4675' = 4
'4676' = 4
'4679' = 4
'4680' = 4
'4681' = 4
'4682' = 4
'4685' = 2
'4686' = 2
'4687' = 2
'4691' = 4
'4692' = 4
'4693' = 4
'4694' = 4
'4695' = 2
'4696' = 2
'4697' = 4
'4699' = 4
'470' = 4
'4701' = 4
'4709' = 4
'471' = 4
'4711' = 4
'4719' = 4
'472' = 4
'4791' = 4
'4792' = 4
'4799' = 4
'480' = 4
'481' = 4
'4821' = 3
'4822' = 1
'4823' = 1
'4824' = 1
'4825' = 3
'4826' = 1
'4829' = 1
'4831' = 2
'4832' = 2
'4833' = 2
'4834' = 2
'4835' = 4
'4836' = 2
'4840' = 4
'4841' = 4
'4849' = 4
'485' = 4
'4850' = 4
'4861' = 4
'4862' = 4
'4863' = 4
'4864' = 4
'4865' = 4
'4866' = 4
'4869' = 4
'4871' = 4
'4872' = 4
'4873' = 4
'4874' = 4
'4875' = 4
'4876' = 4
'4879' = 4
'4881' = 4
'4882' = 4
'4891' = 4
'4892' = 4
'4893' = 4
'4899' = 4
'4901' = 4
'4902' = 4
'4903' = 2
'4904' = 4
'4911' = 4
'4912' = 4
'4921' = 1
'4922' = 1
'4923' = 1
'4929' = 1
'493' = 4
'4931' = 2
'4939' = 4
'4941' = 2
'4942' = 2
'4943' = 2
'4944' = 4
'4945' = 4
'4946' = 4
'4947' = 2
'4949' = 4
'4951' = 4
'4952' = 4
'4959' = 4
'496' = 4
'4971' = 4
'4972' = 4
'4973' = 4
'4974' = 4
'4975' = 4
'4976' = 4
'4979' = 4
'4991' = 4
'4992' = 4
'4993' = 4
'4994' = 4
'4995' = 4
'4999' = 4
'500' = 4
'5011' = 1
'5012' = 3
'5013' = 1 
'5019' = 3
'5021' = 4
'5022' = 4
'5023' = 4
'5024' = 4
'5025' = 4
'5026' = 4
'5029' = 4
'503' = 4
'504' = 4
'5051' = 4
'5059' = 4
'5061' = 4
'5069' = 4
'5091' = 2
'5092' = 2
'5093' = 2
'5094' = 2
'5099' = 2
'5101' = 2
'5102' = 4
'5103' = 4
'5104' = 4
'5110' = 1
'5111' = 1
'5112' = 1
'5113' = 3
'5114' = 1
'5115' = 1
'5119' = 3
'5121' = 4
'5122' = 4
'5123' = 4
'5124' = 4
'5131' = 4
'5132' = 4
'5133' = 4
'5134' = 4
'5135' = 4
'5136' = 4
'5137' = 4
'5139' = 4
'5141' = 4
'5142' = 4
'5143' = 4
'5149' = 4
'5151' = 4
'5159' = 4
'5161' = 4
'5162' = 4
'5163' = 4
'5164' = 2
'5169' = 4
'5171' = 4
'5172' = 4
'5179' = 4
'5181' = 4
'5182' = 4
'5183' = 4
'5184' = 2
'5185' = 2
'5186' = 2
'5187' = 2
'5188' = 2
'5189' = 4
'5191' = 4
'5192' = 4
'5193' = 4
'5194' = 4
'5195' = 4
'5196' = 2
'5197' = 2
'5198' = 2
'5199' = 4
'5201' = 4
'5209' = 4
'5211' = 1
'5212' = 3
'5213' = 1
'5214' = 1
'5219' = 3
'522' = 4
'5221' = 2
'5222' = 4
'523' = 4
'524' = 4
'5251' = 4
'5252' = 4
'5253' = 4
'5259' = 4
'526' = 4
'527' = 4
'5280' = 4
'5281' = 4
'5282' = 4
'5283' = 4
'5284' = 2
'5285' = 2
'5286' = 2
'5291' = 4
'5292' = 4
'5293' = 2
'5294' = 2
'5295' = 4
'5296' = 4
'5297' = 2
'5298' = 2
'5299' = 4
'5300' = 4
'5301' = 4
'5302' = 4
'5303' = 4
'5304' = 4
'5305' = 4
'5310' = 4
'5311' = 4
'5312' = 4
'5313' = 4
'5314' = 4
'5315' = 4
'5316' = 4
'5317' = 4
'5321' = 4
'5329' = 4
'5331' = 4
'5339' = 4
'5341' = 4
'5349' = 4
'5351' = 4
'5359' = 4
'5361' = 4
'5369' = 4
'537' = 4
'5380' = 4
'5381' = 4
'5382' = 4
'539' = 4
'540' = 4
'5411' = 4
'5412' = 4
'5419' = 4
'5421' = 3
'5422' = 3
'5423' = 3
'5424' = 1
'5425' = 1
'5429' = 3
'543' = 4
'544' = 4
'545' = 4
'5451' = 4
'5459' = 4
'5461' = 4
'5462' = 4
'5463' = 4
'5464' = 4
'5471' = 4
'5472' = 4
'5473' = 4
'5474' = 4
'5475' = 4
'5491' = 2
'5492' = 4
'5493' = 4
'5494' = 4
'5495' = 4
'5496' = 2
'5497' = 2
'5498' = 2
'5499' = 2
'5501' = 4
'5502' = 4
'5503' = 4
'5504' = 4
'5511' = 4
'5512' = 4
'5521' = 1
'5522' = 1
'5523' = 1
'5524' = 3
'5529' = 3
'5531' = 4
'5532' = 4
'5533' = 4
'5534' = 4
'5535' = 4
'5539' = 4
'554' = 4
'5551' = 4
'5552' = 4
'5553' = 4
'5554' = 4
'5561' = 4
'5569' = 4
'557' = 4
'5581' = 4
'5582' = 4
'5583' = 4
'5584' = 4
'5585' = 4
'5586' = 4
'5587' = 4
'5589' = 4
'5591' = 4
'5592' = 2
'5593' = 2
'5594' = 2
'5595' = 2
'5596' = 2
'5597' = 4
'5598' = 4
'5599' = 4
'560' = 4
'561' = 4
'562' = 4
'5631' = 1
'5632' = 1
'5633' = 1
'5634' = 3
'5635' = 1
'5639' = 3
'5640' = 4
'5641' = 4
'5642' = 4
'5651' = 4
'5652' = 4
'5661' = 4
'5662' = 4
'5671' = 4
'5672' = 4
'5673' = 4
'5674' = 4
'5675' = 4
'5679' = 4
'5681' = 4
'5682' = 4
'5683' = 4
'5684' = 4
'5685' = 4
'5686' = 4
'5689' = 4
'5691' = 2
'5692' = 4
'5693' = 4
'5694' = 4
'5695' = 4
'5699' = 4
'570' = 2
'5711' = 2
'5712' = 4
'5717' = 2
'5718' = 4
'5719' = 4
'5721' = 4
'5722' = 4
'5731' = 1
'5732' = 1
'5733' = 3
'5734' = 3
'5739' = 3
'5741' = 4
'5749' = 4
'5751' = 4
'5759' = 4
'576' = 4
'5771' = 4
'5779' = 4
'5781' = 4
'5782' = 4
'5783' = 4
'5784' = 4
'5785' = 4
'5786' = 4
'5787' = 4
'5788' = 4
'5789' = 4
'5791' = 4
'5792' = 2
'5793' = 4
'5794' = 2
'5795' = 2
'5796' = 4
'5797' = 4
'5798' = 4
'5799' = 4
'580' = 4
'581' = 4
'5821' = 1
'5822' = 1
'5823' = 1
'5824' = 1
'5829' = 1
'583' = 2
'5831' = 2
'5839' = 2
'5841' = 4
'5842' = 4
'5843' = 4
'5844' = 4
'5845' = 4
'5846' = 4
'5847' = 4
'5849' = 4
'585' = 4
'586' = 2
'5891' = 4
'5892' = 4
'5893' = 4
'5899' = 4
'5900' = 4
'5901' = 4
'5902' = 4
'5903' = 4
'5909' = 4
'5911' = 4
'5912' = 4
'5919' = 4
'5921' = 3
'5929' = 3
'593' = 4
'594' = 4
'595' = 4
'596' = 4
'5971' = 4
'5972' = 2
'5979' = 4
'598' = 2
'5991' = 4
'5992' = 4
'5993' = 2
'5994' = 2
'5995' = 2
'5996' = 2
'5999' = 2
'600' = 4
'6011' = 1
'6012' = 3
'6013' = 1
'6014' = 3
'6015' = 3
'6018' = 3
'6019' = 3
'602' = 4
'6021' = 4
'6029' = 4
'603' = 4
'604' = 4
'605' = 4
'6061' = 4
'6062' = 4
'6069' = 4
'6071' = 2
'6072' = 4
'6073' = 4
'6079' = 4
'6081' = 4
'6082' = 4
'6091' = 2
'6092' = 2
'6093' = 4
'6094' = 4
'6095' = 4
'6096' = 4
'6097' = 4
'6099' = 4
'610' = 2
'6111' = 1
'6119' = 1
'612' = 4
'613' = 2
'6141' = 2
'6142' = 4
'6149' = 4
'6191' = 2
'6192' = 4
'6199' = 4
'620' = 4
'6211' = 1
'6212' = 3
'6219' = 3
'622' = 4
'623' = 4
'6241' = 4
'6242' = 4
'625' = 4
'6261' = 4
'6269' = 4
'627' = 4
'6291' = 2
'6292' = 2
'6299' = 4
'6301' = 1
'6309' = 3
'631' = 4
'632' = 4
'633' = 4
'634' = 4
'6351' = 4
'6352' = 2
'6353' = 4
'6359' = 4
'636' = 2
'6370' = 2
'6371' = 2
'6372' = 2
'6373' = 2
'6381' = 4
'6382' = 4
'6383' = 4
'6384' = 2
'6385' = 4
'6389' = 4
'6391' = 2
'6392' = 4
'6393' = 4
'6394' = 4
'6395' = 4
'6399' = 4
'640' = 4
'6411' = 3
'6419' = 1
'642' = 4
'643' = 4
'6441' = 4
'6442' = 4
'6443' = 4
'6444' = 4
'6445' = 4
'6449' = 4
'645' = 4
'6491' = 2
'6492' = 4
'6493' = 4
'6494' = 2
'6495' = 4
'6496' = 4
'6497' = 4
'6498' = 4
'6499' = 4
'650' = 4
'6501' = 4
'6509' = 4
'6511' = 3
'6512' = 3
'6513' = 3
'6514' = 3
'6519' = 3
'6521' = 4
'6522' = 4
'6523' = 4
'6524' = 4
'6525' = 4
'6529' = 4
'653' = 4
'6531' = 4
'6539' = 4
'654' = 4
'6541' = 4
'6549' = 4
'6551' = 4
'6552' = 4
'6553' = 4
'6554' = 4
'6561' = 4
'6562' = 4
'6563' = 4
'6564' = 4
'6571' = 4
'6572' = 4
'6573' = 4
'6574' = 4
'6575' = 4
'6576' = 4
'6579' = 4
'658' = 4
'6581' = 4
'6589' = 4
'6591' = 4
'6592' = 4
'6593' = 4
'6594' = 4
'6595' = 4
'6599' = 4
'660' = 4
'6601' = 4
'6602' = 4
'6611' = 3
'6619' = 3
'6621' = 4
'6622' = 4
'6629' = 4
'6631' = 4
'6632' = 4
'6639' = 4
'664' = 4
'6651' = 4
'6652' = 4
'6661' = 4
'6662' = 4
'6663' = 4
'6669' = 4
'6671' = 4
'6672' = 4
'6673' = 4
'6674' = 4
'6679' = 4
'668' = 2
'6691' = 2
'6692' = 4
'6693' = 4
'6694' = 4
'6695' = 4
'6696' = 4
'6697' = 4
'6699' = 4
'670' = 2
'6711' = 3
'6712' = 3
'6719' = 3
'672' = 4
'6731' = 4
'6732' = 4
'6733' = 4
'6739' = 4
'674' = 4
'675' = 4
'6751' = 4
'6759' = 4
'6761' = 4
'6762' = 4
'6769' = 4
'680' = 4
'6811' = 1
'6812' = 1
'6813' = 3
'6814' = 3
'6815' = 3
'6816' = 3
'6819' = 3
'6821' = 4
'6822' = 4
'6823' = 4
'6824' = 4   /** Added new in V4.4 (Nov 2011)  **/
'6825' = 4   /** Added new in V4.4 (Nov 2011)  **/
'6829' = 4
'683' = 4
'6831' = 4
'6839' = 4
'684' = 4
'6841' = 4
'6849' = 4
'685' = 4
'6851' = 4
'6859' = 4
'686' = 4
'6861' = 4
'6869' = 4
'687' = 4
'6871' = 4
'6879' = 4
'688' = 4
'689' = 4
'6901' = 4
'6902' = 4
'6909' = 3
'6911' = 4
'6919' = 4
'6921' = 4
'6922' = 4
'6923' = 4
'6929' = 4
'693' = 4
'6941' = 4
'6942' = 4
'6949' = 4
'6951' = 4
'6952' = 4
'6959' = 2
'696' = 2
'697' = 2
'6991' = 2
'6992' = 2
'6993' = 2
'6994' = 2
'6995' = 4
'6996' = 2
'6997' = 4
'6998' = 4
'6999' = 4
'700' = 2
'7011' = 2
'7012' = 4
'7013' = 4
'7014' = 4
'7021' = 1
'7022' = 1
'7023' = 3
'7024' = 3
'7029' = 3
'7031' = 4
'7032' = 4
'7033' = 4
'704' = 4
'7050' = 4
'7051' = 4
'7052' = 4
'7061' = 4
'7062' = 4
'7071' = 4
'7072' = 4
'7073' = 4
'7074' = 4
'7075' = 4
'7076' = 4
'7077' = 4
'7079' = 4
'708' = 4
'7091' = 4
'7092' = 4
'7094' = 2 
'7095' = 2 
'7101' = 4
'7109' = 4
'7111' = 3
'7119' = 3
'7121' = 2
'7122' = 4
'7123' = 4
'7124' = 4
'7129' = 4
'713' = 4
'714' = 4
'715' = 4
'7161' = 4
'7162' = 4
'7171' = 4
'7172' = 4
'7179' = 4
'718' = 4
'719' = 4
'720' = 2
'721' = 2
'7221' = 2
'7229' = 2
'7231' = 2
'7239' = 2
'724' = 2
'7251' = 2
'7252' = 2
'7253' = 2
'7254' = 2
'726' = 2
'7271' = 2
'7279' = 2
'728' = 2
'729' = 2
'7301' = 2
'7309' = 2
'731' = 2
'7321' = 2
'7322' = 2
'733' = 2
'734' = 2
'7351' = 2
'7359' = 2
'736' = 2
'738' = 2
'7391' = 2
'7392' = 2
'7393' = 2
'7394' = 4
'7399' = 4
'740' = 4
'741' = 4
'742' = 4
'743' = 4
'744' = 4
'7491' = 4
'7499' = 4
'750' = 2
'751' = 1
'752' = 2
'7531' = 1
'7532' = 1
'7533' = 1
'7534' = 1
'7535' = 1
'7536' = 4
'7537' = 2
'7538' = 1
'754' = 2
'7550' = 4
'7551' = 4
'7552' = 4
'7561' = 4
'7562' = 2
'7569' = 2
'757' = 2
'758' = 2
'7591' = 2
'7592' = 2
'7593' = 4
'7594' = 2
'7599' = 4
'7601' = 4
'7609' = 4
'7611' = 3
'7619' = 3
'762' = 4
'7631' = 4
'7639' = 4
'7641' = 4
'7642' = 4
'7643' = 4
'7644' = 4
'7645' = 4
'7646' = 4
'765' = 4
'7661' = 4
'7662' = 4
'7663' = 4
'7664' = 4
'7665' = 4
'7666' = 4
'7667' = 4
'7668' = 4
'7669' = 4
'7670' = 4
'7671' = 2
'7672' = 4
'7673' = 2
'7674' = 4
'7675' = 2
'7676' = 4
'7677' = 4
'7678' = 2
'7679' = 4
'7691' = 4
'7692' = 4
'7693' = 2
'7694' = 4
'7695' = 2
'7696' = 2
'7697' = 4
'7699' = 4
'7700' = 4
'7701' = 4
'7702' = 4
'7703' = 4
'7704' = 4
'7705' = 4
'7706' = 4
'7707' = 4
'7708' = 4
'7709' = 4
'7710' = 4
'7711' = 4
'7712' = 4
'7713' = 4
'7714' = 4
'7715' = 4
'7716' = 4
'7717' = 4
'7718' = 4
'7719' = 4
'7720' = 4
'7721' = 4
'7722' = 4
'7723' = 4
'7724' = 4
'7725' = 4
'7726' = 4
'7727' = 4
'7728' = 4
'7729' = 4
'7730' = 4
'7731' = 4
'7732' = 4
'7733' = 4
'7734' = 4
'7735' = 4
'7736' = 4
'7737' = 4
'7738' = 4
'7739' = 4
'7740' = 3
'7741' = 3
'7742' = 3
'7743' = 3
'7744' = 3
'7745' = 3
'7746' = 3
'7747' = 3
'7748' = 3
'7749' = 3
'7751' = 4
'7752' = 4
'7753' = 4
'7754' = 4
'7756' = 4
'7757' = 4
'7758' = 4
'7759' = 4
'7760' = 4
'7761' = 4
'7762' = 4
'7763' = 4
'7764' = 4
'7765' = 4
'7766' = 4
'7767' = 4
'7768' = 4
'7769' = 4
'7770' = 4
'7771' = 4
'7772' = 4
'7773' = 4
'7774' = 4
'7775' = 4
'7776' = 4
'7777' = 4
'7778' = 4
'7779' = 4
'7780' = 4
'7781' = 4
'7782' = 4
'7783' = 4
'7784' = 4
'7785' = 4
'7786' = 4
'7787' = 4
'7788' = 4
'7789' = 4
'7790' = 4
'7791' = 4
'7792' = 4
'7793' = 4
'7794' = 4
'7795' = 4
'7796' = 4
'7797' = 4
'7798' = 4
'7799' = 4
'7800' = 4
'7801' = 4
'7802' = 4
'7803' = 4
'7804' = 4
'7805' = 4
'7806' = 4
'7807' = 4
'7808' = 4
'7809' = 4
'7810' = 4
'7811' = 4
'7812' = 4
'7813' = 4
'7814' = 4
'7815' = 4
'7816' = 4
'7817' = 4
'7818' = 4
'7819' = 4
'7820' = 4
'7822' = 4
'7823' = 4
'7824' = 4
'7825' = 4
'7827' = 4
'7828' = 4
'7829' = 4
'7830' = 4
'7831' = 4
'7832' = 4
'7833' = 4
'7834' = 4
'7835' = 4
'7837' = 4
'7838' = 4
'7839' = 4
'7840' = 4
'7841' = 4
'7842' = 4
'7843' = 4
'7844' = 4
'7845' = 4
'7846' = 4
'7847' = 4
'7848' = 4
'7849' = 4
'7850' = 4
'7851' = 4
'7852' = 4
'7853' = 4
'7854' = 4
'7855' = 4
'7856' = 4
'7857' = 4
'7858' = 4
'7859' = 4
'7860' = 4
'7861' = 4
'7862' = 4
'7863' = 4
'7864' = 4
'7865' = 4
'7866' = 4
'7867' = 4
'7868' = 4
'7869' = 4
'7870' = 4
'7871' = 4
'7872' = 4
'7873' = 4
'7874' = 4
'7875' = 4
'7876' = 4
'7877' = 4
'7878' = 4
'7879' = 4
'7880' = 3
'7881' = 3
'7882' = 3
'7883' = 3
'7884' = 3
'7885' = 3
'7886' = 3
'7887' = 3
'7888' = 3
'7889' = 3
'7890' = 4
'7891' = 4
'7892' = 4
'7893' = 4
'7894' = 4
'7895' = 4
'7896' = 4
'7897' = 4
'7898' = 4
'7899' = 4
'7900' = 2
'7901' = 2
'7902' = 2
'7903' = 2
'7904' = 2
'7905' = 2
'7906' = 2
'7907' = 2
'7908' = 2
'7909' = 2
'7910' = 4
'7911' = 4
'7912' = 4
'7913' = 4
'7914' = 4
'7915' = 4
'7916' = 4
'7917' = 4
'7918' = 4
'7919' = 4
'7920' = 4
'7921' = 4
'7922' = 4
'7923' = 4
'7924' = 4
'7925' = 4
'7926' = 4
'7927' = 4
'7928' = 4
'7929' = 4
'7930' = 4
'7931' = 4
'7932' = 4
'7933' = 4
'7934' = 4
'7935' = 4
'7936' = 4
'7937' = 4
'7938' = 4
'7939' = 4
'7940' = 4
'7941' = 4
'7942' = 4
'7945' = 4
'7946' = 4
'7949' = 4
'7950' = 4
'7951' = 4
'7952' = 4
'7955' = 4
'7956' = 4
'7959' = 4
'7960' = 4
'7961' = 4
'7962' = 4
'7963' = 4
'7964' = 4
'7965' = 4
'7966' = 4
'7967' = 4
'7968' = 4
'7969' = 4
'7970' = 2
'7971' = 2
'7972' = 2
'7973' = 2
'7974' = 2
'7975' = 2
'7976' = 2
'7977' = 2
'7978' = 2
'7979' = 2
'7980' = 4
'7981' = 4
'7982' = 4
'7983' = 4
'7984' = 4
'7985' = 4
'7986' = 4
'7987' = 4
'7988' = 4
'7989' = 4
'7990' = 4
'7991' = 4
'7992' = 4
'7993' = 4
'7994' = 4
'7995' = 4
'7996' = 4
'7997' = 4
'7998' = 4
'7999' = 4
'8000' = 4
'8001' = 4
'8002' = 4
'8003' = 4
'8004' = 4
'8005' = 4
'8006' = 4
'8007' = 4
'8008' = 4
'8009' = 4
'8010' = 4
'8011' = 4
'8012' = 4
'8013' = 4
'8014' = 4
'8015' = 4
'8016' = 4
'8017' = 4
'8018' = 4
'8019' = 4
'8020' = 3
'8021' = 3
'8022' = 3
'8023' = 3
'8024' = 3
'8025' = 3
'8026' = 3
'8027' = 3
'8028' = 3
'8029' = 3
'8030' = 1
'8031' = 1
'8032' = 1
'8033' = 1
'8034' = 1
'8035' = 1
'8036' = 1
'8037' = 1
'8038' = 1
'8039' = 1
'8040' = 4
'8041' = 4
'8042' = 4
'8043' = 4
'8044' = 4
'8045' = 4
'8046' = 4
'8047' = 4
'8048' = 4
'8049' = 4
'805' = 4
'8050' = 4
'8051' = 4
'8052' = 2
'8059' = 4
'806' = 4
'8070' = 4
'8071' = 4
'8072' = 4
'8073' = 4
'8074' = 4
'8075' = 4
'8076' = 4
'8077' = 4
'8078' = 4
'8079' = 4
'8080' = 4
'8081' = 4
'8082' = 4
'8083' = 4
'8084' = 4
'8085' = 4
'8086' = 4
'8087' = 4
'8088' = 4
'8089' = 4
'8090' = 4
'8091' = 4
'8092' = 4
'8093' = 4
'8094' = 4
'8095' = 4
'8096' = 4
'8097' = 4
'8098' = 4
'8099' = 4
'8100' = 4
'8101' = 4
'8102' = 4
'8103' = 4
'8104' = 4
'8105' = 4
'8106' = 4
'8107' = 4
'8108' = 4
'8109' = 4
'8111' = 4
'8112' = 4
'8113' = 4
'8114' = 4
'8115' = 4
'8116' = 4
'8117' = 4
'8118' = 4
'8120' = 4
'8121' = 4
'8122' = 4
'8123' = 4
'8124' = 4
'8125' = 4
'8126' = 4
'8127' = 4
'8128' = 4
'8129' = 4
'8130' = 4
'8131' = 4
'8132' = 4
'8133' = 4
'8134' = 4
'8135' = 4
'8136' = 4
'8137' = 4
'8138' = 4
'8139' = 4
'8140' = 4
'8141' = 4
'8142' = 4
'8143' = 4
'8144' = 4
'8145' = 4
'8146' = 4
'8147' = 4
'8148' = 4
'8149' = 4
'8151' = 4
'8152' = 4
'8153' = 4
'8154' = 4
'8155' = 4
'8156' = 4
'8157' = 4
'8159' = 4
'8161' = 4
'8162' = 4
'8163' = 4
'8164' = 4
'8165' = 4
'8166' = 4
'8169' = 4
'8171' = 4
'8172' = 4
'8173' = 4
'8174' = 4
'8175' = 4
'8179' = 4
'8180' = 4
'8181' = 4
'8182' = 4
'8183' = 4
'8184' = 4
'8185' = 4
'8186' = 4
'8187' = 4
'8188' = 4
'8191' = 2
'8192' = 2
'8193' = 4
'8194' = 4
'8195' = 4
'8196' = 4
'8197' = 4
'8198' = 3
'8199' = 4
'8201' = 4
'8202' = 4
'8203' = 4
'8204' = 2
'8209' = 4
'8211' = 4
'8212' = 4
'8219' = 4
'8221' = 4
'8222' = 4
'8229' = 4
'8231' = 4
'8232' = 4
'8233' = 4
'8234' = 4
'8235' = 4
'8236' = 4
'8239' = 4
'8241' = 4
'8242' = 4
'8243' = 4
'8244' = 4
'8245' = 4
'8246' = 4
'8251' = 4
'8252' = 4
'8253' = 4
'8254' = 4
'8255' = 4
'8256' = 4
'8257' = 4
'8258' = 4
'8259' = 4
'8261' = 4
'8269' = 4
'8271' = 4
'8272' = 4
'8279' = 4
'8281' = 4
'8282' = 4
'8283' = 4
'8284' = 4
'8285' = 4
'8286' = 4
'8289' = 4
'8291' = 4
'8292' = 2
'8293' = 2
'8294' = 2
'8295' = 2
'8296' = 2
'8299' = 4
'8301' = 4
'8302' = 4
'8303' = 4
'8309' = 4
'8311' = 4
'8312' = 4
'8313' = 4
'8314' = 4
'8319' = 4
'8321' = 3
'8329' = 3
'8331' = 4
'8332' = 4
'8339' = 4
'8341' = 4
'8342' = 4
'8343' = 4
'8344' = 4
'8345' = 4
'8349' = 4
'835' = 4
'8361' = 4
'8362' = 4
'8363' = 4
'8364' = 4
'8365' = 4
'8371' = 4
'8372' = 4
'8373' = 4
'8374' = 4
'8375' = 4
'8376' = 4
'8377' = 4
'8379' = 4
'8381' = 4
'8382' = 4
'8383' = 4
'8384' = 4
'8385' = 4
'8386' = 4
'8387' = 4
'8388' = 4
'8389' = 4
'8391' = 4
'8392' = 4
'8393' = 4
'8394' = 2
'8395' = 2
'8396' = 2
'8397' = 2
'8398' = 2
'8399' = 4
'8400' = 4
'8401' = 4
'8402' = 4
'8403' = 4
'8404' = 4
'8405' = 4
'8406' = 4
'8407' = 4
'8408' = 4
'8409' = 4
'8410' = 4
'8411' = 4
'8412' = 4
'8413' = 4
'8414' = 4
'8415' = 4
'8416' = 4
'8417' = 4
'8418' = 4
'8419' = 4
'8421' = 4
'8422' = 4
'8423' = 4
'8424' = 4
'8425' = 4
'8426' = 4
'8427' = 4
'8428' = 4
'8429' = 4
'843' = 4
'8440' = 4
'8441' = 2
'8442' = 2
'8443' = 2
'8444' = 4
'8445' = 2
'8446' = 2
'8447' = 2
'8448' = 4
'8451' = 2
'8452' = 2
'8453' = 2
'8454' = 2
'8455' = 2
'8456' = 2
'8457' = 2
'8458' = 4
'8459' = 4
'8460' = 4
'8461' = 4
'8462' = 4
'8463' = 4
'8464' = 4
'8465' = 4
'8466' = 4
'8467' = 4
'8468' = 4
'8469' = 4
'8471' = 2
'8472' = 2 
'8473' = 2 
'8491' = 4
'8492' = 4
'8493' = 4
'8494' = 4
'8499' = 4
'850' = 2
'8511' = 1
'8512' = 3
'8519' = 1
'8520' = 4
'8521' = 4
'8522' = 4
'8523' = 4
'8524' = 4
'8525' = 4
'8531' = 4
'8532' = 4
'8533' = 4
'8534' = 4
'8535' = 4
'8536' = 4
'8541' = 4
'8542' = 4
'8543' = 4
'8544' = 4
'8545' = 4
'8546' = 4
'8547' = 4
'8548' = 4
'8550' = 4
'8551' = 2
'8552' = 2
'8553' = 4
'8554' = 4
'8555' = 4
'856'  = 4
'857'  = 4
'8570' = 4
'8581' = 2
'8582' = 4
'8583' = 4
'8584' = 4
'8585' = 4
'8586' = 4
'8587' = 4
'8589' = 4
'8591' = 2
'8592' = 2
'8593' = 4
'8594' = 4
'8595' = 4
'8596' = 4
'8599' = 4
'8601' = 2
'8602' = 2
'8603' = 2
'8604' = 2
'8605' = 2
'8606' = 4
'8607' = 2
'8609' = 2
'8611' = 1
'8619' = 1
'8621' = 4
'8622' = 4
'8623' = 2
'8624' = 2
'8625' = 4
'8626' = 2
'8627' = 2
'8628' = 2
'863' = 2
'864' = 4
'8651' = 2
'8659' = 2
'8660' = 4
'8661' = 4
'8662' = 4
'8663' = 4
'8664' = 2
'8665' = 4
'8666' = 4
'8667' = 4
'8669' = 4
'8670' = 4
'8671' = 4
'8672' = 4
'8673' = 4
'8674' = 4
'8675' = 4
'8681' = 4
'8682' = 4
'8683' = 4
'8684' = 4
'8685' = 4
'8686' = 4
'8687' = 4
'8689' = 4
'8690' = 4
'8691' = 4
'8692' = 2
'8693' = 4
'8694' = 4
'8695' = 4
'8696' = 4
'8697' = 4
'8698' = 4
'8699' = 2
'8701' = 1
'8702' = 1
'8703' = 1
'8704' = 1
'8705' = 1
'8706' = 1
'8707' = 1
'8708' = 1
'8709' = 1
'8711' = 1
'8712' = 1
'8713' = 1
'8714' = 1
'8715' = 1
'8716' = 1
'8717' = 1
'8721' = 1
'8722' = 1
'8723' = 1
'8724' = 1
'8729' = 1
'8731' = 1
'8732' = 1
'8733' = 1
'8734' = 1
'8735' = 1
'8736' = 1
'8737' = 1
'8738' = 1
'8739' = 1
'8741' = 1
'8742' = 1
'8743' = 1
'8744' = 1
'8749' = 1
'8751' = 1
'8752' = 1
'8753' = 3
'8754' = 1
'8759' = 1
'8761' = 1
'8762' = 1
'8763' = 1
'8764' = 1
'8765' = 1
'8766' = 1
'8769' = 1
'8771' = 1
'8772' = 1
'8773' = 1
'8774' = 1
'8775' = 1
'8776' = 1
'8777' = 1
'8778' = 1
'8779' = 1
'8781' = 1
'8782' = 1
'8783' = 1
'8784' = 1
'8785' = 1
'8789' = 1
'8791' = 1
'8792' = 1
'8793' = 1
'8794' = 1
'8795' = 1
'8799' = 1
'8801' = 1
'8802' = 1
'8803' = 1
'8804' = 1
'8809' = 1
'8811' = 1
'8812' = 1
'8813' = 1
'8814' = 1
'8815' = 1
'8816' = 1
'8819' = 1
'8821' = 1
'8822' = 1
'8823' = 1
'8824' = 1
'8825' = 1
'8826' = 1
'8827' = 1
'8828' = 1
'8829' = 1
'8831' = 1
'8832' = 1
'8833' = 1
'8834' = 1
'8835' = 1
'8836' = 1
'8837' = 1
'8838' = 1
'8839' = 1
'8840' = 1
'8841' = 1
'8842' = 1
'8843' = 1
'8844' = 1
'8845' = 1
'8846' = 1
'8847' = 1
'8848' = 1
'8849' = 1
'8850' = 1
'8851' = 1
'8852' = 1
'8853' = 1
'8854' = 1
'8855' = 1
'8856' = 1
'8857' = 1
'8858' = 1
'8860' = 1
'8861' = 1
'8862' = 1
'8863' = 1
'8864' = 1
'8865' = 1
'8866' = 1
'8867' = 1
'8868' = 1
'8871' = 1
'8872' = 1
'8873' = 1
'8874' = 1
'8875' = 1
'8876' = 1
'8877' = 1
'8878' = 1
'8879' = 1
'8881' = 1
'8882' = 1
'8883' = 1
'8884' = 1
'8885' = 1
'8886' = 1
'8889' = 1
'8890' = 1
'8891' = 1
'8892' = 1
'8893' = 1
'8894' = 1
'8895' = 1
'8896' = 1
'8897' = 1
'8898' = 1
'8899' = 1
'8901' = 1
'8902' = 1
'8903' = 1
'8904' = 1
'8905' = 1
'8906' = 1
'8907' = 1
'8908' = 1
'8909' = 1
'8910' = 1
'8911' = 1
'8912' = 1
'8913' = 1
'8914' = 1
'8915' = 1
'8916' = 1
'8917' = 1
'8918' = 1
'8919' = 1
'8921' = 1
'8922' = 1
'8923' = 1
'8924' = 1
'8925' = 1
'8926' = 1
'8929' = 1
'8931' = 1
'8932' = 1
'8933' = 1
'8934' = 1
'8935' = 1
'8936' = 1
'8937' = 1
'8938' = 1
'8939' = 1
'8941' = 1
'8942' = 1
'8943' = 1
'8944' = 1
'8945' = 1
'8946' = 1
'8947' = 1
'8948' = 1
'8949' = 1
'8950' = 1
'8951' = 1
'8952' = 1
'8953' = 1
'8954' = 1
'8955' = 1
'8956' = 1
'8957' = 1
'8958' = 1
'8959' = 1
'8960' = 1
'8961' = 1
'8962' = 1
'8963' = 1
'8964' = 1
'8965' = 1
'8966' = 1
'8967' = 1
'8968' = 1
'8969' = 1
'897' = 1
'898' = 1
'9001' = 1
'9002' = 1
'9003' = 1
'9004' = 1
'9005' = 1
'9006' = 1
'9009' = 1
'9011' = 1
'9012' = 1
'9013' = 1
'9014' = 1
'9015' = 1
'9016' = 1
'9019' = 1
'9021' = 1
'9022' = 1
'9023' = 1
'9024' = 1
'9025' = 1
'9026' = 1
'9029' = 1
'9031' = 1
'9032' = 1
'9033' = 1
'9034' = 1
'9035' = 1
'9036' = 1
'9039' = 1
'9041' = 1
'9042' = 1
'9043' = 1
'9044' = 1
'9045' = 1
'9046' = 1
'9049' = 1
'9051' = 1
'9052' = 1
'9053' = 1
'9054' = 1
'9055' = 1
'9056' = 1
'9059' = 1
'9061' = 1
'9062' = 1
'9063' = 1
'9064' = 1
'9065' = 1
'9066' = 1
'9069' = 1
'9071' = 1
'9072' = 1
'9073' = 1
'9074' = 1
'9075' = 1
'9076' = 1
'9079' = 1
'9081' = 1
'9082' = 1
'9083' = 1
'9084' = 1
'9085' = 1
'9086' = 1
'9089' = 1
'9091' = 1
'9092' = 1
'9093' = 1
'9094' = 1
'9095' = 1
'9096' = 1
'9099' = 1
'9101' = 1
'9102' = 1
'9103' = 1
'9104' = 1
'9105' = 1
'9106' = 1
'9109' = 1
'9111' = 1
'9112' = 1
'9113' = 1
'9114' = 1
'9115' = 1
'9116' = 1
'9119' = 1
'9121' = 1
'9122' = 1
'9123' = 1
'9124' = 1
'9125' = 1
'9126' = 1
'9129' = 1
'9131' = 1
'9132' = 1
'9133' = 1
'9134' = 1
'9135' = 1
'9136' = 1
'9139' = 1
'9141' = 1
'9142' = 1
'9143' = 1
'9144' = 1
'9145' = 1
'9146' = 1
'9149' = 1
'9151' = 1
'9152' = 1
'9153' = 1
'9154' = 1
'9155' = 1
'9156' = 1
'9159' = 1
'9161' = 1
'9162' = 1
'9163' = 1
'9164' = 1
'9165' = 1
'9166' = 1
'9169' = 1
'9171' = 1
'9172' = 1
'9173' = 1
'9174' = 1
'9175' = 1
'9176' = 1
'9179' = 1
'9181' = 1
'9182' = 1
'9183' = 1
'9184' = 1
'9185' = 1
'9186' = 1
'9189' = 1
'9191' = 1
'9192' = 1
'9193' = 1
'9194' = 1
'9195' = 1
'9196' = 1
'9199' = 1
'9201' = 1
'9202' = 1
'9203' = 1
'9204' = 1
'9205' = 1
'9209' = 1
'9211' = 1
'9212' = 1
'9213' = 1
'9214' = 1
'9215' = 1
'9216' = 1
'9217' = 1
'9218' = 1
'9219' = 1
'9220' = 2
'9221' = 2
'9222' = 2
'9223' = 2
'9224' = 2
'9225' = 2
'9226' = 2
'9227' = 4 
'9228' = 2
'9229' = 2
'923' = 2
'9230' = 2
'9231' = 2
'9232' = 2
'9233' = 2
'9239' = 2
'9301' = 1
'9302' = 1
'9303' = 1
'9304' = 1
'9305' = 1
'9306' = 1
'9307' = 1
'9308' = 1
'9309' = 1
'9311' = 2
'9312' = 2
'9313' = 2
'9314' = 2
'9315' = 2
'9316' = 2
'9317' = 2
'9318' = 2
'9319' = 2
'9321' = 2
'9322' = 2
'9323' = 2
'9324' = 2
'9325' = 2
'9326' = 2
'9327' = 2
'9328' = 2
'9329' = 2
'9331' = 2
'9332' = 2
'9333' = 2
'9334' = 2
'9335' = 2
'9336' = 2
'9337' = 2
'9338' = 2
'9339' = 2
'9341' = 2
'9342' = 2
'9343' = 2
'9344' = 2
'9345' = 2
'9346' = 2
'9351' = 2
'9352' = 2
'9353' = 2
'9354' = 2
'9355' = 2
'9356' = 2
'9357' = 2
'9358' = 2
'9359' = 2
'9361' = 2
'9362' = 2
'9363' = 2
'9364' = 2
'9365' = 2
'9366' = 2
'9367' = 2
'9371' = 2
'9372' = 2
'9373' = 2
'9374' = 2
'9375' = 2
'9376' = 2
'9377' = 2
'9378' = 2
'9381' = 2
'9382' = 2
'9383' = 2
'9384' = 2
'9385' = 2
'9389' = 2
'9390' = 2
'9391' = 2
'9392' = 2
'9393' = 2
'9394' = 2
'9395' = 2
'9396' = 2
'9397' = 2
'9398' = 2
'9399' = 2
'9401' = 1
'9402' = 1
'9403' = 1
'9408' = 1
'9409' = 1
'9411' = 1
'9412' = 1
'9413' = 1
'9419' = 1
'9421' = 2
'9422' = 2
'9423' = 2
'9424' = 2
'9425' = 2
'9426' = 2
'9427' = 2
'9429' = 2
'9431' = 2
'9432' = 2
'9433' = 2
'9434' = 2
'9435' = 2
'9436' = 2
'9437' = 2
'9438' = 2
'9439' = 2
'9441' = 2
'9442' = 2
'9443' = 2
'9444' = 2
'9445' = 2
'9446' = 2
'9449' = 2
'9451' = 2
'9452' = 2
'9453' = 2
'9454' = 2
'9455' = 2
'9459' = 2
'9461' = 2
'9462' = 2
'9463' = 2
'9464' = 2
'9465' = 2
'9466' = 2
'9467' = 2
'9468' = 2
'9469' = 2
'9501' = 1
'9502' = 1
'9503' = 1
'9504' = 3
'9505' = 1
'9506' = 1
'9507' = 1
'9509' = 1
'9511' = 1
'9512' = 1
'9513' = 1
'9514' = 1
'9515' = 1
'9516' = 1
'9521' = 1
'9522' = 1
'9523' = 1
'9524' = 1
'9525' = 1
'9526' = 1
'9531' = 2
'9532' = 2
'9533' = 2
'9534' = 2
'9535' = 2
'9536' = 2
'9541' = 1
'9542' = 1
'9543' = 1
'9544' = 1
'9545' = 1
'9546' = 1
'9547' = 1
'9548' = 2
'9549' = 2
'9601' = 2
'9602' = 2
'9603' = 2
'9604' = 2
'9605' = 2
'9606' = 2
'9607' = 2
'9608' = 2
'9609' = 2
'9611' = 2
'9614' = 2
'9615' = 2
'9616' = 2
'9617' = 2
'9618' = 2
'9619' = 2
'9621' = 2
'9622' = 2
'9623' = 2
'9624' = 2
'9625' = 2
'9626' = 2
'9627' = 2
'9628' = 2
'9629' = 2
'9631' = 2
'9632' = 2
'9633' = 2
'9634' = 2
'9635' = 2
'9636' = 2
'9637' = 2
'9638' = 2
'9639' = 2
'9641' = 2
'9642' = 2
'9643' = 2
'9644' = 2
'9645' = 2
'9646' = 2
'9647' = 2
'9648' = 2
'9649' = 2
'9651' = 2
'9652' = 2
'9653' = 2
'9654' = 2
'9655' = 2
'9656' = 2
'9657' = 2
'9658' = 2
'9659' = 2
'966' = 2
'9670' = 2
'9671' = 2
'9672' = 2
'9701' = 2
'9702' = 2
'9703' = 2
'9704' = 2
'9705' = 2
'9711' = 2
'9712' = 2
'9713' = 2
'9714' = 2
'9715' = 2
'9716' = 2
'9721' = 2
'9722' = 2
'9723' = 2
'9724' = 2
'9725' = 2
'9726' = 2
'9729' = 2
'9731' = 2
'9732' = 2
'9733' = 2
'9734' = 2
'9735' = 2
'9736' = 2
'9737' = 2
'9738' = 2
'9739' = 2
'9741' = 2
'9742' = 2
'9743' = 2
'9744' = 2
'9749' = 2
'9751' = 2
'9752' = 2
'9753' = 2
'9754' = 2
'9755' = 2
'9756' = 2
'9759' = 2
'9761' = 2
'9762' = 2
'9763' = 2
'9764' = 2
'9765' = 2
'9769' = 2
'9771' = 2
'9772' = 2
'9773' = 2
'9774' = 2
'9775' = 2
'9779' = 2
'9781' = 2
'9782' = 2
'9783' = 2
'9784' = 2
'9785' = 2
'9786' = 2
'9787' = 2
'9788' = 2
'9789' = 2
'9801' = 2
'9802' = 2
'9803' = 2
'9804' = 2
'9805' = 2
'9811' = 2
'9812' = 2
'9813' = 2
'9814' = 2
'9815' = 2
'9816' = 2
'9817' = 2
'9818' = 2
'9819' = 2
'9820' = 2
'9821' = 2
'9822' = 2
'9823' = 2
'9824' = 2
'9825' = 2
'9826' = 2
'9827' = 2
'9828' = 2
'9829' = 2
'9851' = 2
'9852' = 2
'9859' = 2
'9900' = 2
'9901' = 2
'9902' = 2
'9903' = 2
'9904' = 2
'9905' = 2
'9906' = 2
'9907' = 2
'9908' = 2
'9909' = 2
'9910' = 2
'9911' = 2
'9912' = 2
'9913' = 2
'9914' = 2
'9915' = 2
'9916' = 2
'9917' = 2
'9918' = 2
'9919' = 2
'9920' = 2
'9921' = 2
'9922' = 2
'9923' = 2
'9924' = 2
'9925' = 2
'9926' = 2
'9927' = 2
'9928' = 2
'9929' = 2
'9931' = 2
'9932' = 2
'9933' = 2
'9934' = 2
'9935' = 2
'9936' = 2
'9937' = 2
'9938' = 2
'9939' = 2
'9941' = 2
'9942' = 2
'9943' = 2
'9944' = 2
'9945' = 2
'9946' = 2
'9947' = 2
'9948' = 2
'9951' = 2
'9952' = 2
'9953' = 2
'9954' = 2
'9955' = 2
'9956' = 2
'9957' = 2
'9958' = 2
'9959' = 2
'9960' = 2
'9961' = 2
'9962' = 2
'9963' = 2
'9964' = 2
'9969' = 2
'9971' = 2
'9972' = 2
'9973' = 2
'9974' = 2
'9975' = 2
'9976' = 2
'9977' = 2
'9978' = 2
'9979' = 2
'9981' = 2
'9982' = 2
'9983' = 2
'9984' = 2
'9985' = 2
'9986' = 2
'9988' = 2
'9991' = 2
'9992' = 2
'9993' = 2
'9994' = 2
'9995' = 2
'9996' = 2
'9997' = 2
'9998' = 2
'9999' = 2
OTHER  = 0;

 /* -------------------------------------------------------------- */
 /* ---   FORMAT FOR AGE STRATIFIERS                           --- */
 /* ---   MODULE 3. ASSIGNS ARRAY INDEX FOR AGE CATEGORIES     --- */
 /* -------------------------------------------------------------- */

VALUE AGEFMT
low - 4 = 1
 5 -  9 = 2
10 - 14 = 3
15 - 17 = 4
18 - 24 = 5
25 - 29 = 6
30 - 34 = 7
35 - 39 = 8
40 - 44 = 9
45 - 49 = 10
50 - 54 = 11
55 - 59 = 12
60 - 64 = 13
65 - 69 = 14
70 - 74 = 15
75 - 79 = 16
80 - 84 = 17
85 - high = 18;


VALUE $CCS
'0700 ' = 6 /* HEPATITIS A WITH COMA */
'0701 ' = 6 /* HEPATITIS A W/O COMA */
'0702 ' = 6 /* HEPATITIS B WITH COMA  J80  S91 */
'07020' = 6 /* VRL HEPAT B CM W/O DELTA OCT91 */
'07021' = 6 /* VRL HEPAT B CM W DELTA OCT91 */
'07022' = 6 /* CHR HEPAT COMA W/O DELTA OCT94 */
'07023' = 6 /* CHR HEPAT COMA W/ DELTA  OCT94 */
'0703 ' = 6 /* HEPATITIS B W/O COMA   J80  S91 */
'07030' = 6 /* VRL HPT B W/O CM W/O DLT OCT91 */
'07031' = 6 /* VRL HPT B W/O CM W DELTA OCT91 */
'07032' = 6 /* CHR HEPAT W/O COMA W/O DELTA OCT94 */
'07033' = 6 /* CHR HEPAT W/O COMA W/ DELTA  OCT94 */
'0704 ' = 6 /* VIRAL HEPAT NEC W COMA J80  S91 */
'07041' = 6 /* SPF VRL HPT CM HPT C   OCT91 */
'07042' = 6 /* SPF VRL HPT CM DLT W/O B OCT91 */
'07043' = 6 /* SPF VRL HPT CM HPT E   OCT91 */
'07044' = 6 /* CHR HEPAT C W/ COMA OCT94 */
'07049' = 6 /* SPF VRL HPT CM     OCT91 */
'0705 ' = 6 /* VIRAL HEPAT NEC W/O COMA  J80  S91 */
'07051' = 6 /* VRL HPT W/O CM HEPAT C OCT91 */
'07052' = 6 /* VRL HPT W/O CM DLT W/O B OCT91 */
'07053' = 6 /* VRL HPT W/O CM HEPAT E OCT91 */
'07054' = 6 /* CHR HEPAT C W/O COMA OCT94 */
'07059' = 6 /* VRL HPT W/O CM     OCT91 */
'0706 ' = 6 /* VIRAL HEPAT NOS W COMA */
'07070' = 6 /* HPT C W/O HEPAT COMA NOS */
'07071' = 6 /* HPT C W HEPATIC COMA NOS */
'0709 ' = 6 /* VIRAL HEPAT NOS W/O COMA */
'1100 ' = 4 /* DERMATOPHYT SCALP/BEARD */
'1101 ' = 4 /* DERMATOPHYTOSIS OF NAIL */
'1102 ' = 4 /* DERMATOPHYTOSIS OF HAND */
'1103 ' = 4 /* DERMATOPHYTOSIS OF GROIN */
'1104 ' = 4 /* DERMATOPHYTOSIS OF FOOT */
'1105 ' = 4 /* DERMATOPHYTOSIS OF BODY */
'1106 ' = 4 /* DEEP DERMATOPHYTOSIS */
'1108 ' = 4 /* DERMATOPHYTOSIS SITE NEC */
'1109 ' = 4 /* DERMATOPHYTOSIS SITE NOS */
'1110 ' = 4 /* PITYRIASIS VERSICOLOR */
'1111 ' = 4 /* TINEA NIGRA */
'1112 ' = 4 /* TINEA BLANCA */
'1113 ' = 4 /* BLACK PIEDRA */
'1118 ' = 4 /* DERMATOMYCOSES NEC */
'1119 ' = 4 /* DERMATOMYCOSIS NOS */
'1120 ' = 4 /* THRUSH */
'1121 ' = 4 /* CANDIDAL VULVOVAGINITIS */
'1122 ' = 4 /* CANDIDIAS UROGENITAL NEC */
'1123 ' = 4 /* CUTANEOUS CANDIDIASIS */
'1125 ' = 4 /* DISSEMINATED CANDIDIASIS */
'11282' = 4 /* CANDIDAL OTITIS EXTERNA */
'11284' = 4 /* CANDIDAL ESOPHAGITIS   OCT92 */
'11285' = 4 /* CANDIDAL ENTERITIS   OCT92 */
'11289' = 4 /* CANDIDIASIS SITE NEC */
'1129 ' = 4 /* CANDIDIASIS SITE NOS */
'1141 ' = 4 /* PRIM CUTAN COCCIDIOID */
'1143 ' = 4 /* PROGRESS COCCIDIOID NEC */
'1149 ' = 4 /* COCCIDIOIDOMYCOSIS NOS */
'11500' = 4 /* HISTOPLASMA CAPSULAT NOS */
'11509' = 4 /* HISTOPLASMA CAPSULAT NEC */
'11510' = 4 /* HISTOPLASMA DUBOISII NOS */
'11519' = 4 /* HISTOPLASMA DUBOISII NEC */
'11590' = 4 /* HISTOPLASMOSIS NOS */
'11599' = 4 /* HISTOPLASMOSIS NEC */
'1160 ' = 4 /* BLASTOMYCOSIS */
'1161 ' = 4 /* PARACOCCIDIOIDOMYCOSIS */
'1162 ' = 4 /* LOBOMYCOSIS */
'1170 ' = 4 /* RHINOSPORIDIOSIS */
'1171 ' = 4 /* SPOROTRICHOSIS */
'1172 ' = 4 /* CHROMOBLASTOMYCOSIS */
'1173 ' = 4 /* ASPERGILLOSIS */
'1174 ' = 4 /* MYCOTIC MYCETOMAS */
'1175 ' = 4 /* CRYPTOCOCCOSIS */
'1176 ' = 4 /* ALLESCHERIOSIS */
'1177 ' = 4 /* ZYGOMYCOSIS */
'1178 ' = 4 /* DEMATIACIOUS FUNGI INF */
'1179 ' = 4 /* MYCOSES NEC & NOS */
'118  ' = 4 /* OPPORTUNISTIC MYCOSES */
'1640 ' = 41 /* MALIGNANT NEOPL THYMUS */
'1641 ' = 41 /* MALIGNANT NEOPL HEART */
'1642 ' = 41 /* MAL NEO ANT MEDIASTINUM */
'1643 ' = 41 /* MAL NEO POST MEDIASTINUM */
'1648 ' = 41 /* MAL NEO MEDIASTINUM NEC */
'1649 ' = 41 /* MAL NEO MEDIASTINUM NOS */
'1700 ' = 21 /* MAL NEO SKULL/FACE BONE */
'1701 ' = 21 /* MALIGNANT NEO MANDIBLE */
'1702 ' = 21 /* MALIG NEO VERTEBRAE */
'1703 ' = 21 /* MAL NEO RIBS/STERN/CLAV */
'1704 ' = 21 /* MAL NEO LONG BONES ARM */
'1705 ' = 21 /* MAL NEO BONES WRIST/HAND */
'1706 ' = 21 /* MAL NEO PELVIC GIRDLE */
'1707 ' = 21 /* MAL NEO LONG BONES LEG */
'1708 ' = 21 /* MAL NEO BONES ANKLE/FOOT */
'1709 ' = 21 /* MALIG NEOPL BONE NOS */
'1710 ' = 21 /* MAL NEO SOFT TISSUE HEAD */
'1712 ' = 21 /* MAL NEO SOFT TISSUE ARM */
'1713 ' = 21 /* MAL NEO SOFT TISSUE LEG */
'1714 ' = 21 /* MAL NEO SOFT TIS THORAX */
'1715 ' = 21 /* MAL NEO SOFT TIS ABDOMEN */
'1716 ' = 21 /* MAL NEO SOFT TIS PELVIS */
'1717 ' = 21 /* MAL NEOPL TRUNK NOS */
'1718 ' = 21 /* MAL NEO SOFT TISSUE NEC */
'1719 ' = 21 /* MAL NEO SOFT TISSUE NOS */
'1760 ' = 41 /* SKIN - KAPOSI-s SARCOMA  OCT91 */
'1761 ' = 41 /* SFT TISUE - KPSI-s SRCMA OCT91 */
'1762 ' = 41 /* PALATE - KPSI-s SARCOMA  OCT91 */
'1763 ' = 41 /* GI SITES - KPSI-s SRCOMA OCT91 */
'1764 ' = 41 /* LUNG - KAPOSI-s SARCOMA  OCT91 */
'1765 ' = 41 /* LYM NDS - KPSI-s SARCOMA OCT91 */
'1768 ' = 41 /* SPF STS - KPSI-s SARCOMA OCT91 */
'1769 ' = 41 /* KAPOSI-s SARCOMA NOS   OCT91 */
'1890 ' = 33 /* MALIG NEOPL KIDNEY */
'1891 ' = 33 /* MALIG NEO RENAL PELVIS */
'1900 ' = 41 /* MALIGN NEOPL EYEBALL */
'1901 ' = 41 /* MALIGN NEOPL ORBIT */
'1902 ' = 41 /* MAL NEO LACRIMAL GLAND */
'1903 ' = 41 /* MAL NEO CONJUNCTIVA */
'1904 ' = 41 /* MALIGN NEOPL CORNEA */
'1905 ' = 41 /* MALIGN NEOPL RETINA */
'1906 ' = 41 /* MALIGN NEOPL CHOROID */
'1907 ' = 41 /* MAL NEO LACRIMAL DUCT */
'1908 ' = 41 /* MALIGN NEOPL EYE NEC */
'1909 ' = 41 /* MALIGN NEOPL EYE NOS */
'1910 ' = 35 /* MALIGN NEOPL CEREBRUM */
'1911 ' = 35 /* MALIG NEO FRONTAL LOBE */
'1912 ' = 35 /* MAL NEO TEMPORAL LOBE */
'1913 ' = 35 /* MAL NEO PARIETAL LOBE */
'1914 ' = 35 /* MAL NEO OCCIPITAL LOBE */
'1915 ' = 35 /* MAL NEO CEREB VENTRICLE */
'1916 ' = 35 /* MAL NEO CEREBELLUM NOS */
'1917 ' = 35 /* MAL NEO BRAIN STEM */
'1918 ' = 35 /* MALIG NEO BRAIN NEC */
'1919 ' = 35 /* MALIG NEO BRAIN NOS */
'1920 ' = 35 /* MAL NEO CRANIAL NERVES */
'1921 ' = 35 /* MAL NEO CEREBRAL MENING */
'1922 ' = 35 /* MAL NEO SPINAL CORD */
'1923 ' = 35 /* MAL NEO SPINAL MENINGES */
'1928 ' = 35 /* MAL NEO NERVOUS SYST NEC */
'1929 ' = 35 /* MAL NEO NERVOUS SYST NOS */
'1940 ' = 41 /* MALIGN NEOPL ADRENAL */
'1941 ' = 41 /* MALIG NEO PARATHYROID */
'1943 ' = 41 /* MALIG NEO PITUITARY */
'1944 ' = 41 /* MALIGN NEO PINEAL GLAND */
'1945 ' = 41 /* MAL NEO CAROTID BODY */
'1946 ' = 41 /* MAL NEO PARAGANGLIA NEC */
'1948 ' = 41 /* MAL NEO ENDOCRINE NEC */
'1949 ' = 41 /* MAL NEO ENDOCRINE NOS */
'1951 ' = 41 /* MALIGN NEOPL THORAX */
'1952 ' = 41 /* MALIG NEO ABDOMEN */
'1953 ' = 41 /* MALIGN NEOPL PELVIS */
'1954 ' = 41 /* MALIGN NEOPL ARM */
'1955 ' = 41 /* MALIGN NEOPL LEG */
'1958 ' = 41 /* MALIG NEO SITE NEC */
'1960 ' = 42 /* MAL NEO LYMPH-HEAD/NECK */
'1961 ' = 42 /* MAL NEO LYMPH-INTRATHOR */
'1962 ' = 42 /* MAL NEO LYMPH INTRA-ABD */
'1963 ' = 42 /* MAL NEO LYMPH-AXILLA/ARM */
'1965 ' = 42 /* MAL NEO LYMPH-INGUIN/LEG */
'1966 ' = 42 /* MAL NEO LYMPH-INTRAPELV */
'1968 ' = 42 /* MAL NEO LYMPH NODE-MULT */
'1969 ' = 42 /* MAL NEO LYMPH NODE NOS */
'1970 ' = 42 /* SECONDARY MALIG NEO LUNG */
'1971 ' = 42 /* SEC MAL NEO MEDIASTINUM */
'1972 ' = 42 /* SECOND MALIG NEO PLEURA */
'1973 ' = 42 /* SEC MALIG NEO RESP NEC */
'1974 ' = 42 /* SEC MALIG NEO SM BOWEL */
'1975 ' = 42 /* SEC MALIG NEO LG BOWEL */
'1976 ' = 42 /* SEC MAL NEO PERITONEUM */
'1977 ' = 42 /* SECOND MALIG NEO LIVER */
'1978 ' = 42 /* SEC MAL NEO GI NEC */
'1980 ' = 42 /* SECOND MALIG NEO KIDNEY */
'1981 ' = 42 /* SEC MALIG NEO URIN NEC */
'1982 ' = 42 /* SECONDARY MALIG NEO SKIN */
'1983 ' = 42 /* SEC MAL NEO BRAIN/SPINE */
'1984 ' = 42 /* SEC MALIG NEO NERVE NEC */
'1985 ' = 42 /* SECONDARY MALIG NEO BONE */
'1986 ' = 42 /* SECOND MALIG NEO OVARY */
'1987 ' = 42 /* SECOND MALIG NEO ADRENAL */
'19881' = 42 /* SECOND MALIG NEO BREAST */
'19882' = 42 /* SECOND MALIG NEO GENITAL */
'19889' = 42 /* SECONDARY MALIG NEO NEC */
'20000' = 38 /* RETICULOSARCOMA UNSPEC */
'20001' = 38 /* RETICULOSARCOMA HEAD */
'20002' = 38 /* RETICULOSARCOMA THORAX */
'20003' = 38 /* RETICULOSARCOMA ABDOM */
'20004' = 38 /* RETICULOSARCOMA AXILLA */
'20005' = 38 /* RETICULOSARCOMA INGUIN */
'20006' = 38 /* RETICULOSARCOMA PELVIC */
'20007' = 38 /* RETICULOSARCOMA SPLEEN */
'20008' = 38 /* RETICULOSARCOMA MULT */
'20010' = 38 /* LYMPHOSARCOMA UNSPEC */
'20011' = 38 /* LYMPHOSARCOMA HEAD */
'20012' = 38 /* LYMPHOSARCOMA THORAX */
'20013' = 38 /* LYMPHOSARCOMA ABDOM */
'20014' = 38 /* LYMPHOSARCOMA AXILLA */
'20015' = 38 /* LYMPHOSARCOMA INGUIN */
'20016' = 38 /* LYMPHOSARCOMA PELVIC */
'20017' = 38 /* LYMPHOSARCOMA SPLEEN */
'20018' = 38 /* LYMPHOSARCOMA MULT */
'20020' = 38 /* BURKITT-s TUMOR UNSPEC */
'20021' = 38 /* BURKITT-s TUMOR HEAD */
'20022' = 38 /* BURKITT-s TUMOR THORAX */
'20023' = 38 /* BURKITT-s TUMOR ABDOM */
'20024' = 38 /* BURKITT-s TUMOR AXILLA */
'20025' = 38 /* BURKITT-s TUMOR INGUIN */
'20026' = 38 /* BURKITT-s TUMOR PELVIC */
'20027' = 38 /* BURKITT-s TUMOR SPLEEN */
'20028' = 38 /* BURKITT-s TUMOR MULT */
'20030' = 38 /* 	MARGNL ZONE LYM XTRNDL */
'20031' = 38 /* 	MARGIN ZONE LYM HEAD */
'20032' = 38 /* 	MARGIN ZONE LYM THORAX */
'20033' = 38 /* 	MARGIN ZONE LYM ABDOM */
'20034' = 38 /* 	MARGIN ZONE LYM AXILLA */
'20035' = 38 /* 	MARGIN ZONE LYM INGUIN */
'20036' = 38 /* 	MARGIN ZONE LYM PELVIC */
'20037' = 38 /* 	MARGIN ZONE LYMPH SPLEEN */
'20038' = 38 /* 	MARGIN ZONE LYMPH MULTIP */
'20040' = 38 /* 	MANTLE CELL LYM XTRRNDL */
'20041' = 38 /* 	MANTLE CELL LYMPH HEAD */
'20042' = 38 /* 	MANTLE CELL LYMPH THORAX */
'20043' = 38 /* 	MANTLE CELL LYMPH ABDOM */
'20044' = 38 /* 	MANTLE CELL LYMPH AXILLA */
'20045' = 38 /* 	MANTLE CELL LYMPH INGUIN */
'20046' = 38 /* 	MANTLE CELL LYMPH PELVIC */
'20047' = 38 /* 	MANTLE CELL LYMPH SPLEEN */
'20048' = 38 /* 	MANTLE CELL LYMPH MULTIP */
'20050' = 38 /* 	PRIMARY CNS LYMPH XTRNDL */
'20051' = 38 /* 	PRIMARY CNS LYMPH HEAD */
'20052' = 38 /* 	PRIMARY CNS LYMPH THORAX */
'20053' = 38 /* 	PRIMARY CNS LYMPH ABDOM */
'20054' = 38 /* 	PRIMARY CNS LYMPH AXILLA */
'20055' = 38 /* 	PRIMARY CNS LYM INGUIN */
'20056' = 38 /* 	PRIMARY CNS LYMPH PELVIC */
'20057' = 38 /* 	PRIMARY CNS LYMPH SPLEEN */
'20058' = 38 /* 	PRIMARY CNS LYMPH MULTIP */
'20060' = 38 /* 	ANAPLASTIC LYMPH XTRNDL */
'20061' = 38 /* 	ANAPLASTIC LYMPH HEAD */
'20062' = 38 /* 	ANAPLASTIC LYMPH THORAX */
'20063' = 38 /* 	ANAPLASTIC LYMPH ABDOM */
'20064' = 38 /* 	ANAPLASTIC LYMPH AXILLA */
'20065' = 38 /* 	ANAPLASTIC LYMPH INGUIN */
'20066' = 38 /* 	ANAPLASTIC LYMPH PELVIC */
'20067' = 38 /* 	ANAPLASTIC LYMPH SPLEEN */
'20068' = 38 /* 	ANAPLASTIC LYMPH MULTIP */
'20070' = 38 /* 	LARGE CELL LYMPH XTRNDL */
'20071' = 38 /* 	LARGE CELL LYMPHOMA HEAD */
'20072' = 38 /* 	LARGE CELL LYMPH THORAX */
'20073' = 38 /* 	LARGE CELL LYMPH ABDOM */
'20074' = 38 /* 	LARGE CELL LYMPH AXILLA */
'20075' = 38 /* 	LARGE CELL LYMPH INGUIN */
'20076' = 38 /* 	LARGE CELL LYMPH PELVIC */
'20077' = 38 /* 	LARGE CELL LYMPH SPLEEN */
'20078' = 38 /* 	LARGE CELL LYMPH MULTIP */
'20080' = 38 /* MIXED LYMPHOSARC UNSPEC */
'20081' = 38 /* MIXED LYMPHOSARC HEAD */
'20082' = 38 /* MIXED LYMPHOSARC THORAX */
'20083' = 38 /* MIXED LYMPHOSARC ABDOM */
'20084' = 38 /* MIXED LYMPHOSARC AXILLA */
'20085' = 38 /* MIXED LYMPHOSARC INGUIN */
'20086' = 38 /* MIXED LYMPHOSARC PELVIC */
'20087' = 38 /* MIXED LYMPHOSARC SPLEEN */
'20088' = 38 /* MIXED LYMPHOSARC MULT */
'20200' = 38 /* NODULAR LYMPHOMA UNSPEC */
'20201' = 38 /* NODULAR LYMPHOMA HEAD */
'20202' = 38 /* NODULAR LYMPHOMA THORAX */
'20203' = 38 /* NODULAR LYMPHOMA ABDOM */
'20204' = 38 /* NODULAR LYMPHOMA AXILLA */
'20205' = 38 /* NODULAR LYMPHOMA INGUIN */
'20206' = 38 /* NODULAR LYMPHOMA PELVIC */
'20207' = 38 /* NODULAR LYMPHOMA SPLEEN */
'20208' = 38 /* NODULAR LYMPHOMA MULT */
'20210' = 38 /* MYCOSIS FUNGOIDES UNSPEC */
'20211' = 38 /* MYCOSIS FUNGOIDES HEAD */
'20212' = 38 /* MYCOSIS FUNGOIDES THORAX */
'20213' = 38 /* MYCOSIS FUNGOIDES ABDOM */
'20214' = 38 /* MYCOSIS FUNGOIDES AXILLA */
'20215' = 38 /* MYCOSIS FUNGOIDES INGUIN */
'20216' = 38 /* MYCOSIS FUNGOIDES PELVIC */
'20217' = 38 /* MYCOSIS FUNGOIDES SPLEEN */
'20218' = 38 /* MYCOSIS FUNGOIDES MULT */
'20220' = 38 /* SEZARY-s DISEASE UNSPEC */
'20221' = 38 /* SEZARY-s DISEASE HEAD */
'20222' = 38 /* SEZARY-s DISEASE THORAX */
'20223' = 38 /* SEZARY-s DISEASE ABDOM */
'20224' = 38 /* SEZARY-s DISEASE AXILLA */
'20225' = 38 /* SEZARY-s DISEASE INGUIN */
'20226' = 38 /* SEZARY-s DISEASE PELVIC */
'20227' = 38 /* SEZARY-s DISEASE SPLEEN */
'20228' = 38 /* SEZARY-s DISEASE MULT */
'20230' = 41 /* MAL HISTIOCYTOSIS UNSPEC */
'20231' = 41 /* MAL HISTIOCYTOSIS HEAD */
'20232' = 41 /* MAL HISTIOCYTOSIS THORAX */
'20233' = 41 /* MAL HISTIOCYTOSIS ABDOM */
'20234' = 41 /* MAL HISTIOCYTOSIS AXILLA */
'20235' = 41 /* MAL HISTIOCYTOSIS INGUIN */
'20236' = 41 /* MAL HISTIOCYTOSIS PELVIC */
'20237' = 41 /* MAL HISTIOCYTOSIS SPLEEN */
'20238' = 41 /* MAL HISTIOCYTOSIS MULT */
'20240' = 39 /* HAIRY-CELL LEUKEM UNSPEC */
'20241' = 39 /* HAIRY-CELL LEUKEM HEAD */
'20242' = 39 /* HAIRY-CELL LEUKEM THORAX */
'20243' = 39 /* HAIRY-CELL LEUKEM ABDOM */
'20244' = 39 /* HAIRY-CELL LEUKEM AXILLA */
'20245' = 39 /* HAIRY-CELL LEUKEM INGUIN */
'20246' = 39 /* HAIRY-CELL LEUKEM PELVIC */
'20247' = 39 /* HAIRY-CELL LEUKEM SPLEEN */
'20248' = 39 /* HAIRY-CELL LEUKEM MULT */
'20250' = 41 /* LETTERER-SIWE DIS UNSPEC */
'20251' = 41 /* LETTERER-SIWE DIS HEAD */
'20252' = 41 /* LETTERER-SIWE DIS THORAX */
'20253' = 41 /* LETTERER-SIWE DIS ABDOM */
'20254' = 41 /* LETTERER-SIWE DIS AXILLA */
'20255' = 41 /* LETTERER-SIWE DIS INGUIN */
'20256' = 41 /* LETTERER-SIWE DIS PELVIC */
'20257' = 41 /* LETTERER-SIWE DIS SPLEEN */
'20258' = 41 /* LETTERER-SIWE DIS MULT */
'20260' = 41 /* MAL MASTOCYTOSIS UNSPEC */
'20261' = 41 /* MAL MASTOCYTOSIS HEAD */
'20262' = 41 /* MAL MASTOCYTOSIS THORAX */
'20263' = 41 /* MAL MASTOCYTOSIS ABDOM */
'20264' = 41 /* MAL MASTOCYTOSIS AXILLA */
'20265' = 41 /* MAL MASTOCYTOSIS INGUIN */
'20266' = 41 /* MAL MASTOCYTOSIS PELVIC */
'20267' = 41 /* MAL MASTOCYTOSIS SPLEEN */
'20268' = 41 /* MAL MASTOCYTOSIS MULT */
'20270' = 38 /* 	PERIPH T CELL LYM XTRNDL */
'20271' = 38 /* 	PERIPH T CELL LYMPH HEAD */
'20272' = 38 /* 	PERIPH T CELL LYM THORAX */
'20273' = 38 /* 	PERIPH T CELL LYM ABDOM */
'20274' = 38 /* 	PERIPH T CELL LYM AXILLA */
'20275' = 38 /* 	PERIPH T CELL LYM INGUIN */
'20276' = 38 /* 	PERIPH T CELL LYM PELVIC */
'20277' = 38 /* 	PERIPH T CELL LYM SPLEEN */
'20278' = 38 /* 	PERIPH T CELL LYM MULTIP */
'20280' = 38 /* LYMPHOMA NEC UNSPEC SITE */
'20281' = 38 /* LYMPHOMAS NEC HEAD */
'20282' = 38 /* LYMPHOMAS NEC THORAX */
'20283' = 38 /* LYMPHOMAS NEC ABDOM */
'20284' = 38 /* LYMPHOMAS NEC AXILLA */
'20285' = 38 /* LYMPHOMAS NEC INGUIN */
'20286' = 38 /* LYMPHOMAS NEC PELVIC */
'20287' = 38 /* LYMPHOMAS NEC SPLEEN */
'20288' = 38 /* LYMPHOMAS NEC MULT */
'20290' = 38 /* LYMPHOID MAL NEC UNSPEC */
'20291' = 38 /* LYMPHOID MAL NEC HEAD */
'20292' = 38 /* LYMPHOID MAL NEC THORAX */
'20293' = 38 /* LYMPHOID MAL NEC ABDOM */
'20294' = 38 /* LYMPHOID MAL NEC AXILLA */
'20295' = 38 /* LYMPHOID MAL NEC INGUIN */
'20296' = 38 /* LYMPHOID MAL NEC PELVIC */
'20297' = 38 /* LYMPHOID MAL NEC SPLEEN */
'20298' = 38 /* LYMPHOID MAL NEC MULT */
'2031 ' = 39 /* PLASMA CELL LEUKEMIA   J80  S91 */
'20310' = 39 /* PLSM CELL LEUK W/O RMSON OCT91 */
'20311' = 39 /* PLSM CELL LEUK W RMSON OCT91 */
'20312' = 39 /* 	PLSM CEL LEUK IN RELAPSE */
'2040 ' = 39 /* ACUTE LYMPHOID LEUKEMIA  J80  S91 */
'20400' = 39 /* ACT LYM LEUK W/O RMSION  OCT91 */
'20401' = 39 /* ACT LYM LEUK W RMSION  OCT91 */
'20402' = 39 /* 	ACT LYMP LEUK IN RELAPSE */
'2041 ' = 39 /* CHR LYMPHOID LEUKEMIA  J80  S91 */
'20410' = 39 /* CHR LYM LEUK W/O RMSION  OCT91 */
'20411' = 39 /* CHR LYM LEUK W RMSION  OCT91 */
'20412' = 39 /* 	CHR LYMP LEUK IN RELAPSE */
'2042 ' = 39 /* SUBAC LYMPHOID LEUKEMIA  J80  S91 */
'20420' = 39 /* SBAC LYM LEUK W/O RMSION OCT91 */
'20422' = 39 /* 	SBAC LYM LEUK IN RELAPSE */
'20421' = 39 /* SBAC LYM LEUK W RMSION OCT91 */
'2048 ' = 39 /* LYMPHOID LEUKEMIA NEC  J80  S91 */
'20480' = 39 /* OTH LYM LEUK W/O RMSION  OCT91 */
'20481' = 39 /* OTH LYM LEUK W RMSION  OCT91 */
'20482' = 39 /* 	OTH LYM LEUK IN RELAPSE */
'2049 ' = 39 /* LYMPHOID LEUKEMIA NOS  J80  S91 */
'20490' = 39 /* UNS LYM LEUK W/O RMSION  OCT91 */
'20491' = 39 /* UNS LYM LEUK W RMSION  OCT91 */
'20492' = 39 /* 	LYMP LEUK NOS RELAPSE */
'2050 ' = 39 /* ACUTE MYELOID LEUKEMIA J80  S91 */
'20500' = 39 /* ACT MYL LEUK W/O RMSION  OCT91 */
'20501' = 39 /* ACT MYL LEUK W RMSION  OCT91 */
'20502' = 39 /* 	ACT MYEL LEUK IN RELAPSE */
'2051 ' = 39 /* CHRONIC MYELOID LEUKEMIA  J80  S91 */
'20510' = 39 /* CHR MYL LEUK W/O RMSION  OCT91 */
'20511' = 39 /* CHR MYL LEUK W RMSION  OCT91 */
'20512' = 39 /* 	CHR MYEL LEUK IN RELAPSE */
'2052 ' = 39 /* SUBACUT MYELOID LEUKEMIA  J80  S91 */
'20520' = 39 /* SBAC MYL LEUK W/O RMSION OCT91 */
'20521' = 39 /* SBAC MYL LEUK W RMSION OCT91 */
'20522' = 39 /* 	SBAC MYL LEUK IN RELAPSE */
'2053 ' = 39 /* MYELOID SARCOMA    J80  S91 */
'20530' = 39 /* MYL SRCOMA W/O RMSION  OCT91 */
'20531' = 39 /* MYL SRCOMA W RMSION  OCT91 */
'20532' = 39 /* 	MYEL SARCOMA IN RELAPSE */
'2058 ' = 39 /* MYELOID LEUKEMIA NEC   J80  S91 */
'20580' = 39 /* OTH MYL LEUK W/O RMSION  OCT91 */
'20581' = 39 /* OTH MYL LEUK W RMSION  OCT91 */
'20582' = 39 /* 	OTH MYEL LEUK IN RELAPSE */
'2059 ' = 39 /* MYELOID LEUKEMIA NOS   J80  S91 */
'20590' = 39 /* UNS MYL LEUK W/O RMSION  OCT91 */
'20591' = 39 /* UNS MYL LEUK W RMSION  OCT91 */
'20592' = 39 /* 	MYEL LEUK NOS IN RELAPSE */
'2060 ' = 39 /* ACUTE MONOCYTIC LEUKEMIA  J80  S91 */
'20600' = 39 /* ACT MONO LEUK W/O RMSION OCT91 */
'20601' = 39 /* ACT MONO LEUK W RMSION OCT91 */
'20602' = 39 /* 	ACT MONO LEUK IN RELAPSE */
'2061 ' = 39 /* CHR MONOCYTIC LEUKEMIA  J80  S91 */
'20610' = 39 /* CHR MONO LEUK W/O RMSION OCT91 */
'20611' = 39 /* CHR MONO LEUK W RMSION OCT91 */
'20612' = 39 /* 	CHR MONO LEUK IN RELAPSE */
'2062 ' = 39 /* SUBAC MONOCYTIC LEUKEMIA  J80  S91 */
'20620' = 39 /* SBAC MONO LEUK W/O RMSON OCT91 */
'20621' = 39 /* SBAC MONO LEUK W RMSION  OCT91 */
'20622' = 39 /* 	SBAC MONO LEU IN RELAPSE */
'2068 ' = 39 /* MONOCYTIC LEUKEMIA NEC  J80  S91 */
'20680' = 39 /* OTH MONO LEUK W/O RMSION OCT91 */
'20681' = 39 /* OTH MONO LEUK W RMSION OCT91 */
'20682' = 39 /* 	OTH MONO LEUK IN RELAPSE */
'2069 ' = 39 /* MONOCYTIC LEUKEMIA NOS  J80  S91 */
'20690' = 39 /* UNS MONO LEUK W/O RMSION OCT91 */
'20691' = 39 /* UNS MONO LEUK W RMSION OCT91 */
'20692' = 39 /* 	MONO LEUK NOS RELAPSE */
'2070 ' = 39 /* ACUTE ERYTHREMIA   J80  S91 */
'20700' = 39 /* ACT ERTH/ERYLK W/O RMSON OCT91 */
'20701' = 39 /* ACT ERTH/ERYLK W RMSON OCT91 */
'2071 ' = 39 /* CHRONIC ERYTHREMIA   J80  S91 */
'20710' = 39 /* CHR ERYTHRM W/O REMISION OCT91 */
'20702' = 39 /* 	AC ERTH/ERYLK IN RELAPSE */
'20711' = 39 /* CHR ERYTHRM W REMISION OCT91 */
'20712' = 39 /* 	CHR ERYTHRMIA IN RELAPSE */
'2072 ' = 39 /* MEGAKARYOCYTIC LEUKEMIA  J80  S91 */
'20720' = 39 /* MGKRYCYT LEUK W/O RMSION OCT91 */
'20721' = 39 /* MGKRYCYT LEUK W RMSION OCT91 */
'20722' = 39 /* 	MGKRYCYT LEUK IN RELAPSE */
'2078 ' = 39 /* SPECIFIED LEUKEMIA NEC  J80  S91 */
'20780' = 39 /* OTH SPF LEUK W/O REMSION OCT91 */
'20781' = 39 /* OTH SPF LEUK W REMSION OCT91 */
'20782' = 39 /* 	OTH SPF LEUK IN RELAPSE */
'2080 ' = 39 /* ACT LEUK UNS CL W/O RMSN  J80  S91 */
'20800' = 39 /* ACT LEUK UNS CL W/O RMSN OCT91 */
'20801' = 39 /* ACT LEUK UNS CL W RMSON  OCT91 */
'20802' = 39 /* 	AC LEUK UNS CL RELAPSE */
'2081 ' = 39 /* CHRONIC LEUKEMIA NOS   J80  S91 */
'20810' = 39 /* CHR LEUK UNS CL W/O RMSN OCT91 */
'20811' = 39 /* CHR LEUK UNS CL W RMSON  OCT91 */
'20812' = 39 /* 	CH LEU UNS CL IN RELAPSE */
'2082 ' = 39 /* SUBACUTE LEUKEMIA NOS  J80  S91 */
'20820' = 39 /* SBAC LEUK UNS CL W/O RMS OCT91 */
'20821' = 39 /* SBAC LEUK UNS CL W RMSON OCT91 */
'20822' = 39 /* 	SBAC LEU UNS CL-RELAPSE */
'2088 ' = 39 /* LEUKEMIA-UNSPEC CELL NEC  J80  S91 */
'20880' = 39 /* OTH LEUK UNS CL W/O RMSN OCT91 */
'20881' = 39 /* OTH LEUK UNS CL W RMSON  OCT91 */
'20882' = 39 /* 	OTH LEUK UNS CL-RELAPSE */
'2089 ' = 39 /* LEUKEMIA-UNSPEC CELL NOS  J80  S91 */
'20890' = 39 /* LEUKEMIA NOS W/O REMSION OCT91 */
'20891' = 39 /* LEUKEMIA NOS W REMISSION OCT91 */
'20892' = 39 /* 	LEUKEMIA NOS IN RELAPSE */
'20922' = 41 /* 	MALIG CARCINOID THYMUS */
'20924' = 33 /* 	MALIG CARCINOID KIDNEY */
'20925' = 41 /* 	MAL CARCNOID FOREGUT NOS */
'20926' = 41 /* 	MAL CARCINOID MIDGUT NOS */
'20927' = 41 /* 	MAL CARCNOID HINDGUT NOS */
'20971' = 42 /* 	SEC NEUROEND TU DIST LYM */
'20972' = 42 /* 	SEC NEUROEND TUMOR-LIVER */
'20973' = 42 /* 	SEC NEUROENDO TUMOR-BONE */
'20974' = 42 /* 	SEC NEUROENDO TU-PERITON */
'2340 ' = 41 /* CA IN SITU EYE */
'2348 ' = 41 /* CA IN SITU NEC */
'2349 ' = 41 /* CA IN SITU NOS */
'2375 ' = 35 /* UNC BEH NEO BRAIN/SPINAL */
'2396 ' = 35 /* BRAIN NEOPLASM NOS */
'2400 ' = 48 /* SIMPLE GOITER */
'2409 ' = 48 /* GOITER NOS */
'2410 ' = 48 /* NONTOX UNINODULAR GOITER */
'2411 ' = 48 /* NONTOX MULTINODUL GOITER */
'2419 ' = 48 /* NONTOX NODUL GOITER NOS */
'24200' = 48 /* TOX DIF GOITER NO CRISIS */
'24201' = 48 /* TOX DIF GOITER W CRISIS */
'24210' = 48 /* TOX UNINOD GOIT NO CRIS */
'24211' = 48 /* TOX UNINOD GOIT W CRISIS */
'24220' = 48 /* TOX MULTNOD GOIT NO CRIS */
'24221' = 48 /* TOX MULTNOD GOIT W CRIS */
'24230' = 48 /* TOX NOD GOITER NO CRISIS */
'24231' = 48 /* TOX NOD GOITER W CRISIS */
'24240' = 48 /* THYROTOX-ECT NOD NO CRIS */
'24241' = 48 /* THYROTOX-ECT NOD W CRIS */
'24280' = 48 /* THYRTOX ORIG NEC NO CRIS */
'24281' = 48 /* THYROTOX ORIG NEC W CRIS */
'24290' = 48 /* THYROTOX NOS NO CRISIS */
'24291' = 48 /* THYROTOX NOS W CRISIS */
'243  ' = 48 /* CONGENITAL HYPOTHYROIDSM */
'2440 ' = 48 /* POSTSURGICAL HYPOTHYROID */
'2441 ' = 48 /* POSTABLAT HYPOTHYR NEC */
'2442 ' = 48 /* IODINE HYPOTHYROIDISM */
'2443 ' = 48 /* IATROGEN HYPOTHYROID NEC */
'2448 ' = 48 /* ACQUIRED HYPOTHYROID NEC */
'2449 ' = 48 /* HYPOTHYROIDISM NOS */
'2450 ' = 48 /* ACUTE THYROIDITIS */
'2451 ' = 48 /* SUBACUTE THYROIDITIS */
'2452 ' = 48 /* CHR LYMPHOCYT THYROIDIT */
'2453 ' = 48 /* CHR FIBROUS THYROIDITIS */
'2454 ' = 48 /* IATROGENIC THYROIDITIS */
'2458 ' = 48 /* CHR THYROIDITIS NEC/NOS */
'2459 ' = 48 /* THYROIDITIS NOS */
'2460 ' = 48 /* DIS THYROCALCITON SECRET */
'2461 ' = 48 /* DYSHORMONOGENIC GOITER */
'2462 ' = 48 /* CYST OF THYROID */
'2463 ' = 48 /* HEMORR/INFARC THYROID */
'2468 ' = 48 /* DISORDERS OF THYROID NEC */
'2469 ' = 48 /* DISORDER OF THYROID NOS */
'2510 ' = 51 /* HYPOGLYCEMIC COMA  OCT93 */
'2511 ' = 51 /* HYPERINSULINISM NEC */
'2512 ' = 51 /* HYPOGLYCEMIA NOS */
'2513 ' = 51 /* POSTSURG HYPOINSULINEMIA */
'2514 ' = 51 /* ABN SECRETION GLUCAGON */
'2515 ' = 51 /* ABNORM SECRETION GASTRIN */
'2518 ' = 51 /* PANCREATIC DISORDER NEC */
'2519 ' = 51 /* PANCREATIC DISORDER NOS */
'2520 ' = 51 /* HYPERPARATHYROIDISM */
'25200' = 51 /* HYPERPARATHYROIDISM NOS */
'25201' = 51 /* PRIMARY HYPERPARATHYROID */
'25202' = 51 /* SEC HYPRPRTHYRD NONRENAL */
'25208' = 51 /* HYPERPARATHYROIDISM NEC */
'2521 ' = 51 /* HYPOPARATHYROIDISM */
'2528 ' = 51 /* PARATHYROID DISORDER NEC */
'2529 ' = 51 /* PARATHYROID DISORDER NOS */
'2530 ' = 51 /* ACROMEGALY AND GIGANTISM */
'2531 ' = 51 /* ANT PITUIT HYPERFUNC NEC */
'2532 ' = 51 /* PANHYPOPITUITARISM */
'2533 ' = 51 /* PITUITARY DWARFISM */
'2534 ' = 51 /* ANTER PITUITARY DIS NEC */
'2535 ' = 51 /* DIABETES INSIPIDUS */
'2536 ' = 51 /* NEUROHYPOPHYSIS DIS NEC */
'2537 ' = 51 /* IATROGENIC PITUITARY DIS */
'2538 ' = 51 /* PITUITARY DISORDER NEC */
'2539 ' = 51 /* PITUITARY DISORDER NOS */
'2540 ' = 51 /* PERSIST HYPERPLAS THYMUS */
'2541 ' = 51 /* ABSCESS OF THYMUS */
'2548 ' = 51 /* DISEASES OF THYMUS NEC */
'2549 ' = 51 /* DISEASE OF THYMUS NOS */
'2550 ' = 51 /* CUSHING-s SYNDROME */
'2551 ' = 51 /* HYPERALDOSTERONISM */
'25510' = 51 /* Primary aldosteronism */
'25511' = 51 /* Glucocorticoid-remediable aldosteronism */
'25512' = 51 /* Conns syndrome */
'25513' = 51 /* Bartters syndrome */
'25514' = 51 /* Other secondary aldosteronism */
'2552 ' = 51 /* ADRENOGENITAL DISORDERS */
'2553 ' = 51 /* CORTICOADREN OVERACT NEC */
'2554 ' = 51 /* CORTICOADRENAL INSUFFIC */
'25541' = 51 /*  GLUCOCORTICOID DEFICIENT */
'25542' = 51 /*  MINERALCORTICOID DEFCNT */
'2555 ' = 51 /* ADRENAL HYPOFUNCTION NEC */
'2556 ' = 51 /* MEDULLOADRENAL HYPERFUNC */
'2558 ' = 51 /* ADRENAL DISORDER NEC */
'2559 ' = 51 /* ADRENAL DISORDER NOS */
'2560 ' = 51 /* HYPERESTROGENISM */
'2561 ' = 51 /* OVARIAN HYPERFUNC NEC */
'2562 ' = 51 /* POSTABLATIV OVARIAN FAIL */
'2563 ' = 51 /* OVARIAN FAILURE NEC */
'2564 ' = 51 /* POLYCYSTIC OVARIES */
'2568 ' = 51 /* OVARIAN DYSFUNCTION NEC */
'2569 ' = 51 /* OVARIAN DYSFUNCTION NOS */
'2570 ' = 51 /* TESTICULAR HYPERFUNCTION */
'2571 ' = 51 /* POSTABLAT TESTIC HYPOFUN */
'2572 ' = 51 /* TESTICULAR HYPOFUNC NEC */
'2578 ' = 51 /* TESTICULAR DYSFUNCT NEC */
'2579 ' = 51 /* TESTICULAR DYSFUNCT NOS */
'2580 ' = 51 /* WERMER-s SYNDROME */
'25801' = 51 /*  MULT ENDO NEOPLAS TYPE I */
'2581 ' = 51 /* COMB ENDOCR DYSFUNCT NEC */
'2588 ' = 51 /* POLYGLANDUL DYSFUNC NEC */
'2589 ' = 51 /* POLYGLANDUL DYSFUNC NOS */
'2590 ' = 51 /* DELAY SEXUAL DEVELOP NEC */
'2591 ' = 51 /* SEXUAL PRECOCITY NEC */
'2592 ' = 51 /* CARCINOID SYNDROME */
'2593 ' = 51 /* ECTOPIC HORMONE SECR NEC */
'2594 ' = 51 /* DWARFISM NEC */
'2595 ' = 51 /* ANDROGEN INSENSITVTY SYN */
'25950' = 51 /*  ANDROGEN INSENSITVTY NOS */
'25951' = 51 /*  ANDROGEN INSENSITVTY SYN */
'25952' = 51 /*  PART ANDROGEN INSNSITVTY */
'2598 ' = 51 /* ENDOCRINE DISORDERS NEC */
'2599 ' = 51 /* ENDOCRINE DISORDER NOS */
'260  ' = 52 /* KWASHIORKOR */
'261  ' = 52 /* NUTRITIONAL MARASMUS */
'262  ' = 52 /* OTH SEVERE MALNUTRITION */
'2630 ' = 52 /* MALNUTRITION MOD DEGREE */
'2631 ' = 52 /* MALNUTRITION MILD DEGREE */
'2632 ' = 52 /* ARREST DEVEL D/T MALNUTR */
'2638 ' = 52 /* PROTEIN-CAL MALNUTR NEC */
'2639 ' = 52 /* PROTEIN-CAL MALNUTR NOS */
'2640 ' = 52 /* VIT A CONJUNCTIV XEROSIS */
'2641 ' = 52 /* VIT A BITOT-s SPOT */
'2642 ' = 52 /* VIT A CORNEAL XEROSIS */
'2643 ' = 52 /* VIT A CORNEA ULCER/XEROS */
'2644 ' = 52 /* VIT A KERATOMALACIA */
'2645 ' = 52 /* VIT A NIGHT BLINDNESS */
'2646 ' = 52 /* VIT A DEF W CORNEAL SCAR */
'2647 ' = 52 /* VIT A OCULAR DEFIC NEC */
'2648 ' = 52 /* VITAMIN A DEFICIENCY NEC */
'2649 ' = 52 /* VITAMIN A DEFICIENCY NOS */
'2650 ' = 52 /* BERIBERI */
'2651 ' = 52 /* THIAMINE DEFIC NEC/NOS */
'2652 ' = 52 /* PELLAGRA */
'2660 ' = 52 /* ARIBOFLAVINOSIS */
'2661 ' = 52 /* VITAMIN B6 DEFICIENCY */
'2662 ' = 52 /* B-COMPLEX DEFIC NEC */
'2669 ' = 52 /* VITAMIN B DEFICIENCY NOS */
'267  ' = 52 /* ASCORBIC ACID DEFICIENCY */
'2680 ' = 52 /* RICKETS- ACTIVE */
'2681 ' = 52 /* RICKETS- LATE EFFECT */
'2682 ' = 52 /* OSTEOMALACIA NOS */
'2689 ' = 52 /* VITAMIN D DEFICIENCY NOS */
'2690 ' = 52 /* DEFICIENCY OF VITAMIN K */
'2691 ' = 52 /* VITAMIN DEFICIENCY NEC */
'2692 ' = 52 /* VITAMIN DEFICIENCY NOS */
'2693 ' = 52 /* MINERAL DEFICIENCY NEC */
'2698 ' = 52 /* NUTRITION DEFICIENCY NEC */
'2699 ' = 52 /* NUTRITION DEFICIENCY NOS */
'2700 ' = 58 /* AMINO-ACID TRANSPORT DIS */
'2701 ' = 58 /* PHENYLKETONURIA - PKU */
'2702 ' = 58 /* AROM AMIN-ACID METAB NEC */
'2703 ' = 58 /* BRAN-CHAIN AMIN-ACID DIS */
'2704 ' = 58 /* SULPH AMINO-ACID MET DIS */
'2705 ' = 58 /* DIS HISTIDINE METABOLISM */
'2706 ' = 58 /* DIS UREA CYCLE METABOL */
'2707 ' = 58 /* STRAIG AMIN-ACID MET NEC */
'2708 ' = 58 /* DIS AMINO-ACID METAB NEC */
'2709 ' = 58 /* DIS AMINO-ACID METAB NOS */
'2710 ' = 58 /* GLYCOGENOSIS */
'2711 ' = 58 /* GALACTOSEMIA */
'2712 ' = 58 /* HERED FRUCTOSE INTOLERAN */
'2713 ' = 58 /* DISACCHARIDASE DEF/MALAB */
'2714 ' = 58 /* RENAL GLYCOSURIA */
'2718 ' = 58 /* DIS CARBOHYDR METAB NEC */
'2719 ' = 58 /* DIS CARBOHYDR METAB NOS */
'2725 ' = 58 /* LIPOPROTEIN DEFICIENCIES */
'2726 ' = 58 /* LIPODYSTROPHY */
'2727 ' = 58 /* LIPIDOSES */
'2728 ' = 58 /* LIPOID METABOL DIS NEC */
'2729 ' = 58 /* LIPOID METABOL DIS NOS */
'2730 ' = 58 /* POLYCLON HYPERGAMMAGLOBU */
'2731 ' = 58 /* MONOCLON PARAPROTEINEMIA */
'2732 ' = 58 /* PARAPROTEINEMIA NEC */
'2733 ' = 58 /* MACROGLOBULINEMIA */
'2734 ' = 58 /* ALPHA-1-ANTITRYPSIN DEF */
'2738 ' = 58 /* DIS PLAS PROTEIN MET NEC */
'2739 ' = 58 /* DIS PLAS PROTEIN MET NOS */
'2750 ' = 58 /* DIS IRON METABOLISM */
'27501' = 58 /* HEREDIT HEMOCHROMATOSIS */
'27502' = 58 /* HEMOCHROMATOS-RBC TRANS */
'27503' = 58 /* HEMOCHROMATOSIS NEC */
'27509' = 58 /* DISORD IRON METABLSM NEC */
'2751 ' = 58 /* DIS COPPER METABOLISM */
'2752 ' = 58 /* DIS MAGNESIUM METABOLISM */
'2753 ' = 58 /* DIS PHOSPHORUS METABOL */
'2754 ' = 58 /* DIS CALCIUM METABOLISM */
'27540' = 58 /* UNSPEC DISORDER CALCIUM METAB OCT97 */
'27541' = 58 /* HYPOCALCEMIA OCT97 */
'27542' = 58 /* HYPERCALCEMIA OCT97 */
'27549' = 58 /* OT DISORDER OF CALCIUM METAB OCT97 */
'2755 ' = 58 /*  HUNGRY BONE SYNDROME */
'2758 ' = 58 /* DIS MINERAL METABOL NEC */
'2759 ' = 58 /* DIS MINERAL METABOL NOS */
'27700' = 56 /* CYSTIC FIBROS W/O ILEUS */
'27701' = 56 /* CYSTIC FIBROSIS W ILEUS- */
'27702' = 56 /* CYSTIC FIBROSIS W PULM MANFSTATNS OCT02 */
'27703' = 56 /* CYSTIC FIBROSIS W GASTRO MANFSTATNS OCT02 */
'27709' = 56 /* CYSTIC FIBROSIS W OTHER MANFSTATNS  OCT02 */
'2771 ' = 58 /* DIS PORPHYRIN METABOLISM */
'2772 ' = 58 /* PURINE/PYRIMID DIS NEC */
'2773 ' = 58 /* AMYLOIDOSIS */
'27730' = 58 /* AMYLOIDOSIS NOS */
'27731' = 58 /* FAM MEDITERRANEAN FEVER */
'27739' = 58 /* AMYLOIDOSIS NEC */
'2774 ' = 58 /* DIS BILIRUBIN EXCRETION */
'2775 ' = 58 /* MUCOPOLYSACCHARIDOSIS */
'2776 ' = 58 /* DEFIC CIRCUL ENZYME NEC */
'2777 ' = 58 /* DYSMETABOLIC SYNDROME X OCT01 */
'2778 ' = 58 /* METABOLISM DISORDER NEC */
'27781' = 58 /* Primary carnitine deficiency */
'27782' = 58 /* Carnitine deficiency due to inborn errors of */
'27784' = 58 /* Other secondary carnitine deficiency */
'27785' = 58 /* DISORDERS ACID OXIDATION */
'27786' = 58 /* PEROXISOMAL DISORDERS */
'27787' = 58 /* DIS MITOCHONDRIAL METAB */
'27789' = 58 /* Other specified disorders of metabolism */
'2779 ' = 58 /* METABOLISM DISORDER NOS */
'2780 ' = 58 /* OBESITY */
'27800' = 58 /* OBESITY UNSPECIFIED OCT95 */
'27801' = 58 /* MORBID OBESITY OCT95 */
'27802' = 58 /* OVERWEIGHT */
'27803' = 58 /* OBESITY HYPOVENT SYND */
'2781 ' = 58 /* LOCALIZED ADIPOSITY */
'2782 ' = 58 /* HYPERVITAMINOSIS A */
'2783 ' = 58 /* HYPERCAROTINEMIA */
'2784 ' = 58 /* HYPERVITAMINOSIS D */
'2788 ' = 58 /* OTHER HYPERALIMENTATION */
'27900' = 57 /* HYPOGAMMAGLOBULINEM NOS */
'27901' = 57 /* SELECTIVE IGA IMMUNODEF */
'27902' = 57 /* SELECTIVE IGM IMMUNODEF */
'27903' = 57 /* SELECTIVE IG DEFIC NEC */
'27904' = 57 /* CONG HYPOGAMMAGLOBULINEM */
'27905' = 57 /* IMMUNODEFIC W HYPER-IGM */
'27906' = 57 /* COMMON VARIABL IMMUNODEF */
'27909' = 57 /* HUMORAL IMMUNITY DEF NEC */
'27911' = 57 /* DIGEORGE-s SYNDROME */
'27912' = 57 /* WISKOTT-ALDRICH SYNDROME */
'27913' = 57 /* NEZELOF-s SYNDROME */
'2792 ' = 57 /* COMBINED IMMUNITY DEFIC */
'2793 ' = 57 /* IMMUNITY DEFICIENCY NOS */
'2794 ' = 57 /* AUTOIMMUNE DISEASE NEC */
'27941' = 57 /*  AUTOIMMUN LYMPHPROF SYND */
'27949' = 57 /*  AUTOIMMUNE DISEASE NEC */
'2798 ' = 57 /* IMMUNE MECHANISM DIS NEC */
'2799 ' = 57 /* IMMUNE MECHANISM DIS NOS */
'2860 ' = 62 /* CONG FACTOR VIII DIORD */
'2861 ' = 62 /* CONG FACTOR IX DISORDER */
'2862 ' = 62 /* CONG FACTOR XI DISORDER */
'2863 ' = 62 /* CONG DEF CLOT FACTOR NEC */
'2864 ' = 62 /* VON WILLEBRAND-S DISEASE */
'2865 ' = 62 /*  CIRCULATING ANTICOAG DIS */
'28652'	 = 62	/* Acquired hemophilia (Begin 2011) 	*/   
'28653'	 = 62	/* Antiphospholipid w hemor (Begin 2011)*/
'28659'	 = 62	/* Ot hem d/t circ anticoag (Begin 2011)*/
'2866 ' = 62 /*  DEFIBRINATION SYNDROME	*/
'2867 ' = 62 /*  ACQ COAGUL FACTOR DEFIC	*/
'2869 ' = 62 /* COAGULAT DEFECT NEC/NOS */
'2870 ' = 62 /* ALLERGIC PURPURA */
'2871 ' = 62 /* THROMBOCYTOPATHY */
'2872 ' = 62 /* PURPURA NOS */
'2873 ' = 62 /* PRIMARY THROMBOCYTOPENIA */
'28730' = 62 /* PRIM THROMBOCYTOPEN NOS */
'28731' = 62 /* IMMUNE THROMBOCYT PURPRA */
'28732' = 62 /* EVANS SYNDROME */
'28733' = 62 /* CONG-HERID THROMB PURPRA */
'28739' = 62 /* PRIM THROMBOCYTOPEN NEC */
'2874 ' = 62 /*  SECOND THROMBOCYTOPENIA	*/
'28749' = 62 /* SEC THROMBOCYTPENIA NEC */
'2875 ' = 62 /* THROMBOCYTOPENIA NOS */
'2878 ' = 62 /* HEMORRHAGIC COND NEC */
'2879 ' = 62 /* HEMORRHAGIC COND NOS */
'2880 ' = 63 /* AGRANULOCYTOSIS */
'28800' = 63 /* NEUTROPENIA NOS */
'28801' = 63 /* CONGENITAL NEUTROPENIA */
'28802' = 63 /* CYCLIC NEUTROPENIA */
'28803' = 63 /* DRUG INDUCED NEUTROPENIA */
'28804' = 63 /* NEUTROPENIA D/T INFECTN */
'28809' = 63 /* NEUTROPENIA NEC */
'2881 ' = 63 /* FUNCTION DIS NEUTROPHILS */
'2882 ' = 63 /* GENETIC ANOMALY LEUKOCYT */
'2883 ' = 63 /* EOSINOPHILIA */
'2884 ' = 63 /* HEMOPHAGOCYTIC SYNDROMES */
'28850' = 63 /* LEUKOCYTOPENIA NOS */
'28851' = 63 /* LYMPHOCYTOPENIA */
'28859' = 63 /* DECREASED WBC COUNT NEC */
'28860' = 63 /* LEUKOCYTOSIS NOS */
'28861' = 63 /* LYMPHOCYTOSIS-SYMPTOMATC */
'28862' = 63 /* LEUKEMOID REACTION */
'28863' = 63 /* MONOCYTOSIS-SYMPTOMATIC */
'28864' = 63 /* PLASMACYTOSIS */
'28865' = 63 /* BASOPHILIA */
'28866' = 63 /*  BANDEMIA */
'28869' = 63 /* ELEVATED WBC COUNT NEC */
'2888 ' = 63 /* WBC DISEASE NEC */
'2889 ' = 63 /* WBC DISEASE NOS */
'28953' = 63 /* NEUTROPENIC SPLENOMEGALY */
'28981' = 62 /* PRIMARY HYPERCOAGULABLE STATE */
'28982' = 62 /*  SECONDARY HYPERCOAGULABLE STATE */
'28984' = 62 /*  HEPARIN-INDU THROMBOCYTO */
'2920 ' = 661 /* DRUG WITHDRAWAL SYNDROME */
'29211' = 661 /* DRUG PARANOID STATE */
'29212' = 661 /* DRUG HALLUCINOSIS */
'2922 ' = 661 /* PATHOLOGIC DRUG INTOX */
'29281' = 661 /* DRUG-INDUCED DELIRIUM */
'29282' = 661 /* DRUG-INDUCED DEMENTIA */
'29283' = 661 /* DRUG AMNESTIC SYNDROME */
'29284' = 661 /* DRUG DEPRESSIVE SYNDROME */
'29285' = 661 /* DRUG INDUCED SLEEP DISOR */
'29289' = 661 /* DRUG MENTAL DISORDER NEC */
'2929 ' = 661 /* DRUG MENTAL DISORDER NOS */
'30400' = 661 /* OPIOID DEPENDENCE-UNSPEC */
'30401' = 661 /* OPIOID DEPENDENCE-CONTIN */
'30402' = 661 /* OPIOID DEPENDENCE-EPISOD */
'30403' = 661 /* OPIOID DEPENDENCE-REMISS */
'30410' = 661 /* BARBITURAT DEPEND-UNSPEC */
'30411' = 661 /* BARBITURAT DEPEND-CONTIN */
'30412' = 661 /* BARBITURAT DEPEND-EPISOD */
'30413' = 661 /* BARBITURAT DEPEND-REMISS */
'30420' = 661 /* COCAINE DEPEND-UNSPEC */
'30421' = 661 /* COCAINE DEPEND-CONTIN */
'30422' = 661 /* COCAINE DEPEND-EPISODIC */
'30423' = 661 /* COCAINE DEPEND-REMISS */
'30430' = 661 /* CANNABIS DEPEND-UNSPEC */
'30431' = 661 /* CANNABIS DEPEND-CONTIN */
'30432' = 661 /* CANNABIS DEPEND-EPISODIC */
'30433' = 661 /* CANNABIS DEPEND-REMISS */
'30440' = 661 /* AMPHETAMIN DEPEND-UNSPEC */
'30441' = 661 /* AMPHETAMIN DEPEND-CONTIN */
'30442' = 661 /* AMPHETAMIN DEPEND-EPISOD */
'30443' = 661 /* AMPHETAMIN DEPEND-REMISS */
'30450' = 661 /* HALLUCINOGEN DEP-UNSPEC */
'30451' = 661 /* HALLUCINOGEN DEP-CONTIN */
'30452' = 661 /* HALLUCINOGEN DEP-EPISOD */
'30453' = 661 /* HALLUCINOGEN DEP-REMISS */
'30460' = 661 /* DRUG DEPEND NEC-UNSPEC */
'30461' = 661 /* DRUG DEPEND NEC-CONTIN */
'30462' = 661 /* DRUG DEPEND NEC-EPISODIC */
'30463' = 661 /* DRUG DEPEND NEC-IN REM */
'30470' = 661 /* OPIOID/OTHER DEP-UNSPEC */
'30471' = 661 /* OPIOID/OTHER DEP-CONTIN */
'30472' = 661 /* OPIOID/OTHER DEP-EPISOD */
'30473' = 661 /* OPIOID/OTHER DEP-REMISS */
'30480' = 661 /* COMB DRUG DEP NEC-UNSPEC */
'30481' = 661 /* COMB DRUG DEP NEC-CONTIN */
'30482' = 661 /* COMB DRUG DEP NEC-EPISOD */
'30483' = 661 /* COMB DRUG DEP NEC-REMISS */
'30490' = 661 /* DRUG DEPEND NOS-UNSPEC */
'30491' = 661 /* DRUG DEPEND NOS-CONTIN */
'30492' = 661 /* DRUG DEPEND NOS-EPISODIC */
'30493' = 661 /* DRUG DEPEND NOS-REMISS */
'30520' = 661 /* CANNABIS ABUSE-UNSPEC */
'30521' = 661 /* CANNABIS ABUSE-CONTIN */
'30522' = 661 /* CANNABIS ABUSE-EPISODIC */
'30523' = 661 /* CANNABIS ABUSE-IN REMISS */
'30530' = 661 /* HALLUCINOG ABUSE-UNSPEC */
'30531' = 661 /* HALLUCINOG ABUSE-CONTIN */
'30532' = 661 /* HALLUCINOG ABUSE-EPISOD */
'30533' = 661 /* HALLUCINOG ABUSE-REMISS */
'30540' = 661 /* BARBITURATE ABUSE-UNSPEC */
'30541' = 661 /* BARBITURATE ABUSE-CONTIN */
'30542' = 661 /* BARBITURATE ABUSE-EPISOD */
'30543' = 661 /* BARBITURATE ABUSE-REMISS */
'30550' = 661 /* OPIOID ABUSE-UNSPEC */
'30551' = 661 /* OPIOID ABUSE-CONTINUOUS */
'30552' = 661 /* OPIOID ABUSE-EPISODIC */
'30553' = 661 /* OPIOID ABUSE-IN REMISS */
'30560' = 661 /* COCAINE ABUSE-UNSPEC */
'30561' = 661 /* COCAINE ABUSE-CONTINUOUS */
'30562' = 661 /* COCAINE ABUSE-EPISODIC */
'30563' = 661 /* COCAINE ABUSE-IN REMISS */
'30570' = 661 /* AMPHETAMINE ABUSE-UNSPEC */
'30571' = 661 /* AMPHETAMINE ABUSE-CONTIN */
'30572' = 661 /* AMPHETAMINE ABUSE-EPISOD */
'30573' = 661 /* AMPHETAMINE ABUSE-REMISS */
'30580' = 661 /* ANTIDEPRESS ABUSE-UNSPEC */
'30581' = 661 /* ANTIDEPRESS ABUSE-CONTIN */
'30582' = 661 /* ANTIDEPRESS ABUSE-EPISOD */
'30583' = 661 /* ANTIDEPRESS ABUSE-REMISS */
'30590' = 661 /* DRUG ABUSE NEC-UNSPEC */
'30591' = 661 /* DRUG ABUSE NEC-CONTIN */
'30592' = 661 /* DRUG ABUSE NEC-EPISODIC */
'30593' = 661 /* DRUG ABUSE NEC-IN REMISS */
'3070 ' = 654 /* STAMMERING & STUTTERING */
'3079 ' = 654 /* SPECIAL SYMPTOM NECNOS */
'31500' = 654 /* READING DISORDER NOS */
'31501' = 654 /* ALEXIA */
'31502' = 654 /* DEVELOPMENTAL DYSLEXIA */
'31509' = 654 /* READING DISORDER NEC */
'3151 ' = 654 /* ARITHMETICAL DISORDER */
'3152 ' = 654 /* OTH LEARNING DIFFICULTY */
'31531' = 654 /* DEVELOPMENT LANGUAGE DIS */
'31532' = 654 /* RECEPTIVE LANG DIS OCT96-- */
'31534' = 654 /* SPEECH DEL D/T HEAR LOSS  */
'31535' = 654 /* CHLDHD ONSET FLNCY DISOR */
'31539' = 654 /* SPEECHLANGUAGE DIS NEC */
'3154 ' = 654 /* COORDINATION DISORDER */
'3155 ' = 654 /* MIXED DEVELOPMENT DIS */
'3158 ' = 654 /* DEVELOPMENT DELAYS NEC */
'3159 ' = 654 /* DEVELOPMENT DELAY NOS */
'317  ' = 654 /* MILD MENTAL RETARDATION */
'3180 ' = 654 /* MOD MENTAL RETARDATION */
'3181 ' = 654 /* SEVERE MENTAL RETARDAT */
'3182 ' = 654 /* PROFOUND MENTAL RETARDAT */
'319  ' = 654 /* MENTAL RETARDATION NOS- */
'325  ' = 95 /* PHLEBITIS INTRCRAN SINUS */
'32702' = 95 /*	INSOMNIA DT MENTAL DISOR */
'32715' = 95 /*	HYPERSOM DT MENTAL DISOR */
'32730' = 95 /*	CIRCADIAN RHYM SLEEP NOS */
'32731' = 95 /*	CIRCADIAN RHY-DELAY SLP */
'32732' = 95 /*	CIRCADIAN RHY-ADVC SLEEP */
'32733' = 95 /*	CIRCADIAN RHYM-IRREG SLP */
'32734' = 95 /*	CIRCADIAN RHYM-FREE RUN */
'32735' = 95 /*	CIRCADIAN RHYTHM-JETLAG */
'32736' = 95 /*	CIRCADIAN RHY-SHIFT WORK */
'32737' = 95 /*	CIRCADIAN RHYM OTH DIS */
'32739' = 95 /*	CIRCADIAN RHYM SLEEP NEC */
'32752' = 211 /* SLEEP RELATED LEG CRAMPS */
'32753' = 95 /*	SLEEP RELATED BRUXISM */
'3300 ' = 81 /* LEUKODYSTROPHY */
'3301 ' = 81 /* CEREBRAL LIPIDOSES */
'3302 ' = 81 /* CEREB DEGEN IN LIPIDOSIS */
'3303 ' = 81 /* CERB DEG CHLD IN OTH DIS */
'3308 ' = 81 /* CEREB DEGEN IN CHILD NEC */
'3309 ' = 81 /* CEREB DEGEN IN CHILD NOS */
'3313 ' = 81 /* COMMUNICAT HYDROCEPHALUS */
'3314 ' = 81 /* OBSTRUCTIV HYDROCEPHALUS */
'3315 ' = 81 /*  NORML PRESSURE HYDROCEPH */
'3316'	 = 81	/* Corticobasal degneration (Begin 2011)*/
'3317 ' = 81 /* CEREB DEGEN IN OTH DIS */
'33181' = 81 /* REYE-S SYNDROME */
'33183' = 95 /*	MILD COGNITIVE IMPAIREMT */
'33189' = 81 /* CEREB DEGENERATION NEC */
'3319 ' = 81 /* CEREB DEGENERATION NOS */
'3321 ' = 95 /* SECONDARY PARKINSONISM */
'3330 ' = 81 /* DEGEN BASAL GANGLIA NEC */
'3331 ' = 81 /* TREMOR NEC */
'3332 ' = 81 /* MYOCLONUS */
'3333 ' = 81 /* TICS OF ORGANIC ORIGIN */
'3334 ' = 81 /* HUNTINGTON-S CHOREA */
'3335 ' = 81 /* CHOREA NEC */
'3336 ' = 81 /* IDIOPAT TORSION DYSTONIA */
'3337 ' = 81 /* SYMPTOM TORSION DYSTONIA */
'33371' = 81 /* ATHETOID CEREBRAL PALSY */
'33372' = 81 /* ACUTE DYSTONIA D/T DRUGS */
'33379' = 81 /* ACQ TORSION DYSTONIA NEC */
'33381' = 81 /* BLEPHAROSPASM */
'33382' = 81 /* OROFACIAL DYSKINESIA */
'33383' = 81 /* SPASMODIC TORTICOLLIS */
'33384' = 81 /* ORGANIC WRITERS CRAMP */
'33385' = 81 /* SUBAC DYSKINESA D/T DRUG */
'33389' = 81 /* FRAGM TORSION DYSTON NEC */
'33390' = 81 /* EXTRAPYRAMIDAL DIS NOS */
'33391' = 81 /* STIFF-MAN SYNDROME */
'33392' = 81 /* NEUROLEPTIC MALIGNANT SYND OCT94 */
'33393' = 81 /* BENIGN SHUDDERING ATTACKS OCT94 */
'33394' = 81 /* RESTLESS LEGS SYNDROME */
'33399' = 81 /* EXTRAPYRAMIDAL DIS NEC */
'3340 ' = 81 /* FRIEDREICH-S ATAXIA */
'3341 ' = 81 /* HERED SPASTIC PARAPLEGIA */
'3342 ' = 81 /* PRIMARY CEREBELLAR DEGEN */
'3343 ' = 81 /* CEREBELLAR ATAXIA NEC */
'3344 ' = 81 /* CEREBEL ATAX IN OTH DIS */
'3348 ' = 81 /* SPINOCEREBELLAR DIS NEC */
'3349 ' = 81 /* SPINOCEREBELLAR DIS NOS */
'3350 ' = 81 /* WERDNIG-HOFFMANN DISEASE */
'33510' = 81 /* SPINAL MUSCL ATROPHY NOS */
'33511' = 81 /* KUGELBERG-WELANDER DIS */
'33519' = 81 /* SPINAL MUSCL ATROPHY NEC */
'33520' = 81 /* AMYOTROPHIC SCLEROSIS */
'33521' = 81 /* PROG MUSCULAR ATROPHY */
'33522' = 81 /* PROGRESSIVE BULBAR PALSY */
'33523' = 81 /* PSEUDOBULBAR PALSY */
'33524' = 81 /* PRIM LATERAL SCLEROSIS */
'33529' = 81 /* MOTOR NEURON DISEASE NEC */
'3358 ' = 81 /* ANT HORN CELL DIS NEC */
'3359 ' = 81 /* ANT HORN CELL DIS NOS */
'3360 ' = 81 /* SYRINGOMYELIA */
'3361 ' = 81 /* VASCULAR MYELOPATHIES */
'3362 ' = 81 /* COMB DEG CORD IN OTH DIS */
'3363 ' = 81 /* MYELOPATHY IN OTH DIS */
'3368 ' = 81 /* MYELOPATHY NEC */
'3369 ' = 81 /* SPINAL CORD DISEASE NOS */
'3370 ' = 81 /* IDIOPATH AUTO NEUROPATHY */
'3371 ' = 81 /* AUT NEUROPTHY IN OTH DIS */
'33700' =	81	/*	IDIO PERPH AUTO NEUR NOS */
'33701' =	81	/*	CAROTID SINUS SYNDROME */
'33709' =	81	/*	IDIO PERPH AUTO NEUR NEC */
'33720' = 95 /* REFLEX SYMPATH DYSTROPHY UNSPEC OCT93 */
'33721' = 95 /* REFLEX SYMPATH DYSTROPHY UP LIMB OCT93 */
'33722' = 95 /* REFLEX SYMPATH DYSTROPHY LO LIMB OCT93 */
'33729' = 95 /* REFLEX SYMPATH DYSTR OTH SPEC SITE OCT93 */
'3373 ' = 81 /* AUTONOMIC DYSREFLEXIA OCT98 */
'3379 ' = 81 /* AUTONOMIC NERVE DIS NEC */
'3380 ' = 95 /* CENTRAL PAIN SYNDROME */
'33811' = 95 /* ACUTE PAIN DUE TO TRAUMA */
'33812' = 95 /* ACUTE POST-THORACOT PAIN */
'33818' = 95 /* ACUTE POSTOP PAIN NEC */
'33819' = 95 /* ACUTE PAIN NEC */
'33821' = 95 /* CHRONC PAIN D/T TRAUMA */
'33822' = 95 /* CHRON POST-THORACOT PAIN */
'33828' = 95 /* CHRONIC POSTOP PAIN NEC */
'33829' = 95 /* CHRONIC PAIN NEC */
'3383 ' = 95 /* NEOPLASM RELATED PAIN */
'3384 ' = 95 /* CHRONIC PAIN SYNDROME */
'3410 ' = 95 /* NEUROMYELITIS OPTICA */
'3411 ' = 95 /* SCHILDER-s DISEASE */
'3418 ' = 95 /* CNS DEMYELINATION NEC */
'3419 ' = 95 /* CNS DEMYELINATION NOS */
'3420 ' = 82 /* FLACCID HEMIPLEGIA */
'34200' = 82 /* FLACCID HEMIPLEG- UNSPEC SIDE OCT94 */
'34201' = 82 /* FLACCID HEMIPLEG- DOMINANT SIDE OCT94 */
'34202' = 82 /* FLACCID HEMIPLEG- NONDOMINANT SIDE OCT94 */
'3421 ' = 82 /* SPASTIC HEMIPLEGIA */
'34210' = 82 /* SPASTIC HEMIPLEG- UNSPEC SIDE OCT94 */
'34211' = 82 /* SPASTIC HEMIPLEG- DOMINANT SIDE OCT94 */
'34212' = 82 /* SPASTIC HEMIPLEG- NONDOMINANT SIDE OCT94 */
'34280' = 82 /* OTH SPEC HEMIPLEGIA- UNSPEC SIDE OCT94 */
'34281' = 82 /* OTH SPEC HEMIPLEGIA- DOMINANT SIDE OCT94 */
'34282' = 82 /* OTH SPEC HEMIPLEGIA- NONDOMINANT SIDE OCT94 */
'3429 ' = 82 /* HEMIPLEGIA NOS */
'34290' = 82 /* UNSPEC HEMIPLEGIA- UNSPEC SIDE OCT94 */
'34291' = 82 /* UNSPEC HEMIPLEGIA- DOMINANT SIDE OCT94 */
'34292' = 82 /* UNSPEC HEMIPLEGIA- NONDOMINANT SIDE OCT94 */
'3430 ' = 82 /* CONGENITAL DIPLEGIA */
'3431 ' = 82 /* CONGENITAL HEMIPLEGIA */
'3432 ' = 82 /* CONGENITAL QUADRIPLEGIA */
'3433 ' = 82 /* CONGENITAL MONOPLEGIA */
'3434 ' = 82 /* INFANTILE HEMIPLEGIA */
'3438 ' = 82 /* CEREBRAL PALSY NEC */
'3439 ' = 82 /* CEREBRAL PALSY NOS */
'3440 ' = 82 /* QUADRIPLEGIA NOS */
'34400' = 82 /* QUADRIPLEGIA- NOS OCT94 */
'34401' = 82 /* QUADRIPLEGIA- C1-C4 COMPLETE OCT94 */
'34402' = 82 /* QUADRIPLEGIA- C1-C4 INCOMPLETE OCT94 */
'34403' = 82 /* QUADRIPLEGIA- C5-C7 COMPLETE OCT94 */
'34404' = 82 /* QUADRIPLEGIA- C5-C7 INCOMPLETE OCT94 */
'34409' = 82 /* QUADRIPLEGIA- OTHER OCT94 */
'3441 ' = 82 /* PARAPLEGIA NOS */
'3442 ' = 82 /* DIPLEGIA OF UPPER LIMBS */
'3443 ' = 82 /* MONOPLEGIA OF LOWER LIMB */
'34430' = 82 /* MONOPLEGIA LEG NOS OCT94 */
'34431' = 82 /* MONOPLEGIA LEG AFFECT DOM SIDE OCT94 */
'34432' = 82 /* MONOPLEGIA LEG AFFECT NONDOM SIDE OCT94 */
'3444 ' = 82 /* MONOPLEGIA OF UPPER LIMB */
'34440' = 82 /* MONOPLEGIA ARM NOS OCT94 */
'34441' = 82 /* MONOPLEGIA ARM AFFECT DOM SIDE OCT94 */
'34442' = 82 /* MONOPLEGIA ARM AFFECT NONDOM SIDE OCT94 */
'3445 ' = 82 /* MONOPLEGIA NOS */
'34460' = 82 /* CAUDA EQUINA SYND NOS */
'34461' = 95 /* NEUROGENIC BLADDER */
'3448 ' = 82 /* PARALYTIC SYNDROMES NEC */
'34481' = 82 /* LOCKED-IN STATE OCT93 */
'34489' = 82 /* OTH SPEC PARALYTIC SYNDROMES OCT93 */
'3449 ' = 82 /* PARALYSIS NOS */
'3450 ' = 83 /* GEN NONCONVULS EPILEPSY J80  S89 */
'34500' = 83 /* GEN NONCV EP W/O INTR EP  OCT89 */
'34501' = 83 /* GEN NONCONV EP W INTR EP  OCT89 */
'3451 ' = 83 /* GEN CONVULSIVE EPILEPSY J80  S89 */
'34510' = 83 /* GEN CNV EPIL W/O INTR EP  OCT89 */
'34511' = 83 /* GEN CNV EPIL W INTR EPIL  OCT89 */
'3452 ' = 83 /* PETIT MAL STATUS */
'3453 ' = 83 /* GRAND MAL STATUS */
'3454 ' = 83 /* PSYCHOMOTOR EPILEPSY   J80  S89 */
'34540' = 83 /* PSYMOTR EPIL W/O INT EPI OCT89 */
'34541' = 83 /* PSYMOTR EPIL W INTR EPIL OCT89 */
'3455 ' = 83 /* PARTIAL EPILEPSY NEC   J80  S89 */
'34550' = 83 /* PART EPIL W/O INTR EPIL  OCT89 */
'34551' = 83 /* PART EPIL W INTR EPIL  OCT89 */
'3456 ' = 83 /* INFANTILE SPASMS   J80  S89 */
'34560' = 83 /* INF SPASM W/O INTR EPIL  OCT89 */
'34561' = 83 /* INF SPASM W INTRACT EPIL OCT89 */
'3457 ' = 83 /* EPILEPS PARTIAL CONTINUA  J80  S89 */
'34570' = 83 /* EPIL PAR CONT W/O INT EP OCT89 */
'34571' = 83 /* EPIL PAR CONT W INTR EPI OCT89 */
'3458 ' = 83 /* EPILEPSY NEC     J80  S89 */
'34580' = 83 /* EPILEP NEC W/O INTR EPIL OCT89 */
'34581' = 83 /* EPILEPSY NEC W INTR EPIL OCT89 */
'3459 ' = 83 /* EPILEPSY NOS     J80  S89 */
'34590' = 83 /* EPILEP NOS W/O INTR EPIL OCT89 */
'34591' = 83 /* EPILEPSY NOS W INTR EPIL OCT89 */
'347  ' = 95 /* CATAPLEXY AND NARCOLEPSY */
'34700' = 95 /* NARCOLEPSY W/O CATAPLEXY */
'34701' = 95 /* NARCOLEPSY W CATAPLEXY */
'34710' = 95 /* NARCLPSY W/O CAT OTH DIS */
'34711' = 95 /* NARCOLEPSY W CAT OTH DIS */
'3480 ' = 95 /* CEREBRAL CYSTS */
'3481 ' = 85 /* ANOXIC BRAIN DAMAGE */
'3482 ' = 95 /* PSEUDOTUMOR CEREBRI */
'3483 ' = 95 /* ENCEPHALOPATHY NOS */
'34830' = 95 /* Encephalopathy- unspecified */
'34831' = 95 /* Metabolic encephalopathy */
'34839' = 95 /* Other encephalopathy */
'3484 ' = 95 /* COMPRESSION OF BRAIN */
'3485 ' = 95 /* CEREBRAL EDEMA */
'3488 ' = 95 /* BRAIN CONDITIONS NEC */
'34881' = 95 /* TEMPORAL SCLEROSIS */
'34882'	 = 95	/* Brain death (Begin 2011)     	*/
'34889' = 95 /* BRAIN CONDITIONS NEC */
'3489 ' = 95 /* BRAIN CONDITION NOS */
'3492 ' = 95 /* DISORDER OF MENINGES NEC */
'34939' = 227 /* DURAL TEAR NEC */
'34981' = 95 /* CEREBROSPINAL RHINORRHEA */
'34982' = 95 /* TOXIC ENCEPHALOPATHY */
'34989' = 95 /* CNS DISORDER NEC */
'3499 ' = 95 /* CNS DISORDER NOS */
'3501 ' = 95 /* TRIGEMINAL NEURALGIA */
'3502 ' = 95 /* ATYPICAL FACE PAIN */
'3508 ' = 95 /* TRIGEMINAL NERVE DIS NEC */
'3509 ' = 95 /* TRIGEMINAL NERVE DIS NOS */
'3510 ' = 95 /* BELL-s PALSY */
'3511 ' = 95 /* GENICULATE GANGLIONITIS */
'3518 ' = 95 /* FACIAL NERVE DIS NEC */
'3519 ' = 95 /* FACIAL NERVE DIS NOS */
'3520 ' = 95 /* OLFACTORY NERVE DISORDER */
'3521 ' = 95 /* GLOSSOPHARYNG NEURALGIA */
'3522 ' = 95 /* GLOSSOPHAR NERVE DIS NEC */
'3523 ' = 95 /* PNEUMOGASTRIC NERVE DIS */
'3524 ' = 95 /* ACCESSORY NERVE DISORDER */
'3525 ' = 95 /* HYPOGLOSSAL NERVE DIS */
'3526 ' = 95 /* MULT CRANIAL NERVE PALSY */
'3529 ' = 95 /* CRANIAL NERVE DIS NOS */
'3530 ' = 95 /* BRACHIAL PLEXUS LESIONS */
'3531 ' = 95 /* LUMBOSACRAL PLEX LESION */
'3532 ' = 95 /* CERVICAL ROOT LESION NEC */
'3533 ' = 95 /* THORACIC ROOT LESION NEC */
'3534 ' = 95 /* LUMBSACRAL ROOT LES NEC */
'3535 ' = 95 /* NEURALGIC AMYOTROPHY */
'3536 ' = 95 /* PHANTOM LIMB (SYNDROME) */
'3538 ' = 95 /* NERV ROOT/PLEXUS DIS NEC */
'3539 ' = 95 /* NERV ROOT/PLEXUS DIS NOS */
'3540 ' = 95 /* CARPAL TUNNEL SYNDROME */
'3541 ' = 95 /* MEDIAN NERVE LESION NEC */
'3542 ' = 95 /* ULNAR NERVE LESION */
'3543 ' = 95 /* RADIAL NERVE LESION */
'3544 ' = 95 /* CAUSALGIA */
'3545 ' = 95 /* MONONEURITIS MULTIPLEX */
'3548 ' = 95 /* MONONEURITIS ARM NEC */
'3549 ' = 95 /* MONONEURITIS ARM NOS */
'3550 ' = 95 /* SCIATIC NERVE LESION */
'3551 ' = 95 /* MERALGIA PARESTHETICA */
'3552 ' = 95 /* FEMORAL NERVE LESION NEC */
'3553 ' = 95 /* LAT POPLITEAL NERVE LES */
'3554 ' = 95 /* MED POPLITEAL NERVE LES */
'3555 ' = 95 /* TARSAL TUNNEL SYNDROME */
'3556 ' = 95 /* PLANTAR NERVE LESION */
'3557 ' = 95 /* MONONEURITIS LEG NEC */
'35571' = 95 /* CAUSALGIA OF LOWER LIMB OCT93 */
'35579' = 95 /* OTH MONONEURITIS OF LOWER LIMB OCT93 */
'3558 ' = 95 /* MONONEURITIS LEG NOS */
'3559 ' = 95 /* MONONEURITIS NOS */
'3560 ' = 95 /* HERED PERIPH NEUROPATHY */
'3561 ' = 95 /* PERONEAL MUSCLE ATROPHY */
'3562 ' = 95 /* HERED SENSORY NEUROPATHY */
'3563 ' = 95 /* REFSUM-s DISEASE */
'3564 ' = 95 /* IDIO PROG POLYNEUROPATHY */
'3568 ' = 95 /* IDIO PERIPH NEURPTHY NEC */
'3569 ' = 95 /* IDIO PERIPH NEURPTHY NOS */
'3570 ' = 95 /* AC INFECT POLYNEURITIS */
'3571 ' = 95 /* NEURPTHY IN COL VASC DIS */
'3572 ' = 95 /* NEUROPATHY IN DIABETES */
'3573 ' = 95 /* NEUROPATHY IN MALIG DIS */
'3574 ' = 95 /* NEUROPATHY IN OTHER DIS */
'3575 ' = 95 /* ALCOHOLIC POLYNEUROPATHY */
'3576 ' = 95 /* NEUROPATHY DUE TO DRUGS */
'3577 ' = 95 /* NEURPTHY TOXIC AGENT NEC */
'3578 ' = 95 /* INFLAM/TOX NEUROPTHY NEC */
'35781' = 95 /* CHRONIC INFLAMM DEMYELINATING PLYNEUR OCT02 */
'35782' = 95 /* CRITICAL ILLNESS POLYNEUROPATHY   OCT02 */
'35789' = 95 /* OTHER INFLAMMATORY AND TOX NEUROPATHY OCT02 */
'3579 ' = 95 /* INFLAM/TOX NEUROPTHY NOS */
'3580 ' = 95 /* MYASTHENIA GRAVIS */
'35800' = 95 /* Myasthenia gravis without (acute) exacerbatio */
'35801' = 95 /* Myasthenia gravis with (acute) exacerbation */
'3581 ' = 95 /* MYASTHENIA IN OTH DIS */
'3582 ' = 95 /* TOXIC MYONEURAL DISORDER */
'35830'	 = 95	/* Lambert-Eaton synd NOS (Begin 2011)  */
'35831'	 = 95	/* Lambert-Eaton synd neopl (Begin 2011)*/ 
'35839'	 = 95	/* Lambert-Eaton syn ot dis (Begin 2011)*/ 
'3588 ' = 95 /* MYONEURAL DISORDERS NEC */
'3589 ' = 95 /* MYONEURAL DISORDERS NOS */
'3590 ' = 95 /* CONG HERED MUSC DYSTRPHY */
'3591 ' = 95 /* HERED PROG MUSC DYSTRPHY */
'3592 ' = 95 /* MYOTONIC DISORDERS */
'35921' =	95	/*	MYOTONIC MUSCLR DYSTRPHY */
'35922' =	95	/*	MYOTONIA CONGENITA */
'35923' =	95	/*	MYOTONIC CHONDRODYSTRPHY */
'35924' =	95	/*	DRUG INDUCED MYOTONIA */
'35929' =	95	/*	MYOTONIC DISORDER NEC */
'35971' =	95	/*	INCLUSION BODY MYOSITIS */
'35979' =	95	/*	INFLM/IMMUNE MYOPATH NEC */
'3593 ' = 95 /* FAMIL PERIODIC PARALYSIS */
'3594 ' = 95 /* TOXIC MYOPATHY */
'3595 ' = 95 /* MYOPATHY IN ENDOCRIN DIS */
'3596 ' = 95 /* INFL MYOPATHY IN OTH DIS */
'3598 ' = 95 /* MYOPATHY NEC */
'35981' = 95 /* CRITICAL ILLNESS MYOPATHY    OCT02 */
'35989' = 95 /* OTHER MYOPATHIES       OCT02 */
'3599 ' = 95 /* MYOPATHY NOS */
'3940 ' = 96 /* MITRAL STENOSIS */
'3941 ' = 96 /* RHEUMATIC MITRAL INSUFF */
'3942 ' = 96 /* MITRAL STENOSIS W INSUFF */
'3949 ' = 96 /* MITRAL VALVE DIS NEC/NOS */
'3950 ' = 96 /* RHEUMAT AORTIC STENOSIS */
'3951 ' = 96 /* RHEUMATIC AORTIC INSUFF */
'3952 ' = 96 /* RHEUM AORTIC STEN/INSUFF */
'3959 ' = 96 /* RHEUM AORTIC DIS NEC/NOS */
'3960 ' = 96 /* MITRAL/AORTIC STENOSIS */
'3961 ' = 96 /* MITRAL STENOS/AORT INSUF */
'3962 ' = 96 /* MITRAL INSUF/AORT STENOS */
'3963 ' = 96 /* MITRAL/AORTIC VAL INSUFF */
'3968 ' = 96 /* MITR/AORTIC MULT INVOLV */
'3969 ' = 96 /* MITRAL/AORTIC V DIS NOS */
'3970 ' = 96 /* TRICUSPID VALVE DISEASE */
'3971 ' = 96 /* RHEUM PULMON VALVE DIS */
'3979 ' = 96 /* RHEUM ENDOCARDITIS NOS */
'39891' = 108 /* RHEUMATIC HEART FAILURE */
'4041 ' = 224 /* INFANT BOTULISM */
'4011 ' = 98 /* BENIGN HYPERTENSION */
'4019 ' = 98 /* HYPERTENSION NOS */
'4150 ' = 103 /* ACUTE COR PULMONALE */
'4151 ' = 103 /* PULMON EMBOLISM/INFARCT */
'41512' = 103 /*	SEPTIC PULMONARY EMBOLSM */
'41513'	 = 103	/* Saddle embol pulmon art (Begin 2011)	*/
'41519' = 103 /* OTHER PULMON EMBOL INFARCT OCT95 */
'4160 ' = 103 /* PRIM PULM HYPERTENSION */
'4161 ' = 103 /* KYPHOSCOLIOTIC HEART DIS */
'4162 ' = 103 /*	CHR PULMONARY EMBOLISM */
'4168 ' = 103 /* CHR PULMON HEART DIS NEC */
'4169 ' = 103 /* CHR PULMON HEART DIS NOS */
'4170 ' = 103 /* ARTERIOVEN FISTU PUL VES */
'4171 ' = 103 /* PULMON ARTERY ANEURYSM */
'4178 ' = 103 /* PULMON CIRCULAT DIS NEC */
'4179 ' = 103 /* PULMON CIRCULAT DIS NOS */
'4240 ' = 96 /* MITRAL VALVE DISORDER */
'4241 ' = 96 /* AORTIC VALVE DISORDER */
'4242 ' = 96 /* NONRHEUM TRICUSP VAL DIS */
'4243 ' = 96 /* PULMONARY VALVE DISORDER */
'42490' = 96 /* ENDOCARDITIS NOS */
'42491' = 96 /* ENDOCARDITIS IN OTH DIS */
'42499' = 96 /* ENDOCARDITIS NEC */
'4254 ' = 108 /* PRIM CARDIOMYOPATHY NEC */
'4260 ' = 105 /* ATRIOVENT BLOCK COMPLETE */
'42610' = 105 /* ATRIOVENT BLOCK NOS */
'42611' = 105 /* ATRIOVENT BLOCK-1ST DEGR */
'42612' = 105 /* ATRIOVEN BLOCK-MOBITZ II */
'42613' = 105 /* AV BLOCK-2ND DEGREE NEC */
'4262 ' = 105 /* LEFT BB HEMIBLOCK */
'4263 ' = 105 /* LEFT BB BLOCK NEC */
'4264 ' = 105 /* RT BUNDLE BRANCH BLOCK */
'42650' = 105 /* BUNDLE BRANCH BLOCK NOS */
'42651' = 105 /* RT BBB/LFT POST FASC BLK */
'42652' = 105 /* RT BBB/LFT ANT FASC BLK */
'42653' = 105 /* BILAT BB BLOCK NEC */
'42654' = 105 /* TRIFASCICULAR BLOCK */
'4266 ' = 105 /* OTHER HEART BLOCK */
'4267 ' = 105 /* ANOMALOUS AV EXCITATION */
'42681' = 105 /* LOWN-GANONG-LEVINE SYND */
'42682' = 105 /*	LONG QT SYNDROME */
'42689' = 105 /* CONDUCTION DISORDER NEC */
'4269 ' = 105 /* CONDUCTION DISORDER NOS */
'4270 ' = 106 /* PAROX ATRIAL TACHYCARDIA */
'4271 ' = 106 /* PAROX VENTRIC TACHYCARD */
'4272 ' = 106 /* PAROX TACHYCARDIA NOS */
'42731' = 106 /* ATRIAL FIBRILLATION */
'42732' = 106 /* ATRIAL FLUTTER */
'42760' = 106 /* PREMATURE BEATS NOS */
'42761' = 106 /* ATRIAL PREMATURE BEATS */
'42769' = 106 /* PREMATURE BEATS NEC */
'42781' = 106 /* SINOATRIAL NODE DYSFUNCT */
'42789' = 106 /* CARDIAC DYSRHYTHMIAS NEC */
'4279 ' = 106 /* CARDIAC DYSRHYTHMIA NOS */
'4280 ' = 108 /* CONGESTIVE HEART FAILURE */
'4281 ' = 108 /* LEFT HEART FAILURE */
'42820' = 108 /* UNSPECIFIED SYSTOLIC HEART FAILURE OCT02 */
'42821' = 108 /* ACUTE SYSTOLIC HEART FAILURE OCT02 */
'42822' = 108 /* CHRONIC SYSTOLIC HEART FAILURE   OCT02 */
'42823' = 108 /* ACUTE ON CHRONIC SYSTOLIC HEART FAILR OCT02 */
'42830' = 108 /* UNSPECIFIED DIASTOLIC HEART FAILURE  OCT02 */
'42831' = 108 /* ACUTE DIASTOLIC HEART FAILURE    OCT02 */
'42832' = 108 /* CHRONIC DIASTOLIC HEART FAILURE  OCT02 */
'42833' = 108 /* ACUTE ON CHRONIC DIASTOLIC HEART FAILR OCT0 */
'42840' = 108 /* UNSPEC CMBINED SYST & DIAS HEART FAILR OCT0 */
'42841' = 108 /* ACUTE CMBINED SYST & DIAS HEART FAILR  OCT0 */
'42842' = 108 /* CHRON CMBINED SYST & DIAS HEART FAILR  OCT0 */
'42843' = 108 /* ACU CHRO COMBI SYST & DIAS HRT FAILR OCT0 */
'4289 ' = 108 /* HEART FAILURE NOS */
'4561 ' = 138 /* ESOPH VARICES W/O BLEED */
'45621' = 138 /* ESOPH VARICE OTH DIS NOS */
'51181' =  42 /*	MALIGNANT PLEURAL EFFUSN */
'5131 ' = 133 /* ABSCESS OF MEDIASTINUM */
'514  ' = 133 /* PULM CONGEST/HYPOSTASIS */
'515  ' = 133 /* POSTINFLAM PULM FIBROSIS */
'5160 ' = 133 /* PUL ALVEOLAR PROTEINOSIS */
'5161 ' = 133 /* IDIO PULM HEMOSIDEROSIS */
'5162 ' = 133 /* PULM ALVEOLAR MICROLITH */
'5163 ' = 133 /* IDIO FIBROS ALVEOLITIS */
'51630'	 = 133	/* Idiopath inters pneu NOS (Begin 2011)*/
'51631'	 = 133	/* Idiopath pulmon fibrosis (Begin 2011)*/
'51632'	 = 133	/* Idio non-spec inter pneu (Begin 2011)*/
'51633'	 = 133	/* Acute interstitial pneum (Begin 2011)*/
'51634'	 = 133	/* Resp brncio interst lung (Begin 2011)*/
'51635'	 = 133	/* Idiopth lym interst pneu (Begin 2011)*/
'51636'	 = 133	/* Cryptogenic organiz pneu (Begin 2011)*/
'51637'	 = 133	/* Desquamatv interst pneu (Begin 2011)	*/
'5164'	 = 133	/* Lymphangioleiomyomatosis (Begin 2011)*/
'5165'	 = 133	/* Adlt pul Langs cell hist (Begin 2011)*/
'51661'	 = 133	/* Neuroend cell hyprpl inf (Begin 2011)*/
'51662'	 = 133	/* Pulm interstitl glycogen (Begin 2011)*/
'51663'	 = 133	/* Surfactant mutation lung (Begin 2011)*/
'51664'	 = 133	/* Alv cap dysp w vn misaln (Begin 2011)*/
'51669'	 = 133	/* Oth intrst lung dis chld (Begin 2011)*/
'5168 ' = 133 /* ALVEOL PNEUMONOPATHY NEC */
'5169 ' = 133 /* ALVEOL PNEUMONOPATHY NOS */
'5172 ' = 133 /* SYST SCLEROSIS LUNG DIS */
'5178 ' = 133 /* LUNG INVOLV IN OTH DIS */
'5183 ' = 133 /* PULMONARY EOSINOPHILIA */
'5184 ' = 133 /* ACUTE LUNG EDEMA NOS */
'51889' = 133 /* OTHER LUNG DISEASE NEC */
'5194 ' = 133 /* DISORDERS OF DIAPHRAGM */
'5198 ' = 133 /* RESP SYSTEM DISEASE NEC */
'5199 ' = 133 /* RESP SYSTEM DISEASE NOS */
'5300 ' = 138 /* ACHALASIA & CARDIOSPASM */
'5301 ' = 138 /* ESOPHAGITIS */
'53010' = 138 /* ESOPHAGITIS UNSPEC OCT93 */
'53011' = 138 /* REFLUX ESOPHAGITIS OCT93 */
'53012' = 138 /* ACUTE ESOPHAGITIS OCT01 */
'53013' = 138 /*	EOSINOPHILIC ESOPHAGITIS */
'53019' = 138 /* OTH ESOPHAGITIS OCT93 */
'5302 ' = 138 /* ULCER OF ESOPHAGUS */
'53020' = 138 /* Ulcer of esophagus without bleeding */
'53021' = 138 /* Ulcer of esophagus with bleeding */
'5303 ' = 138 /* ESOPHAGEAL STRICTURE */
'5304 ' = 138 /* PERFORATION OF ESOPHAGUS */
'5305 ' = 138 /* DYSKINESIA OF ESOPHAGUS */
'5306 ' = 138 /* ACQ ESOPHAG DIVERTICULUM */
'5308 ' = 138 /* ESOPHAGEAL DISORDER NEC */
'53081' = 138 /* ESOPHAGEAL REFLUX OCT93 */
'53083' = 138 /* ESOPHAGEAL LEUKOPLAKIA OCT93 */
'53084' = 138 /* TRACHEOESOPHAGEAL FISTULA OCT93 */
'53085' = 138 /* Barretts esophagus */
'53089' = 138 /* OTH SPEC DISORDER ESOPHAGUS OCT93 */
'5309 ' = 138 /* ESOPHAGEAL DISORDER NOS */
'56731' = 211 /* PSOAS MUSCLE ABSCESS */
'570  ' = 151 /* ACUTE NECROSIS OF LIVER */
'57140' = 6 /* CHRONIC HEPATITIS NOS */
'57141' = 6 /* CHR PERSISTENT HEPATITIS */
'57142' = 6	/*  AUTOIMMUNE HEPATITIS */
'57149' = 6 /* CHRONIC HEPATITIS NEC */
'5715 ' = 151 /* CIRRHOSIS OF LIVER NOS */
'5716 ' = 151 /* BILIARY CIRRHOSIS */
'5718 ' = 151 /* CHRONIC LIVER DIS NEC */
'5719 ' = 151 /* CHRONIC LIVER DIS NOS */
'5720 ' = 151 /* ABSCESS OF LIVER */
'5721 ' = 151 /* PORTAL PYEMIA */
'5722 ' = 151 /* HEPATIC COMA */
'5723 ' = 151 /* PORTAL HYPERTENSION */
'5724 ' = 151 /* HEPATORENAL SYNDROME */
'5728 ' = 151 /* OTH SEQUELA- CHR LIV DIS */
'5730 ' = 151 /* CHR PASSIV CONGEST LIVER */
'5731 ' = 6 /* HEPATITIS IN VIRAL DIS */
'5732 ' = 6 /* HEPATITIS IN OTH INF DIS */
'5733 ' = 6 /* HEPATITIS NOS */
'5734 ' = 151 /* HEPATIC INFARCTION */
'5735'   =  151	/* Hepatopulmonary syndrome (Begin 2011)*/
'5738 ' = 151 /* LIVER DISORDERS NEC */
'5739 ' = 151 /* LIVER DISORDER NOS */
'585  ' = 158 /* CHRONIC RENAL FAILURE */
'5851 ' = 161 /* CHRO KIDNEY DIS STAGE I */
'5852 ' = 161 /* CHRO KIDNEY DIS STAGE II */
'5853 ' = 158 /* CHR KIDNEY DIS STAGE III */
'5854 ' = 158 /* CHR KIDNEY DIS STAGE IV */
'5855 ' = 158 /* CHRON KIDNEY DIS STAGE V */
'5856 ' = 158 /* END STAGE RENAL DISEASE */
'5859 ' = 158 /* CHRONIC KIDNEY DIS NOS */
'5880 ' = 161 /* RENAL OSTEODYSTROPHY */
'5881 ' = 161 /* NEPHROGEN DIABETES INSIP */
'5888 ' = 161 /* IMPAIRED RENAL FUNCT NEC */
'58881' = 161 /* SEC HYPERPARATHYRD-RENAL */
'58889' = 161 /* IMPAIR REN FUNCT DIS NEC */
'5889 ' = 161 /* IMPAIRED RENAL FUNCT NOS */
'5890 ' = 161 /* UNILATERAL SMALL KIDNEY */
'5891 ' = 161 /* BILATERAL SMALL KIDNEYS */
'5899 ' = 161 /* SMALL KIDNEY NOS */
'591  ' = 161 /* HYDRONEPHROSIS */
'5930 ' = 161 /* NEPHROPTOSIS */
'5931 ' = 161 /* HYPERTROPHY OF KIDNEY */
'5932 ' = 161 /* CYST OF KIDNEY- ACQUIRED */
'5933 ' = 161 /* STRICTURE OF URETER */
'5934 ' = 161 /* URETERIC OBSTRUCTION NEC */
'5935 ' = 161 /* HYDROURETER */
'5936 ' = 161 /* POSTURAL PROTEINURIA */
'5937 ' = 161 /* VESICOURETERAL REFLUX */
'59370' = 161 /* VESICOURETERAL REFLUX W/O NEPHRO OCT94 */
'59371' = 161 /* VESICOURETER REFLUX W UNILAT NEPHROP OCT94 */
'59372' = 161 /* VESICOURETER REFLUX W BILAT NEPHROP OCT94 */
'59373' = 161 /* VESICOURETER REFLUX NOS OCT94 */
'59381' = 161 /* RENAL VASCULAR DISORDER */
'59382' = 161 /* URETERAL FISTULA */
'59389' = 161 /* RENAL & URETERAL DIS NEC */
'5939 ' = 161 /* RENAL & URETERAL DIS NOS */
'64830' = 661 /* DRUG DEPENDENCY IN PREGNANCY UNSPECIFIED */
'64831' = 661 /* DRUG DEPENDENCY IN PREGNANCY DELIVERED/ ANTEPAR */
'64832' = 661 /* DRUG DEPENDENCY IN PREGNANCY DELIVERED/ POSTPAR */
'64833' = 661 /* DRUG DEPENDENCY IN PREGNANCY/ ANTEPARTUM COND */
'64834' = 661 /* DRUG DEPENDENCY IN PREGNANCY/ POSTPARTUM COND */
'65550' = 661 /* SUSPECT DAMAGE TO FETUS - DRUGS UNSPECIFIED */
'65551' = 661 /* SUSPECT DAMAGE TO FETUS - DRUGS DELIVERED ANTEP */
'65553' = 661 /* SUSPECT DAMAGE TO FETUS - ANTEPARTUM */
'7100 ' = 210 /* SYST LUPUS ERYTHEMATOSUS */
'7101 ' = 210 /* SYSTEMIC SCLEROSIS */
'7102 ' = 210 /* SICCA SYNDROME */
'7103 ' = 210 /* DERMATOMYOSITIS */
'7104 ' = 210 /* POLYMYOSITIS */
'7105 ' = 211 /* EOSINOPHILIA MYALGIA   OCT92 */
'7108 ' = 210 /* DIFF CONNECT TIS DIS NEC */
'7109 ' = 210 /* DIFF CONNECT TIS DIS NOS */
'725  ' = 211 /* POLYMYALGIA RHEUMATICA */
'7260 ' = 211 /* ADHESIVE CAPSULIT SHLDER */
'72610' = 211 /* ROTATOR CUFF SYND NOS */
'72611' = 211 /* CALCIF TENDINITIS SHLDER */
'72612' = 211 /* BICIPITAL TENOSYNOVITIS */
'72613'	 = 211	/* Partial tear rotatr cuff (Begin 2011)*/
'72619' = 211 /* ROTATOR CUFF DIS NEC */
'7262 ' = 211 /* SHOULDER REGION DIS NEC */
'72630' = 211 /* ELBOW ENTHESOPATHY NOS */
'72631' = 211 /* MEDIAL EPICONDYLITIS */
'72632' = 211 /* LATERAL EPICONDYLITIS */
'72633' = 211 /* OLECRANON BURSITIS */
'72639' = 211 /* ELBOW ENTHESOPATHY NEC */
'7264 ' = 211 /* ENTHESOPATHY OF WRIST */
'7265 ' = 211 /* ENTHESOPATHY OF HIP */
'72660' = 211 /* ENTHESOPATHY OF KNEE NOS */
'72661' = 211 /* PES ANSERINUS TENDINITIS */
'72662' = 211 /* TIBIAL COLL LIG BURSITIS */
'72663' = 211 /* FIBULA COLL LIG BURSITIS */
'72664' = 211 /* PATELLAR TENDINITIS */
'72665' = 211 /* PREPATELLAR BURSITIS */
'72669' = 211 /* ENTHESOPATHY OF KNEE NEC */
'72670' = 211 /* ANKLE ENTHESOPATHY NOS */
'72671' = 211 /* ACHILLES TENDINITIS */
'72672' = 211 /* TIBIALIS TENDINITIS */
'72673' = 211 /* CALCANEAL SPUR */
'72679' = 211 /* ANKLE ENTHESOPATHY NEC */
'7268 ' = 211 /* PERIPH ENTHESOPATHY NEC */
'72690' = 211 /* ENTHESOPATHY- SITE NOS */
'72691' = 211 /* EXOSTOSIS- SITE NOS */
'72700' = 211 /* SYNOVITIS NOS */
'72701' = 211 /* SYNOVITIS IN OTH DIS */
'72702' = 211 /* GIANT CELL TUMOR TENDON */
'72703' = 211 /* TRIGGER FINGER */
'72704' = 211 /* RADIAL STYLOID TENOSYNOV */
'72705' = 211 /* TENOSYNOV HAND/WRIST NEC */
'72706' = 211 /* TENOSYNOVITIS FOOT/ANKLE */
'72709' = 211 /* SYNOVITIS NEC */
'7272 ' = 211 /* OCCUPATIONAL BURSITIS */
'7273 ' = 211 /* BURSITIS NEC */
'72740' = 211 /* SYNOVIAL CYST NOS */
'72741' = 211 /* GANGLION OF JOINT */
'72742' = 211 /* GANGLION OF TENDON */
'72743' = 211 /* GANGLION NOS */
'72749' = 211 /* BURSAL CYST NEC */
'72750' = 211 /* RUPTURE OF SYNOVIUM NOS */
'72751' = 211 /* POPLITEAL SYNOVIAL CYST */
'72759' = 211 /* RUPTURE OF SYNOVIUM NEC */
'72760' = 211 /* NONTRAUM TENDON RUPT NOS */
'72761' = 211 /* ROTATOR CUFF RUPTURE */
'72762' = 211 /* BICEPS TENDON RUPTURE */
'72763' = 211 /* RUPT EXTEN TENDON HAND */
'72764' = 211 /* RUPT FLEXOR TENDON HAND */
'72765' = 211 /* RUPTURE QUADRICEP TENDON */
'72766' = 211 /* RUPTURE PATELLAR TENDON */
'72767' = 211 /* RUPTURE ACHILLES TENDON */
'72768' = 211 /* RUPTURE TENDON FOOT NEC */
'72769' = 211 /* NONTRAUM TENDON RUPT NEC */
'72781' = 211 /* CONTRACTURE OF TENDON */
'72782' = 211 /* CALCIUM DEPOSIT TENDON */
'72783' = 211 /* PLICA SYNDROME     OCT00 */
'72789' = 211 /* SYNOV/TEND/BURSA DIS NEC */
'7279 ' = 211 /* SYNOV/TEND/BURSA DIS NOS */
'7280 ' = 211 /* INFECTIVE MYOSITIS */
'72810' = 211 /* MUSCULAR CALCIFICAT NOS */
'72811' = 211 /* PROG MYOSITIS OSSIFICANS */
'72812' = 211 /* TRAUM MYOSITIS OSSIFICAN */
'72813' = 211 /* POSTOP HETEROTOPIC CALC */
'72819' = 211 /* MUSCULAR CALCIFICAT NEC */
'7282 ' = 211 /* MUSC DISUSE ATROPHY NEC */
'7283 ' = 211 /* MUSCLE DISORDERS NEC */
'7284 ' = 211 /* LAXITY OF LIGAMENT */
'7285 ' = 211 /* HYPERMOBILITY SYNDROME */
'7286 ' = 211 /* CONTRACTED PALMAR FASCIA */
'72871' = 211 /* PLANTAR FIBROMATOSIS */
'72879' = 211 /* FIBROMATOSES NEC */
'72881' = 211 /* INTERSTITIAL MYOSITIS */
'72882' = 211 /* FB GRANULOMA OF MUSCLE */
'72883' = 211 /* NONTRAUM MUSCLE RUPTURE */
'72884' = 211 /* DIASTASIS OF MUSCLE */
'72885' = 211 /* SPASM OF MUSCLE */
'72886' = 211 /* NECROTIZING FASCIITIS OCT95 */
'72887' = 211 /* Muscle weakness */
'72888' = 211 /* Rhabdomyolysis */
'72889' = 211 /* MUSCLE/LIGAMENT DIS NEC */
'7289 ' = 211 /* MUSCLE/LIGAMENT DIS NOS */
'7290 ' = 211 /* RHEUMATISM NOS */
'7291 ' = 211 /* MYALGIA AND MYOSITIS NOS */
'7292 ' = 211 /* NEURALGIA/NEURITIS NOS */
'72930' = 211 /* PANNICULITIS- UNSP SITE */
'72931' = 211 /* HYPERTROPHY OF FAT PAD */
'72939' = 211 /* PANNICULITIS- SITE NEC */
'7294 ' = 211 /* FASCIITIS NOS */
'7295 ' = 211 /* PAIN IN LIMB */
'7296 ' = 211 /* OLD FB IN SOFT TISSUE */
'72971' = 211 /* NONTRAUM COMP SYN-UP EXT */
'72972' = 211 /* NONTRAUM COMP SYN-LOW EX */
'72973' = 211 /* NONTRAUMA COMP SYN-ABD */
'72979' = 211 /* NONTRAUMA COMP SYN NEC */
'72981' = 211 /* SWELLING OF LIMB */
'72982' = 211 /* CRAMP IN LIMB */
'72989' = 211 /* MUSCSKEL SYMPT LIMB NEC */
'7299 ' = 211 /* SOFT TISSUE DIS NEC/NOS */
'72990' = 211 /*	SOFT TISSUE DISORD NOS */
'72991' = 211 /*	POST-TRAUMATIC SEROMA */
'72992' = 211 /*	NONTRAUMA HEMA SOFT TISS */
'72999' = 211 /*	SOFT TISSUE DISORDER NEC */
'7400 ' = 216 /* ANENCEPHALUS */
'7401 ' = 216 /* CRANIORACHISCHISIS */
'7402 ' = 216 /* INIENCEPHALY */
'74100' = 216 /* SPIN BIF W HYDROCEPH NOS */
'74101' = 216 /* SPIN BIF W HYDRCEPH-CERV */
'74102' = 216 /* SPIN BIF W HYDRCEPH-DORS */
'74103' = 216 /* SPIN BIF W HYDRCEPH-LUMB */
'74190' = 216 /* SPINA BIFIDA */
'74191' = 216 /* SPINA BIFIDA-CERV */
'74192' = 216 /* SPINA BIFIDA-DORSAL */
'74193' = 216 /* SPINA BIFIDA-LUMBAR */
'7420 ' = 216 /* ENCEPHALOCELE */
'7421 ' = 216 /* MICROCEPHALUS */
'7422 ' = 216 /* REDUCTION DEFORM- BRAIN */
'7423 ' = 216 /* CONGENITAL HYDROCEPHALUS */
'7424 ' = 216 /* BRAIN ANOMALY NEC */
'74251' = 216 /* DIASTEMATOMYELIA */
'74253' = 216 /* HYDROMYELIA */
'74259' = 216 /* SPINAL CORD ANOMALY NEC */
'7428 ' = 216 /* NERVOUS SYSTEM ANOM NEC */
'7429 ' = 216 /* NERVOUS SYSTEM ANOM NOS */
'74300' = 217 /* CLINIC ANOPHTHALMOS NOS */
'74303' = 217 /* CONGEN CYSTIC EYEBALL */
'74306' = 217 /* CRYPTOPHTHALMOS */
'74310' = 217 /* MICROPHTHALMOS NOS */
'74311' = 217 /* SIMPLE MICROPHTHALMOS */
'74312' = 217 /* MICROPHTH W OTH EYE ANOM */
'74320' = 217 /* BUPHTHALMOS NOS */
'74321' = 217 /* SIMPLE BUPHTHALMOS */
'74322' = 217 /* BUPHTHAL W OTH EYE ANOM */
'74330' = 217 /* CONGENITAL CATARACT NOS */
'74331' = 217 /* CAPSULAR CATARACT */
'74332' = 217 /* CORTICAL/ZONULAR CATARAC */
'74333' = 217 /* NUCLEAR CATARACT */
'74334' = 217 /* CONG TOT/SUBTOT CATARACT */
'74335' = 217 /* CONGENITAL APHAKIA */
'74336' = 217 /* ANOMALIES OF LENS SHAPE */
'74337' = 217 /* CONGENITAL ECTOPIC LENS */
'74339' = 217 /* CONG CATAR/LENS ANOM NEC */
'74341' = 217 /* ANOM CORNEAL SIZE/SHAPE */
'74342' = 217 /* CONG CORNEA OPAC AFF VIS */
'74343' = 217 /* CONG CORNEAL OPACIT NEC */
'74344' = 217 /* ANOM ANTER CHAMBER-EYE */
'74345' = 217 /* ANIRIDIA */
'74346' = 217 /* ANOM IRIS & CIL BODY NEC */
'74347' = 217 /* ANOMALIES OF SCLERA */
'74348' = 217 /* MULT ANOM ANTER SEG-EYE */
'74349' = 217 /* ANOM ANTER SEG NEC-EYE */
'74351' = 217 /* VITREOUS ANOMALIES */
'74352' = 217 /* FUNDUS COLOBOMA */
'74353' = 217 /* CONG CHORIORETINAL DEGEN */
'74354' = 217 /* CONG FOLD/CYST POST EYE */
'74355' = 217 /* CONG MACULAR CHANGE-EYE */
'74356' = 217 /* CONG RETINAL CHANGES NEC */
'74357' = 217 /* OPTIC DISC ANOMALIES */
'74358' = 217 /* VASCULAR ANOM POST EYE */
'74359' = 217 /* POST SEGMNT ANOM NEC-EYE */
'74361' = 217 /* CONGENITAL PTOSIS */
'74362' = 217 /* CONGENITAL EYELID DEFORM */
'74363' = 217 /* SPEC ANOM OF EYELID NEC */
'74364' = 217 /* SPEC LACRIMAL GLAND ANOM */
'74365' = 217 /* SPEC LACRIMAL PASS ANOM */
'74366' = 217 /* SPEC ANOMALY OF ORBIT */
'74369' = 217 /* ANOM EYELID/LACR/ORB NEC */
'7438 ' = 217 /* EYE ANOMALIES NEC */
'7439 ' = 217 /* EYE ANOMALY NOS */
'74400' = 217 /* EAR ANOM NOS/IMPAIR HEAR */
'74401' = 217 /* CONG ABSENCE EXT EAR */
'74402' = 217 /* EX EAR ANM NEC-IMPR HEAR */
'74403' = 217 /* MIDDLE EAR ANOMALY NEC */
'74404' = 217 /* ANOMALIES EAR OSSICLES */
'74405' = 217 /* ANOMALIES OF INNER EAR */
'74409' = 217 /* EAR ANOM NEC/IMPAIR HEAR */
'7441 ' = 217 /* ACCESSORY AURICLE */
'74421' = 217 /* CONG ABSENCE OF EAR LOBE */
'74422' = 217 /* MACROTIA */
'74423' = 217 /* MICROTIA */
'74424' = 217 /* EUSTACHIAN TUBE ANOM NEC */
'74429' = 217 /* EAR ANOMALIES NEC */
'7443 ' = 217 /* EAR ANOMALY NOS */
'74441' = 217 /* BRANCH CLEFT SINUS/FISTU */
'74442' = 217 /* BRANCHIAL CLEFT CYST */
'74443' = 217 /* CERVICAL AURICLE */
'74446' = 217 /* PREAURICULAR SINUS/FISTU */
'74447' = 217 /* PREAURICULAR CYST */
'74449' = 217 /* BRANCHIAL CLEFT ANOM NEC */
'7445 ' = 217 /* WEBBING OF NECK */
'74481' = 217 /* MACROCHEILIA */
'74482' = 217 /* MICROCHEILIA */
'74483' = 217 /* MACROSTOMIA */
'74484' = 217 /* MICROSTOMIA */
'74489' = 217 /* CONG FACE/NECK ANOM NEC */
'7449 ' = 217 /* CONG FACE/NECK ANOM NOS */
'7450 ' = 213 /* COMMON TRUNCUS */
'74510' = 213 /* COMPL TRANSPOS GREAT VES */
'74511' = 213 /* DOUBLE OUTLET RT VENTRIC */
'74512' = 213 /* CORRECT TRANSPOS GRT VES */
'74519' = 213 /* TRANSPOS GREAT VESS NEC */
'7452 ' = 213 /* TETRALOGY OF FALLOT */
'7453 ' = 213 /* COMMON VENTRICLE */
'7454 ' = 213 /* VENTRICULAR SEPT DEFECT */
'7455 ' = 213 /* SECUNDUM ATRIAL SEPT DEF */
'74560' = 213 /* ENDOCARD CUSHION DEF NOS */
'74561' = 213 /* OSTIUM PRIMUM DEFECT */
'74569' = 213 /* ENDOCARD CUSHION DEF NEC */
'7457 ' = 213 /* COR BILOCULARE */
'7458 ' = 213 /* SEPTAL CLOSURE ANOM NEC */
'7459 ' = 213 /* SEPTAL CLOSURE ANOM NOS */
'74600' = 213 /* PULMONARY VALVE ANOM NOS */
'74601' = 213 /* CONG PULMON VALV ATRESIA */
'74602' = 213 /* CONG PULMON VALVE STENOS */
'74609' = 213 /* PULMONARY VALVE ANOM NEC */
'7461 ' = 213 /* CONG TRICUSP ATRES/STEN */
'7462 ' = 213 /* EBSTEIN-s ANOMALY */
'7463 ' = 213 /* CONG AORTA VALV STENOSIS */
'7464 ' = 213 /* CONG AORTA VALV INSUFFIC */
'7465 ' = 213 /* CONGEN MITRAL STENOSIS */
'7466 ' = 213 /* CONG MITRAL INSUFFICIENC */
'7467 ' = 213 /* HYPOPLAS LEFT HEART SYND */
'74681' = 213 /* CONG SUBAORTIC STENOSIS */
'74682' = 213 /* COR TRIATRIATUM */
'74683' = 213 /* INFUNDIB PULMON STENOSIS */
'74684' = 213 /* OBSTRUCT HEART ANOM NEC */
'74685' = 213 /* CORONARY ARTERY ANOMALY */
'74686' = 213 /* CONGENITAL HEART BLOCK */
'74687' = 213 /* MALPOSITION OF HEART */
'74689' = 213 /* CONG HEART ANOMALY NEC */
'7469 ' = 213 /* CONG HEART ANOMALY NOS */
'7470 ' = 213 /* PATENT DUCTUS ARTERIOSUS */
'74710' = 213 /* COARCTATION OF AORTA */
'74711' = 213 /* INTERRUPT OF AORTIC ARCH */
'74720' = 213 /* CONG ANOM OF AORTA NOS */
'74721' = 213 /* ANOMALIES OF AORTIC ARCH */
'74722' = 213 /* AORTIC ATRESIA/STENOSIS */
'74729' = 213 /* CONG ANOM OF AORTA NEC */
'7473 ' = 213 /* PULMONARY ARTERY ANOM */
'74731'	= 213	/* Pulmon art coarct/atres (Begin 2011)	*/
'74732'	= 213	/* Pulmonary AV malformatn (Begin 2011)	*/
'74739'	= 213	/* Oth anom pul artery/circ (Begin 2011)*/
'74740' = 213 /* GREAT VEIN ANOMALY NOS */
'74741' = 213 /* TOT ANOM PULM VEN CONNEC */
'74742' = 213 /* PART ANOM PULM VEN CONN */
'74749' = 213 /* GREAT VEIN ANOMALY NEC */
'7475 ' = 213 /* UMBILICAL ARTERY ABSENCE */
'7476 ' = 213 /* PERIPH VASCULAR ANOM NEC */
'74760' = 213 /* UNSPEC PERIPH VASCULAR ANOM OCT93 */
'74761' = 213 /* GI VESSEL ANOMALY  OCT93 */
'74762' = 213 /* RENAL VESSEL ANOMALY OCT93 */
'74763' = 213 /* UP LIMB VESSEL ANOMALY OCT93 */
'74764' = 213 /* LOWER LIMB VESSEL ANOMALY OCT93 */
'74769' = 213 /* OTH SPEC PERIPH VASCULAR ANOM OCT93 */
'74781' = 213 /* CEREBROVASCULAR ANOMALY */
'74782' = 213 /* SPINAL VESSEL ANOMALY OCT93 */
'74783' = 213 /* PERSISTENT FETAL CIRCULATION  OCT02 */
'74789' = 213 /* CIRCULATORY ANOMALY NEC */
'7479 ' = 213 /* CIRCULATORY ANOMALY NOS */
'7480 ' = 217 /* CHOANAL ATRESIA */
'7481 ' = 217 /* NOSE ANOMALY NEC */
'7482 ' = 217 /* LARYNGEAL WEB */
'7483 ' = 217 /* LARYNGOTRACH ANOMALY NEC */
'7484 ' = 217 /* CONGENITAL CYSTIC LUNG */
'7485 ' = 217 /* AGENESIS OF LUNG */
'74860' = 217 /* LUNG ANOMALY NOS */
'74861' = 217 /* CONGEN BRONCHIECTASIS */
'74869' = 217 /* LUNG ANOMALY NEC */
'7488 ' = 217 /* RESPIRATORY ANOMALY NEC */
'7489 ' = 217 /* RESPIRATORY ANOMALY NOS */
'74900' = 217 /* CLEFT PALATE NOS */
'74901' = 217 /* UNILAT CLEFT PALATE-COMP */
'74902' = 217 /* UNILAT CLEFT PALATE-INC */
'74903' = 217 /* BILAT CLEFT PALATE-COMPL */
'74904' = 217 /* BILAT CLEFT PALATE-INC */
'74910' = 217 /* CLEFT LIP NOS */
'74911' = 217 /* UNILAT CLEFT LIP-COMPL */
'74912' = 217 /* UNILAT CLEFT LIP-IMCOMPL */
'74913' = 217 /* BILAT CLEFT LIP-COMPLETE */
'74914' = 217 /* BILAT CLEFT LIP-INCOMPL */
'74920' = 217 /* CLEFT PALATE & LIP NOS */
'74921' = 217 /* UNIL CLEFT PALAT/LIP-COM */
'74922' = 217 /* UNIL CLEFT PALAT/LIP-INC */
'74923' = 217 /* BILAT CLFT PALAT/LIP-COM */
'74924' = 217 /* BILAT CLFT PALAT/LIP-INC */
'74925' = 217 /* CLEFT PALATE & LIP NEC */
'7500 ' = 214 /* TONGUE TIE */
'75010' = 214 /* TONGUE ANOMALY NOS */
'75011' = 214 /* AGLOSSIA */
'75012' = 214 /* CONG ADHESIONS OF TONGUE */
'75013' = 214 /* CONG FISSURE OF TONGUE */
'75015' = 214 /* CONG MACROGLOSSIA */
'75016' = 214 /* MICROGLOSSIA */
'75019' = 214 /* TONGUE ANOMALY NEC */
'75021' = 214 /* SALIVARY GLAND ABSENCE */
'75022' = 214 /* ACCESSORY SALIVARY GLAND */
'75023' = 214 /* CONG ATRESIA- SALIV DUCT */
'75024' = 214 /* CONG SALIVARY FISTULA */
'75025' = 214 /* CONGENITAL LIP FISTULA */
'75026' = 214 /* MOUTH ANOMALY NEC */
'75027' = 214 /* DIVERTICULUM OF PHARYNX */
'75029' = 214 /* PHARYNGEAL ANOMALY NEC */
'7503 ' = 214 /* CONG ESOPH FISTULA/ATRES */
'7504 ' = 214 /* ESOPHAGEAL ANOMALY NEC */
'7505 ' = 214 /* CONG PYLORIC STENOSIS */
'7506 ' = 214 /* CONGENITAL HIATUS HERNIA */
'7507 ' = 214 /* GASTRIC ANOMALY NEC */
'7508 ' = 214 /* UPPER GI ANOMALY NEC */
'7509 ' = 214 /* UPPER GI ANOMALY NOS */
'7510 ' = 214 /* MECKEL-s DIVERTICULUM */
'7511 ' = 214 /* ATRESIA SMALL INTESTINE */
'7512 ' = 214 /* ATRESIA LARGE INTESTINE */
'7513 ' = 214 /* HIRSCHSPRUNG-s DISEASE */
'7514 ' = 214 /* INTESTINAL FIXATION ANOM */
'7515 ' = 214 /* INTESTINAL ANOMALY NEC */
'75160' = 214 /* BILIARY & LIVER ANOM NOS */
'75161' = 214 /* BILIARY ATRESIA */
'75162' = 214 /* CONG CYSTIC LIVER DIS */
'75169' = 214 /* BILIARY & LIVER ANOM NEC */
'7517 ' = 214 /* PANCREAS ANOMALIES */
'7518 ' = 214 /* ANOM DIGESTIVE SYST NEC */
'7519 ' = 214 /* ANOM DIGESTIVE SYST NOS */
'7520 ' = 215 /* ANOMALIES OF OVARIES */
'75210' = 215 /* TUBAL/BROAD LIG ANOM NOS */
'75211' = 215 /* EMBRYONIC CYST OF ADNEXA */
'75219' = 215 /* TUBAL/BROAD LIG ANOM NEC */
'7522 ' = 215 /* DOUBLING OF UTERUS */
'7523 ' = 215 /* UTERINE ANOMALY NEC */
'75231' = 215 /* AGENESIS OF UTERUS */
'75232' = 215 /* HYPOPLASIA OF UTERUS */
'75233' = 215 /* UNICORNUATE UTERUS */
'75234' = 215 /* BICORNUATE UTERUS */
'75235' = 215 /* SEPTATE UTERUS */
'75236' = 215 /* ARCUATE UTERUS */
'75239' = 215 /* ANOMALIES OF UTERUS NEC */
'75240' = 215 /* CERVIX/FEM GEN ANOM NOS */
'75241' = 215 /* EMBRYON CYST FEM GEN NEC */
'75242' = 215 /* IMPERFORATE HYMEN */
'75243' = 215 /* CERVICAL AGENESIS */
'75244' = 215 /* CERVICAL DUPLICATION */
'75245' = 215 /* VAGINAL AGENESIS */
'75246' = 215 /* TRANSV VAGINAL SEPTUM */
'75247' = 215 /* LONGITUD VAGINAL SEPTUM */
'75249' = 215 /* CERVIX/FEM GEN ANOM NEC */
'7525 ' = 215 /* UNDESCENDED TESTICLE */
'75251' = 215 /* UNDESCEND TESTIS  OCT96 */
'75252' = 215 /* RETRACTILE TESTIS  OCT96 */
'7526 ' = 215 /* MALE HYPOSPADIAS/EPISPAD */
'75261' = 215 /* HYPOSPADIAS  OCT96 */
'75262' = 215 /* EPISPADIAS  OCT96 */
'75263' = 215 /* CONG CHORDEE  OCT96 */
'75264' = 215 /* MICROPENIS  OCT96 */
'75265' = 215 /* HIDDEN PENIS  OCT96 */
'75269' = 215 /* OTH PENILE ANOM  OCT96 */
'7527 ' = 215 /* INDETERMINATE SEX */
'7528 ' = 215 /* GENITAL ORGAN ANOM NEC */
'75281' = 215 /* Scrotal transposition */
'75289' = 215 /* Other specified anomalies of genital organs */
'7529 ' = 215 /* GENITAL ORGAN ANOM NOS */
'7530 ' = 215 /* RENAL AGENESIS */
'7531 ' = 215 /* CYSTIC KIDNEY DISEASE   J80  S90 */
'75310' = 215 /* CYSTIC KIDNEY DISEAS NOS O90 */
'75311' = 215 /* CONGENITAL RENAL CYST  O90 */
'75312' = 215 /* POLYCYSTIC KIDNEY NOS  O90 */
'75313' = 215 /* POLYCYST KID-AUTOSOM DOM O90 */
'75314' = 215 /* POLYCYST KID-AUTOSOM REC O90 */
'75315' = 215 /* RENAL DYSPLASIA    O90 */
'75316' = 215 /* MEDULLARY CYSTIC KIDNEY  O90 */
'75317' = 215 /* MEDULLARY SPONGE KIDNEY  O90 */
'75319' = 215 /* CYSTIC KIDNEY DISEAS NEC O90 */
'7532 ' = 215 /* CONGEN URETERAL OBSTRUCT */
'75320' = 215 /* OBSTR URETER NOS  OCT96 */
'75321' = 215 /* OBSTR URETERPELV JCT  OCT96 */
'75322' = 215 /* OBSTR URETERVESC JCT  OCT96 */
'75323' = 215 /* CONG URETEROCELE  OCT96 */
'75329' = 215 /* OTH OBSTR DEF URETER  OCT96 */
'7533 ' = 215 /* KIDNEY ANOMALY NEC */
'7534 ' = 215 /* URETERAL ANOMALY NEC */
'7535 ' = 215 /* BLADDER EXSTROPHY */
'7536 ' = 215 /* CONGEN URETHRAL STENOSIS */
'7537 ' = 215 /* ANOMALIES OF URACHUS */
'7538 ' = 215 /* CYSTOURETHRAL ANOM NEC */
'7539 ' = 215 /* URINARY ANOMALY NOS */
'7540 ' = 217 /* CONG SKULL/FACE/JAW DEF */
'7541 ' = 217 /* CONGENITAL TORTICOLLIS */
'7542 ' = 217 /* CONG POSTURAL DEFORMITY */
'75430' = 217 /* CONG HIP DISLOC- UNILAT */
'75431' = 217 /* CONGEN HIP DISLOC- BILAT */
'75432' = 217 /* CONG HIP SUBLUX- UNILAT */
'75433' = 217 /* CONG HIP SUBLUX- BILAT */
'75435' = 217 /* CONG HIP DISLOC W SUBLUX */
'75440' = 217 /* CONG GENU RECURVATUM */
'75441' = 217 /* CONG KNEE DISLOCATION */
'75442' = 217 /* CONGEN BOWING OF FEMUR */
'75443' = 217 /* CONG BOWING TIBIA/FIBULA */
'75444' = 217 /* CONG BOWING LEG NOS */
'75450' = 217 /* TALIPES VARUS */
'75451' = 217 /* TALIPES EQUINOVARUS */
'75452' = 217 /* METATARSUS PRIMUS VARUS */
'75453' = 217 /* METATARSUS VARUS */
'75459' = 217 /* CONG VARUS FOOT DEF NEC */
'75460' = 217 /* TALIPES VALGUS */
'75461' = 217 /* CONGENITAL PES PLANUS */
'75462' = 217 /* TALIPES CALCANEOVALGUS */
'75469' = 217 /* CONG VALGUS FOOT DEF NEC */
'75470' = 217 /* TALIPES NOS */
'75471' = 217 /* TALIPES CAVUS */
'75479' = 217 /* CONG FOOT DEFORM NEC */
'75481' = 217 /* PECTUS EXCAVATUM */
'75482' = 217 /* PECTUS CARINATUM */
'75489' = 217 /* NONTERATOGENIC ANOM NEC */
'75500' = 217 /* POLYDACTYLY NOS */
'75501' = 217 /* POLYDACTYLY- FINGERS */
'75502' = 217 /* POLYDACTYLY- TOES */
'75510' = 217 /* SYNDACTYLY- MULTIPLE/NOS */
'75511' = 217 /* SYNDACTYL FING-NO FUSION */
'75512' = 217 /* SYNDACTYL FING W FUSION */
'75513' = 217 /* SYNDACTYL TOE-NO FUSION */
'75514' = 217 /* SYNDACTYL TOE W FUSION */
'75520' = 217 /* REDUC DEFORM UP LIMB NOS */
'75521' = 217 /* TRANSVERSE DEFIC ARM */
'75522' = 217 /* LONGITUD DEFIC ARM NEC */
'75523' = 217 /* COMBIN LONGIT DEFIC ARM */
'75524' = 217 /* LONGITUDIN DEFIC HUMERUS */
'75525' = 217 /* LONGITUD DEFIC RADIOULNA */
'75526' = 217 /* LONGITUD DEFIC RADIUS */
'75527' = 217 /* LONGITUDINAL DEFIC ULNA */
'75528' = 217 /* LONGITUDINAL DEFIC HAND */
'75529' = 217 /* LONGITUD DEFIC PHALANGES */
'75530' = 217 /* REDUCTION DEFORM LEG NOS */
'75531' = 217 /* TRANSVERSE DEFIC LEG */
'75532' = 217 /* LONGITUDIN DEFIC LEG NEC */
'75533' = 217 /* COMB LONGITUDIN DEF LEG */
'75534' = 217 /* LONGITUDINAL DEFIC FEMUR */
'75535' = 217 /* TIBIOFIBULA LONGIT DEFIC */
'75536' = 217 /* LONGITUDINAL DEFIC TIBIA */
'75537' = 217 /* LONGITUDIN DEFIC FIBULA */
'75538' = 217 /* LONGITUDINAL DEFIC FOOT */
'75539' = 217 /* LONGITUD DEFIC PHALANGES */
'7554 ' = 217 /* REDUCT DEFORM LIMB NOS */
'75550' = 217 /* UPPER LIMB ANOMALY NOS */
'75551' = 217 /* CONG DEFORMITY-CLAVICLE */
'75552' = 217 /* CONG ELEVATION-SCAPULA */
'75553' = 217 /* RADIOULNAR SYNOSTOSIS */
'75554' = 217 /* MADELUNG-s DEFORMITY */
'75555' = 217 /* ACROCEPHALOSYNDACTYLY */
'75556' = 217 /* ACCESSORY CARPAL BONES */
'75557' = 217 /* MACRODACTYLIA (FINGERS) */
'75558' = 217 /* CONGENITAL CLEFT HAND */
'75559' = 217 /* UPPER LIMB ANOMALY NEC */
'75560' = 217 /* LOWER LIMB ANOMALY NOS */
'75561' = 217 /* CONGENITAL COXA VALGA */
'75562' = 217 /* CONGENITAL COXA VARA */
'75563' = 217 /* CONG HIP DEFORMITY NEC */
'75564' = 217 /* CONG KNEE DEFORMITY */
'75565' = 217 /* MACRODACTYLIA OF TOES */
'75566' = 217 /* ANOMALIES OF TOES NEC */
'75567' = 217 /* ANOMALIES OF FOOT NEC */
'75569' = 217 /* LOWER LIMB ANOMALY NEC */
'7558 ' = 217 /* CONGEN LIMB ANOMALY NEC */
'7559 ' = 217 /* CONGEN LIMB ANOMALY NOS */
'7560 ' = 217 /* ANOMAL SKULL/FACE BONES */
'75610' = 217 /* ANOMALY OF SPINE NOS */
'75611' = 217 /* LUMBOSACR SPONDYLOLYSIS */
'75612' = 217 /* SPONDYLOLISTHESIS */
'75613' = 217 /* CONG ABSENCE OF VERTEBRA */
'75614' = 217 /* HEMIVERTEBRA */
'75615' = 217 /* CONGEN FUSION OF SPINE */
'75616' = 217 /* KLIPPEL-FEIL SYNDROME */
'75617' = 217 /* SPINA BIFIDA OCCULTA */
'75619' = 217 /* ANOMALY OF SPINE NEC */
'7562 ' = 217 /* CERVICAL RIB */
'7563 ' = 217 /* RIB & STERNUM ANOMAL NEC */
'7564 ' = 217 /* CHONDRODYSTROPHY */
'75650' = 217 /* OSTEODYSTROPHY NOS */
'75651' = 217 /* OSTEOGENESIS IMPERFECTA */
'75652' = 217 /* OSTEOPETROSIS */
'75653' = 217 /* OSTEOPOIKILOSIS */
'75654' = 217 /* POLYOSTOTIC FIBROS DYSPL */
'75655' = 217 /* CHONDROECTODERM DYSPLAS */
'75656' = 217 /* MULT EPIPHYSEAL DYSPLAS */
'75659' = 217 /* OSTEODYSTROPHY NEC */
'7566 ' = 217 /* ANOMALIES OF DIAPHRAGM */
'7567 ' = 217 /* ABDOMINAL WALL ANOMALIES */
'75670' = 217 /* CONG ANOM ABD WALL NOS OCT97 */
'75671' = 217 /* CONG ANOM PRUNE BELLY SYND OCT97 */
'75672' = 217 /*	OMPHALOCELE */
'75673' = 217 /*	GASTROSCHISIS */
'75679' = 217 /* OT CONG ANOM ABD WALL OCT97 */
'75681' = 217 /* ABSENCE OF MUSCLE/TENDON */
'75682' = 217 /* ACCESSORY MUSCLE */
'75683' = 217 /* EHLERS-DANLOS SYNDROME */
'75689' = 217 /* SOFT TISSUE ANOMALY NEC */
'7569 ' = 217 /* MUSCULOSKEL ANOM NEC/NOS */
'7570 ' = 217 /* HEREDITARY EDEMA OF LEGS */
'7571 ' = 217 /* ICHTHYOSIS CONGENITA */
'7572 ' = 217 /* DERMATOGLYPHIC ANOMALIES */
'75731' = 217 /* CONG ECTODERMAL DYSPLAS */
'75732' = 217 /* VASCULAR HAMARTOMAS */
'75733' = 217 /* CONG SKIN PIGMENT ANOMAL */
'75739' = 217 /* SKIN ANOMALY NEC */
'7574 ' = 217 /* HAIR ANOMALIES NEC */
'7575 ' = 217 /* NAIL ANOMALIES NEC */
'7576 ' = 217 /* BREAST ANOMALIES NEC */
'7578 ' = 217 /* OTH INTEGUMENT ANOMALIES */
'7579 ' = 217 /* INTEGUMENT ANOMALY NOS */
'7590 ' = 217 /* ANOMALIES OF SPLEEN */
'7591 ' = 217 /* ADRENAL GLAND ANOMALY */
'7592 ' = 217 /* ENDOCRINE ANOMALY NEC */
'7593 ' = 217 /* SITUS INVERSUS */
'7594 ' = 217 /* CONJOINED TWINS */
'7595 ' = 217 /* TUBEROUS SCLEROSIS */
'7596 ' = 217 /* HAMARTOSES NEC */
'7597 ' = 217 /* MULT CONGEN ANOMAL NEC */
'7598 ' = 217 /* CONGENITAL ANOMALIES NEC  J80  S89 */
'75981' = 217 /* PRADER-WILLI SYNDROME  OCT89 */
'75982' = 217 /* MARFAN SYNDROME    OCT89 */
'75983' = 217 /* FRAGILE X SYNDROME OCT94 */
'75989' = 217 /* SPECFIED CONG ANOMAL NEC OCT89 */
'7599 ' = 217 /* CONGENITAL ANOMALY NOS */
'7600 ' = 224 /* MATERN HYPERTEN AFF NB */
'7601 ' = 224 /* MATERN URINE DIS AFF NB */
'7602 ' = 224 /* MATERNAL INFEC AFF NB */
'7603 ' = 224 /* MATERN CARDIORESP AFF NB */
'7604 ' = 224 /* MATERN NUTRIT DIS AFF NB */
'7605 ' = 224 /* MATERNAL INJURY AFF NB */
'7606 ' = 224 /* SURG OP ON MOTHER AFF NB */
'76061' = 224 /*	AMNIOCENTESIS AFFECT NB */
'76062' = 224 /*	IN UTERO PROC NEC AFF NB */
'76063' = 224 /*	MAT SURG DUR PREG AFF NB */
'76064' = 224 /*	PREV MATERN SURG AFF NB */
'76070' = 224 /* NOXIOUS SUBST NOS AFF NB */
'76071' = 224 /* MATERNAL ALCOHOL AFF NB */
'76072' = 661 /* NARCOTICS AFFECT FETUS */
'76073' = 661 /* HALLUCINOGENS AFFECT FETUS */
'76074' = 224 /* MATERNAL ANTI-INF AFF NB */
'76075' = 661 /* COCAINE AFFECTS FETUS  */
'76076' = 224 /* DES AFFECTING FETUS VIA PLAC OR MILK OCT94 */
'76077' = 224 /* MAT ANTICONV AFF NB/FET */
'76078' = 224 /* MAT ANTIMETABOL AFF NB */
'76079' = 224 /* NOXIOUS SUBST NEC AFF NB */
'7608 ' = 224 /* MATERNAL COND NEC AFF NB */
'7609 ' = 224 /* MATERNAL COND NOS AFF NB */
'7610 ' = 224 /* INCOMPETNT CERVIX AFF NB */
'7611 ' = 224 /* PREMAT RUPT MEMB AFF NB */
'7612 ' = 224 /* OLIGOHYDRAMNIOS AFF NB */
'7613 ' = 224 /* POLYHYDRAMNIOS AFF NB */
'7614 ' = 224 /* ECTOPIC PREGNANCY AFF NB */
'7615 ' = 224 /* MULT PREGNANCY AFF NB */
'7616 ' = 224 /* MATERNAL DEATH AFF NB */
'7617 ' = 224 /* ANTEPART MALPRES AFF NB */
'7618 ' = 224 /* MATERN COMPL NEC AFF NB */
'7619 ' = 224 /* MATERN COMPL NOS AFF NB */
'7620 ' = 224 /* PLACENTA PREVIA AFF NB */
'7621 ' = 224 /* PLACENTA HEM NEC AFF NB */
'7622 ' = 224 /* ABN PLAC NEC/NOS AFF NB */
'7623 ' = 224 /* PLACENT TRANSFUSION SYN */
'7624 ' = 224 /* PROLAPSED CORD AFF NB */
'7625 ' = 224 /* OTH UMBIL CORD COMPRESS */
'7626 ' = 224 /* UMBIL COND NEC AFF NB */
'7627 ' = 224 /* CHORIOAMNIONITIS AFF NB */
'7628 ' = 224 /* ABN AMNION NEC AFF NB */
'7629 ' = 224 /* ABN AMNION NOS AFF NB */
'7630 ' = 224 /* BREECH DEL/EXTRAC AFF NB */
'7631 ' = 224 /* MALPOS/DISPRO NEC AFF NB */
'7632 ' = 224 /* FORCEPS DELIVERY AFF NB */
'7633 ' = 224 /* VACUUM EXTRAC DEL AFF NB */
'7634 ' = 224 /* CESAREAN DELIVERY AFF NB */
'7635 ' = 224 /* MAT ANESTH/ANALG AFF NB */
'7636 ' = 224 /* PRECIPITATE DEL AFF NB */
'7637 ' = 224 /* ABN UTERINE CONTR AFF NB */
'7638 ' = 224 /* COMPL DELIV NEC AFF NB */
'76381' = 224 /* ABN FTL HRT BEFORE LABOR  OCT98 */
'76382' = 224 /* ABN FTL HRT DURING LABOR  OCT98 */
'76383' = 224 /* ABN FTL HRT UNSP ONSET  OCT98 */
'76384' = 224 /* MECONIUM DUR DEL AFF NB */
'76389' = 224 /* OTH SPEC COMPL LABOR/DELIV  OCT98 */
'7639 ' = 224 /* COMPL DELIV NOS AFF NB */
'7640 ' = 219 /* LT-FOR-DATES W/O FET MAL  J80  S88 */
'76400' = 219 /* LIGHT-FOR-DATES WTNOS  OCT88 */
'76401' = 219 /* LIGHT-FOR-DATES <500G  OCT88 */
'76402' = 219 /* LT-FOR-DATES 500-749G  OCT88 */
'76403' = 219 /* LT-FOR-DATES 750-999G  OCT88 */
'76404' = 219 /* LT-FOR-DATES 1000-1249G  OCT88 */
'76405' = 219 /* LT-FOR-DATES 1250-1499G  OCT88 */
'76406' = 219 /* LT-FOR-DATES 1500-1749G  OCT88 */
'76407' = 219 /* LT-FOR-DATES 1750-1999G  OCT88 */
'76408' = 219 /* LT-FOR-DATES 2000-2499G  OCT88 */
'76409' = 219 /* LT-FOR-DATES 2500+G  OCT88 */
'7641 ' = 219 /* LT-FOR-DATES W FETAL MAL  J80  S88 */
'76410' = 219 /* LT-FOR-DATE W/MAL WTNOS  OCT88 */
'76411' = 219 /* LT-FOR-DATE W/MAL <500G  OCT88 */
'76412' = 219 /* LT-DATE W/MAL 500-749G OCT88 */
'76413' = 219 /* LT-DATE W/MAL 750-999G OCT88 */
'76414' = 219 /* LT-DATE W/MAL 1000-1249G OCT88 */
'76415' = 219 /* LT-DATE W/MAL 1250-1499G OCT88 */
'76416' = 219 /* LT-DATE W/MAL 1500-1749G OCT88 */
'76417' = 219 /* LT-DATE W/MAL 1750-1999G OCT88 */
'76418' = 219 /* LT-DATE W/MAL 2000-2499G OCT88 */
'76419' = 219 /* LT-FOR-DATE W/MAL 2500+G OCT88 */
'7642 ' = 219 /* FET MAL W/O LT-FOR-DATES  J80  S88 */
'76420' = 219 /* FETAL MALNUTRITION WTNOS OCT88 */
'76421' = 219 /* FETAL MALNUTRITION <500G OCT88 */
'76422' = 219 /* FETAL MALNUTR 500-749G OCT88 */
'76423' = 219 /* FETAL MAL 750-999G   OCT88 */
'76424' = 219 /* FETAL MAL 1000-1249G   OCT88 */
'76425' = 219 /* FETAL MAL 1250-1499G   OCT88 */
'76426' = 219 /* FETAL MAL 1500-1749G   OCT88 */
'76427' = 219 /* FETAL MALNUTR 1750-1999G OCT88 */
'76428' = 219 /* FETAL MALNUTR 2000-2499G OCT88 */
'76429' = 219 /* FETAL MALNUTR 2500+G   OCT88 */
'7649 ' = 219 /* FETAL GROWTH RETARD NOS J80  S88 */
'76490' = 219 /* FET GROWTH RETARD WTNOS  OCT88 */
'76491' = 219 /* FET GROWTH RETARD <500G  OCT88 */
'76492' = 219 /* FET GROWTH RET 500-749G  OCT88 */
'76493' = 219 /* FET GROWTH RET 750-999G  OCT88 */
'76494' = 219 /* FET GRWTH RET 1000-1249G OCT88 */
'76495' = 219 /* FET GRWTH RET 1250-1499G OCT88 */
'76496' = 219 /* FET GRWTH RET 1500-1749G OCT88 */
'76497' = 219 /* FET GRWTH RET 1750-1999G OCT88 */
'76498' = 219 /* FET GRWTH RET 2000-2499G OCT88 */
'76499' = 219 /* FET GROWTH RET 2500+G  OCT88 */
'7650 ' = 219 /* EXTREME IMMATURITY    J80  S88 */
'76500' = 219 /* EXTREME IMMATUR WTNOS  OCT88 */
'76501' = 219 /* EXTREME IMMATUR <500G  OCT88 */
'76502' = 219 /* EXTREME IMMATUR 500-749G OCT88 */
'76503' = 219 /* EXTREME IMMATUR 750-999G OCT88 */
'76504' = 219 /* EXTREME IMMAT 1000-1249G OCT88 */
'76505' = 219 /* EXTREME IMMAT 1250-1499G OCT88 */
'76506' = 219 /* EXTREME IMMAT 1500-1749G OCT88 */
'76507' = 219 /* EXTREME IMMAT 1750-1999G OCT88 */
'76508' = 219 /* EXTREME IMMAT 2000-2499G OCT88 */
'76509' = 219 /* EXTREME IMMAT 2500+G   OCT88 */
'7651 ' = 219 /* OTHER PRETERM INFANTS   J80  S88 */
'76510' = 219 /* PRETERM INFANT NEC WTNOS OCT88 */
'76511' = 219 /* PRETERM NEC <500G    OCT88 */
'76512' = 219 /* PRETERM NEC 500-749G   OCT88 */
'76513' = 219 /* PRETERM NEC 750-999G   OCT88 */
'76514' = 219 /* PRETERM NEC 1000-1249G OCT88 */
'76515' = 219 /* PRETERM NEC 1250-1499G OCT88 */
'76516' = 219 /* PRETERM NEC 1500-1749G OCT88 */
'76517' = 219 /* PRETERM NEC 1750-1999G OCT88 */
'76518' = 219 /* PRETERM NEC 2000-2499G OCT88 */
'76519' = 219 /* PRETERM NEC 2500+G   OCT88 */
'76520' = 219 /* UNSPECIFIED WEEKS OF GESTATION    OCT02 */
'76521' = 219 /* LESS THAN 24 COMPLETED WEEKS OF GEST  OCT02 */
'76522' = 219 /* 24 COMPLETED WEEKS OF GESTATION   OCT02 */
'76523' = 219 /* 25-26 COMPLETED WEEKS OF GESTATION  OCT02 */
'76524' = 219 /* 27-28 COMPLETED WEEKS OF GESTATION  OCT02 */
'76525' = 219 /* 29-30 COMPLETED WEEKS OF GESTATION  OCT02 */
'76526' = 219 /* 31-32 COMPLETED WEEKS OF GESTATION  OCT02 */
'76527' = 219 /* 33-34 COMPLETED WEEKS OF GESTATION  OCT02 */
'76528' = 219 /* 35-36 COMPLETED WEEKS OF GESTATION  OCT02 */
'76529' = 219 /* 37 OR MORE COMPLETED WEEKS OF GEST  OCT02 */
'7660 ' = 224 /* EXCEPTIONALLY LARGE BABY */
'7661 ' = 224 /* HEAVY-FOR-DATE INFAN NEC */
'7662 ' = 224 /* POST-TERM INFANT NOS */
'76621' = 224 /* Post-term infant */
'76622' = 224 /* Prolonged gestation of infant */
'769  ' = 221 /* RESPIRATORY DISTRESS SYN */
'7700 ' = 224 /* CONGENITAL PNEUMONIA */
'7701 ' = 224 /* NB MASSIVE ASPIRAT SYN */
'77010' = 224 /* MECONIUM ASP NOS */
'77011' = 224 /* MECONIUM ASP WO RESP SYM */
'77012' = 224 /* MECONIUM ASP W RESP SYMP */
'77013' = 224 /* AMNIOTC ASP W/O RESP SYM */
'77014' = 224 /* AMNIOTIC ASP W RESP SYM */
'77015' = 224 /* BLOOD ASP W/O RESP SYMPT */
'77016' = 224 /* BLOOD ASP W RESP SYMPT */
'77017' = 224 /* NB ASP W/O RESP SYMP NEC */
'77018' = 224 /* NB ASP W RESP SYMP NEC */
'7702 ' = 224 /* NB INTERSTIT EMPHYSEMA */
'7703 ' = 224 /* NB PULMONARY HEMORRHAGE */
'7704 ' = 224 /* PRIMARY ATELECTASIS */
'7705 ' = 224 /* NB ATELECTASIS NEC/NOS */
'7706 ' = 224 /* NB TRANSITORY TACHYPNEA */
'7707 ' = 224 /* PERINATAL CHR RESP DIS */
'7708 ' = 224 /* POST-BIRTH RESP PROB NEC */
'77081' = 224 /* PRIMARY APNEA OF NEWBORN   OCT02 */
'77082' = 224 /* OTHER APNEA OF NEWBORN     OCT02 */
'77083' = 224 /* CYANOTIC ATTACKS OF NEWBORN  OCT02 */
'77084' = 224 /* RESPIRATORY FAILURE OF NEWBORN OCT02 */
'77085' = 224 /* STOMCH CONT ASP W/O RESP */
'77086' = 224 /* STOMACH CONT ASP W RESP */
'77087' = 224 /* NB RESPIRATORY ARREST */
'77089' = 224 /* OTHER RESPIRATORY PROBLEMS AFT BIRTH OCT02 */
'7709 ' = 224 /* NB RESPIRATORY COND NOS */
'7710 ' = 224 /* CONGENITAL RUBELLA */
'7711 ' = 224 /* CONG CYTOMEGALOVIRUS INF */
'7712 ' = 224 /* CONGENITAL INFEC NEC */
'7713 ' = 224 /* TETANUS NEONATORUM */
'7714 ' = 224 /* OMPHALITIS OF NEWBORN */
'7715 ' = 224 /* NEONATAL INFEC MASTITIS */
'7716 ' = 224 /* NEONATAL CONJUNCTIVITIS */
'7717 ' = 224 /* NEONATAL CANDIDA INFECT */
'7718 ' = 224 /* PERINATAL INFECTION NEC */
'77181' = 224 /* SEPTICEMIA [SEPSIS] OF NEWBORN  OCT02 */
'77182' = 224 /* URINARY TRACT INFECTION OF NEWBORN  OCT02 */
'77183' = 224 /* BACTEREMIA OF NEWBORN */
'77189' = 224 /* OT INFECTIONS SPEC TO PERINATAL PERIOD OCT02 */
'7720 ' = 224 /* FETAL BLOOD LOSS NEC */
'7721 ' = 224 /* NB INTRAVENTRICULAR HEM */
'77210' = 224 /* INTRAVENT HEMORRHAGE NOS OCT01 */
'77211' = 224 /* INTRAVENT HEMORRHAGE GRADE I OCT01 */
'77212' = 224 /* INTRAVENT HEMORRHAGEGRADE II OCT01 */
'77213' = 224 /* INTRAVENT HEMORRHAGE GRADE III OCT01 */
'77214' = 224 /* INTRAVENT HEMORRHAGE GRADE IV  OCT01 */
'7722 ' = 224 /* NB SUBARACHNOID HEMORR */
'7723 ' = 224 /* POST-BIRTH UMBIL HEMORR */
'7724 ' = 224 /* NB GI HEMORRHAGE */
'7725 ' = 224 /* NB ADRENAL HEMORRHAGE */
'7726 ' = 224 /* NB CUTANEOUS HEMORRHAGE */
'7728 ' = 224 /* NEONATAL HEMORRHAGE NEC */
'7729 ' = 224 /* NEONATAL HEMORRHAGE NOS */
'7750 ' = 224 /* INFANT DIABET MOTHER SYN */
'7751 ' = 224 /* NEONAT DIABETES MELLITUS */
'7752 ' = 224 /* NEONAT MYASTHENIA GRAVIS */
'7753 ' = 224 /* NEONATAL THYROTOXICOSIS */
'7754 ' = 224 /* HYPOCALCEM/HYPOMAGNES NB */
'7755 ' = 224 /* NEONATAL DEHYDRATION */
'7756 ' = 224 /* NEONATAL HYPOGLYCEMIA */
'7757 ' = 224 /* LATE METAB ACIDOSIS NB */
'7758 ' = 224 /* TRANSIENT MET DIS NB NEC */
'77581' = 224 /* NB ACIDOSIS NEC */
'77589' = 224 /* NEONAT ENDO/MET DIS NEC */
'7759 ' = 224 /* TRANSIENT MET DIS NB NOS */
'7760 ' = 224 /* NB HEMORRHAGIC DISEASE */
'7761 ' = 224 /* NEONATAL THROMBOCYTOPEN */
'7762 ' = 224 /* DISSEM INTRAVASC COAG NB */
'7763 ' = 224 /* OTH NEONATAL COAG DIS */
'7764 ' = 224 /* POLYCYTHEMIA NEONATORUM */
'7765 ' = 224 /* CONGENITAL ANEMIA */
'7766 ' = 224 /* ANEMIA OF PREMATURITY */
'7767 ' = 224 /* NEONATAL NEUTROPENIA */
'7768 ' = 224 /* TRANSIENT HEMAT DIS NEC */
'7769 ' = 224 /* NB HEMATOLOGICAL DIS NOS */
'7771 ' = 224 /* MECONIUM OBSTRUCTION */
'7772 ' = 224 /* INTEST OBST-INSPISS MILK */
'7773 ' = 224 /* SWALLOWED BLOOD SYNDROME */
'7774 ' = 224 /* TRANSITORY ILEUS OF NB */
'7775 ' = 224 /* NECROT ENTEROCOLITIS NB */
'77750' = 224 /*	NEC ENTEROCOLTIS NB NOS */
'77751' = 224 /*	STG I NEC ENTEROCOL NB */
'77752' = 224 /*	STG II NEC ENTEROCOL NB */
'77753' = 224 /*	STG III NEC ENTEROCOL NB */
'7776 ' = 224 /* PERINATAL INTEST PERFOR */
'7778 ' = 224 /* PERINAT GI SYS DIS NEC */
'7779 ' = 224 /* PERINAT GI SYS DIS NOS */
'7780 ' = 224 /* HYDROPS FETALIS NO ISOIM */
'7781 ' = 224 /* SCLEREMA NEONATORUM */
'7782 ' = 224 /* NB COLD INJURY SYNDROME */
'7783 ' = 224 /* NB HYPOTHERMIA NEC */
'7784 ' = 224 /* NB TEMP REGULAT DIS NEC */
'7785 ' = 224 /* EDEMA OF NEWBORN NEC/NOS */
'7786 ' = 224 /* CONGENITAL HYDROCELE */
'7787 ' = 224 /* NB BREAST ENGORGEMENT */
'7788 ' = 224 /* NB INTEGUMENT COND NEC */
'7789 ' = 224 /* NB INTEGUMENT COND NOS */
'7790 ' = 224 /* CONVULSIONS IN NEWBORN */
'7791 ' = 224 /* NB CEREB IRRIT NEC/NOS */
'7792 ' = 224 /* CNS DYSFUNCTION SYN NB */
'7793 ' = 224 /* NB FEEDING PROBLEMS */
'77931' = 224 /*	NB FEEDING PROBLEMS */
'77932' = 224 /*	NB BILIOUS VOMITING */
'77933' = 224 /*	NB OTHER VOMITING */
'77934' = 224 /*	NB FAILURE TO THRIVE */
'7794 ' = 224 /* NB DRUG REACTION/INTOXIC */
'7795 ' = 661 /* DRUG WITHDRAWAL IN NEWBORN */
'7796 ' = 224 /* TERMINATION OF PREGNANCY */
'7797 ' = 224 /* PREVENTRICULAR LEUKOMALACIA OCT01 */
'7798 ' = 224 /* PERINATAL CONDITION NEC */
'77981' = 224 /* NEONATAL BRADYCARDIA   OCT02 */
'77982' = 224 /* NEONATAL TACHYCARDIA   OCT02 */
'77983' = 224 /* Delayed separation of umbilical cord */
'77985' = 224 /* NB CARDIAC ARREST */
'77989' = 224 /* OT SPEC COND ORIG IN PERINATAL PERIOD  OCT02 */
'7799 ' = 224 /* PERINATAL CONDITION NOS */
'7800 ' = 85 /* COMA AND STUPOR     J80  S92 */
'78001' = 85 /* COMA         OCT92 */
'78003' = 85 /* PERSISTENT VEGATATIVE STATE OCT93 */
'78009' = 85 /* STUPOR       OCT92 */
'7803 ' = 83 /* CONVULSIONS */
'78031' = 83 /* FEBRILE CONVULSIONS OCT97 */
'78032' = 83 /* COMPLX FEBRILE CONVULSNS */
'78033' = 83 /* POST TRAUMATIC SEIZURES */
'78039' = 83 /* OT CONVULSIONS OCT97 */
'78072' = 82 /*  FUNCTIONAL QUADRIPLEGIA */
'78091' = 224 /* FUSSY INFANT (BABY)     OCT02 */
'78092' = 224 /* EXCESSIVE CRYING OF INFANT (BABY)  OCT02 */
'7810 ' = 95 /* ABN INVOLUN MOVEMENT NEC */
'7811 ' = 95 /* SMELL & TASTE DISTURB */
'7812 ' = 95 /* ABNORMALITY OF GAIT */
'7813 ' = 95 /* LACK OF COORDINATION */
'7814 ' = 82 /* TRANSIENT LIMB PARALYSIS */
'7817 ' = 95 /* TETANY */
'7818 ' = 95 /* NEUROLOGIC NEGLECT SYNDROME OCT94 */
'7819 ' = 211 /* NERV/MUSCULSKEL SYM NEC */
'78191' = 211 /* LOSS OF HEIGHT      OCT00 */
'78192' = 211 /* ABNORMAL POSTURE    OCT00 */
'78194' = 211 /* Facial weakness */
'78199' = 211 /* OTHER SYMPTOMS-MUSCULOSKEL  OCT00 */
'7820 ' = 95 /*  SKIN SENSATION DISTURB */
'7824 ' = 151 /* JAUNDICE NOS */
'7825 ' = 133 /* CYANOSIS */
'7827 ' = 62 /*	SPONTANEOUS ECCHYMOSES	*/
'7831 ' = 58 /* ABNORMAL WEIGHT GAIN */
'7832 ' = 58 /* ABNORMAL LOSS OF WEIGHT */
'78321' = 58 /* LOSS OF WEIGHT     OCT00 */
'78322' = 58 /* UNDERWEIGHT      OCT00 */
'7833 ' = 58 /* FEEDING PROBLEM */
'7834 ' = 58 /* LACK NORM PHYSIOL DEVEL */
'78340' = 58 /* LACK NORM PHYSIOL DEVELOP UNSPEC  OCT00 */
'78341' = 58 /* FAILURE TO THRIVE       OCT00 */
'78342' = 58 /* DELAYED MILESTONE       OCT00 */
'78343' = 58 /* SHORT STATURE       OCT00 */
'78451' = 95 /*	DYSARTHRIA */
'78459' = 95 /*	SPEECH DISTURBANCE NEC */
'7835 ' = 58 /* POLYDIPSIA */
'7837 ' = 58 /* ADULT FAILURE TO THRIVE     OCT00 */
'7839 ' = 58 /* NUTR/METAB/DEVEL SYM NEC */
'7843 ' = 95 /* APHASIA */
'7845 ' = 95 /* SPEECH DISTURBANCE NEC */
'78452' = 95 /* FLNCY DSORD COND ELSEWHR */
'78460' = 95 /* SYMBOLIC DYSFUNCTION NOS */
'78461' = 95 /* ALEXIA AND DYSLEXIA */
'78469' = 95 /* SYMBOLIC DYSFUNCTION NEC */
'7850 ' = 106 /* TACHYCARDIA NOS */
'7851 ' = 106 /* PALPITATIONS */
'7852 ' = 96 /* CARDIAC MURMURS NEC */
'7853 ' = 96 /* ABNORM HEART SOUNDS NEC */
'78600' = 133 /* RESPIRATORY ABNORM NOS */
'78601' = 133 /* HYPERVENTILATION */
'78602' = 133 /* ORTHOPNEA */
'78603' = 133 /* APNEA      OCT98 */
'78604' = 133 /* CHEYNE-STOKES RESP OCT98 */
'78605' = 133 /* SHORTNESS OF BREATH  OCT98 */
'78606' = 133 /* TACHYPNEA    OCT98 */
'78607' = 133 /* WHEEZING     OCT98 */
'78609' = 133 /* RESPIRATORY ABNORM NEC */
'7862 ' = 133 /* COUGH */
'7863 ' = 133 /* HEMOPTYSIS */
'78630' = 133 /* HEMOPTYSIS NOS */
'78631' = 133 /* AC IDIO PUL HEMRG INFANT */
'78639' = 133 /* HEMOPTYSIS NEC */
'7864 ' = 133 /* ABNORMAL SPUTUM */
'78652' = 133 /* PAINFUL RESPIRATION */
'7866 ' = 133 /* CHEST SWELLING/MASS/LUMP */
'7867 ' = 133 /* ABNORMAL CHEST SOUNDS */
'7868 ' = 133 /* HICCOUGH */
'7869 ' = 133 /* RESP SYS/CHEST SYMP NEC */
'7891 ' = 151 /* HEPATOMEGALY */
'7895 ' = 151 /* ASCITES */
'78951' = 42  /*	MALIGNANT ASCITES */
'78959' = 151 /*	ASCITES NEC */
'7897 ' = 224 /*	COLIC */
'7904 ' = 151 /* ELEV TRANSAMINASE/LDH */
'7905 ' = 151 /* ABN SERUM ENZY LEVEL NEC */
'7920 ' = 95 /* ABN FND-CEREBROSPINAL FL */
'7925 ' = 158 /* CLOUDY DIALYSIS EFFLUENT     OCT00 */
'7930 ' = 95 /* ABN FINDING-SKULL & HEAD */
'7931 ' = 133 /* ABN FINDINGS-LUNG FIELD */
'79311'	 = 133	/* Solitary pulmonry nodule (Begin 2011)*/
'79319'	 = 133	/* Ot nonsp ab fnd lung fld (Begin 2011)*/
'7937 ' = 211 /* ABN FIND-MUSCULOSKEL SYS */
'79391' = 58 /* IMAGE TEST INCON D/T FAT */
'79400' = 95 /* ABN CNS FUNCT STUDY NOS */
'79401' = 95 /* ABNORM ECHOENCEPHALOGRAM */
'79402' = 95 /* ABN ELECTROENCEPHALOGRAM */
'79409' = 95 /* ABN CNS FUNCT STUDY NEC */
'79410' = 95 /* ABN STIMUL RESPONSE NOS */
'79411' = 95 /* ABN RETINAL FUNCT STUDY */
'79412' = 95 /* ABNORM ELECTRO-OCULOGRAM */
'79413' = 95 /* ABNORMAL VEP */
'79414' = 95 /* ABN OCULOMOTOR STUDIES */
'79415' = 95 /* ABN AUDITORY FUNCT STUDY */
'79416' = 95 /* ABN VESTIBULAR FUNC STUD */
'79417' = 95 /* ABNORM ELECTROMYOGRAM */
'79419' = 95 /* ABN PERIPH NERV STUD NEC */
'7942 ' = 133 /* ABN PULMONARY FUNC STUDY */
'7945 ' = 48 /* ABN THYROID FUNCT STUDY */
'7946 ' = 51 /* ABN ENDOCRINE STUDY NEC */
'7947 ' = 58 /* ABN BASAL METABOL STUDY */
'7948 ' = 151 /* ABN LIVER FUNCTION STUDY */
'7951 ' = 41 /* ABN PAP SMEAR-OTH SITE */
'79510' = 41 /*	ABN GLAND PAP SMR VAGINA */
'79511' = 41 /*	PAP SMEAR VAG W ASC-US */
'79512' = 41 /*	PAP SMEAR VAGINA W ASC-H */
'79513' = 41 /*	PAP SMEAR VAGINA W LGSIL */
'79514' = 41 /*	PAP SMEAR VAGINA W HGSIL */
'7952 ' = 217 /* ABN CHROMOSOMAL ANALYSIS */
'7957 ' = 58 /* IMMUNOLOGICAL FIND NEC */
'79579' = 58 /* NONSPECIFIC IMMUN FINDING NOS OCT94 */
'7961 ' = 95 /* ABNORMAL REFLEX */
'7994 ' = 52 /* CACHEXIA */
'79951' = 95 /* ATTN/CONCENTRATE DEFICIT */
'79952' = 95 /* COG COMMUNICATE DEFICIT */
'79953' = 95 /* VISUOSPATIAL DEFICIT */
'79954' = 95 /* PSYCHOMOTOR DEFICIT */
'79955' = 95 /* FRONTAL LOBE DEFICIT */
'79959' = 95 /* COGNITION SIGN/SYMPT NEC */
'80600' = 227 /* C1-C4 FX-CL/CORD INJ NOS */
'80601' = 227 /* C1-C4 FX-CL/COM CORD LES */
'80602' = 227 /* C1-C4 FX-CL/ANT CORD SYN */
'80603' = 227 /* C1-C4 FX-CL/CEN CORD SYN */
'80604' = 227 /* C1-C4 FX-CL/CORD INJ NEC */
'80605' = 227 /* C5-C7 FX-CL/CORD INJ NOS */
'80606' = 227 /* C5-C7 FX-CL/COM CORD LES */
'80607' = 227 /* C5-C7 FX-CL/ANT CORD SYN */
'80608' = 227 /* C5-C7 FX-CL/CEN CORD SYN */
'80609' = 227 /* C5-C7 FX-CL/CORD INJ NEC */
'80610' = 227 /* C1-C4 FX-OP/CORD INJ NOS */
'80611' = 227 /* C1-C4 FX-OP/COM CORD LES */
'80612' = 227 /* C1-C4 FX-OP/ANT CORD SYN */
'80613' = 227 /* C1-C4 FX-OP/CEN CORD SYN */
'80614' = 227 /* C1-C4 FX-OP/CORD INJ NEC */
'80615' = 227 /* C5-C7 FX-OP/CORD INJ NOS */
'80616' = 227 /* C5-C7 FX-OP/COM CORD LES */
'80617' = 227 /* C5-C7 FX-OP/ANT CORD SYN */
'80618' = 227 /* C5-C7 FX-OP/CEN CORD SYN */
'80619' = 227 /* C5-C7 FX-OP/CORD INJ NEC */
'80620' = 227 /* T1-T6 FX-CL/CORD INJ NOS */
'80621' = 227 /* T1-T6 FX-CL/COM CORD LES */
'80622' = 227 /* T1-T6 FX-CL/ANT CORD SYN */
'80623' = 227 /* T1-T6 FX-CL/CEN CORD SYN */
'80624' = 227 /* T1-T6 FX-CL/CORD INJ NEC */
'80625' = 227 /* T7-T12 FX-CL/CRD INJ NOS */
'80626' = 227 /* T7-T12 FX-CL/COM CRD LES */
'80627' = 227 /* T7-T12 FX-CL/ANT CRD SYN */
'80628' = 227 /* T7-T12 FX-CL/CEN CRD SYN */
'80629' = 227 /* T7-T12 FX-CL/CRD INJ NEC */
'80630' = 227 /* T1-T6 FX-OP/CORD INJ NOS */
'80631' = 227 /* T1-T6 FX-OP/COM CORD LES */
'80632' = 227 /* T1-T6 FX-OP/ANT CORD SYN */
'80633' = 227 /* T1-T6 FX-OP/CEN CORD SYN */
'80634' = 227 /* T1-T6 FX-OP/CORD INJ NEC */
'80635' = 227 /* T7-T12 FX-OP/CRD INJ NOS */
'80636' = 227 /* T7-T12 FX-OP/COM CRD LES */
'80637' = 227 /* T7-T12 FX-OP/ANT CRD SYN */
'80638' = 227 /* T7-T12 FX-OP/CEN CRD SYN */
'80639' = 227 /* T7-T12 FX-OP/CRD INJ NEC */
'8064 ' = 227 /* CL LUMBAR FX W CORD INJ */
'8065 ' = 227 /* OPN LUMBAR FX W CORD INJ */
'80660' = 227 /* FX SACRUM-CL/CRD INJ NOS */
'80661' = 227 /* FX SACR-CL/CAUDA EQU LES */
'80662' = 227 /* FX SACR-CL/CAUDA INJ NEC */
'80669' = 227 /* FX SACRUM-CL/CRD INJ NEC */
'80670' = 227 /* FX SACRUM-OP/CRD INJ NOS */
'80671' = 227 /* FX SACR-OP/CAUDA EQU LES */
'80672' = 227 /* FX SACR-OP/CAUDA INJ NEC */
'80679' = 227 /* FX SACRUM-OP/CRD INJ NEC */
'8068 ' = 227 /* VERT FX NOS-CL W CRD INJ */
'8069 ' = 227 /* VERT FX NOS-OP W CRD INJ */
'9072 ' = 227 /* LATE EFF SPINAL CORD INJ */
'95200' = 227 /* C1-C4 SPIN CORD INJ NOS */
'95201' = 227 /* COMPLETE LES CORD/C1-C4 */
'95202' = 227 /* ANTERIOR CORD SYND/C1-C4 */
'95203' = 227 /* CENTRAL CORD SYND/C1-C4 */
'95204' = 227 /* C1-C4 SPIN CORD INJ NEC */
'95205' = 227 /* C5-C7 SPIN CORD INJ NOS */
'95206' = 227 /* COMPLETE LES CORD/C5-C7 */
'95207' = 227 /* ANTERIOR CORD SYND/C5-C7 */
'95208' = 227 /* CENTRAL CORD SYND/C5-C7 */
'95209' = 227 /* C5-C7 SPIN CORD INJ NEC */
'95210' = 227 /* T1-T6 SPIN CORD INJ NOS */
'95211' = 227 /* COMPLETE LES CORD/T1-T6 */
'95212' = 227 /* ANTERIOR CORD SYND/T1-T6 */
'95213' = 227 /* CENTRAL CORD SYND/T1-T6 */
'95214' = 227 /* T1-T6 SPIN CORD INJ NEC */
'95215' = 227 /* T7-T12 SPIN CORD INJ NOS */
'95216' = 227 /* COMPLETE LES CORD/T7-T12 */
'95217' = 227 /* ANTERIOR CORD SYN/T7-T12 */
'95218' = 227 /* CENTRAL CORD SYN/T7-T12 */
'95219' = 227 /* T7-T12 SPIN CORD INJ NEC */
'9522 ' = 227 /* LUMBAR SPINAL CORD INJUR */
'9523 ' = 227 /* SACRAL SPINAL CORD INJUR */
'9524 ' = 227 /* CAUDA EQUINA INJURY */
'9528 ' = 227 /* SPIN CORD INJ-MULT SITE */
'9529 ' = 227 /* SPINAL CORD INJURY NOS */
'96500' = 661 /* POISONING BY OPIUM */
'96501' = 661 /* POISONING BY HEROIN */
'96502' = 661 /* POISONING BY METHADONE */
'96509' = 661 /* POISONING BY OTH NARCOTICS */
'9941 ' = 85 /* DROWNING-NONFATAL SUBMER */
'V1029' = 41 /* HX-INTRATHORACIC MAL NEC */
'V1052' = 33 /* HX OF KIDNEY MALIGNANCY */
'V1053' = 33 /* HX MALIGNANT NEOPLASM- RENAL PELVIS */
'V1060' = 39 /* HX OF LEUKEMIA NOS */
'V1061' = 39 /* HX OF LYMPHOID LEUKEMIA */
'V1062' = 39 /* HX OF MYELOID LEUKEMIA */
'V1063' = 39 /* HX OF MONOCYTIC LEUKEMIA */
'V1069' = 39 /* HX OF LEUKEMIA NEC */
'V1071' = 38 /* HX-LYMPHOSARCOMA */
'V1079' = 38 /* HX-LYMPHATIC MALIGN NEC */
'V1081' = 41 /* HX OF BONE MALIGNANCY */
'V1084' = 41 /* HX OF EYE MALIGNANCY */
'V1085' = 35 /* HX OF BRAIN MALIGNANCY */
'V1086' = 35 /* HX-MALIGN NERVE SYST NEC */
'V1088' = 41 /* HX-ENDOCRINE MALIGN NEC */
'V1089' = 41 /* HX OF MALIGNANCY NEC */
'V109 ' = 41 /* HX OF MALIGNANCY NOS */
'V1090' = 41 /* HX MALIG NEOPLASM NOS */
'V1091' = 41 /* HX MALIG NEUROENDO TUMOR */
'V121 ' = 52 /* HX-NUTRITION DEFICIENCY */
'V122 ' = 58 /* HX-ENDOCR/META/IMMUN DIS */
'V1221'	 = 58	/* Hx gestational diabetes (Begin 2011)	*/
'V1229'	 = 58	/* Hx-endocr/meta/immun dis (Begin 2011)*/
'V124 ' = 95 /* HX-NERV SYS/SENS ORG DIS */
'V1240' = 95 /* PERS HX UNSPEC NERV SYS DX OCT97 */
'V1241' = 95 /* PERS HX BENIGN NEOP BRAIN OCT97 */
'V1242' = 95 /* PERSONL HX INFECTION CNS */
'V1249' = 95 /* PERS HX OT DIS NERV SYS OCT97 */
'V126 ' = 133 /* HX-RESPIRATORY SYS DIS */
'V1260' = 133 /* HX RESP SYSTEM DIS NOS */
'V1261' = 133 /* PRSNL HX RECUR PNEUMONIA */
'V1269' = 133 /* HX RESP SYSTEM DIS NEC */
'V135 ' = 211 /* HX-MUSCULOSKELET DIS NEC */
'V1359' = 211 /*	HX MUSCULOSKLETL DIS NEC */
'V136 ' = 217 /* HX-CONGENITAL MALFORM */
'V1361' = 215 /* HX HYPOSPADIAS   OCT98 */
'V1362' = 215 /* HX-CONG MALFORM-GU */
'V1363' = 216 /* HX-CONG MALFORM-NERVOUS */
'V1364' = 217 /* HX-CONG MALFORM-EYE,FACE */
'V1365' = 213 /* HX-CONG MALFORM-HEART */
'V1366' = 217 /* HX-CONG MALFORM-RESP SYS */
'V1367' = 214 /* HX-CONG MALFORM-DIGEST */
'V1368' = 217 /* HX-CONG MALFORM-SKIN,MS */
'V1369' = 217 /* HX OTH CONG ANOM  OCT98 */
'V137 ' = 224 /* HX-PERINATAL PROBLEMS */
'V2130' = 219 /* LOW BIRTH WEIGHT UNSPEC     OCT00 */
'V2131' = 219 /* LOW BIRTH WEIGHT- < 500 GRAMS   OCT00 */
'V2132' = 219 /* LOW BIRTH WEIGHT- 500-999 GRAMS OCT00 */
'V2133' = 219 /* LOW BIRTH WEIGHT- 1000-1499 GRAMS OCT00 */
'V2134' = 219 /* LOW BIRTH WEIGHT- 1500-1999 GRAMS OCT00 */
'V2135' = 219 /* LOW BIRTH WEIGHT- 2000-2500 GRAMS OCT00 */
'V415 ' = 95 /* SMELL AND TASTE PROBLEM */
'V420 ' = 158 /* KIDNEY TRANSPLANT STATUS */
'V422 ' = 96 /* HEART VALVE TRANSPLANT */
'V426 ' = 133 /* LUNG TRANSPLANT STATUS */
'V427 ' = 151 /* LIVER TRANSPLANT STATUS */
'V433 ' = 96 /* HEART VALVE REPLAC NEC */
'V436 ' = 211 /* JOINT REPLACEMENT NEC */
'V4360' = 211 /* JOINT REPLACE NOS OCT94 */
'V4361' = 211 /* JOINT REPLACE SHOULDER OCT94 */
'V4362' = 211 /* JOINT REPLACE ELBOW OCT94 */
'V4363' = 211 /* JOINT REPLACE WRIST OCT94 */
'V4364' = 211 /* JOINT REPLACE HIP OCT94 */
'V4365' = 211 /* JOINT REPLACE KNEE OCT94 */
'V4366' = 211 /* JOINT REPLACE ANKLE OCT94 */
'V4369' = 211 /* JOINT REPLACE NEC OCT94 */
'V437 ' = 211 /* LIMB REPLACEMENT NEC */
'V400 ' = 654 /* PROBLEMS WITH LEARNING */
'V401 ' = 654 /* PROBLEMS WITH COMMUNICATION */
'V441 ' = 52 /* GASTROSTOMY STATUS */
'V450 ' = 105 /* CARDIAC PACEMAKER STATUS */
'V4500' = 105 /* CARDIAC DEVICE NOS IN SITU  OCT94 */
'V4501' = 105 /* CARDIAC PACEM IN SITU OCT94 */
'V4502' = 105 /* AUTO IMPLANT DEBRIL IN SITU OCT94 */
'V4509' = 105 /* OTH CARDIAC DEVICE NEC IN SITU OCT94 */
'V451 ' = 158 /* RENAL DIALYSIS STATUS */
'V4511' = 158 /*	RENAL DIALYSIS STATUS */
'V4512' = 158 /*	NONCMPLNT W RENAL DIALYS */
'V452 ' = 95 /* VENTRICULAR SHUNT STATUS */
'V454 ' = 211 /* ARTHRODESIS STATUS */
'V481 ' = 211 /* DEFICIENCIES NECK/TRUNK */
'V482 ' = 211 /* MECHANICAL PROB W HEAD */
'V483 ' = 211 /* MECH PROB W NECK & TRUNK */
'V484 ' = 95 /* SENSORY PROBLEM W HEAD */
'V485 ' = 95 /* SENSOR PROB W NECK/TRUNK */
'V490 ' = 211 /* DEFICIENCIES OF LIMBS */
'V491 ' = 211 /* MECHANICAL PROB W LIMBS */
'V492 ' = 211 /* MOTOR PROBLEMS W LIMBS */
'V493 ' = 95 /* SENSORY PROBLEMS W LIMBS */
'V495 ' = 211 /* LIMB PROBLEMS NEC */
'V4960' = 211 /* AMPUTATION STATUS - UPP EXT NOS OCT94 */
'V4961' = 211 /* AMPUTATION STATUS - THUMB OCT94 */
'V4962' = 211 /* AMPUTATION STATUS - OTH FINGER OCT94 */
'V4963' = 211 /* AMPUTATION STATUS - HAND OCT94 */
'V4964' = 211 /* AMPUTATION STATUS - WRIST OCT94 */
'V4965' = 211 /* AMPUTATION STATUS - BELOW ELBOW OCT94 */
'V4966' = 211 /* AMPUTATION STATUS - ABOVE ELBOW OCT94 */
'V4967' = 211 /* AMPUTATION STATUS - SHOULDER OCT94 */
'V4970' = 211 /* AMPUTATION STATUS - LOW EXT NOS OCT94 */
'V4971' = 211 /* AMPUTATION STATUS - GREAT TOE OCT94 */
'V4972' = 211 /* AMPUTATION STATUS - OTHER TOE OCT94 */
'V4973' = 211 /* AMPUTATION STATUS - FOOT OCT94 */
'V4974' = 211 /* AMPUTATION STATUS - ANKLE OCT94 */
'V4975' = 211 /* AMPUTATION STATUS - BELOW KNEE OCT94 */
'V4976' = 211 /* AMPUTATION STATUS - ABOVE KNEE OCT94 */
'V4977' = 211 /* AMPUTATION STATUS - HIP OCT94 */
'V502 ' = 224 /* ROUTINE CIRCUMCISION */
'V530 ' = 95 /* ADJUST NERV SYST DEVICE */
'V5301' = 95 /* FIT ADJUST CEREBR VENTR SHUNT OCT97 */
'V5302' = 95 /* FIT ADJUST NEUROPACEMAKER OCT97 */
'V5309' = 95 /* FIT ADJUST OT NERV SYS DEV OCT97 */
'V533 ' = 105 /* ADJUST CARDIAC PACEMAKER */
'V5331' = 105 /* ADJUST CARDIAC PACEMAKER OCT94 */
'V5332' = 105 /* ADJUST AUTO IMPLANT DEBRIL  OCT94 */
'V5339' = 105 /* ADJUST OTH CARDIAC DEVICE OCT94 */
'V537 ' = 211 /* FIT ORTHOPEDIC DEVICES */
'V560 ' = 158 /* RENAL DIALYSIS ENCOUNTER */
'V561 ' = 158 /* FIT ADJUST DIALYSIS CATHET OCT95 */
'V562 ' = 158 /* FIT ADJUST PERITON DIAL CATH OCT98 */
'V5631' = 158 /* ADEQUACY TESTING-HEMODIALYSIS    OCT00 */
'V5632' = 158 /* ADEQUACY TESTING-PERITONEAL DIALYSIS OCT00 */
'V568 ' = 158 /* DIALYSIS ENCOUNTER- NEC */
'V6542' = 661 /* COUNSELING FOR SUBSTANCE ABUSE  */
'V711 ' = 41 /* OBSV-SUSPCT MAL NEOPLASM */
'V850 ' = 58 /* BMI LESS THAN 19 */
'V8521' = 58 /* BMI 25.0-25.9 */
'V8522' = 58 /* BMI 26.0-26.9 */
'V8523' = 58 /* BMI 27.0-27.9 */
'V8524' = 58 /* BMI 28.0-28.9 */
'V8525' = 58 /* BMI 29.0-29.9 */
'V8530' = 58 /* BMI 30.0-30.9 */
'V8531' = 58 /* BMI 31.0-31.9 */
'V8532' = 58 /* BMI 32.0-32.9 */
'V8533' = 58 /* BMI 33.0-33.9 */
'V8534' = 58 /* BMI 34.0-34.9 */
'V8535' = 58 /* BMI 35.0-35.9 */
'V8536' = 58 /* BMI 36.0-36.9 */
'V8537' = 58 /* BMI 37.0-37.9 */
'V8538' = 58 /* BMI 38.0-38.9 */
'V8539' = 58 /* BMI 39.0-39.9 */
'V854 ' = 58 /* BMI 40 AND OVER */
'V8541' = 58 /* BMI 40.0-44.9, ADULT */
'V8542' = 58 /* BMI 45.0-49.9, ADULT */
'V8543' = 58 /* BMI 50.0-59.9, ADULT */
'V8544' = 58 /* BMI 60.0-69.9, ADULT */
'V8545' = 58 /* BMI 70 AND OVER, ADULT */
'V8551' = 58 /* BMI, PEDIATRIC <5% */
'V8553' = 58 /* BMI, PEDIATRIC 85% - <95% */
'V8554' = 58 /* BMI, PEDIATRIC >= 95%     */
OTHER   = 0
;










/*============================================================================;
*  TITLE:
*          FORMAT LIBRARY FOR PEDIATRIC QUALITY INDICATORS
*
*  DESCRIPTION:
*          COVARIATE FORMAT LIB FOR AHRQ PEDIATRIC QUALITY INDICATORS;
*
*          >>>  VERSION 5.0.3 - FEBRUARY, 2016 <<<
*
*============================================================================;*/

 /* -------------------------------------------------------------- */
 /* ---   FORMATS FOR SEX STRATIFIERS                          --- */
 /* ---   ONE FORMAT PER QI.  NUMBER REFERS TO N VARIABLE IN   --- */
 /* ---   MODULE 3. ASSIGNS ARRAY INDEX FOR SEX CATEGORIES     --- */
 /* -------------------------------------------------------------- */

Value S1PDFMT
1 = 0
2 = 0
other = 0 
; 

Value S2PDFMT
1 = 0
2 = 0
other = 0 
; 

Value S5PDFMT
1 = 0
2 = 0
other = 0 
; 

Value S6PDFMT
1 = 0
2 = 0
other = 0 
; 

Value S8PDFMT
1 = 0
2 = 0
other = 0 
; 

Value S9PDFMT
1 = 0
2 = 0
other = 0 
; 

Value S10PDFMT
1 = 0
2 = 0
other = 0 
; 

Value S11PDFMT
1 = 0
2 = 0
other = 0 
; 

Value S12PDFMT
1 = 0
2 = 0
other = 0 
; 

Value S70PDFMT
1 = 0
2 = 0
other = 0 
; 

Value S71PDFMT
1 = 0
2 = 1
other = 0 
; 

Value S72PDFMT
1 = 0
2 = 0
other = 0 
; 

 /* -------------------------------------------------------------- */
 /* ---   FORMATS FOR AGE (YEARS) STRATIFIERS                  --- */
 /* ---   ONE FORMAT PER QI.  NUMBER REFERS TO N VARIABLE IN   --- */
 /* ---   MODULE 3. ASSIGNS ARRAY INDEX FOR AGE CATEGORIES     --- */
 /* -------------------------------------------------------------- */

Value P1PDFMT
2 = 0
3 = 0
4 = 0
5 = 0
other = 0 
; 

Value P2PDFMT
2 = 0
3 = 0
4 = 2
5 = 1
other = 0 
; 

Value P5PDFMT
2 = 2
3 = 2
4 = 2
5 = 1
other = 0 
; 

Value P6PDFMT
2 = 0
3 = 0
4 = 0
5 = 0
other = 0 
; 

Value P8PDFMT
2 = 0
3 = 0
4 = 0
5 = 0
other = 0 
; 

Value P9PDFMT
2 = 4
3 = 3
4 = 2
5 = 1
other = 0 
; 

Value P10PDFMT
2 = 0
3 = 3
4 = 2
5 = 1
other = 0 
; 

Value P11PDFMT
2 = 0
3 = 0
4 = 0
5 = 0
other = 0 
; 

Value P12PDFMT
2 = 1
3 = 2
4 = 3
5 = 4
other = 0 
; 

Value P70PDFMT
2 = 0
3 = 0
4 = 0
5 = 0
other = 0 
; 

Value P71PDFMT
2 = 0
3 = 0
4 = 0
5 = 0
other = 0 
; 

Value P72PDFMT
2 = 0
3 = 0
4 = 0
5 = 0
other = 0 
; 

 /* -------------------------------------------------------------- */
 /* ---   FORMATS FOR AGE (DAYS) STRATIFIERS                   --- */
 /* ---   ONE FORMAT PER QI.  NUMBER REFERS TO N VARIABLE IN   --- */
 /* ---   MODULE 3. ASSIGNS ARRAY INDEX FOR AGE CATEGORIES     --- */
 /* -------------------------------------------------------------- */

Value A1PDFMT
2 = 0
3 = 0
4 = 0
other = 0 
; 

Value A2PDFMT
2 = 0
3 = 0
4 = 0
other = 0 
; 

Value A5PDFMT
2 = 0
3 = 0
4 = 0
other = 0 
; 

Value A6PDFMT
1 = 3
2 = 2
3 = 2
4 = 1
other = 0 
; 

Value A8PDFMT
2 = 0
3 = 0
4 = 0
other = 0 
; 

Value A9PDFMT
2 = 5
3 = 5
4 = 5
other = 0 
; 

Value A10PDFMT
2 = 0
3 = 0
4 = 0
other = 0 
; 

Value A11PDFMT
2 = 0
3 = 0
4 = 0
other = 0 
; 

Value A12PDFMT
2 = 0
3 = 0
4 = 0
other = 0 
; 

Value A70PDFMT
2 = 0
3 = 0
4 = 0
other = 0 
; 

Value A71PDFMT
2 = 0
3 = 0
4 = 0
other = 0 
; 

Value A72PDFMT
2 = 0
3 = 0
4 = 0
other = 0 
; 

 /* -------------------------------------------------------------- */
 /* ---   FORMATS FOR BIRTHWEIGHT STRATIFIERS                  --- */
 /* ---   ONE FORMAT PER QI.  NUMBER REFERS TO N VARIABLE IN   --- */
 /* ---   MODULE 3. ASSIGNS ARRAY INDEX FOR BWHT CATEGORIES    --- */
 /* -------------------------------------------------------------- */

Value B1PDFMT
0 = 0
1 = 0
2 = 0
3 = 0
4 = 0
5 = 0
6 = 0
7 = 0
8 = 0
9 = 0
other = 0 
; 

Value B2PDFMT
0 = 0
1 = 0
2 = 0
3 = 0
4 = 0
5 = 0
6 = 0
7 = 0
8 = 0
9 = 0
other = 0 
; 

Value B5PDFMT
0 = 0
1 = 0
2 = 0
3 = 0
4 = 0
5 = 0
6 = 0
7 = 0
8 = 0
9 = 0
other = 0 
; 

Value B6PDFMT
0 = 0
1 = 4
2 = 4
3 = 4
4 = 4
5 = 4
6 = 4
7 = 4
8 = 4
9 = 0
other = 0 
; 

Value B8PDFMT
0 = 0
1 = 0
2 = 0
3 = 0
4 = 0
5 = 0
6 = 0
7 = 0
8 = 0
9 = 0
other = 0 
; 

Value B9PDFMT
0 = 0
1 = 0
2 = 0
3 = 0
4 = 0
5 = 0
6 = 0
7 = 0
8 = 0
9 = 0
other = 0 
; 

Value B10PDFMT
0 = 0
1 = 0
2 = 0
3 = 0
4 = 0
5 = 0
6 = 0
7 = 0
8 = 0
9 = 0
other = 0 
; 

Value B11PDFMT
0 = 0
1 = 0
2 = 0
3 = 0
4 = 0
5 = 0
6 = 0
7 = 0
8 = 0
9 = 0
other = 0 
; 

Value B12PDFMT
0 = 0
1 = 7
2 = 7
3 = 6
4 = 5
5 = 0
6 = 0
7 = 0
8 = 0
9 = 0
other = 0 
; 

Value B70PDFMT
0 = 0
1 = 0
2 = 0
3 = 0
4 = 0
5 = 0
6 = 0
7 = 0
8 = 0
9 = 0
other = 0 
; 

Value B71PDFMT
0 = 0
1 = 9
2 = 9
3 = 8
4 = 7
5 = 6
6 = 5
7 = 4
8 = 3
9 = 2
other = 0 
; 

Value B72PDFMT
0 = 0
1 = 3
2 = 3
3 = 2
4 = 1
5 = 1
6 = 1
7 = 1
8 = 1
9 = 1
other = 0 
; 


 /* -------------------------------------------------------------- */
 /* ---   FORMATS FOR DRG STRATIFIERS                          --- */
 /* ---   MODULE 3. ASSIGNS ARRAY INDEX FOR DRG CATEGORIES     --- */
 /* -------------------------------------------------------------- */

 /* CMS-DRG (V24) TO MODIFIED DRG */;

VALUE $DRGFMT
001 = 0103
002 = 0103
003 = 0103
004 = 0104
005 = 0107
006 = 0108
007 = 0108
008 = 0108
009 = 0109
010 = 0110
011 = 0110
012 = 0111
013 = 0112
014 = 0114
015 = 0115
016 = 0117
017 = 0117
018 = 0118
019 = 0118
020 = 0198
021 = 0119
022 = 0120
023 = 0121
024 = 0198
025 = 0198
026 = 0128
027 = 0122
028 = 0123
029 = 0123
030 = 0123
031 = 0124
032 = 0124
033 = 0124
034 = 0125
035 = 0125
036 = 0203
037 = 0201
038 = 0203
039 = 0203
040 = 0202
041 = 0202
042 = 0203
043 = 0206
044 = 0204
045 = 0205
046 = 0206
047 = 0206
048 = 0206
049 = 0301
050 = 0305
051 = 0305
052 = 0302
053 = 0303
054 = 0303
055 = 0302
056 = 0302
057 = 0302
058 = 0302
059 = 0302
060 = 0302
061 = 0302
062 = 0302
063 = 0302
064 = 0306
065 = 0307
066 = 0308
067 = 0309
068 = 0309
069 = 0309
070 = 0309
071 = 0309
072 = 0310
073 = 0310
074 = 0310
075 = 0401
076 = 0402
077 = 0402
078 = 0403
079 = 0404
080 = 0404
081 = 0404
082 = 0405
083 = 0406
084 = 0406
085 = 0407
086 = 0407
087 = 0408
088 = 0409
089 = 0410
090 = 0410
091 = 0410
092 = 0411
093 = 0411
094 = 0412
095 = 0412
096 = 0413
097 = 0413
098 = 0413
099 = 0414
100 = 0414
101 = 0415
102 = 0415
103 = 7701
104 = 0503
105 = 0503
106 = 0506
107 = 0507
108 = 0505
109 = 0507
110 = 0508
111 = 0508
112 = 0599
113 = 0509
114 = 0515
115 = 0510
116 = 0510
117 = 0517
118 = 0516
119 = 0518
120 = 0519
121 = 0520
122 = 0520
123 = 0521
124 = 0522
125 = 0522
126 = 0523
127 = 0524
128 = 0525
129 = 0526
130 = 0527
131 = 0527
132 = 0528
133 = 0528
134 = 0529
135 = 0530
136 = 0530
137 = 0530
138 = 0531
139 = 0531
140 = 0532
141 = 0533
142 = 0533
143 = 0534
144 = 0535
145 = 0535
146 = 0603
147 = 0603
148 = 0602
149 = 0602
150 = 0604
151 = 0604
152 = 0607
153 = 0607
154 = 0601
155 = 0601
156 = 0601
157 = 0608
158 = 0608
159 = 0610
160 = 0610
161 = 0609
162 = 0609
163 = 0609
164 = 0605
165 = 0605
166 = 0606
167 = 0606
168 = 0304
169 = 0304
170 = 0611
171 = 0611
172 = 0614
173 = 0614
174 = 0615
175 = 0615
176 = 0616
177 = 0617
178 = 0617
179 = 0618
180 = 0619
181 = 0619
182 = 0620
183 = 0620
184 = 0620
185 = 0311
186 = 0311
187 = 0311
188 = 0621
189 = 0621
190 = 0621
191 = 0701
192 = 0701
193 = 0702
194 = 0702
195 = 0703
196 = 0703
197 = 0704
198 = 0704
199 = 0706
200 = 0706
201 = 0707
202 = 0708
203 = 0709
204 = 0710
205 = 0711
206 = 0711
207 = 0712
208 = 0712
209 = 0899
210 = 0811
211 = 0811
212 = 0811
213 = 0809
214 = 0899
215 = 0899
216 = 0810
217 = 0805
218 = 0816
219 = 0816
220 = 0816
221 = 0899
222 = 0899
223 = 0822
224 = 0824
225 = 0820
226 = 0819
227 = 0819
228 = 0821
229 = 0825
230 = 0818
231 = 0899
232 = 0823
233 = 0826
234 = 0826
235 = 0827
236 = 0828
237 = 0829
238 = 0830
239 = 0831
240 = 0832
241 = 0832
242 = 0833
243 = 0834
244 = 0835
245 = 0835
246 = 0835
247 = 0836
248 = 0837
249 = 0838
250 = 0839
251 = 0839
252 = 0839
253 = 0839
254 = 0839
255 = 0839
256 = 0840
257 = 0904
258 = 0904
259 = 0905
260 = 0905
261 = 0905
262 = 0905
263 = 0901
264 = 0901
265 = 0902
266 = 0902
267 = 0903
268 = 0903
269 = 0903
270 = 0903
271 = 0906
272 = 0907
273 = 0907
274 = 0908
275 = 0908
276 = 0909
277 = 0910
278 = 0910
279 = 0910
280 = 0911
281 = 0911
282 = 0911
283 = 0912
284 = 0912
285 = 1002
286 = 1001
287 = 1004
288 = 1003
289 = 1005
290 = 1005
291 = 1005
292 = 1006
293 = 1006
294 = 1007
295 = 1007
296 = 1008
297 = 1008
298 = 1008
299 = 1009
300 = 1010
301 = 1010
302 = 1101
303 = 1103
304 = 1104
305 = 1104
306 = 1106
307 = 1106
308 = 1105
309 = 1105
310 = 1107
311 = 1107
312 = 1108
313 = 1108
314 = 1108
315 = 1109
316 = 1110
317 = 1111
318 = 1112
319 = 1112
320 = 1113
321 = 1113
322 = 1113
323 = 1114
324 = 1115
325 = 1116
326 = 1116
327 = 1116
328 = 1117
329 = 1117
330 = 1117
331 = 1118
332 = 1118
333 = 1118
334 = 1201
335 = 1201
336 = 1204
337 = 1204
338 = 1203
339 = 1203
340 = 1203
341 = 1202
342 = 1206
343 = 1206
344 = 1205
345 = 1206
346 = 1207
347 = 1207
348 = 1208
349 = 1208
350 = 1209
351 = 1210
352 = 1210
353 = 1301
354 = 1303
355 = 1303
356 = 1307
357 = 1302
358 = 1304
359 = 1304
360 = 1306
361 = 1305
362 = 1305
363 = 1305
364 = 1305
365 = 1308
366 = 1309
367 = 1309
368 = 1310
369 = 1311
370 = 1401
371 = 1401
372 = 1405
373 = 1405
374 = 1402
375 = 1402
376 = 1406
377 = 1403
378 = 1407
379 = 1408
380 = 1409
381 = 1404
382 = 1410
383 = 1411
384 = 1412
385 = 1501
386 = 1502
387 = 1503
388 = 1504
389 = 1505
390 = 1506
391 = 1507
392 = 1601
393 = 1601
394 = 1602
395 = 1604
396 = 1604
397 = 1605
398 = 1606
399 = 1606
400 = 1799
401 = 1708
402 = 1708
403 = 1713
404 = 1713
405 = 1711
406 = 1709
407 = 1709
408 = 1710
409 = 1716
410 = 1715
411 = 1714
412 = 1714
413 = 1714
414 = 1714
415 = 1899
416 = 1898
417 = 1807
418 = 1803
419 = 1804
420 = 1804
421 = 1805
422 = 1805
423 = 1806
424 = 1909
425 = 1910
426 = 1911
427 = 1912
428 = 1913
429 = 1914
430 = 1915
431 = 1916
432 = 1917
433 = 2018
434 = 2098
435 = 2098
436 = 2098
437 = 2098
438 = 2098
439 = 2102
440 = 2101
441 = 2103
442 = 2104
443 = 2104
444 = 2105
445 = 2105
446 = 2105
447 = 2106
448 = 2106
449 = 2107
450 = 2107
451 = 2107
452 = 2108
453 = 2108
454 = 2109
455 = 2109
456 = 2298
457 = 2298
458 = 2298
459 = 2298
460 = 2298
461 = 2301
462 = 2302
463 = 2303
464 = 2303
465 = 2304
466 = 2304
467 = 2305
468 = 8899
469 = 8898
470 = 8898
471 = 0804
472 = 2299
473 = 1711
474 = 0198
475 = 0416
476 = 8899
477 = 8899
478 = 0514
479 = 0514
480 = 7702
481 = 7705
482 = 7799
483 = 7799
484 = 2406
485 = 2407
486 = 2408
487 = 2409
488 = 2501
489 = 2502
490 = 2503
491 = 0812
492 = 1712
493 = 0705
494 = 0705
495 = 7703
496 = 0801
497 = 0803
498 = 0803
499 = 0815
500 = 0815
501 = 0813
502 = 0813
503 = 0814
504 = 2210
505 = 2212
506 = 2201
507 = 2201
508 = 2213
509 = 2213
510 = 2214
511 = 2214
512 = 7704
513 = 7706
514 = 0599
515 = 0504
516 = 0502
517 = 0502
518 = 0513
519 = 0808
520 = 0808
521 = 2019
522 = 2019
523 = 2020
524 = 0116
525 = 0501
526 = 0511
527 = 0511
528 = 0101
529 = 0105
530 = 0105
531 = 0104
532 = 0104
533 = 0107
534 = 0107
535 = 0504
536 = 0504
537 = 0817
538 = 0817
539 = 1707
540 = 1707
541 = 7799
542 = 7799
543 = 0102
544 = 0807
545 = 0806
546 = 0802
547 = 0507
548 = 0507
549 = 0507
550 = 0507
551 = 0510
552 = 0510
553 = 0514
554 = 0514
555 = 0502
556 = 0502
557 = 0511
558 = 0511
559 = 0113
560 = 0126
561 = 0127
562 = 0128
563 = 0128
564 = 0129
565 = 0416
566 = 0416
567 = 0601
568 = 0601
569 = 0602
570 = 0602
571 = 0612
572 = 0613
573 = 1102
574 = 1603
575 = 1807
576 = 1808
577 = 0106
578 = 1801
579 = 1802
OTHER = 8898
;

 /* MS-DRG (V25) TO MODIFIED DRG */;

VALUE $DRGF2T
001 = 7701
002 = 7701
003 = 7799
004 = 7799
005 = 7702
006 = 7702
007 = 7703
008 = 7704
009 = 7705
010 = 7706
011 = 7799
012 = 7799
013 = 7799
014 = 7705
015 = 7705
016 = 7705
017 = 7705
020 = 0101
021 = 0101
022 = 0101
023 = 0102
024 = 0102
025 = 0103
026 = 0103
027 = 0103
028 = 0104
029 = 0104
030 = 0104
031 = 0105
032 = 0105
033 = 0105
034 = 0106
035 = 0106
036 = 0106
037 = 0107
038 = 0107
039 = 0107
040 = 0108
041 = 0108
042 = 0108
052 = 0109
053 = 0109
054 = 0110
055 = 0110
056 = 0111
057 = 0111
058 = 0112
059 = 0112
060 = 0112
061 = 0113
062 = 0113
063 = 0113
064 = 0114
065 = 0114
066 = 0114
067 = 0115
068 = 0115
069 = 0116
070 = 0117
071 = 0117
072 = 0117
073 = 0118
074 = 0118
075 = 0119
076 = 0119
077 = 0120
078 = 0120
079 = 0120
080 = 0121
081 = 0121
082 = 0122
083 = 0122
084 = 0122
085 = 0123
086 = 0123
087 = 0123
088 = 0124
089 = 0124
090 = 0124
091 = 0125
092 = 0125
093 = 0125
094 = 0126
095 = 0126
096 = 0126
097 = 0127
098 = 0127
099 = 0127
100 = 0128
101 = 0128
102 = 0129
103 = 0129
113 = 0201
114 = 0201
115 = 0202
116 = 0203
117 = 0203
121 = 0204
122 = 0204
123 = 0205
124 = 0206
125 = 0206
129 = 0301
130 = 0301
131 = 0301
132 = 0301
133 = 0302
134 = 0302
135 = 0303
136 = 0303
137 = 0304
138 = 0304
139 = 0305
146 = 0306
147 = 0306
148 = 0306
149 = 0307
150 = 0308
151 = 0308
152 = 0309
153 = 0309
154 = 0310
155 = 0310
156 = 0310
157 = 0311
158 = 0311
159 = 0311
163 = 0401
164 = 0401
165 = 0401
166 = 0402
167 = 0402
168 = 0402
175 = 0403
176 = 0403
177 = 0404
178 = 0404
179 = 0404
180 = 0405
181 = 0405
182 = 0405
183 = 0406
184 = 0406
185 = 0406
186 = 0407
187 = 0407
188 = 0407
189 = 0408
190 = 0409
191 = 0409
192 = 0409
193 = 0410
194 = 0410
195 = 0410
196 = 0411
197 = 0411
198 = 0411
199 = 0412
200 = 0412
201 = 0412
202 = 0413
203 = 0413
204 = 0414
205 = 0415
206 = 0415
207 = 0416
208 = 0416
215 = 0501
216 = 0503
217 = 0503
218 = 0503
219 = 0503
220 = 0503
221 = 0503
222 = 0504
223 = 0504
224 = 0504
225 = 0504
226 = 0504
227 = 0504
228 = 0505
229 = 0505
230 = 0505
231 = 0506
232 = 0506
233 = 0507
234 = 0507
235 = 0507
236 = 0507
237 = 0508
238 = 0508
239 = 0509
240 = 0509
241 = 0509
242 = 0510
243 = 0510
244 = 0510
245 = 0510
246 = 0511
247 = 0511
248 = 0502
249 = 0502
250 = 0513
251 = 0513
252 = 0514
253 = 0514
254 = 0514
255 = 0515
256 = 0515
257 = 0515
258 = 0516
259 = 0516
260 = 0517
261 = 0517
262 = 0517
263 = 0518
264 = 0519
265 = 0510
266 = 0540
267 = 0540
280 = 0520
281 = 0520
282 = 0520
283 = 0521
284 = 0521
285 = 0521
286 = 0522
287 = 0522
288 = 0523
289 = 0523
290 = 0523
291 = 0524
292 = 0524
293 = 0524
294 = 0525
295 = 0525
296 = 0526
297 = 0526
298 = 0526
299 = 0527
300 = 0527
301 = 0527
302 = 0528
303 = 0528
304 = 0529
305 = 0529
306 = 0530
307 = 0530
308 = 0531
309 = 0531
310 = 0531
311 = 0532
312 = 0533
313 = 0534
314 = 0535
315 = 0535
316 = 0535
326 = 0601
327 = 0601
328 = 0601
329 = 0602
330 = 0602
331 = 0602
332 = 0603
333 = 0603
334 = 0603
335 = 0604
336 = 0604
337 = 0604
338 = 0605
339 = 0605
340 = 0605
341 = 0606
342 = 0606
343 = 0606
344 = 0607
345 = 0607
346 = 0607
347 = 0608
348 = 0608
349 = 0608
350 = 0609
351 = 0609
352 = 0609
353 = 0610
354 = 0610
355 = 0610
356 = 0611
357 = 0611
358 = 0611
368 = 0612
369 = 0612
370 = 0612
371 = 0613
372 = 0613
373 = 0613
374 = 0614
375 = 0614
376 = 0614
377 = 0615
378 = 0615
379 = 0615
380 = 0616
381 = 0616
382 = 0616
383 = 0617
384 = 0617
385 = 0618
386 = 0618
387 = 0618
388 = 0619
389 = 0619
390 = 0619
391 = 0620
392 = 0620
393 = 0621
394 = 0621
395 = 0621
405 = 0701
406 = 0701
407 = 0701
408 = 0702
409 = 0702
410 = 0702
411 = 0703
412 = 0703
413 = 0703
414 = 0704
415 = 0704
416 = 0704
417 = 0705
418 = 0705
419 = 0705
420 = 0706
421 = 0706
422 = 0706
423 = 0707
424 = 0707
425 = 0707
432 = 0708
433 = 0708
434 = 0708
435 = 0709
436 = 0709
437 = 0709
438 = 0710
439 = 0710
440 = 0710
441 = 0711
442 = 0711
443 = 0711
444 = 0712
445 = 0712
446 = 0712
453 = 0801
454 = 0801
455 = 0801
456 = 0802
457 = 0802
458 = 0802
459 = 0803
460 = 0803
461 = 0804
462 = 0804
463 = 0805
464 = 0805
465 = 0805
466 = 0806
467 = 0806
468 = 0806
469 = 0807
470 = 0807
471 = 0808
472 = 0808
473 = 0808
474 = 0809
475 = 0809
476 = 0809
477 = 0810
478 = 0810
479 = 0810
480 = 0811
481 = 0811
482 = 0811
483 = 0812
484 = 0812
485 = 0813
486 = 0813
487 = 0813
488 = 0814
489 = 0814
490 = 0815
491 = 0815
492 = 0816
493 = 0816
494 = 0816
495 = 0817
496 = 0817
497 = 0817
498 = 0818
499 = 0818
500 = 0819
501 = 0819
502 = 0819
503 = 0820
504 = 0820
505 = 0820
506 = 0821
507 = 0822
508 = 0822
509 = 0823
510 = 0824
511 = 0824
512 = 0824
513 = 0825
514 = 0825
515 = 0826
516 = 0826
517 = 0826
518 = 0815
519 = 0815
520 = 0815
533 = 0827
534 = 0827
535 = 0828
536 = 0828
537 = 0829
538 = 0829
539 = 0830
540 = 0830
541 = 0830
542 = 0831
543 = 0831
544 = 0831
545 = 0832
546 = 0832
547 = 0832
548 = 0833
549 = 0833
550 = 0833
551 = 0834
552 = 0834
553 = 0835
554 = 0835
555 = 0836
556 = 0836
557 = 0837
558 = 0837
559 = 0838
560 = 0838
561 = 0838
562 = 0839
563 = 0839
564 = 0840
565 = 0840
566 = 0840
570 = 0901
571 = 0901
572 = 0901
573 = 0901
574 = 0901
575 = 0901
576 = 0902
577 = 0902
578 = 0902
579 = 0903
580 = 0903
581 = 0903
582 = 0904
583 = 0904
584 = 0905
585 = 0905
592 = 0906
593 = 0906
594 = 0906
595 = 0907
596 = 0907
597 = 0908
598 = 0908
599 = 0908
600 = 0909
601 = 0909
602 = 0910
603 = 0910
604 = 0911
605 = 0911
606 = 0912
607 = 0912
614 = 1001
615 = 1001
616 = 1002
617 = 1002
618 = 1002
619 = 1003
620 = 1003
621 = 1003
622 = 1004
623 = 1004
624 = 1004
625 = 1005
626 = 1005
627 = 1005
628 = 1006
629 = 1006
630 = 1006
637 = 1007
638 = 1007
639 = 1007
640 = 1008
641 = 1008
642 = 1009
643 = 1010
644 = 1010
645 = 1010
652 = 1101
653 = 1102
654 = 1102
655 = 1102
656 = 1103
657 = 1103
658 = 1103
659 = 1104
660 = 1104
661 = 1104
662 = 1105
663 = 1105
664 = 1105
665 = 1106
666 = 1106
667 = 1106
668 = 1107
669 = 1107
670 = 1107
671 = 1108
672 = 1108
673 = 1109
674 = 1109
675 = 1109
682 = 1110
683 = 1110
684 = 1110
685 = 1111
686 = 1112
687 = 1112
688 = 1112
689 = 1113
690 = 1113
691 = 1114
692 = 1114
693 = 1115
694 = 1115
695 = 1116
696 = 1116
697 = 1117
698 = 1118
699 = 1118
700 = 1118
707 = 1201
708 = 1201
709 = 1202
710 = 1202
711 = 1203
712 = 1203
713 = 1204
714 = 1204
715 = 1205
716 = 1205
717 = 1206
718 = 1206
722 = 1207
723 = 1207
724 = 1207
725 = 1208
726 = 1208
727 = 1209
728 = 1209
729 = 1210
730 = 1210
734 = 1301
735 = 1301
736 = 1302
737 = 1302
738 = 1302
739 = 1303
740 = 1303
741 = 1303
742 = 1304
743 = 1304
744 = 1305
745 = 1305
746 = 1306
747 = 1306
748 = 1307
749 = 1308
750 = 1308
754 = 1309
755 = 1309
756 = 1309
757 = 1310
758 = 1310
759 = 1310
760 = 1311
761 = 1311
765 = 1401
766 = 1401
767 = 1402
768 = 1402
769 = 1403
770 = 1404
774 = 1405
775 = 1405
776 = 1406
777 = 1407
778 = 1408
779 = 1409
780 = 1410
781 = 1411
782 = 1412
789 = 1501
790 = 1502
791 = 1503
792 = 1504
793 = 1505
794 = 1506
795 = 1507
799 = 1601
800 = 1601
801 = 1601
802 = 1602
803 = 1602
804 = 1602
808 = 1603
809 = 1603
810 = 1603
811 = 1604
812 = 1604
813 = 1605
814 = 1606
815 = 1606
816 = 1606
820 = 1707
821 = 1707
822 = 1707
823 = 1708
824 = 1708
825 = 1708
826 = 1709
827 = 1709
828 = 1709
829 = 1710
830 = 1710
834 = 1711
835 = 1711
836 = 1711
837 = 1712
838 = 1712
839 = 1712
840 = 1713
841 = 1713
842 = 1713
843 = 1714
844 = 1714
845 = 1714
846 = 1715
847 = 1715
848 = 1715
849 = 1716
853 = 1801
854 = 1801
855 = 1801
856 = 1802
857 = 1802
858 = 1802
862 = 1803
863 = 1803
864 = 1804
865 = 1805
866 = 1805
867 = 1806
868 = 1806
869 = 1806
870 = 1807
871 = 1808
872 = 1808
876 = 1909
880 = 1910
881 = 1911
882 = 1912
883 = 1913
884 = 1914
885 = 1915
886 = 1916
887 = 1917
894 = 2018
895 = 2019
896 = 2020
897 = 2020
901 = 2101
902 = 2101
903 = 2101
904 = 2102
905 = 2102
906 = 2103
907 = 2104
908 = 2104
909 = 2104
913 = 2105
914 = 2105
915 = 2106
916 = 2106
917 = 2107
918 = 2107
919 = 2108
920 = 2108
921 = 2108
922 = 2109
923 = 2109
927 = 2210
928 = 2201
929 = 2201
933 = 2212
934 = 2213
935 = 2214
939 = 2301
940 = 2301
941 = 2301
945 = 2302
946 = 2302
947 = 2303
948 = 2303
949 = 2304
950 = 2304
951 = 2305
955 = 2406
956 = 2407
957 = 2408
958 = 2408
959 = 2408
963 = 2409
964 = 2409
965 = 2409
969 = 2501
970 = 2501
974 = 2502
975 = 2502
976 = 2502
977 = 2503
981 = 8899
982 = 8899
983 = 8899
984 = 8899
985 = 8899
986 = 8899
987 = 8899
988 = 8899
989 = 8899
998 = 8898
999 = 8898
OTHER = 8898
;

 /* -------------------------------------------------------------- */
 /* ---   FORMATS FOR DRG STRATIFIERS                         --- */
 /* ---   ONE FORMAT PER QI.  NUMBER REFERS TO N VARIABLE IN   --- */
 /* ---   MODULE 3. ASSIGNS ARRAY INDEX FOR DRG CATEGORIES    --- */
 /* -------------------------------------------------------------- */

Value D1PDFMT
1505 = 0
other = -1 
; 

Value D2PDFMT
other = -1 
; 

Value D5PDFMT
other = -1 
; 

Value D6PDFMT
503 = 0
505 = 0
508 = 0
other = -1 
; 

Value D8PDFMT
other = -1 
; 

Value D9PDFMT
802 = 6
other = -1 
; 

Value D10PDFMT
other = -1 
; 

Value D11PDFMT
other = -1 
; 

Value D12PDFMT
416 = 8
602 = 9
1711 = 10
7705 = 11
other = -1 
; 

Value D70PDFMT
other = -1 
; 

Value D71PDFMT
416 = 10
505 = 11
508 = 12
530 = 0
other = -1 
; 

Value D72PDFMT
1501 = 4
other = -1 
; 

 /* CMS-DRG (V24) TO MDC */;

VALUE MDCFMT
001 = 01
002 = 01
003 = 01
004 = 01
005 = 01
006 = 01
007 = 01
008 = 01
009 = 01
010 = 01
011 = 01
012 = 01
013 = 01
014 = 01
015 = 01
016 = 01
017 = 01
018 = 01
019 = 01
020 = 01
021 = 01
022 = 01
023 = 01
024 = 01
025 = 01
026 = 01
027 = 01
028 = 01
029 = 01
030 = 01
031 = 01
032 = 01
033 = 01
034 = 01
035 = 01
036 = 02
037 = 02
038 = 02
039 = 02
040 = 02
041 = 02
042 = 02
043 = 02
044 = 02
045 = 02
046 = 02
047 = 02
048 = 02
049 = 03
050 = 03
051 = 03
052 = 03
053 = 03
054 = 03
055 = 03
056 = 03
057 = 03
058 = 03
059 = 03
060 = 03
061 = 03
062 = 03
063 = 03
064 = 03
065 = 03
066 = 03
067 = 03
068 = 03
069 = 03
070 = 03
071 = 03
072 = 03
073 = 03
074 = 03
075 = 04
076 = 04
077 = 04
078 = 04
079 = 04
080 = 04
081 = 04
082 = 04
083 = 04
084 = 04
085 = 04
086 = 04
087 = 04
088 = 04
089 = 04
090 = 04
091 = 04
092 = 04
093 = 04
094 = 04
095 = 04
096 = 04
097 = 04
098 = 04
099 = 04
100 = 04
101 = 04
102 = 04
103 = 77
104 = 05
105 = 05
106 = 05
107 = 05
108 = 05
109 = 05
110 = 05
111 = 05
112 = 05
113 = 05
114 = 05
115 = 05
116 = 05
117 = 05
118 = 05
119 = 05
120 = 05
121 = 05
122 = 05
123 = 05
124 = 05
125 = 05
126 = 05
127 = 05
128 = 05
129 = 05
130 = 05
131 = 05
132 = 05
133 = 05
134 = 05
135 = 05
136 = 05
137 = 05
138 = 05
139 = 05
140 = 05
141 = 05
142 = 05
143 = 05
144 = 05
145 = 05
146 = 06
147 = 06
148 = 06
149 = 06
150 = 06
151 = 06
152 = 06
153 = 06
154 = 06
155 = 06
156 = 06
157 = 06
158 = 06
159 = 06
160 = 06
161 = 06
162 = 06
163 = 06
164 = 06
165 = 06
166 = 06
167 = 06
168 = 03
169 = 03
170 = 06
171 = 06
172 = 06
173 = 06
174 = 06
175 = 06
176 = 06
177 = 06
178 = 06
179 = 06
180 = 06
181 = 06
182 = 06
183 = 06
184 = 06
185 = 03
186 = 03
187 = 03
188 = 06
189 = 06
190 = 06
191 = 07
192 = 07
193 = 07
194 = 07
195 = 07
196 = 07
197 = 07
198 = 07
199 = 07
200 = 07
201 = 07
202 = 07
203 = 07
204 = 07
205 = 07
206 = 07
207 = 07
208 = 07
209 = 08
210 = 08
211 = 08
212 = 08
213 = 08
214 = 08
215 = 08
216 = 08
217 = 08
218 = 08
219 = 08
220 = 08
221 = 08
222 = 08
223 = 08
224 = 08
225 = 08
226 = 08
227 = 08
228 = 08
229 = 08
230 = 08
231 = 08
232 = 08
233 = 08
234 = 08
235 = 08
236 = 08
237 = 08
238 = 08
239 = 08
240 = 08
241 = 08
242 = 08
243 = 08
244 = 08
245 = 08
246 = 08
247 = 08
248 = 08
249 = 08
250 = 08
251 = 08
252 = 08
253 = 08
254 = 08
255 = 08
256 = 08
257 = 09
258 = 09
259 = 09
260 = 09
261 = 09
262 = 09
263 = 09
264 = 09
265 = 09
266 = 09
267 = 09
268 = 09
269 = 09
270 = 09
271 = 09
272 = 09
273 = 09
274 = 09
275 = 09
276 = 09
277 = 09
278 = 09
279 = 09
280 = 09
281 = 09
282 = 09
283 = 09
284 = 09
285 = 10
286 = 10
287 = 10
288 = 10
289 = 10
290 = 10
291 = 10
292 = 10
293 = 10
294 = 10
295 = 10
296 = 10
297 = 10
298 = 10
299 = 10
300 = 10
301 = 10
302 = 11
303 = 11
304 = 11
305 = 11
306 = 11
307 = 11
308 = 11
309 = 11
310 = 11
311 = 11
312 = 11
313 = 11
314 = 11
315 = 11
316 = 11
317 = 11
318 = 11
319 = 11
320 = 11
321 = 11
322 = 11
323 = 11
324 = 11
325 = 11
326 = 11
327 = 11
328 = 11
329 = 11
330 = 11
331 = 11
332 = 11
333 = 11
334 = 12
335 = 12
336 = 12
337 = 12
338 = 12
339 = 12
340 = 12
341 = 12
342 = 12
343 = 12
344 = 12
345 = 12
346 = 12
347 = 12
348 = 12
349 = 12
350 = 12
351 = 12
352 = 12
353 = 13
354 = 13
355 = 13
356 = 13
357 = 13
358 = 13
359 = 13
360 = 13
361 = 13
362 = 13
363 = 13
364 = 13
365 = 13
366 = 13
367 = 13
368 = 13
369 = 13
370 = 14
371 = 14
372 = 14
373 = 14
374 = 14
375 = 14
376 = 14
377 = 14
378 = 14
379 = 14
380 = 14
381 = 14
382 = 14
383 = 14
384 = 14
385 = 15
386 = 15
387 = 15
388 = 15
389 = 15
390 = 15
391 = 15
392 = 16
393 = 16
394 = 16
395 = 16
396 = 16
397 = 16
398 = 16
399 = 16
400 = 17
401 = 17
402 = 17
403 = 17
404 = 17
405 = 17
406 = 17
407 = 17
408 = 17
409 = 17
410 = 17
411 = 17
412 = 17
413 = 17
414 = 17
415 = 18
416 = 18
417 = 18
418 = 18
419 = 18
420 = 18
421 = 18
422 = 18
423 = 18
424 = 19
425 = 19
426 = 19
427 = 19
428 = 19
429 = 19
430 = 19
431 = 19
432 = 19
433 = 20
434 = 20
435 = 20
436 = 20
437 = 20
438 = 20
439 = 21
440 = 21
441 = 21
442 = 21
443 = 21
444 = 21
445 = 21
446 = 21
447 = 21
448 = 21
449 = 21
450 = 21
451 = 21
452 = 21
453 = 21
454 = 21
455 = 21
456 = 22
457 = 22
458 = 22
459 = 22
460 = 22
461 = 23
462 = 23
463 = 23
464 = 23
465 = 23
466 = 23
467 = 23
468 = 88
469 = 88
470 = 88
471 = 08
472 = 22
473 = 17
474 = 04
475 = 04
476 = 88
477 = 88
478 = 05
479 = 05
480 = 77
481 = 77
482 = 77
483 = 77
484 = 24
485 = 24
486 = 24
487 = 24
488 = 25
489 = 25
490 = 25
491 = 08
492 = 17
493 = 07
494 = 07
495 = 77
496 = 08
497 = 08
498 = 08
499 = 08
500 = 08
501 = 08
502 = 08
503 = 08
504 = 22
505 = 22
506 = 22
507 = 22
508 = 22
509 = 22
510 = 22
511 = 22
512 = 77
513 = 77
514 = 05
515 = 05
516 = 05
517 = 05
518 = 05
519 = 08
520 = 08
521 = 20
522 = 20
523 = 20
524 = 01
525 = 05
526 = 05
527 = 05
528 = 01
529 = 01
530 = 01
531 = 01
532 = 01
533 = 01
534 = 01
535 = 05
536 = 05
537 = 08
538 = 08
539 = 17
540 = 17
541 = 77
542 = 77
543 = 01
544 = 08
545 = 08
546 = 08
547 = 05
548 = 05
549 = 05
550 = 05
551 = 05
552 = 05
553 = 05
554 = 05
555 = 05
556 = 05
557 = 05
558 = 05
559 = 01
560 = 01
561 = 01
562 = 01
563 = 01
564 = 01
565 = 04
566 = 04
567 = 06
568 = 06
569 = 06
570 = 06
571 = 06
572 = 06
573 = 11
574 = 16
575 = 18
576 = 18
577 = 01
578 = 18
579 = 18
OTHER  = 99 ;

 /* MS-DRG (V25) TO MDC */;

VALUE MDCF2T
001 = 77
002 = 77
003 = 77
004 = 77
005 = 77
006 = 77
007 = 77
008 = 77
009 = 77
010 = 77
011 = 77
012 = 77
013 = 77
014 = 77   
015 = 77  
016 = 77
017 = 77
020 = 01
021 = 01
022 = 01
023 = 01
024 = 01
025 = 01
026 = 01
027 = 01
028 = 01
029 = 01
030 = 01
031 = 01
032 = 01
033 = 01
034 = 01
035 = 01
036 = 01
037 = 01
038 = 01
039 = 01
040 = 01
041 = 01
042 = 01
052 = 01
053 = 01
054 = 01
055 = 01
056 = 01
057 = 01
058 = 01
059 = 01
060 = 01
061 = 01
062 = 01
063 = 01
064 = 01
065 = 01
066 = 01
067 = 01
068 = 01
069 = 01
070 = 01
071 = 01
072 = 01
073 = 01
074 = 01
075 = 01
076 = 01
077 = 01
078 = 01
079 = 01
080 = 01
081 = 01
082 = 01
083 = 01
084 = 01
085 = 01
086 = 01
087 = 01
088 = 01
089 = 01
090 = 01
091 = 01
092 = 01
093 = 01
094 = 01
095 = 01
096 = 01
097 = 01
098 = 01
099 = 01
100 = 01
101 = 01
102 = 01
103 = 01
113 = 02
114 = 02
115 = 02
116 = 02
117 = 02
121 = 02
122 = 02
123 = 02
124 = 02
125 = 02
129 = 03
130 = 03
131 = 03
132 = 03
133 = 03
134 = 03
135 = 03
136 = 03
137 = 03
138 = 03
139 = 03
146 = 03
147 = 03
148 = 03
149 = 03
150 = 03
151 = 03
152 = 03
153 = 03
154 = 03
155 = 03
156 = 03
157 = 03
158 = 03
159 = 03
163 = 04
164 = 04
165 = 04
166 = 04
167 = 04
168 = 04
175 = 04
176 = 04
177 = 04
178 = 04
179 = 04
180 = 04
181 = 04
182 = 04
183 = 04
184 = 04
185 = 04
186 = 04
187 = 04
188 = 04
189 = 04
190 = 04
191 = 04
192 = 04
193 = 04
194 = 04
195 = 04
196 = 04
197 = 04
198 = 04
199 = 04
200 = 04
201 = 04
202 = 04
203 = 04
204 = 04
205 = 04
206 = 04
207 = 04
208 = 04
215 = 05
216 = 05
217 = 05
218 = 05
219 = 05
220 = 05
221 = 05
222 = 05
223 = 05
224 = 05
225 = 05
226 = 05
227 = 05
228 = 05
229 = 05
230 = 05
231 = 05
232 = 05
233 = 05
234 = 05
235 = 05
236 = 05
237 = 05
238 = 05
239 = 05
240 = 05
241 = 05
242 = 05
243 = 05
244 = 05
245 = 05
246 = 05
247 = 05
248 = 05
249 = 05
250 = 05
251 = 05
252 = 05
253 = 05
254 = 05
255 = 05
256 = 05
257 = 05
258 = 05
259 = 05
260 = 05
261 = 05
262 = 05
263 = 05
264 = 05
265 = 05
266 = 05
267 = 05
280 = 05
281 = 05
282 = 05
283 = 05
284 = 05
285 = 05
286 = 05
287 = 05
288 = 05
289 = 05
290 = 05
291 = 05
292 = 05
293 = 05
294 = 05
295 = 05
296 = 05
297 = 05
298 = 05
299 = 05
300 = 05
301 = 05
302 = 05
303 = 05
304 = 05
305 = 05
306 = 05
307 = 05
308 = 05
309 = 05
310 = 05
311 = 05
312 = 05
313 = 05
314 = 05
315 = 05
316 = 05
326 = 06
327 = 06
328 = 06
329 = 06
330 = 06
331 = 06
332 = 06
333 = 06
334 = 06
335 = 06
336 = 06
337 = 06
338 = 06
339 = 06
340 = 06
341 = 06
342 = 06
343 = 06
344 = 06
345 = 06
346 = 06
347 = 06
348 = 06
349 = 06
350 = 06
351 = 06
352 = 06
353 = 06
354 = 06
355 = 06
356 = 06
357 = 06
358 = 06
368 = 06
369 = 06
370 = 06
371 = 06
372 = 06
373 = 06
374 = 06
375 = 06
376 = 06
377 = 06
378 = 06
379 = 06
380 = 06
381 = 06
382 = 06
383 = 06
384 = 06
385 = 06
386 = 06
387 = 06
388 = 06
389 = 06
390 = 06
391 = 06
392 = 06
393 = 06
394 = 06
395 = 06
405 = 07
406 = 07
407 = 07
408 = 07
409 = 07
410 = 07
411 = 07
412 = 07
413 = 07
414 = 07
415 = 07
416 = 07
417 = 07
418 = 07
419 = 07
420 = 07
421 = 07
422 = 07
423 = 07
424 = 07
425 = 07
432 = 07
433 = 07
434 = 07
435 = 07
436 = 07
437 = 07
438 = 07
439 = 07
440 = 07
441 = 07
442 = 07
443 = 07
444 = 07
445 = 07
446 = 07
453 = 08
454 = 08
455 = 08
456 = 08
457 = 08
458 = 08
459 = 08
460 = 08
461 = 08
462 = 08
463 = 08
464 = 08
465 = 08
466 = 08
467 = 08
468 = 08
469 = 08
470 = 08
471 = 08
472 = 08
473 = 08
474 = 08
475 = 08
476 = 08
477 = 08
478 = 08
479 = 08
480 = 08
481 = 08
482 = 08
483 = 08
484 = 08
485 = 08
486 = 08
487 = 08
488 = 08
489 = 08
490 = 08
491 = 08
492 = 08
493 = 08
494 = 08
495 = 08
496 = 08
497 = 08
498 = 08
499 = 08
500 = 08
501 = 08
502 = 08
503 = 08
504 = 08
505 = 08
506 = 08
507 = 08
508 = 08
509 = 08
510 = 08
511 = 08
512 = 08
513 = 08
514 = 08
515 = 08
516 = 08
517 = 08
518 = 08
519 = 08
520 = 08
533 = 08
534 = 08
535 = 08
536 = 08
537 = 08
538 = 08
539 = 08
540 = 08
541 = 08
542 = 08
543 = 08
544 = 08
545 = 08
546 = 08
547 = 08
548 = 08
549 = 08
550 = 08
551 = 08
552 = 08
553 = 08
554 = 08
555 = 08
556 = 08
557 = 08
558 = 08
559 = 08
560 = 08
561 = 08
562 = 08
563 = 08
564 = 08
565 = 08
566 = 08
570 = 09
571 = 09
572 = 09
573 = 09
574 = 09
575 = 09
576 = 09
577 = 09
578 = 09
579 = 09
580 = 09
581 = 09
582 = 09
583 = 09
584 = 09
585 = 09
592 = 09
593 = 09
594 = 09
595 = 09
596 = 09
597 = 09
598 = 09
599 = 09
600 = 09
601 = 09
602 = 09
603 = 09
604 = 09
605 = 09
606 = 09
607 = 09
614 = 10
615 = 10
616 = 10
617 = 10
618 = 10
619 = 10
620 = 10
621 = 10
622 = 10
623 = 10
624 = 10
625 = 10
626 = 10
627 = 10
628 = 10
629 = 10
630 = 10
637 = 10
638 = 10
639 = 10
640 = 10
641 = 10
642 = 10
643 = 10
644 = 10
645 = 10
652 = 11
653 = 11
654 = 11
655 = 11
656 = 11
657 = 11
658 = 11
659 = 11
660 = 11
661 = 11
662 = 11
663 = 11
664 = 11
665 = 11
666 = 11
667 = 11
668 = 11
669 = 11
670 = 11
671 = 11
672 = 11
673 = 11
674 = 11
675 = 11
682 = 11
683 = 11
684 = 11
685 = 11
686 = 11
687 = 11
688 = 11
689 = 11
690 = 11
691 = 11
692 = 11
693 = 11
694 = 11
695 = 11
696 = 11
697 = 11
698 = 11
699 = 11
700 = 11
707 = 12
708 = 12
709 = 12
710 = 12
711 = 12
712 = 12
713 = 12
714 = 12
715 = 12
716 = 12
717 = 12
718 = 12
722 = 12
723 = 12
724 = 12
725 = 12
726 = 12
727 = 12
728 = 12
729 = 12
730 = 12
734 = 13
735 = 13
736 = 13
737 = 13
738 = 13
739 = 13
740 = 13
741 = 13
742 = 13
743 = 13
744 = 13
745 = 13
746 = 13
747 = 13
748 = 13
749 = 13
750 = 13
754 = 13
755 = 13
756 = 13
757 = 13
758 = 13
759 = 13
760 = 13
761 = 13
765 = 14
766 = 14
767 = 14
768 = 14
769 = 14
770 = 14
774 = 14
775 = 14
776 = 14
777 = 14
778 = 14
779 = 14
780 = 14
781 = 14
782 = 14
789 = 15
790 = 15
791 = 15
792 = 15
793 = 15
794 = 15
795 = 15
799 = 16
800 = 16
801 = 16
802 = 16
803 = 16
804 = 16
808 = 16
809 = 16
810 = 16
811 = 16
812 = 16
813 = 16
814 = 16
815 = 16
816 = 16
820 = 17
821 = 17
822 = 17
823 = 17
824 = 17
825 = 17
826 = 17
827 = 17
828 = 17
829 = 17
830 = 17
834 = 17
835 = 17
836 = 17
837 = 17
838 = 17
839 = 17
840 = 17
841 = 17
842 = 17
843 = 17
844 = 17
845 = 17
846 = 17
847 = 17
848 = 17
849 = 17
853 = 18
854 = 18
855 = 18
856 = 18
857 = 18
858 = 18
862 = 18
863 = 18
864 = 18
865 = 18
866 = 18
867 = 18
868 = 18
869 = 18
870 = 18
871 = 18
872 = 18
876 = 19
880 = 19
881 = 19
882 = 19
883 = 19
884 = 19
885 = 19
886 = 19
887 = 19
894 = 20
895 = 20
896 = 20
897 = 20
901 = 21
902 = 21
903 = 21
904 = 21
905 = 21
906 = 21
907 = 21
908 = 21
909 = 21
913 = 21
914 = 21
915 = 21
916 = 21
917 = 21
918 = 21
919 = 21
920 = 21
921 = 21
922 = 21
923 = 21
927 = 22
928 = 22
929 = 22
933 = 22
934 = 22
935 = 22
939 = 23
940 = 23
941 = 23
945 = 23
946 = 23
947 = 23
948 = 23
949 = 23
950 = 23
951 = 23
955 = 24
956 = 24
957 = 24
958 = 24
959 = 24
963 = 24
964 = 24
965 = 24
969 = 25
970 = 25
974 = 25
975 = 25
976 = 25
977 = 25
981 = 88
982 = 88
983 = 88
984 = 88
985 = 88
986 = 88
987 = 88
988 = 88
989 = 88
998 = 88
999 = 88
OTHER  = 99 ;

 /* -------------------------------------------------------------- */
 /* ---   FORMATS FOR MDC STRATIFIERS                         --- */
 /* ---   ONE FORMAT PER QI.  NUMBER REFERS TO N VARIABLE IN   --- */
 /* ---   MODULE 3. ASSIGNS ARRAY INDEX FOR MDC CATEGORIES    --- */
 /* -------------------------------------------------------------- */

Value M1PDFMT
5 = 1
6 = 2
8 = 3
11 = 4
15 = 5
other = 6 
; 

Value M2PDFMT
1 = 3
other = 0 
; 

Value M5PDFMT
other = 0 
; 

Value M6PDFMT
other = 0 
; 

Value M8PDFMT
5 = 1
other = 0 
; 

Value M9PDFMT
1 = 7
other = 0 
; 

Value M10PDFMT
other = 0 
; 

Value M11PDFMT
other = 0 
; 

Value M12PDFMT
5 = 12
7 = 13
10 = 14
15 = 15
16 = 16
other = 0 
; 

Value M70PDFMT
other = 0 
; 

Value M71PDFMT
1 = 13
4 = 14
5 = 15
6 = 16
15 = 17
other = 18 
; 

Value M72PDFMT
other = 0 
; 


 /* --------------------------------------------------------------- */
 /* ---   POVERTY DECILE                                          - */
 /* --------------------------------------------------------------- */

VALUE $POVCAT
"01001" = 3
"01003" = 4
"01005" = 10
"01007" = 9
"01009" = 6
"01011" = 10
"01013" = 10
"01015" = 10
"01017" = 10
"01019" = 9
"01021" = 9
"01023" = 9
"01025" = 10
"01027" = 9
"01029" = 8
"01031" = 9
"01033" = 9
"01035" = 10
"01037" = 8
"01039" = 9
"01041" = 9
"01043" = 9
"01045" = 8
"01047" = 10
"01049" = 9
"01051" = 4
"01053" = 10
"01055" = 8
"01057" = 10
"01059" = 9
"01061" = 9
"01063" = 10
"01065" = 10
"01067" = 8
"01069" = 8
"01071" = 9
"01073" = 8
"01075" = 9
"01077" = 7
"01079" = 8
"01081" = 9
"01083" = 4
"01085" = 10
"01087" = 10
"01089" = 4
"01091" = 10
"01093" = 9
"01095" = 9
"01097" = 9
"01099" = 10
"01101" = 9
"01103" = 4
"01105" = 10
"01107" = 10
"01109" = 10
"01111" = 10
"01113" = 10
"01115" = 4
"01117" = 2
"01119" = 10
"01121" = 10
"01123" = 8
"01125" = 8
"01127" = 10
"01129" = 9
"01131" = 10
"01133" = 9
"02013" = 7
"02016" = 2
"02020" = 2
"02050" = 10
"02060" = 2
"02068" = 1
"02070" = 9
"02090" = 2
"02100" = 3
"02105" = 9
"02110" = 1
"02122" = 2
"02130" = 2
"02150" = 2
"02164" = 8
"02170" = 3
"02180" = 10
"02185" = 3
"02188" = 9
"02195" = 2
"02198" = 7
"02220" = 2
"02230" = 1
"02240" = 4
"02261" = 2
"02270" = 10
"02275" = 4
"02282" = 5
"02290" = 10
"04001" = 10
"04003" = 8
"04005" = 10
"04007" = 9
"04009" = 9
"04011" = 4
"04012" = 10
"04013" = 6
"04015" = 8
"04017" = 10
"04019" = 8
"04021" = 5
"04023" = 10
"04025" = 8
"04027" = 9
"05001" = 8
"05003" = 9
"05005" = 6
"05007" = 2
"05009" = 6
"05011" = 10
"05013" = 6
"05015" = 6
"05017" = 10
"05019" = 10
"05021" = 8
"05023" = 8
"05025" = 6
"05027" = 10
"05029" = 8
"05031" = 9
"05033" = 6
"05035" = 10
"05037" = 9
"05039" = 9
"05041" = 10
"05043" = 9
"05045" = 5
"05047" = 7
"05049" = 8
"05051" = 9
"05053" = 3
"05055" = 7
"05057" = 10
"05059" = 5
"05061" = 9
"05063" = 8
"05065" = 8
"05067" = 10
"05069" = 10
"05071" = 10
"05073" = 10
"05075" = 10
"05077" = 10
"05079" = 10
"05081" = 8
"05083" = 7
"05085" = 4
"05087" = 9
"05089" = 9
"05091" = 9
"05093" = 10
"05095" = 10
"05097" = 10
"05099" = 10
"05101" = 10
"05103" = 9
"05105" = 7
"05107" = 10
"05109" = 9
"05111" = 10
"05113" = 10
"05115" = 8
"05117" = 8
"05119" = 7
"05121" = 9
"05123" = 10
"05125" = 2
"05127" = 10
"05129" = 10
"05131" = 9
"05133" = 10
"05135" = 10
"05137" = 10
"05139" = 9
"05141" = 9
"05143" = 9
"05145" = 6
"05147" = 10
"05149" = 9
"06001" = 4
"06003" = 7
"06005" = 4
"06007" = 9
"06009" = 3
"06011" = 5
"06013" = 2
"06015" = 10
"06017" = 2
"06019" = 10
"06021" = 7
"06023" = 8
"06025" = 10
"06027" = 4
"06029" = 9
"06031" = 10
"06033" = 9
"06035" = 7
"06037" = 7
"06039" = 9
"06041" = 2
"06043" = 5
"06045" = 9
"06047" = 10
"06049" = 10
"06051" = 3
"06053" = 7
"06055" = 2
"06057" = 3
"06059" = 3
"06061" = 2
"06063" = 5
"06065" = 6
"06067" = 6
"06069" = 4
"06071" = 8
"06073" = 5
"06075" = 4
"06077" = 8
"06079" = 5
"06081" = 1
"06083" = 8
"06085" = 2
"06087" = 5
"06089" = 8
"06091" = 4
"06093" = 9
"06095" = 3
"06097" = 4
"06099" = 9
"06101" = 7
"06103" = 9
"06105" = 8
"06107" = 10
"06109" = 5
"06111" = 3
"06113" = 6
"06115" = 9
"08001" = 4
"08003" = 9
"08005" = 3
"08007" = 4
"08009" = 7
"08011" = 10
"08013" = 4
"08014" = 1
"08015" = 4
"08017" = 3
"08019" = 2
"08021" = 9
"08023" = 10
"08025" = 10
"08027" = 5
"08029" = 6
"08031" = 9
"08033" = 4
"08035" = 1
"08037" = 2
"08039" = 1
"08041" = 4
"08043" = 6
"08045" = 2
"08047" = 1
"08049" = 2
"08051" = 5
"08053" = 2
"08055" = 10
"08057" = 5
"08059" = 2
"08061" = 4
"08063" = 4
"08065" = 5
"08067" = 3
"08069" = 4
"08071" = 8
"08073" = 8
"08075" = 6
"08077" = 5
"08079" = 3
"08081" = 2
"08083" = 7
"08085" = 5
"08087" = 5
"08089" = 9
"08091" = 2
"08093" = 2
"08095" = 3
"08097" = 1
"08099" = 10
"08101" = 9
"08103" = 2
"08105" = 7
"08107" = 1
"08109" = 10
"08111" = 6
"08113" = 2
"08115" = 4
"08117" = 2
"08119" = 2
"08121" = 4
"08123" = 5
"08125" = 4
"09001" = 2
"09003" = 3
"09005" = 1
"09007" = 1
"09009" = 3
"09011" = 2
"09013" = 1
"09015" = 3
"10001" = 3
"10003" = 3
"10005" = 4
"11001" = 8
"12001" = 10
"12003" = 7
"12005" = 5
"12007" = 9
"12009" = 4
"12011" = 5
"12013" = 10
"12015" = 4
"12017" = 7
"12019" = 3
"12021" = 6
"12023" = 9
"12027" = 10
"12029" = 10
"12031" = 6
"12033" = 9
"12035" = 6
"12037" = 10
"12039" = 10
"12041" = 9
"12043" = 9
"12045" = 9
"12047" = 10
"12049" = 10
"12051" = 10
"12053" = 5
"12055" = 9
"12057" = 6
"12059" = 10
"12061" = 5
"12063" = 8
"12065" = 8
"12067" = 10
"12069" = 4
"12071" = 7
"12073" = 10
"12075" = 10
"12077" = 10
"12079" = 10
"12081" = 5
"12083" = 9
"12085" = 3
"12086" = 9
"12087" = 4
"12089" = 3
"12091" = 4
"12093" = 10
"12095" = 6
"12097" = 6
"12099" = 5
"12101" = 5
"12103" = 5
"12105" = 7
"12107" = 10
"12109" = 3
"12111" = 7
"12113" = 4
"12115" = 4
"12117" = 3
"12119" = 4
"12121" = 9
"12123" = 9
"12125" = 10
"12127" = 6
"12129" = 4
"12131" = 6
"12133" = 9
"13001" = 10
"13003" = 10
"13005" = 10
"13007" = 10
"13009" = 10
"13011" = 6
"13013" = 3
"13015" = 5
"13017" = 10
"13019" = 9
"13021" = 10
"13023" = 9
"13025" = 10
"13027" = 10
"13029" = 3
"13031" = 10
"13033" = 10
"13035" = 6
"13037" = 10
"13039" = 6
"13043" = 10
"13045" = 8
"13047" = 5
"13049" = 10
"13051" = 9
"13053" = 8
"13055" = 9
"13057" = 2
"13059" = 10
"13061" = 10
"13063" = 10
"13065" = 10
"13067" = 4
"13069" = 10
"13071" = 10
"13073" = 2
"13075" = 10
"13077" = 3
"13079" = 8
"13081" = 10
"13083" = 6
"13085" = 4
"13087" = 10
"13089" = 9
"13091" = 10
"13093" = 10
"13095" = 10
"13097" = 4
"13099" = 10
"13101" = 10
"13103" = 2
"13105" = 10
"13107" = 10
"13109" = 10
"13111" = 8
"13113" = 1
"13115" = 9
"13117" = 1
"13119" = 8
"13121" = 8
"13123" = 6
"13125" = 8
"13127" = 8
"13129" = 8
"13131" = 10
"13133" = 10
"13135" = 4
"13137" = 7
"13139" = 8
"13141" = 10
"13143" = 9
"13145" = 2
"13147" = 10
"13149" = 9
"13151" = 2
"13153" = 4
"13155" = 10
"13157" = 6
"13159" = 8
"13161" = 10
"13163" = 10
"13165" = 10
"13167" = 10
"13169" = 3
"13171" = 8
"13173" = 10
"13175" = 9
"13177" = 2
"13179" = 10
"13181" = 9
"13183" = 9
"13185" = 10
"13187" = 6
"13189" = 9
"13191" = 8
"13193" = 10
"13195" = 7
"13197" = 10
"13199" = 9
"13201" = 10
"13205" = 10
"13207" = 5
"13209" = 10
"13211" = 6
"13213" = 9
"13215" = 9
"13217" = 5
"13219" = 1
"13221" = 6
"13223" = 2
"13225" = 10
"13227" = 4
"13229" = 8
"13231" = 4
"13233" = 10
"13235" = 9
"13237" = 8
"13239" = 10
"13241" = 8
"13243" = 10
"13245" = 10
"13247" = 5
"13249" = 7
"13251" = 10
"13253" = 10
"13255" = 10
"13257" = 10
"13259" = 10
"13261" = 10
"13263" = 9
"13265" = 10
"13267" = 10
"13269" = 10
"13271" = 10
"13273" = 10
"13275" = 10
"13277" = 10
"13279" = 10
"13281" = 5
"13283" = 10
"13285" = 9
"13287" = 10
"13289" = 10
"13291" = 9
"13293" = 9
"13295" = 8
"13297" = 5
"13299" = 10
"13301" = 10
"13303" = 10
"13305" = 10
"13307" = 10
"13309" = 10
"13311" = 7
"13313" = 9
"13315" = 10
"13317" = 10
"13319" = 9
"13321" = 9
"15001" = 8
"15003" = 2
"15005" = 1
"15007" = 3
"15009" = 3
"16001" = 4
"16003" = 6
"16005" = 6
"16007" = 6
"16009" = 7
"16011" = 6
"16013" = 2
"16015" = 5
"16017" = 7
"16019" = 4
"16021" = 7
"16023" = 6
"16025" = 3
"16027" = 9
"16029" = 3
"16031" = 6
"16033" = 8
"16035" = 5
"16037" = 5
"16039" = 6
"16041" = 2
"16043" = 6
"16045" = 7
"16047" = 6
"16049" = 8
"16051" = 3
"16053" = 9
"16055" = 5
"16057" = 7
"16059" = 9
"16061" = 8
"16063" = 4
"16065" = 10
"16067" = 6
"16069" = 4
"16071" = 4
"16073" = 10
"16075" = 7
"16077" = 6
"16079" = 9
"16081" = 3
"16083" = 6
"16085" = 4
"16087" = 7
"17001" = 4
"17003" = 10
"17005" = 4
"17007" = 3
"17009" = 5
"17011" = 3
"17013" = 3
"17015" = 4
"17017" = 4
"17019" = 9
"17021" = 5
"17023" = 3
"17025" = 5
"17027" = 2
"17029" = 8
"17031" = 7
"17033" = 5
"17035" = 3
"17037" = 5
"17039" = 3
"17041" = 3
"17043" = 1
"17045" = 5
"17047" = 3
"17049" = 2
"17051" = 6
"17053" = 3
"17055" = 9
"17057" = 5
"17059" = 8
"17061" = 5
"17063" = 1
"17065" = 5
"17067" = 4
"17069" = 9
"17071" = 3
"17073" = 3
"17075" = 3
"17077" = 10
"17079" = 3
"17081" = 7
"17083" = 2
"17085" = 2
"17087" = 5
"17089" = 3
"17091" = 5
"17093" = 1
"17095" = 6
"17097" = 2
"17099" = 4
"17101" = 7
"17103" = 3
"17105" = 3
"17107" = 3
"17109" = 10
"17111" = 1
"17113" = 3
"17115" = 8
"17117" = 4
"17119" = 5
"17121" = 6
"17123" = 3
"17125" = 5
"17127" = 6
"17129" = 2
"17131" = 3
"17133" = 1
"17135" = 5
"17137" = 5
"17139" = 2
"17141" = 3
"17143" = 5
"17145" = 7
"17147" = 1
"17149" = 7
"17151" = 8
"17153" = 9
"17155" = 1
"17157" = 4
"17159" = 5
"17161" = 4
"17163" = 6
"17165" = 9
"17167" = 4
"17169" = 3
"17171" = 2
"17173" = 3
"17175" = 2
"17177" = 4
"17179" = 2
"17181" = 8
"17183" = 9
"17185" = 5
"17187" = 4
"17189" = 1
"17191" = 5
"17193" = 7
"17195" = 3
"17197" = 2
"17199" = 6
"17201" = 7
"17203" = 1
"18001" = 7
"18003" = 4
"18005" = 4
"18007" = 3
"18009" = 6
"18011" = 1
"18013" = 4
"18015" = 2
"18017" = 6
"18019" = 4
"18021" = 4
"18023" = 4
"18025" = 7
"18027" = 5
"18029" = 2
"18031" = 4
"18033" = 2
"18035" = 10
"18037" = 2
"18039" = 7
"18041" = 7
"18043" = 4
"18045" = 4
"18047" = 3
"18049" = 4
"18051" = 3
"18053" = 9
"18055" = 4
"18057" = 1
"18059" = 2
"18061" = 3
"18063" = 1
"18065" = 6
"18067" = 6
"18069" = 3
"18071" = 4
"18073" = 2
"18075" = 6
"18077" = 6
"18079" = 5
"18081" = 2
"18083" = 7
"18085" = 4
"18087" = 6
"18089" = 8
"18091" = 6
"18093" = 5
"18095" = 8
"18097" = 9
"18099" = 4
"18101" = 4
"18103" = 7
"18105" = 10
"18107" = 5
"18109" = 3
"18111" = 3
"18113" = 4
"18115" = 2
"18117" = 7
"18119" = 4
"18121" = 6
"18123" = 4
"18125" = 5
"18127" = 3
"18129" = 2
"18131" = 5
"18133" = 4
"18135" = 6
"18137" = 2
"18139" = 4
"18141" = 6
"18143" = 8
"18145" = 4
"18147" = 3
"18149" = 8
"18151" = 4
"18153" = 5
"18155" = 6
"18157" = 9
"18159" = 2
"18161" = 4
"18163" = 7
"18165" = 4
"18167" = 9
"18169" = 3
"18171" = 2
"18173" = 1
"18175" = 6
"18177" = 9
"18179" = 2
"18181" = 3
"18183" = 2
"19001" = 2
"19003" = 4
"19005" = 4
"19007" = 6
"19009" = 2
"19011" = 2
"19013" = 8
"19015" = 2
"19017" = 1
"19019" = 3
"19021" = 4
"19023" = 2
"19025" = 3
"19027" = 2
"19029" = 4
"19031" = 1
"19033" = 4
"19035" = 2
"19037" = 2
"19039" = 4
"19041" = 3
"19043" = 3
"19045" = 4
"19047" = 4
"19049" = 1
"19051" = 7
"19053" = 9
"19055" = 2
"19057" = 5
"19059" = 2
"19061" = 2
"19063" = 4
"19065" = 4
"19067" = 5
"19069" = 3
"19071" = 3
"19073" = 3
"19075" = 1
"19077" = 2
"19079" = 3
"19081" = 2
"19083" = 3
"19085" = 2
"19087" = 5
"19089" = 4
"19091" = 2
"19093" = 4
"19095" = 1
"19097" = 4
"19099" = 4
"19101" = 5
"19103" = 7
"19105" = 3
"19107" = 4
"19109" = 2
"19111" = 6
"19113" = 2
"19115" = 3
"19117" = 7
"19119" = 2
"19121" = 2
"19123" = 6
"19125" = 2
"19127" = 4
"19129" = 2
"19131" = 3
"19133" = 3
"19135" = 4
"19137" = 5
"19139" = 4
"19141" = 3
"19143" = 2
"19145" = 5
"19147" = 3
"19149" = 1
"19151" = 3
"19153" = 3
"19155" = 5
"19157" = 3
"19159" = 8
"19161" = 2
"19163" = 5
"19165" = 2
"19167" = 1
"19169" = 8
"19171" = 3
"19173" = 4
"19175" = 5
"19177" = 6
"19179" = 7
"19181" = 1
"19183" = 2
"19185" = 7
"19187" = 6
"19189" = 2
"19191" = 2
"19193" = 5
"19195" = 3
"19197" = 3
"20001" = 8
"20003" = 5
"20005" = 6
"20007" = 4
"20009" = 4
"20011" = 6
"20013" = 8
"20015" = 2
"20017" = 4
"20019" = 6
"20021" = 9
"20023" = 4
"20025" = 3
"20027" = 3
"20029" = 6
"20031" = 2
"20033" = 2
"20035" = 7
"20037" = 9
"20039" = 4
"20041" = 3
"20043" = 4
"20045" = 6
"20047" = 3
"20049" = 8
"20051" = 4
"20053" = 3
"20055" = 5
"20057" = 4
"20059" = 3
"20061" = 3
"20063" = 3
"20065" = 4
"20067" = 3
"20069" = 1
"20071" = 2
"20073" = 7
"20075" = 4
"20077" = 5
"20079" = 2
"20081" = 3
"20083" = 2
"20085" = 3
"20087" = 2
"20089" = 4
"20091" = 1
"20093" = 3
"20095" = 4
"20097" = 4
"20099" = 7
"20101" = 2
"20103" = 2
"20105" = 4
"20107" = 5
"20109" = 2
"20111" = 9
"20113" = 2
"20115" = 3
"20117" = 3
"20119" = 2
"20121" = 2
"20123" = 2
"20125" = 8
"20127" = 3
"20129" = 3
"20131" = 2
"20133" = 6
"20135" = 2
"20137" = 4
"20139" = 3
"20141" = 5
"20143" = 2
"20145" = 4
"20147" = 3
"20149" = 2
"20151" = 3
"20153" = 4
"20155" = 5
"20157" = 3
"20159" = 4
"20161" = 9
"20163" = 5
"20165" = 4
"20167" = 6
"20169" = 7
"20171" = 2
"20173" = 5
"20175" = 6
"20177" = 7
"20179" = 4
"20181" = 7
"20183" = 4
"20185" = 4
"20187" = 3
"20189" = 3
"20191" = 3
"20193" = 2
"20195" = 3
"20197" = 2
"20199" = 4
"20201" = 2
"20203" = 4
"20205" = 6
"20207" = 7
"20209" = 10
"21001" = 10
"21003" = 10
"21005" = 4
"21007" = 5
"21009" = 9
"21011" = 10
"21013" = 10
"21015" = 2
"21017" = 7
"21019" = 9
"21021" = 6
"21023" = 6
"21025" = 10
"21027" = 9
"21029" = 2
"21031" = 9
"21033" = 8
"21035" = 7
"21037" = 4
"21039" = 5
"21041" = 10
"21043" = 10
"21045" = 10
"21047" = 9
"21049" = 7
"21051" = 10
"21053" = 10
"21055" = 9
"21057" = 10
"21059" = 6
"21061" = 8
"21063" = 10
"21065" = 10
"21067" = 9
"21069" = 8
"21071" = 10
"21073" = 6
"21075" = 10
"21077" = 6
"21079" = 7
"21081" = 8
"21083" = 9
"21085" = 9
"21087" = 9
"21089" = 7
"21091" = 5
"21093" = 5
"21095" = 10
"21097" = 6
"21099" = 10
"21101" = 6
"21103" = 7
"21105" = 8
"21107" = 9
"21109" = 10
"21111" = 7
"21113" = 6
"21115" = 10
"21117" = 4
"21119" = 10
"21121" = 10
"21123" = 9
"21125" = 10
"21127" = 9
"21129" = 10
"21131" = 10
"21133" = 10
"21135" = 10
"21137" = 10
"21139" = 5
"21141" = 8
"21143" = 5
"21145" = 6
"21147" = 10
"21149" = 6
"21151" = 9
"21153" = 10
"21155" = 8
"21157" = 3
"21159" = 10
"21161" = 9
"21163" = 5
"21165" = 10
"21167" = 5
"21169" = 9
"21171" = 10
"21173" = 9
"21175" = 10
"21177" = 9
"21179" = 6
"21181" = 8
"21183" = 9
"21185" = 1
"21187" = 6
"21189" = 10
"21191" = 5
"21193" = 10
"21195" = 10
"21197" = 10
"21199" = 9
"21201" = 10
"21203" = 10
"21205" = 10
"21207" = 10
"21209" = 3
"21211" = 3
"21213" = 6
"21215" = 2
"21217" = 10
"21219" = 10
"21221" = 5
"21223" = 5
"21225" = 9
"21227" = 9
"21229" = 6
"21231" = 10
"21233" = 5
"21235" = 10
"21237" = 10
"21239" = 3
"22001" = 9
"22003" = 9
"22005" = 4
"22007" = 6
"22009" = 9
"22011" = 6
"22013" = 10
"22015" = 4
"22017" = 9
"22019" = 7
"22021" = 9
"22023" = 4
"22025" = 10
"22027" = 10
"22029" = 10
"22031" = 9
"22033" = 7
"22035" = 10
"22037" = 8
"22039" = 10
"22041" = 10
"22043" = 9
"22045" = 10
"22047" = 10
"22049" = 9
"22051" = 6
"22053" = 9
"22055" = 8
"22057" = 4
"22059" = 5
"22061" = 10
"22063" = 4
"22065" = 10
"22067" = 10
"22069" = 10
"22071" = 10
"22073" = 9
"22075" = 5
"22077" = 7
"22079" = 9
"22081" = 10
"22083" = 10
"22085" = 10
"22087" = 8
"22089" = 4
"22091" = 10
"22093" = 6
"22095" = 8
"22097" = 10
"22099" = 10
"22101" = 9
"22103" = 2
"22105" = 9
"22107" = 10
"22109" = 8
"22111" = 9
"22113" = 7
"22115" = 4
"22117" = 10
"22119" = 10
"22121" = 5
"22123" = 10
"22125" = 9
"22127" = 10
"23001" = 5
"23003" = 4
"23005" = 2
"23007" = 6
"23009" = 4
"23011" = 3
"23013" = 4
"23015" = 4
"23017" = 5
"23019" = 6
"23021" = 6
"23023" = 2
"23025" = 8
"23027" = 6
"23029" = 9
"23031" = 2
"24001" = 7
"24003" = 1
"24005" = 1
"24009" = 1
"24011" = 4
"24013" = 1
"24015" = 2
"24017" = 1
"24019" = 6
"24021" = 1
"24023" = 5
"24025" = 1
"24027" = 1
"24029" = 5
"24031" = 1
"24033" = 2
"24035" = 1
"24037" = 1
"24039" = 9
"24041" = 2
"24043" = 3
"24045" = 6
"24047" = 2
"24510" = 10
"25001" = 3
"25003" = 4
"25005" = 4
"25007" = 2
"25009" = 2
"25011" = 3
"25013" = 7
"25015" = 4
"25017" = 1
"25019" = 1
"25021" = 1
"25023" = 2
"25025" = 10
"25027" = 3
"26001" = 6
"26003" = 5
"26005" = 5
"26007" = 7
"26009" = 5
"26011" = 8
"26013" = 4
"26015" = 3
"26017" = 6
"26019" = 4
"26021" = 7
"26023" = 9
"26025" = 7
"26027" = 6
"26029" = 4
"26031" = 7
"26033" = 9
"26035" = 10
"26037" = 2
"26039" = 6
"26041" = 5
"26043" = 4
"26045" = 3
"26047" = 3
"26049" = 9
"26051" = 9
"26053" = 9
"26055" = 3
"26057" = 8
"26059" = 7
"26061" = 9
"26063" = 6
"26065" = 9
"26067" = 6
"26069" = 9
"26071" = 5
"26073" = 10
"26075" = 9
"26077" = 9
"26079" = 8
"26081" = 6
"26083" = 4
"26085" = 10
"26087" = 4
"26089" = 2
"26091" = 5
"26093" = 1
"26095" = 9
"26097" = 5
"26099" = 4
"26101" = 7
"26103" = 5
"26105" = 6
"26107" = 10
"26109" = 4
"26111" = 3
"26113" = 6
"26115" = 3
"26117" = 9
"26119" = 9
"26121" = 9
"26123" = 9
"26125" = 2
"26127" = 10
"26129" = 9
"26131" = 6
"26133" = 9
"26135" = 9
"26137" = 4
"26139" = 3
"26141" = 5
"26143" = 10
"26145" = 8
"26147" = 6
"26149" = 6
"26151" = 7
"26153" = 6
"26155" = 5
"26157" = 6
"26159" = 6
"26161" = 4
"26163" = 10
"26165" = 7
"27001" = 4
"27003" = 1
"27005" = 5
"27007" = 9
"27009" = 2
"27011" = 3
"27013" = 7
"27015" = 2
"27017" = 3
"27019" = 1
"27021" = 6
"27023" = 2
"27025" = 1
"27027" = 4
"27029" = 6
"27031" = 2
"27033" = 3
"27035" = 3
"27037" = 1
"27039" = 1
"27041" = 2
"27043" = 3
"27045" = 4
"27047" = 3
"27049" = 2
"27051" = 3
"27053" = 4
"27055" = 2
"27057" = 4
"27059" = 2
"27061" = 3
"27063" = 2
"27065" = 4
"27067" = 5
"27069" = 2
"27071" = 5
"27073" = 2
"27075" = 3
"27077" = 3
"27079" = 2
"27081" = 2
"27083" = 3
"27085" = 2
"27087" = 10
"27089" = 1
"27091" = 3
"27093" = 2
"27095" = 4
"27097" = 4
"27099" = 3
"27101" = 2
"27103" = 2
"27105" = 4
"27107" = 3
"27109" = 2
"27111" = 4
"27113" = 3
"27115" = 5
"27117" = 2
"27119" = 3
"27121" = 2
"27123" = 7
"27125" = 3
"27127" = 2
"27129" = 3
"27131" = 2
"27133" = 3
"27135" = 2
"27137" = 7
"27139" = 1
"27141" = 1
"27143" = 2
"27145" = 3
"27147" = 2
"27149" = 3
"27151" = 2
"27153" = 7
"27155" = 4
"27157" = 1
"27159" = 7
"27161" = 2
"27163" = 1
"27165" = 3
"27167" = 2
"27169" = 6
"27171" = 1
"27173" = 4
"28001" = 10
"28003" = 10
"28005" = 10
"28007" = 10
"28009" = 10
"28011" = 10
"28013" = 10
"28015" = 8
"28017" = 10
"28019" = 10
"28021" = 10
"28023" = 10
"28025" = 10
"28027" = 10
"28029" = 10
"28031" = 9
"28033" = 2
"28035" = 10
"28037" = 9
"28039" = 7
"28041" = 10
"28043" = 9
"28045" = 8
"28047" = 9
"28049" = 10
"28051" = 10
"28053" = 10
"28055" = 10
"28057" = 7
"28059" = 6
"28061" = 9
"28063" = 10
"28065" = 10
"28067" = 10
"28069" = 10
"28071" = 9
"28073" = 6
"28075" = 10
"28077" = 8
"28079" = 10
"28081" = 9
"28083" = 10
"28085" = 8
"28087" = 10
"28089" = 4
"28091" = 10
"28093" = 10
"28095" = 10
"28097" = 10
"28099" = 10
"28101" = 9
"28103" = 10
"28105" = 10
"28107" = 10
"28109" = 9
"28111" = 9
"28113" = 10
"28115" = 6
"28117" = 10
"28119" = 10
"28121" = 4
"28123" = 9
"28125" = 10
"28127" = 10
"28129" = 9
"28131" = 9
"28133" = 10
"28135" = 10
"28137" = 8
"28139" = 9
"28141" = 8
"28143" = 10
"28145" = 9
"28147" = 10
"28149" = 10
"28151" = 10
"28153" = 10
"28155" = 10
"28157" = 10
"28159" = 10
"28161" = 10
"28163" = 10
"29001" = 10
"29003" = 2
"29005" = 3
"29007" = 8
"29009" = 8
"29011" = 7
"29013" = 6
"29015" = 9
"29017" = 9
"29019" = 8
"29021" = 6
"29023" = 9
"29025" = 4
"29027" = 4
"29029" = 5
"29031" = 5
"29033" = 6
"29035" = 10
"29037" = 2
"29039" = 9
"29041" = 4
"29043" = 3
"29045" = 6
"29047" = 2
"29049" = 3
"29051" = 3
"29053" = 6
"29055" = 9
"29057" = 9
"29059" = 9
"29061" = 7
"29063" = 6
"29065" = 9
"29067" = 10
"29069" = 10
"29071" = 4
"29073" = 4
"29075" = 5
"29077" = 9
"29079" = 7
"29081" = 7
"29083" = 7
"29085" = 10
"29087" = 5
"29089" = 6
"29091" = 9
"29093" = 9
"29095" = 7
"29097" = 7
"29099" = 3
"29101" = 8
"29103" = 9
"29105" = 8
"29107" = 3
"29109" = 6
"29111" = 6
"29113" = 3
"29115" = 6
"29117" = 6
"29119" = 9
"29121" = 5
"29123" = 9
"29125" = 5
"29127" = 6
"29129" = 5
"29131" = 9
"29133" = 10
"29135" = 5
"29137" = 5
"29139" = 7
"29141" = 9
"29143" = 10
"29145" = 6
"29147" = 7
"29149" = 10
"29151" = 3
"29153" = 10
"29155" = 10
"29157" = 4
"29159" = 8
"29161" = 8
"29163" = 8
"29165" = 1
"29167" = 9
"29169" = 5
"29171" = 9
"29173" = 3
"29175" = 8
"29177" = 3
"29179" = 10
"29181" = 10
"29183" = 1
"29185" = 9
"29186" = 3
"29187" = 8
"29189" = 2
"29195" = 9
"29197" = 9
"29199" = 6
"29201" = 8
"29203" = 10
"29205" = 5
"29207" = 8
"29209" = 6
"29211" = 7
"29213" = 9
"29215" = 10
"29217" = 8
"29219" = 4
"29221" = 10
"29223" = 10
"29225" = 7
"29227" = 6
"29229" = 10
"29510" = 10
"30001" = 8
"30003" = 10
"30005" = 10
"30007" = 3
"30009" = 4
"30011" = 8
"30013" = 4
"30015" = 6
"30017" = 5
"30019" = 3
"30021" = 4
"30023" = 8
"30025" = 2
"30027" = 4
"30029" = 5
"30031" = 4
"30033" = 9
"30035" = 10
"30037" = 9
"30039" = 5
"30041" = 8
"30043" = 2
"30045" = 6
"30047" = 9
"30049" = 3
"30051" = 10
"30053" = 8
"30055" = 6
"30057" = 3
"30059" = 9
"30061" = 8
"30063" = 5
"30065" = 8
"30067" = 4
"30069" = 9
"30071" = 6
"30073" = 9
"30075" = 5
"30077" = 9
"30079" = 6
"30081" = 7
"30083" = 3
"30085" = 10
"30087" = 8
"30089" = 9
"30091" = 3
"30093" = 8
"30095" = 2
"30097" = 3
"30099" = 6
"30101" = 6
"30103" = 3
"30105" = 4
"30107" = 7
"30109" = 4
"30111" = 4
"31001" = 4
"31003" = 4
"31005" = 3
"31007" = 4
"31009" = 9
"31011" = 2
"31013" = 4
"31015" = 4
"31017" = 4
"31019" = 4
"31021" = 3
"31023" = 2
"31025" = 1
"31027" = 3
"31029" = 3
"31031" = 4
"31033" = 2
"31035" = 3
"31037" = 3
"31039" = 2
"31041" = 4
"31043" = 4
"31045" = 7
"31047" = 3
"31049" = 4
"31051" = 2
"31053" = 4
"31055" = 5
"31057" = 4
"31059" = 2
"31061" = 5
"31063" = 4
"31065" = 4
"31067" = 4
"31069" = 6
"31071" = 5
"31073" = 2
"31075" = 3
"31077" = 4
"31079" = 4
"31081" = 2
"31083" = 3
"31085" = 7
"31087" = 5
"31089" = 4
"31091" = 2
"31093" = 2
"31095" = 4
"31097" = 3
"31099" = 2
"31101" = 3
"31103" = 10
"31105" = 4
"31107" = 5
"31109" = 5
"31111" = 3
"31113" = 4
"31115" = 7
"31117" = 8
"31119" = 4
"31121" = 3
"31123" = 6
"31125" = 4
"31127" = 4
"31129" = 4
"31131" = 2
"31133" = 4
"31135" = 2
"31137" = 2
"31139" = 2
"31141" = 2
"31143" = 2
"31145" = 4
"31147" = 4
"31149" = 6
"31151" = 2
"31153" = 1
"31155" = 2
"31157" = 6
"31159" = 1
"31161" = 7
"31163" = 4
"31165" = 7
"31167" = 2
"31169" = 3
"31171" = 6
"31173" = 10
"31175" = 5
"31177" = 1
"31179" = 5
"31181" = 3
"31183" = 9
"31185" = 2
"32001" = 3
"32003" = 5
"32005" = 2
"32007" = 2
"32009" = 5
"32011" = 2
"32013" = 2
"32015" = 2
"32017" = 4
"32019" = 3
"32021" = 6
"32023" = 8
"32027" = 8
"32029" = 2
"32031" = 5
"32033" = 4
"32510" = 5
"33001" = 2
"33003" = 2
"33005" = 3
"33007" = 5
"33009" = 3
"33011" = 1
"33013" = 2
"33015" = 1
"33017" = 3
"33019" = 3
"34001" = 4
"34003" = 1
"34005" = 1
"34007" = 3
"34009" = 3
"34011" = 7
"34013" = 6
"34015" = 1
"34017" = 6
"34019" = 1
"34021" = 3
"34023" = 1
"34025" = 1
"34027" = 1
"34029" = 3
"34031" = 6
"34033" = 3
"34035" = 1
"34037" = 1
"34039" = 3
"34041" = 1
"35001" = 6
"35003" = 10
"35005" = 10
"35006" = 10
"35007" = 8
"35009" = 9
"35011" = 8
"35013" = 10
"35015" = 6
"35017" = 8
"35019" = 10
"35021" = 4
"35023" = 10
"35025" = 8
"35027" = 8
"35028" = 1
"35029" = 10
"35031" = 10
"35033" = 10
"35035" = 10
"35037" = 10
"35039" = 9
"35041" = 10
"35043" = 4
"35045" = 10
"35047" = 10
"35049" = 6
"35051" = 9
"35053" = 10
"35055" = 8
"35057" = 10
"35059" = 8
"35061" = 10
"36001" = 4
"36003" = 7
"36005" = 10
"36007" = 6
"36009" = 5
"36011" = 4
"36013" = 7
"36015" = 6
"36017" = 6
"36019" = 6
"36021" = 2
"36023" = 5
"36025" = 3
"36027" = 1
"36029" = 5
"36031" = 4
"36033" = 6
"36035" = 6
"36037" = 3
"36039" = 7
"36041" = 2
"36043" = 6
"36045" = 5
"36047" = 10
"36049" = 5
"36051" = 4
"36053" = 3
"36055" = 5
"36057" = 7
"36059" = 1
"36061" = 6
"36063" = 4
"36065" = 5
"36067" = 4
"36069" = 2
"36071" = 3
"36073" = 4
"36075" = 7
"36077" = 6
"36079" = 1
"36081" = 5
"36083" = 4
"36085" = 3
"36087" = 3
"36089" = 7
"36091" = 1
"36093" = 3
"36095" = 4
"36097" = 4
"36099" = 4
"36101" = 5
"36103" = 1
"36105" = 9
"36107" = 2
"36109" = 9
"36111" = 4
"36113" = 2
"36115" = 3
"36117" = 2
"36119" = 2
"36121" = 3
"36123" = 7
"37001" = 8
"37003" = 7
"37005" = 10
"37007" = 10
"37009" = 9
"37011" = 10
"37013" = 9
"37015" = 10
"37017" = 10
"37019" = 6
"37021" = 7
"37023" = 8
"37025" = 4
"37027" = 8
"37029" = 2
"37031" = 4
"37033" = 9
"37035" = 5
"37037" = 5
"37039" = 8
"37041" = 9
"37043" = 8
"37045" = 9
"37047" = 10
"37049" = 7
"37051" = 8
"37053" = 3
"37055" = 3
"37057" = 7
"37059" = 4
"37061" = 10
"37063" = 8
"37065" = 10
"37067" = 6
"37069" = 6
"37071" = 9
"37073" = 7
"37075" = 10
"37077" = 6
"37079" = 10
"37081" = 8
"37083" = 10
"37085" = 6
"37087" = 5
"37089" = 6
"37091" = 10
"37093" = 8
"37095" = 10
"37097" = 4
"37099" = 9
"37101" = 6
"37103" = 8
"37105" = 8
"37107" = 10
"37109" = 5
"37111" = 9
"37113" = 9
"37115" = 9
"37117" = 10
"37119" = 6
"37121" = 8
"37123" = 10
"37125" = 6
"37127" = 6
"37129" = 8
"37131" = 10
"37133" = 6
"37135" = 7
"37137" = 5
"37139" = 10
"37141" = 6
"37143" = 6
"37145" = 6
"37147" = 9
"37149" = 5
"37151" = 8
"37153" = 10
"37155" = 10
"37157" = 8
"37159" = 9
"37161" = 10
"37163" = 9
"37165" = 10
"37167" = 6
"37169" = 5
"37171" = 9
"37173" = 8
"37175" = 6
"37177" = 10
"37179" = 2
"37181" = 10
"37183" = 3
"37185" = 10
"37187" = 10
"37189" = 10
"37191" = 9
"37193" = 9
"37195" = 10
"37197" = 5
"37199" = 9
"38001" = 2
"38003" = 3
"38005" = 10
"38007" = 3
"38009" = 3
"38011" = 1
"38013" = 2
"38015" = 2
"38017" = 3
"38019" = 2
"38021" = 3
"38023" = 2
"38025" = 3
"38027" = 3
"38029" = 6
"38031" = 2
"38033" = 4
"38035" = 6
"38037" = 8
"38039" = 2
"38041" = 3
"38043" = 6
"38045" = 2
"38047" = 5
"38049" = 4
"38051" = 5
"38053" = 4
"38055" = 2
"38057" = 1
"38059" = 2
"38061" = 4
"38063" = 2
"38065" = 3
"38067" = 2
"38069" = 4
"38071" = 4
"38073" = 2
"38075" = 2
"38077" = 3
"38079" = 10
"38081" = 2
"38083" = 7
"38085" = 10
"38087" = 4
"38089" = 2
"38091" = 1
"38093" = 3
"38095" = 2
"38097" = 2
"38099" = 3
"38101" = 4
"38103" = 4
"38105" = 2
"39001" = 10
"39003" = 8
"39005" = 6
"39007" = 6
"39009" = 10
"39011" = 2
"39013" = 6
"39015" = 4
"39017" = 4
"39019" = 6
"39021" = 4
"39023" = 9
"39025" = 2
"39027" = 6
"39029" = 8
"39031" = 9
"39033" = 6
"39035" = 8
"39037" = 3
"39039" = 3
"39041" = 1
"39043" = 5
"39045" = 3
"39047" = 6
"39049" = 8
"39051" = 3
"39053" = 8
"39055" = 1
"39057" = 4
"39059" = 9
"39061" = 8
"39063" = 3
"39065" = 7
"39067" = 8
"39069" = 4
"39071" = 8
"39073" = 6
"39075" = 6
"39077" = 4
"39079" = 10
"39081" = 8
"39083" = 6
"39085" = 2
"39087" = 9
"39089" = 4
"39091" = 7
"39093" = 5
"39095" = 9
"39097" = 5
"39099" = 7
"39101" = 9
"39103" = 1
"39105" = 10
"39107" = 2
"39109" = 3
"39111" = 7
"39113" = 8
"39115" = 9
"39117" = 4
"39119" = 8
"39121" = 7
"39123" = 2
"39125" = 4
"39127" = 9
"39129" = 4
"39131" = 10
"39133" = 5
"39135" = 3
"39137" = 2
"39139" = 5
"39141" = 9
"39143" = 3
"39145" = 10
"39147" = 5
"39149" = 3
"39151" = 5
"39153" = 6
"39155" = 8
"39157" = 5
"39159" = 1
"39161" = 4
"39163" = 10
"39165" = 1
"39167" = 6
"39169" = 4
"39171" = 3
"39173" = 4
"39175" = 2
"40001" = 10
"40003" = 7
"40005" = 10
"40007" = 3
"40009" = 8
"40011" = 9
"40013" = 7
"40015" = 9
"40017" = 2
"40019" = 8
"40021" = 10
"40023" = 10
"40025" = 8
"40027" = 4
"40029" = 9
"40031" = 7
"40033" = 6
"40035" = 6
"40037" = 6
"40039" = 7
"40041" = 10
"40043" = 4
"40045" = 4
"40047" = 6
"40049" = 6
"40051" = 6
"40053" = 4
"40055" = 10
"40057" = 10
"40059" = 3
"40061" = 7
"40063" = 10
"40065" = 7
"40067" = 9
"40069" = 10
"40071" = 7
"40073" = 3
"40075" = 10
"40077" = 8
"40079" = 10
"40081" = 5
"40083" = 5
"40085" = 6
"40087" = 3
"40089" = 10
"40091" = 9
"40093" = 4
"40095" = 8
"40097" = 8
"40099" = 5
"40101" = 9
"40103" = 5
"40105" = 6
"40107" = 10
"40109" = 7
"40111" = 9
"40113" = 6
"40115" = 9
"40117" = 6
"40119" = 9
"40121" = 8
"40123" = 8
"40125" = 8
"40127" = 10
"40129" = 4
"40131" = 2
"40133" = 10
"40135" = 9
"40137" = 6
"40139" = 3
"40141" = 10
"40143" = 6
"40145" = 3
"40147" = 4
"40149" = 5
"40151" = 6
"40153" = 5
"41001" = 9
"41003" = 9
"41005" = 2
"41007" = 5
"41009" = 4
"41011" = 9
"41013" = 7
"41015" = 6
"41017" = 5
"41019" = 9
"41021" = 3
"41023" = 6
"41025" = 9
"41027" = 4
"41029" = 6
"41031" = 9
"41033" = 8
"41035" = 7
"41037" = 9
"41039" = 9
"41041" = 7
"41043" = 8
"41045" = 10
"41047" = 8
"41049" = 6
"41051" = 8
"41053" = 6
"41055" = 4
"41057" = 6
"41059" = 6
"41061" = 6
"41063" = 6
"41065" = 6
"41067" = 2
"41069" = 9
"41071" = 5
"42001" = 2
"42003" = 3
"42005" = 4
"42007" = 5
"42009" = 4
"42011" = 4
"42013" = 4
"42015" = 3
"42017" = 1
"42019" = 2
"42021" = 4
"42023" = 5
"42025" = 3
"42027" = 8
"42029" = 1
"42031" = 8
"42033" = 7
"42035" = 7
"42037" = 6
"42039" = 9
"42041" = 1
"42043" = 4
"42045" = 2
"42047" = 3
"42049" = 7
"42051" = 9
"42053" = 9
"42055" = 2
"42057" = 2
"42059" = 8
"42061" = 5
"42063" = 8
"42065" = 6
"42067" = 3
"42069" = 4
"42071" = 2
"42073" = 6
"42075" = 3
"42077" = 4
"42079" = 6
"42081" = 7
"42083" = 5
"42085" = 6
"42087" = 6
"42089" = 4
"42091" = 1
"42093" = 3
"42095" = 2
"42097" = 5
"42099" = 2
"42101" = 10
"42103" = 2
"42105" = 5
"42107" = 4
"42109" = 4
"42111" = 5
"42113" = 5
"42115" = 4
"42117" = 6
"42119" = 4
"42121" = 6
"42123" = 4
"42125" = 2
"42127" = 4
"42129" = 2
"42131" = 4
"42133" = 2
"44001" = 1
"44003" = 2
"44005" = 2
"44007" = 7
"44009" = 2
"45001" = 9
"45003" = 8
"45005" = 10
"45007" = 8
"45009" = 10
"45011" = 10
"45013" = 4
"45015" = 5
"45017" = 8
"45019" = 8
"45021" = 9
"45023" = 9
"45025" = 10
"45027" = 10
"45029" = 10
"45031" = 10
"45033" = 10
"45035" = 3
"45037" = 9
"45039" = 10
"45041" = 9
"45043" = 9
"45045" = 6
"45047" = 10
"45049" = 10
"45051" = 9
"45053" = 10
"45055" = 8
"45057" = 9
"45059" = 9
"45061" = 10
"45063" = 4
"45065" = 9
"45067" = 10
"45069" = 10
"45071" = 8
"45073" = 4
"45075" = 10
"45077" = 7
"45079" = 7
"45081" = 9
"45083" = 7
"45085" = 9
"45087" = 8
"45089" = 10
"45091" = 4
"46003" = 3
"46005" = 5
"46007" = 10
"46009" = 7
"46011" = 7
"46013" = 2
"46015" = 5
"46017" = 10
"46019" = 5
"46021" = 3
"46023" = 10
"46025" = 5
"46027" = 9
"46029" = 3
"46031" = 10
"46033" = 3
"46035" = 5
"46037" = 7
"46039" = 2
"46041" = 10
"46043" = 5
"46045" = 3
"46047" = 6
"46049" = 5
"46051" = 3
"46053" = 10
"46055" = 4
"46057" = 3
"46059" = 3
"46061" = 2
"46063" = 7
"46065" = 2
"46067" = 3
"46069" = 4
"46071" = 10
"46073" = 6
"46075" = 6
"46077" = 2
"46079" = 3
"46081" = 4
"46083" = 1
"46085" = 10
"46087" = 2
"46089" = 8
"46091" = 5
"46093" = 2
"46095" = 10
"46097" = 4
"46099" = 3
"46101" = 3
"46103" = 5
"46105" = 7
"46107" = 3
"46109" = 9
"46111" = 5
"46113" = 10
"46115" = 4
"46117" = 2
"46119" = 2
"46121" = 10
"46123" = 9
"46125" = 3
"46127" = 1
"46129" = 6
"46135" = 3
"46137" = 10
"47001" = 6
"47003" = 10
"47005" = 9
"47007" = 10
"47009" = 4
"47011" = 9
"47013" = 10
"47015" = 6
"47017" = 9
"47019" = 10
"47021" = 3
"47023" = 9
"47025" = 10
"47027" = 10
"47029" = 10
"47031" = 10
"47033" = 9
"47035" = 8
"47037" = 9
"47039" = 9
"47041" = 9
"47043" = 4
"47045" = 9
"47047" = 4
"47049" = 10
"47051" = 5
"47053" = 8
"47055" = 7
"47057" = 9
"47059" = 10
"47061" = 10
"47063" = 9
"47065" = 6
"47067" = 10
"47069" = 10
"47071" = 10
"47073" = 8
"47075" = 10
"47077" = 7
"47079" = 9
"47081" = 9
"47083" = 9
"47085" = 6
"47087" = 9
"47089" = 6
"47091" = 10
"47093" = 4
"47095" = 10
"47097" = 10
"47099" = 8
"47101" = 9
"47103" = 7
"47105" = 5
"47107" = 8
"47109" = 10
"47111" = 10
"47113" = 9
"47115" = 10
"47117" = 5
"47119" = 5
"47121" = 10
"47123" = 9
"47125" = 6
"47127" = 4
"47129" = 9
"47131" = 6
"47133" = 9
"47135" = 9
"47137" = 9
"47139" = 9
"47141" = 9
"47143" = 9
"47145" = 5
"47147" = 4
"47149" = 5
"47151" = 10
"47153" = 10
"47155" = 6
"47157" = 9
"47159" = 9
"47161" = 5
"47163" = 8
"47165" = 4
"47167" = 4
"47169" = 7
"47171" = 7
"47173" = 10
"47175" = 10
"47177" = 10
"47179" = 8
"47181" = 10
"47183" = 9
"47185" = 9
"47187" = 1
"47189" = 2
"48001" = 9
"48003" = 4
"48005" = 8
"48007" = 10
"48009" = 3
"48011" = 2
"48013" = 9
"48015" = 4
"48017" = 8
"48019" = 6
"48021" = 6
"48023" = 9
"48025" = 10
"48027" = 4
"48029" = 7
"48031" = 4
"48033" = 3
"48035" = 7
"48037" = 8
"48039" = 3
"48041" = 10
"48043" = 5
"48045" = 6
"48047" = 10
"48049" = 8
"48051" = 5
"48053" = 5
"48055" = 7
"48057" = 9
"48059" = 6
"48061" = 10
"48063" = 9
"48065" = 2
"48067" = 9
"48069" = 9
"48071" = 2
"48073" = 10
"48075" = 10
"48077" = 4
"48079" = 9
"48081" = 4
"48083" = 9
"48085" = 1
"48087" = 8
"48089" = 7
"48091" = 3
"48093" = 9
"48095" = 10
"48097" = 5
"48099" = 4
"48101" = 9
"48103" = 2
"48105" = 6
"48107" = 10
"48109" = 10
"48111" = 5
"48113" = 8
"48115" = 10
"48117" = 9
"48119" = 8
"48121" = 1
"48123" = 9
"48125" = 9
"48127" = 10
"48129" = 7
"48131" = 10
"48133" = 10
"48135" = 9
"48137" = 10
"48139" = 3
"48141" = 10
"48143" = 8
"48145" = 10
"48147" = 6
"48149" = 4
"48151" = 5
"48153" = 9
"48155" = 8
"48157" = 2
"48159" = 6
"48161" = 8
"48163" = 10
"48165" = 8
"48167" = 4
"48169" = 10
"48171" = 3
"48173" = 3
"48175" = 6
"48177" = 9
"48179" = 6
"48181" = 5
"48183" = 9
"48185" = 9
"48187" = 3
"48189" = 9
"48191" = 10
"48193" = 6
"48195" = 5
"48197" = 10
"48199" = 4
"48201" = 8
"48203" = 7
"48205" = 3
"48207" = 10
"48209" = 5
"48211" = 2
"48213" = 9
"48215" = 10
"48217" = 7
"48219" = 9
"48221" = 3
"48223" = 8
"48225" = 10
"48227" = 10
"48229" = 10
"48231" = 9
"48233" = 4
"48235" = 2
"48237" = 6
"48239" = 6
"48241" = 9
"48243" = 3
"48245" = 10
"48247" = 10
"48249" = 9
"48251" = 4
"48253" = 10
"48255" = 10
"48257" = 3
"48259" = 2
"48261" = 4
"48263" = 3
"48265" = 6
"48267" = 8
"48269" = 4
"48271" = 10
"48273" = 10
"48275" = 10
"48277" = 8
"48279" = 9
"48281" = 5
"48283" = 10
"48285" = 5
"48287" = 4
"48289" = 5
"48291" = 8
"48293" = 8
"48295" = 4
"48297" = 8
"48299" = 6
"48301" = 5
"48303" = 9
"48305" = 9
"48307" = 10
"48309" = 9
"48311" = 3
"48313" = 10
"48315" = 10
"48317" = 6
"48319" = 6
"48321" = 9
"48323" = 10
"48325" = 7
"48327" = 10
"48329" = 5
"48331" = 9
"48333" = 7
"48335" = 10
"48337" = 6
"48339" = 3
"48341" = 5
"48343" = 9
"48345" = 6
"48347" = 10
"48349" = 9
"48351" = 10
"48353" = 9
"48355" = 9
"48357" = 4
"48359" = 4
"48361" = 5
"48363" = 7
"48365" = 4
"48367" = 3
"48369" = 5
"48371" = 10
"48373" = 9
"48375" = 10
"48377" = 10
"48379" = 6
"48381" = 2
"48383" = 3
"48385" = 10
"48387" = 9
"48389" = 10
"48391" = 8
"48393" = 1
"48395" = 9
"48397" = 1
"48399" = 10
"48401" = 5
"48403" = 8
"48405" = 9
"48407" = 9
"48409" = 9
"48411" = 9
"48413" = 7
"48415" = 7
"48417" = 4
"48419" = 10
"48421" = 4
"48423" = 5
"48425" = 2
"48427" = 10
"48429" = 9
"48431" = 4
"48433" = 7
"48435" = 4
"48437" = 9
"48439" = 5
"48441" = 8
"48443" = 5
"48445" = 10
"48447" = 5
"48449" = 9
"48451" = 9
"48453" = 8
"48455" = 8
"48457" = 9
"48459" = 6
"48461" = 6
"48463" = 10
"48465" = 10
"48467" = 7
"48469" = 8
"48471" = 10
"48473" = 9
"48475" = 9
"48477" = 5
"48479" = 10
"48481" = 9
"48483" = 4
"48485" = 7
"48487" = 7
"48489" = 10
"48491" = 1
"48493" = 3
"48495" = 6
"48497" = 4
"48499" = 8
"48501" = 5
"48503" = 7
"48505" = 10
"48507" = 10
"49001" = 4
"49003" = 2
"49005" = 6
"49007" = 5
"49009" = 1
"49011" = 1
"49013" = 4
"49015" = 3
"49017" = 3
"49019" = 5
"49021" = 9
"49023" = 3
"49025" = 4
"49027" = 4
"49029" = 1
"49031" = 9
"49033" = 3
"49035" = 4
"49037" = 10
"49039" = 8
"49041" = 5
"49043" = 1
"49045" = 2
"49047" = 5
"49049" = 5
"49051" = 1
"49053" = 5
"49055" = 5
"49057" = 4
"50001" = 3
"50003" = 4
"50005" = 6
"50007" = 3
"50009" = 7
"50011" = 3
"50013" = 1
"50015" = 4
"50017" = 4
"50019" = 7
"50021" = 4
"50023" = 3
"50025" = 4
"50027" = 2
"51001" = 9
"51003" = 2
"51005" = 4
"51007" = 3
"51009" = 4
"51011" = 4
"51013" = 1
"51015" = 2
"51017" = 3
"51019" = 2
"51021" = 5
"51023" = 1
"51025" = 9
"51027" = 10
"51029" = 9
"51031" = 5
"51033" = 3
"51035" = 7
"51036" = 3
"51037" = 8
"51041" = 1
"51043" = 2
"51045" = 3
"51047" = 2
"51049" = 7
"51051" = 10
"51053" = 3
"51057" = 4
"51059" = 1
"51061" = 1
"51063" = 4
"51065" = 1
"51067" = 5
"51069" = 1
"51071" = 4
"51073" = 2
"51075" = 1
"51077" = 7
"51079" = 2
"51081" = 10
"51083" = 9
"51085" = 1
"51087" = 2
"51089" = 8
"51091" = 5
"51093" = 2
"51095" = 1
"51097" = 4
"51099" = 1
"51101" = 1
"51103" = 4
"51105" = 10
"51107" = 1
"51109" = 2
"51111" = 9
"51113" = 3
"51115" = 2
"51117" = 9
"51119" = 4
"51121" = 9
"51125" = 4
"51127" = 1
"51131" = 8
"51133" = 5
"51135" = 9
"51137" = 2
"51139" = 6
"51141" = 8
"51143" = 6
"51145" = 1
"51147" = 10
"51149" = 2
"51153" = 1
"51155" = 6
"51157" = 2
"51159" = 8
"51161" = 1
"51163" = 3
"51165" = 3
"51167" = 8
"51169" = 8
"51171" = 3
"51173" = 8
"51175" = 6
"51177" = 1
"51179" = 1
"51181" = 3
"51183" = 10
"51185" = 8
"51187" = 2
"51191" = 4
"51193" = 5
"51195" = 10
"51197" = 6
"51199" = 1
"51510" = 2
"51515" = 7
"51520" = 9
"51530" = 6
"51540" = 9
"51550" = 1
"51570" = 2
"51580" = 6
"51590" = 10
"51595" = 10
"51600" = 1
"51610" = 1
"51620" = 9
"51630" = 9
"51640" = 10
"51650" = 4
"51660" = 10
"51670" = 7
"51678" = 9
"51680" = 10
"51683" = 3
"51685" = 2
"51690" = 10
"51700" = 5
"51710" = 8
"51720" = 9
"51730" = 10
"51735" = 1
"51740" = 8
"51750" = 10
"51760" = 10
"51770" = 10
"51775" = 2
"51790" = 5
"51800" = 3
"51810" = 1
"51820" = 7
"51830" = 8
"51840" = 9
"53001" = 9
"53003" = 6
"53005" = 4
"53007" = 5
"53009" = 6
"53011" = 4
"53013" = 5
"53015" = 9
"53017" = 5
"53019" = 9
"53021" = 8
"53023" = 4
"53025" = 9
"53027" = 8
"53029" = 2
"53031" = 3
"53033" = 3
"53035" = 3
"53037" = 9
"53039" = 7
"53041" = 6
"53043" = 3
"53045" = 6
"53047" = 10
"53049" = 8
"53051" = 8
"53053" = 3
"53055" = 3
"53057" = 4
"53059" = 4
"53061" = 2
"53063" = 5
"53065" = 7
"53067" = 2
"53069" = 4
"53071" = 6
"53073" = 5
"53075" = 10
"53077" = 10
"54001" = 7
"54003" = 4
"54005" = 8
"54007" = 10
"54009" = 5
"54011" = 10
"54013" = 10
"54015" = 10
"54017" = 9
"54019" = 10
"54021" = 10
"54023" = 7
"54025" = 9
"54027" = 8
"54029" = 4
"54031" = 6
"54033" = 7
"54035" = 9
"54037" = 3
"54039" = 5
"54041" = 9
"54043" = 10
"54045" = 10
"54047" = 10
"54049" = 7
"54051" = 7
"54053" = 8
"54055" = 9
"54057" = 6
"54059" = 10
"54061" = 10
"54063" = 8
"54065" = 4
"54067" = 8
"54069" = 6
"54071" = 5
"54073" = 5
"54075" = 9
"54077" = 6
"54079" = 2
"54081" = 8
"54083" = 8
"54085" = 9
"54087" = 10
"54089" = 10
"54091" = 9
"54093" = 9
"54095" = 6
"54097" = 10
"54099" = 9
"54101" = 10
"54103" = 8
"54105" = 10
"54107" = 6
"54109" = 9
"55001" = 5
"55003" = 8
"55005" = 4
"55007" = 5
"55009" = 2
"55011" = 3
"55013" = 5
"55015" = 1
"55017" = 3
"55019" = 5
"55021" = 2
"55023" = 5
"55025" = 3
"55027" = 2
"55029" = 3
"55031" = 5
"55033" = 5
"55035" = 6
"55037" = 4
"55039" = 3
"55041" = 7
"55043" = 6
"55045" = 2
"55047" = 4
"55049" = 2
"55051" = 7
"55053" = 8
"55055" = 3
"55057" = 6
"55059" = 4
"55061" = 2
"55063" = 4
"55065" = 3
"55067" = 4
"55069" = 3
"55071" = 3
"55073" = 3
"55075" = 5
"55077" = 3
"55078" = 10
"55079" = 10
"55081" = 6
"55083" = 4
"55085" = 3
"55087" = 2
"55089" = 1
"55091" = 3
"55093" = 3
"55095" = 4
"55097" = 3
"55099" = 4
"55101" = 5
"55103" = 5
"55105" = 4
"55107" = 9
"55109" = 1
"55111" = 3
"55113" = 8
"55115" = 4
"55117" = 2
"55119" = 4
"55121" = 4
"55123" = 5
"55125" = 5
"55127" = 4
"55129" = 5
"55131" = 1
"55133" = 1
"55135" = 3
"55137" = 5
"55139" = 3
"55141" = 3
"56001" = 9
"56003" = 4
"56005" = 1
"56007" = 4
"56009" = 2
"56011" = 1
"56013" = 4
"56015" = 7
"56017" = 3
"56019" = 2
"56021" = 3
"56023" = 2
"56025" = 2
"56027" = 5
"56029" = 3
"56031" = 3
"56033" = 2
"56035" = 1
"56037" = 2
"56039" = 2
"56041" = 3
"56043" = 3
"56045" = 2
"02201" = 7
"02232" = 5
"02280" = 3
OTHER = 0
;



 /* -----------------------------------------------------------------------------  */
 /*  CCS 653 - Delirium, dementia, and amnestic and other cognitive disorders   -  */
 /* ------------------------------------------------------------------------------ */


/*VALUE $CCS653*/

VALUE $DGNEUID

'2900 ' = 1 /* SENILE DEMENTIA UNCOMP */
'29010' = 1 /* PRESENILE DEMENTIA */
'29011' = 1 /* PRESENILE DELIRIUM */
'29012' = 1 /* PRESENILE DELUSION */
'29013' = 1 /* PRESENILE DEPRESSION */
'29020' = 1 /* SENILE DELUSION */
'29021' = 1 /* SENILE DEPRESSIVE */
'2903 ' = 1 /* SENILE DELIRIUM */
'29040' = 1 /* ARTERIOSCLER DEMENT NOS */
'29041' = 1 /* ARTERIOSCLER DELIRIUM */
'29042' = 1 /* ARTERIOSCLER DELUSION */
'29043' = 1 /* ARTERIOSCLER DEPRESSIVE */
'2908 ' = 1 /* SENILE PSYCHOSIS NEC */
'2909 ' = 1 /* SENILE PSYCHOT COND NOS */
'2930 ' = 1 /* ACUTE DELIRIUM */
'2931 ' = 1 /* SUBACUTE DELIRIUM */
'2940 ' = 1 /* AMNESTIC SYNDROME */
'2941 ' = 1 /* DEMENTIA IN OTH DISEASES */
'29410' = 1 /* DEMENTIA IN OTH DISEASES W0 BEHAVRAL OCT00- */
'29411' = 1 /* DEMENTIA IN OTH DISEASES WBEHAVIORAL OCT00- */
'2948 ' = 1 /* ORGANIC BRAIN SYND NEC */
'2949 ' = 1 /* ORGANIC BRAIN SYND NOS */
'3100 ' = 1 /* FRONTAL LOBE SYNDROME */
'3102 ' = 1 /* POSTCONCUSSION SYNDROME */
'3108 ' = 1 /* NONPSYCHOT BRAIN SYN NEC */
'31081' = 1 /* PSEDOBULBAR AFFECT */
'31089' = 1 /* OTHER SPECIFIED NONPSYCHOTIC MENTAL DISORDER */
'3109 ' = 1 /* NONPSYCHOT BRAIN SYN NOS */
'3310 ' = 1 /* ALZHEIMERS DISEASE */
'3311 ' = 1 /* FRONTOTEMPORAL DEMENTIA */
'33111' = 1 /* PICKS DISEASE */
'33119' = 1 /* OTHER FRONTOTEMPORAL DEMENTIA */
'3312 ' = 1 /* SENILE DEGENERAT BRAIN */
'3316 ' = 1 /* CORTICOBASAL DEGENERATION */
'33182' = 1 /* DEMENTIA WITH LEWY BODIES */
'34882' = 1 /* BRAIN DEATH*/
 OTHER  = '0' ;


/* ---------------------------------------- */
 /* Esophageal Cancer Resection (PRESOP)     */
 /*   Volume Indicator / IQI #1              */
 /*   Mortality (post-op) Indicator / IQI #8 */
 /* ---------------------------------------- */

 /* Esophageal resection */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRESOPP
'4210' = '1' /* Added 5.0: ESOPHAGOSTOMY */
'4211' = '1' /* Added 5.0: ESOPHAGOSTOMY */
'4212' = '1' /* Added 5.0: ESOPHAGOSTOMY */
'4219' = '1' /* Added 5.0: ESOPHAGOSTOMY */
'424 ' = '1' /* ESOPHAGECTOMY */
'4240' = '1' /* ESOPHAGECTOMY NOS */
'4241' = '1' /* PARTIAL ESOPHAGECTOMY */
'4242' = '1' /* TOTAL ESOPHAGECTOMY */
'425 ' = '1' /* THORAC ESOPHAG ANAST */
'4251' = '1' /* THORAC ESOPHAGOESOPHAGOS */
'4252' = '1' /* THORAC ESOPHAGOGASTROST */
'4253' = '1' /* THORAC SM BOWEL INTERPOS */
'4254' = '1' /* THORAC ESOPHAGOENTER NEC */
'4255' = '1' /* THORAC LG BOWEL INTERPOS */
'4256' = '1' /* THORAC ESOPHAGOCOLOS NEC */
'4258' = '1' /* THORAC INTERPOSITION NEC */
'4259' = '1' /* THORAC ESOPHAG ANAST NEC */
'426 ' = '1' /* STERN ESOPHAG ANAST */
'4261' = '1' /* STERN ESOPHAGOESOPHAGOST */
'4262' = '1' /* STERN ESOPHAGOGASTROSTOM */
'4263' = '1' /* STERN SM BOWEL INTERPOS */
'4264' = '1' /* STERN ESOPHAGOENTER NEC */
'4265' = '1' /* STERN LG BOWEL INTERPOS */
'4266' = '1' /* STERN ESOPHAGOCOLOS NEC */
'4268' = '1' /* STERN INTERPOSITION NEC */
'4269' = '1' /* STERN ESOPHAG ANAST NEC */
OTHER  = '0' ;

 /* Esophageal resection */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRESO2P
'4399' = '1' /* TOTAL GASTRECTOMY NEC */
OTHER  = '0' ;

VALUE $POAXMPT 
  '137'-'13999'
,'2681'-'26819'
,'326'-'32699'
,'412'-'41299'
,'438'-'43899'
,'650'-'65099'
,'6607'-'66079'
,'677'-'67799'
,'740'-'75999'
,'905'-'90999'
,'V02'-'V0799'
,'V10'-'V3999'
,'V42'-'V4699'
,'V4960'-'V4977'
,'V4981'-'V4985'
,'V50'-'V6299'
,'V64'-'V8699'
,'V8732'
,'V874'-'V8749'
,'V88'-'V9199'
,'E000'-'E0309'
,'E800'-'E8079'
,'E810'-'E8389'
,'E840'-'E8496'
,'E8498'-'E8499'
,'E8831'-'E8832'
,'E8840'-'E8841'
,'E8850'-'E8854'
,'E8860'
,'E8900'-'E8909'
,'E8930'
,'E8932'
,'E894'-'E8959'
,'E897'-'E8979'
,'E9170'-'E9172'
,'E9175'-'E9176'
,'E919'-'E9191'
,'E9193'-'E9199'
,'E921'-'E9229'
,'E9262'
,'E9280'-'E9288'
,'E9290'-'E9299'
,'E959'-'E9599'
,'E970'-'E9799'
,'E981'-'E9829'
,'E985'-'E9859'
,'E9870'
,'E9872'
,'E989'-'E9999'='1'
OTHER='0'
; 

RUN;
